(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 8.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       157,          7]
NotebookDataLength[    684492,      12544]
NotebookOptionsPosition[    678364,      12360]
NotebookOutlinePosition[    678801,      12377]
CellTagsIndexPosition[    678758,      12374]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell[TextData[{
 "Geometric Collective Model ver. 3.0 - Bohr hamiltonian solver\n",
 StyleBox["F.Ferrari-Ruffino and L.Fortunato*  ", "Subtitle"],
 StyleBox["(University of Padova & I.N.F.N. Padova - Italy)",
  FontSize->14,
  FontSlant->"Italic",
  FontColor->RGBColor[
   0.5254901960784314, 0.30196078431372547`, 0.050980392156862744`]],
 StyleBox["\n",
  FontSize->14],
 StyleBox["Version 0.1 - 30 Apr 2013 : thesis version.\nVersion 0.2 - 30 Jul \
2013 : matrices up to L=8 and fitting procedure added.\nVersion 1.0 - 15 Oct \
2013: finalized for publishing (spectrum only).\nVersion 1.x - xx mm 2015: \
wavefunction module added. BE2 added.\nVersion 2.0 - 09 Dec 2016: databases \
and comments added. Reduced energies added.\nVersion 3.0 - 24 Jul 2018: \
finalized for publishing.",
  FontSize->10],
 StyleBox["\n",
  FontSize->14],
 StyleBox["The present notebook diagonalizes the Geometric Collective Model - \
Bohr hamiltonian [1-4] with a generalized potential that contains terms up to \
the 6th power in \[Beta] and to the 2nd power in Cos(3\[Gamma]). The 5D \
harmonic oscillator basis, truncated at a given maximal number of phonons, is \
used (in a different code) to generate matrix elements for the six potential \
energy terms ",
  FontSize->12,
  FontColor->RGBColor[
   0.7490196078431373, 0.3686274509803922, 0.08235294117647059]],
 Cell[BoxData[
  FormBox[
   StyleBox[
    SuperscriptBox["\[Beta]", "2"],
    FontSize->14], TraditionalForm]],
  FontSize->12,
  FontColor->RGBColor[
   0.7490196078431373, 0.3686274509803922, 0.08235294117647059]],
 Cell[BoxData[
  FormBox[
   StyleBox[
    RowBox[{",", 
     SuperscriptBox["\[Beta]", "3"]}],
    FontSize->14], TraditionalForm]],
  FontSize->12,
  FontColor->RGBColor[
   0.7490196078431373, 0.3686274509803922, 0.08235294117647059]],
 StyleBox["cos(3\[Gamma]),  ",
  FontSize->12,
  FontColor->RGBColor[
   0.7490196078431373, 0.3686274509803922, 0.08235294117647059]],
 Cell[BoxData[
  FormBox[
   StyleBox[
    RowBox[{
     SuperscriptBox["\[Beta]", "4"], ","}],
    FontSize->14], TraditionalForm]],
  FontSize->12,
  FontColor->RGBColor[
   0.7490196078431373, 0.3686274509803922, 0.08235294117647059]],
 StyleBox[" ",
  FontSize->12,
  FontColor->RGBColor[
   0.7490196078431373, 0.3686274509803922, 0.08235294117647059]],
 Cell[BoxData[
  FormBox[
   StyleBox[
    SuperscriptBox["\[Beta]", "5"],
    FontSize->14], TraditionalForm]],
  FontSize->12,
  FontColor->RGBColor[
   0.7490196078431373, 0.3686274509803922, 0.08235294117647059]],
 StyleBox["cos(3\[Gamma]), ",
  FontSize->12,
  FontColor->RGBColor[
   0.7490196078431373, 0.3686274509803922, 0.08235294117647059]],
 Cell[BoxData[
  FormBox[
   StyleBox[
    SuperscriptBox["\[Beta]", "6"],
    FontSize->14], TraditionalForm]],
  FontSize->12,
  FontColor->RGBColor[
   0.7490196078431373, 0.3686274509803922, 0.08235294117647059]],
 Cell[BoxData[
  FormBox[
   RowBox[{",", 
    StyleBox[
     SuperscriptBox["\[Beta]", "6"],
     FontSize->14]}], TraditionalForm]],
  FontSize->12,
  FontColor->RGBColor[
   0.7490196078431373, 0.3686274509803922, 0.08235294117647059]],
 Cell[BoxData[
  FormBox[
   SuperscriptBox[
    RowBox[{"cos", "(", 
     RowBox[{"3", "\[Gamma]"}], ")"}], "2"], TraditionalForm]],
  FontSize->12,
  FontColor->RGBColor[
   0.7490196078431373, 0.3686274509803922, 0.08235294117647059]],
 StyleBox[" . Matrices are read from a library that is distributed with the \
code and stored for local use. Values of Nmax of the order of a few tens are \
usually enough for results that converge within a few keV. The present \
notebook can fit the parameters (coefficients of the potential energy terms) \
from experimental data, but they can also be given as input. Its modular \
structure allows for iterative subroutine callings. Several consistency \
checks are perfomed within analytic cases and examples are given that \
perfectly reproduce older calculations.  Although the approach used is not \
original, there are  several innovations in the way the matrix elements are \
computed and stored [1], for instance: double-check (analytic integration and \
group theory) for radial matrix elements, correct implementation of \
\[OpenCurlyQuote]border effects\[CloseCurlyQuote] in the matrices, due to \
finite basis truncation, convergence assessment. This code will be of \
interest to nuclear physicists both for reasearch and didactical purpose, and \
we publish it because codes for solving this problem are not widely available \
(with perhaps the exception of Ref. [5]).\nTwo databases named ",
  FontSize->12,
  FontColor->RGBColor[
   0.7490196078431373, 0.3686274509803922, 0.08235294117647059]],
 StyleBox["habs",
  FontSize->12,
  FontSlant->"Italic",
  FontColor->RGBColor[
   0.7490196078431373, 0.3686274509803922, 0.08235294117647059]],
 StyleBox[" and ",
  FontSize->12,
  FontColor->RGBColor[
   0.7490196078431373, 0.3686274509803922, 0.08235294117647059]],
 StyleBox["fortunato",
  FontSize->12,
  FontSlant->"Italic",
  FontColor->RGBColor[
   0.7490196078431373, 0.3686274509803922, 0.08235294117647059]],
 StyleBox[" containing sets of parameters for a number of nuclides can be \
loaded (alternative or better sets might be searced with this program in the \
playing area).",
  FontSize->12,
  FontColor->RGBColor[
   0.7490196078431373, 0.3686274509803922, 0.08235294117647059]],
 StyleBox["\n",
  FontSize->14],
 StyleBox["Instructions:",
  FontSize->14,
  FontColor->RGBColor[
   0.35294117647058826`, 0.17254901960784313`, 0.0392156862745098]],
 StyleBox[" ",
  FontSize->14,
  FontColor->RGBColor[
   0.7490196078431373, 0.3686274509803922, 0.08235294117647059]],
 StyleBox["-run cells in the correct order with Shift+Enter.  Yellow \
background indicate parameters that should/must be changed or adapted by the \
user. ",
  FontSize->12,
  FontColor->RGBColor[
   0.7490196078431373, 0.3686274509803922, 0.08235294117647059]]
}], "Title",
 CellFrame->{{0, 0}, {3, 0}},
 CellChangeTimes->{{3.5757068801166034`*^9, 3.5757070193867984`*^9}, {
   3.5757070793468823`*^9, 3.575707194997044*^9}, {3.5757079875381536`*^9, 
   3.575708566389964*^9}, {3.575708733440198*^9, 3.5757088065703*^9}, {
   3.57570885637037*^9, 3.575709094630704*^9}, {3.5757093265810285`*^9, 
   3.5757094126311493`*^9}, {3.5757100656930633`*^9, 3.575710150703182*^9}, {
   3.575710214913272*^9, 3.5757102752433567`*^9}, {3.5757108815742054`*^9, 
   3.575711018614397*^9}, {3.575712538477525*^9, 3.5757125808775845`*^9}, {
   3.5766473702061667`*^9, 3.576647384901393*^9}, {3.5766477166687756`*^9, 
   3.576647717152376*^9}, {3.576649033391491*^9, 3.5766490438903093`*^9}, {
   3.577381294083547*^9, 3.5773812997775574`*^9}, {3.5832338534846263`*^9, 
   3.583233853704627*^9}, {3.5842059560745068`*^9, 3.584205969708931*^9}, {
   3.584248769762307*^9, 3.584248807422389*^9}, {3.58424885333327*^9, 
   3.584248865984892*^9}, {3.584248907449765*^9, 3.584248909914569*^9}, {
   3.5842525096870937`*^9, 3.584252532993535*^9}, {3.5842526661665697`*^9, 
   3.584252692702216*^9}, {3.5842527520603204`*^9, 3.5842527588775325`*^9}, {
   3.5842527964891987`*^9, 3.5842528334612637`*^9}, 3.58425337257821*^9, {
   3.584253413996283*^9, 3.5842534237619*^9}, {3.587183127835972*^9, 
   3.5871831372271886`*^9}, {3.5905607591408887`*^9, 
   3.5905607858949356`*^9}, {3.690264219280509*^9, 3.6902643031206264`*^9}, {
   3.6902643501706924`*^9, 3.6902644394908175`*^9}, {3.690264757286437*^9, 
   3.690264762416444*^9}, {3.690267590288619*^9, 3.69026759817307*^9}, {
   3.6903530687433214`*^9, 3.6903530753933306`*^9}, {3.690354083314742*^9, 
   3.6903541290548058`*^9}, {3.690354704235611*^9, 3.6903547080956163`*^9}, {
   3.74143010436812*^9, 3.741430127618611*^9}}],

Cell["\<\
1 - Initialization and settings: here all the building blocks and basic \
ingredients of the calculations are set up\
\>", "Subtitle",
 CellChangeTimes->{{3.5842530438120327`*^9, 3.584253112842154*^9}, {
  3.587119249015339*^9, 3.5871192697353683`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
    "Define", " ", "the", " ", "path", " ", "to", " ", "the", " ", 
     "directory", " ", "where", " ", "the", " ", "files", " ", "are", " ", 
     "stored"}], ",", " ", 
    RowBox[{
    "must", " ", "finish", " ", "with", " ", "\"\</\>\"", "  ", 
     "\[IndentingNewLine]", "Loads", " ", "modules"}]}], " ", "*)"}], 
  StyleBox["\[IndentingNewLine]",
   Background->RGBColor[1, 1, 0]], 
  RowBox[{
   RowBox[{
    RowBox[{"NotebookEvaluate", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"NotebookDirectory", "[", "]"}], "<>", 
       "\"\<basismodules.nb\>\""}], ",", 
      RowBox[{"InsertResults", "\[Rule]", "True"}]}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"NotebookDirectory", "[", "]"}]}]}]], "Input",
 CellChangeTimes->{{3.5757070686768675`*^9, 3.5757070688768673`*^9}, {
   3.5757081602593956`*^9, 3.5757081642794013`*^9}, {3.575708694790144*^9, 
   3.5757087189701777`*^9}, {3.576594901623064*^9, 3.5765949294847136`*^9}, {
   3.576594997048432*^9, 3.576595030728891*^9}, {3.576595124047455*^9, 
   3.576595132034669*^9}, {3.576596013979018*^9, 3.5765960143690195`*^9}, {
   3.5765963451332*^9, 3.576596375896454*^9}, {3.576596452757789*^9, 
   3.5765965832520185`*^9}, {3.576596637649314*^9, 3.5765966949326143`*^9}, 
   3.5765968041016064`*^9, {3.5765968633661103`*^9, 3.5765968646765127`*^9}, {
   3.5765970210979877`*^9, 3.5765970364796143`*^9}, {3.5794126556644382`*^9, 
   3.5794126563644395`*^9}, {3.6903658040207047`*^9, 3.69036581705145*^9}}],

Cell[BoxData["\<\"C:\\\\Lorenzo\\\\Fisica\\\\Work_in_Progress\\\\GCM_Solver\\\
\\\"\>"], "Output",
 CellChangeTimes->{{3.576597037181616*^9, 3.576597044451228*^9}, 
   3.576597225661147*^9, 3.5766474071938314`*^9, 3.5766481066538606`*^9, 
   3.576649114730034*^9, 3.5766492852227335`*^9, 3.5773811784561443`*^9, 
   3.5792438034632006`*^9, 3.5792601960541506`*^9, {3.5792602867562785`*^9, 
   3.579260299936297*^9}, 3.5792608606000834`*^9, {3.579329398640788*^9, 
   3.5793294164228168`*^9}, 3.579335759802863*^9, 3.5793359675511847`*^9, 
   3.5793378644118686`*^9, 3.579338239197396*^9, 3.579338459569708*^9, 
   3.57933897192843*^9, 3.5793394780991383`*^9, 3.579340475461543*^9, {
   3.579340836594051*^9, 3.57934085785408*^9}, 3.5794112222784305`*^9, 
   3.579411672880061*^9, 3.579411704064106*^9, 3.5794117371321526`*^9, 
   3.5794126568844404`*^9, 3.5794127255845366`*^9, 3.5794128594547243`*^9, {
   3.579434560869157*^9, 3.5794345854591913`*^9}, 3.579494317484566*^9, 
   3.579494435756733*^9, {3.5794946269330044`*^9, 3.579494632717016*^9}, 
   3.579496868871147*^9, {3.579498777606821*^9, 3.5794987822288284`*^9}, 
   3.579581362716488*^9, 3.5830621888064814`*^9, 3.5832293371525617`*^9, 
   3.583229686955937*^9, 3.5832298188073683`*^9, 3.583230376427148*^9, {
   3.5841668730035563`*^9, 3.584166882488373*^9}, 3.5842033465431347`*^9, 
   3.584248754204324*^9, 3.5842489216145897`*^9, 3.5842642874230623`*^9, 
   3.584335200489628*^9, 3.5847845113269415`*^9, 3.5865843598034697`*^9, 
   3.5866629755872583`*^9, 3.5868435116322107`*^9, 3.586851610652669*^9, {
   3.586853583629943*^9, 3.5868535907903557`*^9}, 3.5871125147863197`*^9, 
   3.587115061405594*^9, {3.5871151449125404`*^9, 3.587115152057353*^9}, 
   3.587115204691845*^9, 3.587116429812599*^9, 3.5871165579316254`*^9, 
   3.587120183029648*^9, 3.587183187521677*^9, 3.5905591528194656`*^9, 
   3.597731750930794*^9, 3.630513846553344*^9, 3.6512807409592066`*^9, 
   3.6798898869230447`*^9, 3.69000262757231*^9, 3.69002580913922*^9, 
   3.690115483292847*^9, 3.6902639506870832`*^9, 3.6902929436750445`*^9, 
   3.6903070892810345`*^9, 3.6903525920043993`*^9, 3.6903538760744514`*^9, 
   3.6903658178944983`*^9, 3.6904412732296953`*^9, 3.690474780206041*^9, 
   3.6904749880163317`*^9, 3.6905481513955193`*^9, 3.6907790983640413`*^9, 
   3.6957249158215303`*^9, 3.7057239822342167`*^9, 3.7284918067852435`*^9, 
   3.7285433491705074`*^9, 3.741431867795394*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "Set", " ", "the", " ", "maximum", " ", "phonon", " ", "number", " ", 
    "and", " ", "initialize", " ", "the", " ", "basis"}], "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Nmax", "=", "40"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Jlist", "=", 
     RowBox[{"{", 
      RowBox[{
      "0", ",", "2", ",", "3", ",", "4", ",", "5", ",", "6", ",", "7", ",", 
       "8"}], "}"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{"basis", "[", 
    RowBox[{"Nmax", "+", "6"}], "]"}], "\[IndentingNewLine]", 
   RowBox[{"Print", "[", 
    RowBox[{"\"\<Actual Phonon number: \>\"", ",", " ", "Nmax"}], " ", "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{"Print", "[", 
    RowBox[{"\"\<Enlarged Phonon number: \>\"", ",", " ", 
     RowBox[{"Nmax", "+", "6"}]}], "]"}], "\[IndentingNewLine]", 
   RowBox[{"Print", "[", 
    RowBox[{"\"\<Basis dimension: \>\"", ",", "dtot"}], "]"}]}]}]], "Input",
 CellChangeTimes->CompressedData["
1:eJwlzF1Ik3EYBfAlNEdFtDCXlkMlP5rLcglBs+jtYjEIC93cHFiom0kzYyZb
xQicFF6EWYiMpHRpXeg2bRuVSUpLKiOtLoKVWq0PZ68QqDDKTet/ni4OP87D
w8moOltiShAIBLtYYHv6hQr+Ls89z91YCTO0CZ3U/yy7YKrb+wim7wj+N0/7
Amoajr+CZYNt36HC0hmBi+GLlfPMoFFbAwNTR82wPqQh81MFPTN9PJccKeyF
x5LM/T+YA1LeDUWjRj8sWjxFduTVWBL72e7jWvKl6VPrbmbMGSb7DqxzwsMT
7TfhQtPlLhjXXyc9YmcPvF0dIh3KJA/9u9VeyBekBeDD1Z3kWnvHJN3VzR+h
9FbzHGwb0/+i3cZQ4h7m9uVvpDCyRQLFIynk9MxkJnxiC2XBusYNE/uZD7QS
8oZOF4ZHqqyzcGv3B4GS+W5klgwKz0V1zNb4FNk2Oh6D1vLYKhStuVSqZz61
VGvgW5WhsJxZpjCSV8P+Q/DOtWFy9aC/GLqvBMiWaE6Wgfl7r4zcLF9wOJj1
w0vkdGlacraP5+ZkBWT8Z64MBlxiOZRa3vhszJLer6T5i6SOC/Ccodh+BipW
tjXCBquc9H5WpoSHeG7f4ACpMK3ch+dPrvfBJo84CKPdtc+gfair6P3peS77
r4sU3RtWwZZ8lRqesI3r4JjwNbkpnlkB40sy8h+i14Wn
  "]],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Actual Phonon number: \"\>", "\[InvisibleSpace]", "40"}],
  SequenceForm["Actual Phonon number: ", 40],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.576649298966357*^9, {3.5766505086824827`*^9, 3.5766505472613506`*^9}, 
   3.57665058693222*^9, 3.577381179579346*^9, {3.579243805943204*^9, 
   3.57924381039321*^9}, 3.5792530654211674`*^9, 3.579253105971224*^9, 
   3.5792602001261573`*^9, {3.579260252706231*^9, 3.579260315928321*^9}, 
   3.579260861860085*^9, 3.579329423562827*^9, 3.5793357601768675`*^9, 
   3.5793359677231874`*^9, 3.5793378645738697`*^9, 3.579338243269405*^9, 
   3.5793384597337103`*^9, 3.579338972688431*^9, 3.57933947826114*^9, 
   3.5793404765315447`*^9, {3.579340836704051*^9, 3.5793408587240815`*^9}, 
   3.5794112237384324`*^9, 3.5794115753299246`*^9, {3.579411648840028*^9, 
   3.579411673670062*^9}, {3.579411708852113*^9, 3.5794117430321608`*^9}, {
   3.5794118181422663`*^9, 3.579411827272279*^9}, 3.579411873702344*^9, 
   3.5794120856926403`*^9, {3.5794121174226847`*^9, 3.5794121809627743`*^9}, 
   3.5794122966829357`*^9, {3.579412327183979*^9, 3.579412339373996*^9}, 
   3.5794125439842825`*^9, {3.579412658124442*^9, 3.579412665304452*^9}, 
   3.579412726774538*^9, {3.579412765794593*^9, 3.579412783254617*^9}, 
   3.5794128597467256`*^9, 3.579434507509082*^9, {3.579434562429159*^9, 
   3.5794346013392134`*^9}, {3.579434767119446*^9, 3.579434804629498*^9}, 
   3.579435015530793*^9, {3.57949432015457*^9, 3.5794943290845823`*^9}, {
   3.579494367644636*^9, 3.5794943926846714`*^9}, 3.579494436732738*^9, 
   3.5794946342370186`*^9, {3.579495069447628*^9, 3.5794950780676403`*^9}, 
   3.5794968695511484`*^9, 3.5794969663912835`*^9, 3.5794970781114397`*^9, {
   3.5794987830088296`*^9, 3.5794987936888447`*^9}, 3.5795813640064898`*^9, 
   3.57958146401663*^9, 3.5830621947364893`*^9, {3.583062354183364*^9, 
   3.583062369346591*^9}, 3.583229338892564*^9, 3.58322968864074*^9, 
   3.5832298202737713`*^9, {3.5832303720435405`*^9, 3.583230378111951*^9}, 
   3.5841667682993727`*^9, 3.584166818731061*^9, {3.5841668748287597`*^9, 
   3.5841668840483756`*^9}, 3.5842041317769065`*^9, 3.584248923268193*^9, 
   3.5842642891702657`*^9, 3.584335202408431*^9, 3.584784512933744*^9, 
   3.5865843615662727`*^9, 3.586662977303261*^9, 3.586843512972213*^9, 
   3.5868516124622717`*^9, 3.586853592381559*^9, 3.5871125165491233`*^9, 
   3.587115062653596*^9, 3.5871151540697565`*^9, 3.5871152145354624`*^9, 
   3.5871164332602053`*^9, {3.587116564873637*^9, 3.587116586807276*^9}, 
   3.587120184103652*^9, 3.58718318928448*^9, 3.5905591555494704`*^9, 
   3.5977317528607965`*^9, 3.630513848183346*^9, 3.651280742787311*^9, 
   3.6798898940084505`*^9, 3.6798899752560973`*^9, 3.679890062434084*^9, 
   3.67989011079385*^9, 3.6798901545653534`*^9, 3.6900026287473774`*^9, 
   3.6900258100062695`*^9, 3.690115484616923*^9, 3.6902639522870855`*^9, 
   3.6902929455250473`*^9, 3.6903070906681137`*^9, 3.6903526016244135`*^9, 
   3.6903538781044545`*^9, 3.69036581949459*^9, {3.6904412682296886`*^9, 
   3.6904412747096977`*^9}, 3.690474781686043*^9, 3.6904749889263334`*^9, 
   3.6905481536836505`*^9, 3.6907791001851454`*^9, 3.6957249171906085`*^9, 
   3.705723983673299*^9, 3.7284918131152525`*^9, 3.7285433513005104`*^9, 
   3.74143186990182*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Enlarged Phonon number: \"\>", "\[InvisibleSpace]", "46"}],
  SequenceForm["Enlarged Phonon number: ", 46],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.576649298966357*^9, {3.5766505086824827`*^9, 3.5766505472613506`*^9}, 
   3.57665058693222*^9, 3.577381179579346*^9, {3.579243805943204*^9, 
   3.57924381039321*^9}, 3.5792530654211674`*^9, 3.579253105971224*^9, 
   3.5792602001261573`*^9, {3.579260252706231*^9, 3.579260315928321*^9}, 
   3.579260861860085*^9, 3.579329423562827*^9, 3.5793357601768675`*^9, 
   3.5793359677231874`*^9, 3.5793378645738697`*^9, 3.579338243269405*^9, 
   3.5793384597337103`*^9, 3.579338972688431*^9, 3.57933947826114*^9, 
   3.5793404765315447`*^9, {3.579340836704051*^9, 3.5793408587240815`*^9}, 
   3.5794112237384324`*^9, 3.5794115753299246`*^9, {3.579411648840028*^9, 
   3.579411673670062*^9}, {3.579411708852113*^9, 3.5794117430321608`*^9}, {
   3.5794118181422663`*^9, 3.579411827272279*^9}, 3.579411873702344*^9, 
   3.5794120856926403`*^9, {3.5794121174226847`*^9, 3.5794121809627743`*^9}, 
   3.5794122966829357`*^9, {3.579412327183979*^9, 3.579412339373996*^9}, 
   3.5794125439842825`*^9, {3.579412658124442*^9, 3.579412665304452*^9}, 
   3.579412726774538*^9, {3.579412765794593*^9, 3.579412783254617*^9}, 
   3.5794128597467256`*^9, 3.579434507509082*^9, {3.579434562429159*^9, 
   3.5794346013392134`*^9}, {3.579434767119446*^9, 3.579434804629498*^9}, 
   3.579435015530793*^9, {3.57949432015457*^9, 3.5794943290845823`*^9}, {
   3.579494367644636*^9, 3.5794943926846714`*^9}, 3.579494436732738*^9, 
   3.5794946342370186`*^9, {3.579495069447628*^9, 3.5794950780676403`*^9}, 
   3.5794968695511484`*^9, 3.5794969663912835`*^9, 3.5794970781114397`*^9, {
   3.5794987830088296`*^9, 3.5794987936888447`*^9}, 3.5795813640064898`*^9, 
   3.57958146401663*^9, 3.5830621947364893`*^9, {3.583062354183364*^9, 
   3.583062369346591*^9}, 3.583229338892564*^9, 3.58322968864074*^9, 
   3.5832298202737713`*^9, {3.5832303720435405`*^9, 3.583230378111951*^9}, 
   3.5841667682993727`*^9, 3.584166818731061*^9, {3.5841668748287597`*^9, 
   3.5841668840483756`*^9}, 3.5842041317769065`*^9, 3.584248923268193*^9, 
   3.5842642891702657`*^9, 3.584335202408431*^9, 3.584784512933744*^9, 
   3.5865843615662727`*^9, 3.586662977303261*^9, 3.586843512972213*^9, 
   3.5868516124622717`*^9, 3.586853592381559*^9, 3.5871125165491233`*^9, 
   3.587115062653596*^9, 3.5871151540697565`*^9, 3.5871152145354624`*^9, 
   3.5871164332602053`*^9, {3.587116564873637*^9, 3.587116586807276*^9}, 
   3.587120184103652*^9, 3.58718318928448*^9, 3.5905591555494704`*^9, 
   3.5977317528607965`*^9, 3.630513848183346*^9, 3.651280742787311*^9, 
   3.6798898940084505`*^9, 3.6798899752560973`*^9, 3.679890062434084*^9, 
   3.67989011079385*^9, 3.6798901545653534`*^9, 3.6900026287473774`*^9, 
   3.6900258100062695`*^9, 3.690115484616923*^9, 3.6902639522870855`*^9, 
   3.6902929455250473`*^9, 3.6903070906681137`*^9, 3.6903526016244135`*^9, 
   3.6903538781044545`*^9, 3.69036581949459*^9, {3.6904412682296886`*^9, 
   3.6904412747096977`*^9}, 3.690474781686043*^9, 3.6904749889263334`*^9, 
   3.6905481536836505`*^9, 3.6907791001851454`*^9, 3.6957249171906085`*^9, 
   3.705723983673299*^9, 3.7284918131152525`*^9, 3.7285433513005104`*^9, 
   3.74143186990182*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Basis dimension: \"\>", "\[InvisibleSpace]", "40100"}],
  SequenceForm["Basis dimension: ", 40100],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.576649298966357*^9, {3.5766505086824827`*^9, 3.5766505472613506`*^9}, 
   3.57665058693222*^9, 3.577381179579346*^9, {3.579243805943204*^9, 
   3.57924381039321*^9}, 3.5792530654211674`*^9, 3.579253105971224*^9, 
   3.5792602001261573`*^9, {3.579260252706231*^9, 3.579260315928321*^9}, 
   3.579260861860085*^9, 3.579329423562827*^9, 3.5793357601768675`*^9, 
   3.5793359677231874`*^9, 3.5793378645738697`*^9, 3.579338243269405*^9, 
   3.5793384597337103`*^9, 3.579338972688431*^9, 3.57933947826114*^9, 
   3.5793404765315447`*^9, {3.579340836704051*^9, 3.5793408587240815`*^9}, 
   3.5794112237384324`*^9, 3.5794115753299246`*^9, {3.579411648840028*^9, 
   3.579411673670062*^9}, {3.579411708852113*^9, 3.5794117430321608`*^9}, {
   3.5794118181422663`*^9, 3.579411827272279*^9}, 3.579411873702344*^9, 
   3.5794120856926403`*^9, {3.5794121174226847`*^9, 3.5794121809627743`*^9}, 
   3.5794122966829357`*^9, {3.579412327183979*^9, 3.579412339373996*^9}, 
   3.5794125439842825`*^9, {3.579412658124442*^9, 3.579412665304452*^9}, 
   3.579412726774538*^9, {3.579412765794593*^9, 3.579412783254617*^9}, 
   3.5794128597467256`*^9, 3.579434507509082*^9, {3.579434562429159*^9, 
   3.5794346013392134`*^9}, {3.579434767119446*^9, 3.579434804629498*^9}, 
   3.579435015530793*^9, {3.57949432015457*^9, 3.5794943290845823`*^9}, {
   3.579494367644636*^9, 3.5794943926846714`*^9}, 3.579494436732738*^9, 
   3.5794946342370186`*^9, {3.579495069447628*^9, 3.5794950780676403`*^9}, 
   3.5794968695511484`*^9, 3.5794969663912835`*^9, 3.5794970781114397`*^9, {
   3.5794987830088296`*^9, 3.5794987936888447`*^9}, 3.5795813640064898`*^9, 
   3.57958146401663*^9, 3.5830621947364893`*^9, {3.583062354183364*^9, 
   3.583062369346591*^9}, 3.583229338892564*^9, 3.58322968864074*^9, 
   3.5832298202737713`*^9, {3.5832303720435405`*^9, 3.583230378111951*^9}, 
   3.5841667682993727`*^9, 3.584166818731061*^9, {3.5841668748287597`*^9, 
   3.5841668840483756`*^9}, 3.5842041317769065`*^9, 3.584248923268193*^9, 
   3.5842642891702657`*^9, 3.584335202408431*^9, 3.584784512933744*^9, 
   3.5865843615662727`*^9, 3.586662977303261*^9, 3.586843512972213*^9, 
   3.5868516124622717`*^9, 3.586853592381559*^9, 3.5871125165491233`*^9, 
   3.587115062653596*^9, 3.5871151540697565`*^9, 3.5871152145354624`*^9, 
   3.5871164332602053`*^9, {3.587116564873637*^9, 3.587116586807276*^9}, 
   3.587120184103652*^9, 3.58718318928448*^9, 3.5905591555494704`*^9, 
   3.5977317528607965`*^9, 3.630513848183346*^9, 3.651280742787311*^9, 
   3.6798898940084505`*^9, 3.6798899752560973`*^9, 3.679890062434084*^9, 
   3.67989011079385*^9, 3.6798901545653534`*^9, 3.6900026287473774`*^9, 
   3.6900258100062695`*^9, 3.690115484616923*^9, 3.6902639522870855`*^9, 
   3.6902929455250473`*^9, 3.6903070906681137`*^9, 3.6903526016244135`*^9, 
   3.6903538781044545`*^9, 3.69036581949459*^9, {3.6904412682296886`*^9, 
   3.6904412747096977`*^9}, 3.690474781686043*^9, 3.6904749889263334`*^9, 
   3.6905481536836505`*^9, 3.6907791001851454`*^9, 3.6957249171906085`*^9, 
   3.705723983673299*^9, 3.7284918131152525`*^9, 3.7285433513005104`*^9, 
   3.74143186990182*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "for", " ", "selected", " ", "Nmax", " ", "this", " ", "can", " ", "be", 
    " ", "checked", " ", "with", " ", "table", " ", "3.2", " ", "of", " ", 
    RowBox[{"Ref", ".", " ", 
     RowBox[{"[", "2", "]"}]}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Do", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{"subbasis", "[", 
       RowBox[{"J", ",", "Nmax"}], "]"}], ";", "\[IndentingNewLine]", " ", 
      RowBox[{
       RowBox[{"ns", "[", "J", "]"}], "=", "Nst"}], ";", " ", 
      RowBox[{
       RowBox[{"ns2", "[", "J", "]"}], "=", "Nst2"}], ";"}], ",", 
     RowBox[{"{", 
      RowBox[{"J", ",", "Jlist"}], "}"}]}], "]"}], "\[IndentingNewLine]", 
   RowBox[{
   "Print", "[", "\"\<  J     sub-basis dim    trimmed dim\>\"", " ", "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{"Grid", "[", 
    RowBox[{
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"J", ",", 
         RowBox[{"ns", "[", "J", "]"}], ",", 
         RowBox[{"ns2", "[", "J", "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"J", ",", "Jlist"}], "}"}]}], "]"}], ",", 
     RowBox[{"Spacings", "\[Rule]", "7"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.5765947490887957`*^9, 3.5765947542212048`*^9}, {
  3.5765947888064656`*^9, 3.5765947899764676`*^9}, {3.5765957482825513`*^9, 
  3.576595801104244*^9}, {3.576595862162751*^9, 3.5765958971224127`*^9}, {
  3.57664837284193*^9, 3.576648470232901*^9}, {3.5766485071557665`*^9, 
  3.576648908341671*^9}, {3.5766489740333867`*^9, 3.576648979961397*^9}, {
  3.579412537334273*^9, 3.5794125378642735`*^9}, {3.5794127403445573`*^9, 
  3.5794127404945574`*^9}, {3.5794348403995485`*^9, 3.5794348806606045`*^9}, {
  3.579435119660939*^9, 3.579435125210947*^9}, {3.5794944012246833`*^9, 
  3.579494401354684*^9}, {3.5794945050428333`*^9, 3.579494505172834*^9}, {
  3.5832339322347364`*^9, 3.5832339322847366`*^9}}],

Cell[BoxData["\<\"  J     sub-basis dim    trimmed dim\"\>"], "Print",
 CellChangeTimes->{{3.576648568463874*^9, 3.576648589258711*^9}, 
   3.576648675074462*^9, {3.576648783666252*^9, 3.5766489090280724`*^9}, 
   3.5766489803669977`*^9, 3.5766491152916346`*^9, 3.576649160001313*^9, {
   3.5766492859091344`*^9, 3.576649299980359*^9}, {3.576650510242485*^9, 
   3.576650548088152*^9}, 3.5766505877590218`*^9, 3.5773811816073494`*^9, 
   3.579243813233214*^9, 3.579253067991171*^9, 3.579253106801225*^9, 
   3.5792602022161603`*^9, {3.5792602537262325`*^9, 3.5792603174883227`*^9}, 
   3.579260862640086*^9, 3.5793294251128287`*^9, 3.579335761296869*^9, 
   3.5793359686551895`*^9, 3.579337865493871*^9, {3.579338240479401*^9, 
   3.579338244029406*^9}, 3.579338460645713*^9, 3.579338973578432*^9, 
   3.579339478941141*^9, 3.5793404775315456`*^9, {3.5793408373440514`*^9, 
   3.579340859794083*^9}, 3.5794112626784873`*^9, 3.579411298199537*^9, 
   3.5794115761299257`*^9, 3.579411744052162*^9, {3.5794118191622677`*^9, 
   3.579411829032281*^9}, 3.579411875382346*^9, {3.579412122582692*^9, 
   3.5794121821027756`*^9}, {3.5794123043139467`*^9, 3.579412340173997*^9}, {
   3.5794125391442757`*^9, 3.5794125449042835`*^9}, 3.5794126692244577`*^9, {
   3.579412730734544*^9, 3.579412784524619*^9}, 3.579412861246728*^9, 
   3.579434508889084*^9, {3.5794345648691626`*^9, 3.579434602359215*^9}, 
   3.5794348139195113`*^9, 3.5794348897006173`*^9, 3.579435016660795*^9, {
   3.5794351215509415`*^9, 3.57943512730095*^9}, 3.5794943326145873`*^9, {
   3.5794943690746384`*^9, 3.579494402614685*^9}, 3.5794944383227406`*^9, 
   3.579494506112835*^9, {3.5794946289670115`*^9, 3.579494635677021*^9}, {
   3.57949507096763*^9, 3.579495080807644*^9}, 3.57949687057115*^9, 
   3.579496967221285*^9, 3.5794970793214417`*^9, {3.579498778618823*^9, 
   3.579498794408846*^9}, 3.579581365496492*^9, 3.5795814647366314`*^9, 
   3.5830622011164985`*^9, {3.583062355353366*^9, 3.583062371639795*^9}, 
   3.583229340862567*^9, 3.583229689295941*^9, 3.583229820804172*^9, {
   3.583230372636341*^9, 3.583230378735952*^9}, 3.5841667709825773`*^9, 
   3.5841668209462647`*^9, 3.5841668859203787`*^9, 3.5841670348818407`*^9, 
   3.58420413382051*^9, 3.584248925826597*^9, 3.5842642910422688`*^9, 
   3.5843352051384363`*^9, 3.58478451614735*^9, 3.586584363297876*^9, 
   3.586662979003664*^9, 3.586843514022214*^9, 3.5868516138974743`*^9, {
   3.5868535846283455`*^9, 3.586853593785561*^9}, 3.5871125187019267`*^9, 
   3.5871150637143974`*^9, {3.587115146846944*^9, 3.587115155520559*^9}, 
   3.587115215424664*^9, 3.587116434851408*^9, 3.5871165890536795`*^9, 
   3.587120185143654*^9, 3.5871831907508826`*^9, 3.5905591584510756`*^9, 
   3.5977317552307997`*^9, 3.630513849353348*^9, 3.651280744638417*^9, 
   3.6798898971276283`*^9, 3.6798899765711727`*^9, 3.679890064060177*^9, 
   3.679890111617897*^9, 3.6798901588055954`*^9, 3.690002630308467*^9, 
   3.690025811486354*^9, 3.690115486406025*^9, 3.690263954017088*^9, 
   3.6902929484950514`*^9, 3.6903070923942127`*^9, 3.690352603604416*^9, 
   3.69035388185446*^9, 3.6903658209806747`*^9, {3.6904412693196898`*^9, 
   3.6904412768097005`*^9}, 3.690474783076045*^9, 3.690474990136335*^9, 
   3.690548155516755*^9, 3.690779101400215*^9, 3.6957249195637445`*^9, 
   3.705723985338394*^9, 3.728491814235254*^9, 3.7285433550705156`*^9, 
   3.741431871188239*^9}],

Cell[BoxData[
 TagBox[GridBox[{
    {"0", "200", "147"},
    {"2", "376", "273"},
    {"3", "176", "127"},
    {"4", "529", "380"},
    {"5", "330", "234"},
    {"6", "660", "469"},
    {"7", "462", "324"},
    {"8", "771", "540"}
   },
   AutoDelete->False,
   GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
   GridBoxSpacings->{"Columns" -> {{7}}}],
  "Grid"]], "Output",
 CellChangeTimes->{{3.576648568463874*^9, 3.576648589258711*^9}, 
   3.576648675074462*^9, {3.5766487836818523`*^9, 3.5766489090280724`*^9}, 
   3.5766489803669977`*^9, 3.5766491152916346`*^9, 3.576649160001313*^9, {
   3.5766492859091344`*^9, 3.576649299980359*^9}, {3.5766505102580853`*^9, 
   3.576650548088152*^9}, 3.5766505877590218`*^9, 3.5773811816073494`*^9, 
   3.579243813283214*^9, 3.579253068001171*^9, 3.579253106811225*^9, 
   3.5792602022361603`*^9, {3.5792602537262325`*^9, 3.5792603174883227`*^9}, 
   3.579260862650086*^9, 3.5793294251228285`*^9, 3.5793357613068686`*^9, 
   3.5793359686651897`*^9, 3.579337865513871*^9, {3.579338240479401*^9, 
   3.579338244029406*^9}, 3.579338460655713*^9, 3.579338973578432*^9, 
   3.5793394789511414`*^9, 3.579340477541546*^9, {3.5793408373540516`*^9, 
   3.579340859804083*^9}, 3.579411262688487*^9, 3.579411298199537*^9, 
   3.579411576139926*^9, 3.579411744052162*^9, {3.5794118191622677`*^9, 
   3.579411829032281*^9}, 3.579411875382346*^9, {3.579412122582692*^9, 
   3.5794121821027756`*^9}, {3.579412304323947*^9, 3.579412340173997*^9}, {
   3.579412539154276*^9, 3.5794125449042835`*^9}, 3.5794126692344575`*^9, {
   3.5794127307445436`*^9, 3.579412784524619*^9}, 3.5794128612567277`*^9, 
   3.579434508889084*^9, {3.5794345648691626`*^9, 3.579434602359215*^9}, 
   3.5794348139195113`*^9, 3.5794348897006173`*^9, 3.579435016660795*^9, {
   3.5794351215509415`*^9, 3.5794351273109503`*^9}, 3.579494332624587*^9, {
   3.5794943690846386`*^9, 3.579494402614685*^9}, 3.5794944383527403`*^9, 
   3.579494506112835*^9, {3.5794946289670115`*^9, 3.579494635687021*^9}, {
   3.57949507096763*^9, 3.579495080807644*^9}, 3.57949687057115*^9, 
   3.579496967221285*^9, 3.579497079331442*^9, {3.579498778618823*^9, 
   3.579498794408846*^9}, 3.579581365496492*^9, 3.579581464746631*^9, 
   3.583062201166498*^9, {3.583062355353366*^9, 3.5830623716553946`*^9}, 
   3.5832293408725667`*^9, 3.5832296893115406`*^9, 3.583229820819772*^9, {
   3.5832303726519413`*^9, 3.583230378735952*^9}, 3.584166770998177*^9, 
   3.5841668209618645`*^9, 3.584166885935979*^9, 3.5841670348818407`*^9, 
   3.5842041338517103`*^9, 3.584248925873397*^9, 3.584264291057869*^9, 
   3.584335205263236*^9, 3.58478451620975*^9, 3.586584363344676*^9, 
   3.5866629790504637`*^9, 3.5868435140422144`*^9, 3.5868516139130745`*^9, {
   3.5868535846127453`*^9, 3.586853593785561*^9}, 3.5871125187019267`*^9, 
   3.5871150637299976`*^9, {3.587115146846944*^9, 3.587115155520559*^9}, 
   3.5871152154402637`*^9, 3.587116434851408*^9, 3.5871165890536795`*^9, 
   3.5871201851536536`*^9, 3.587183190766483*^9, 3.5905591586070757`*^9, 
   3.5977317552507997`*^9, 3.6305138494033475`*^9, 3.65128074469642*^9, 
   3.6798898972266345`*^9, 3.679889976574173*^9, 3.679890064066177*^9, 
   3.6798901116218967`*^9, 3.6798901588125963`*^9, 3.6900026303584695`*^9, 
   3.6900258114933543`*^9, 3.6901154864120255`*^9, 3.690263954067088*^9, 
   3.6902929485450516`*^9, 3.6903070924062133`*^9, 3.690352603634416*^9, 
   3.69035388185446*^9, 3.690365821057679*^9, {3.6904412693596897`*^9, 
   3.6904412768197002`*^9}, 3.690474783106045*^9, 3.6904749901463346`*^9, 
   3.690548155526756*^9, 3.690779101450218*^9, 3.6957249196257477`*^9, 
   3.705723985377396*^9, 3.728491814235254*^9, 3.728543355080516*^9, 
   3.741431871190239*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "Uncomment", " ", "the", " ", "following", " ", "lines", " ", "to", " ", 
    "see", " ", "an", " ", "example", " ", "of", " ", "the", " ", "output", 
    " ", "of", " ", "the", " ", "subbasis", " ", "module"}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{"(*", "  ", 
   RowBox[{
    RowBox[{"subbasis", "[", 
     RowBox[{"6", ",", "Nmax"}], "]"}], "\[IndentingNewLine]", "DDD", " ", 
    "\[IndentingNewLine]", "NNN", " ", "\[IndentingNewLine]", "lll", "  ", 
    "\[IndentingNewLine]", "vvv"}], " ", "*)"}], " "}]], "Input",
 CellChangeTimes->{{3.579435216641075*^9, 3.579435244481114*^9}, {
   3.5794352961511865`*^9, 3.5794353062212005`*^9}, {3.5794944143847017`*^9, 
   3.5794944449727497`*^9}, {3.5832297356436224`*^9, 3.583229735690422*^9}, {
   3.5832299058711214`*^9, 3.5832299060427217`*^9}, {3.5832299530580044`*^9, 
   3.5832299590796146`*^9}, {3.5832303824019585`*^9, 
   3.5832303826047587`*^9}, {3.5842489452486315`*^9, 
   3.5842489623306613`*^9}, {3.584264317281515*^9, 3.584264331898741*^9}, {
   3.5842643886204405`*^9, 3.584264391069645*^9}, {3.5842655885009484`*^9, 
   3.5842656072677813`*^9}, 3.584335220613663*^9, {3.5865931445836277`*^9, 
   3.586593147797233*^9}, {3.5868517909109855`*^9, 3.5868517963085947`*^9}, {
   3.58685190752119*^9, 3.586851948171262*^9}, {3.587117059317506*^9, 
   3.5871170627339115`*^9}, {3.69035386042443*^9, 3.690353862184432*^9}, {
   3.690353923654518*^9, 3.6903539425145445`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
    "Read", " ", "matrices", " ", "from", " ", "BasMat", " ", "library"}], 
    " ", "-", " ", 
    RowBox[{"it", " ", "takes", " ", "a", " ", "few", " ", "seconds"}]}], " ",
    "*)"}], "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{
   "Kinetic", " ", "Energy", " ", "matrix", " ", "is", " ", "found", " ", 
    "through", " ", 
    RowBox[{"eq", ".", " ", 
     RowBox[{"(", "3.39", ")"}]}], " ", "of", " ", 
    RowBox[{"Ref", ".", 
     RowBox[{"[", "2", "]"}]}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
     RowBox[{
     "Notice", " ", "that", " ", "the", " ", "matrices", " ", "for", " ", 
      "J"}], "=", "6"}], ",", 
    RowBox[{
    "8", " ", "have", " ", "been", " ", "orthogonalized", " ", "before", " ", 
     "readup"}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"Do", "[", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"subbasis", "[", 
      RowBox[{"J", ",", "Nmax"}], "]"}], ";", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"Vb2", "[", "J", "]"}], "=", 
      RowBox[{"Import", "[", 
       RowBox[{
        RowBox[{"NotebookDirectory", "[", "]"}], "<>", "\"\<\\\\N\>\"", "<>", 
        RowBox[{"ToString", "[", "Nmax", "]"}], "<>", "\"\<\\\\N\>\"", "<>", 
        RowBox[{"ToString", "[", "Nmax", "]"}], "<>", "\"\<L\>\"", "<>", 
        RowBox[{"ToString", "[", "J", "]"}], "<>", "\"\<\\\\Vb2D.rha\>\""}], 
       "]"}]}], ";", "\[IndentingNewLine]", " ", 
     RowBox[{
      RowBox[{"T", "[", "J", "]"}], "=", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"lll", "[", 
            RowBox[{"[", "i", "]"}], "]"}], "\[Equal]", 
           RowBox[{"lll", "[", 
            RowBox[{"[", "k", "]"}], "]"}]}], ",", 
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"NNN", "[", 
               RowBox[{"[", "i", "]"}], "]"}], "+", "2.5"}], ")"}], 
            RowBox[{"KroneckerDelta", "[", 
             RowBox[{"i", ",", "k"}], "]"}]}], "-", 
           RowBox[{
            RowBox[{
             RowBox[{"Vb2", "[", "J", "]"}], "[", 
             RowBox[{"[", 
              RowBox[{"i", ",", "k"}], "]"}], "]"}], "/", "2"}]}], ",", 
          "0."}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "1", ",", 
          RowBox[{"ns2", "[", "J", "]"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"k", ",", "1", ",", 
          RowBox[{"ns2", "[", "J", "]"}]}], "}"}]}], "]"}]}], ";", "  ", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"Vb3c", "[", "J", "]"}], "=", 
      RowBox[{"Import", "[", 
       RowBox[{
        RowBox[{"NotebookDirectory", "[", "]"}], "<>", "\"\<\\\\N\>\"", "<>", 
        RowBox[{"ToString", "[", "Nmax", "]"}], "<>", "\"\<\\\\N\>\"", "<>", 
        RowBox[{"ToString", "[", "Nmax", "]"}], "<>", "\"\<L\>\"", "<>", 
        RowBox[{"ToString", "[", "J", "]"}], "<>", "\"\<\\\\Vb3cD.rha\>\""}], 
       "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"Vb4", "[", "J", "]"}], "=", 
      RowBox[{"Import", "[", 
       RowBox[{
        RowBox[{"NotebookDirectory", "[", "]"}], "<>", "\"\<\\\\N\>\"", "<>", 
        RowBox[{"ToString", "[", "Nmax", "]"}], "<>", "\"\<\\\\N\>\"", "<>", 
        RowBox[{"ToString", "[", "Nmax", "]"}], "<>", "\"\<L\>\"", "<>", 
        RowBox[{"ToString", "[", "J", "]"}], "<>", "\"\<\\\\Vb4D.rha\>\""}], 
       "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"Vb5c", "[", "J", "]"}], "=", 
      RowBox[{"Import", "[", 
       RowBox[{
        RowBox[{"NotebookDirectory", "[", "]"}], "<>", "\"\<\\\\N\>\"", "<>", 
        RowBox[{"ToString", "[", "Nmax", "]"}], "<>", "\"\<\\\\N\>\"", "<>", 
        RowBox[{"ToString", "[", "Nmax", "]"}], "<>", "\"\<L\>\"", "<>", 
        RowBox[{"ToString", "[", "J", "]"}], "<>", "\"\<\\\\Vb5cD.rha\>\""}], 
       "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"Vb6c", "[", "J", "]"}], "=", 
      RowBox[{"Import", "[", 
       RowBox[{
        RowBox[{"NotebookDirectory", "[", "]"}], "<>", "\"\<\\\\N\>\"", "<>", 
        RowBox[{"ToString", "[", "Nmax", "]"}], "<>", "\"\<\\\\N\>\"", "<>", 
        RowBox[{"ToString", "[", "Nmax", "]"}], "<>", "\"\<L\>\"", "<>", 
        RowBox[{"ToString", "[", "J", "]"}], "<>", "\"\<\\\\Vb6cD.rha\>\""}], 
       "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"Vb6", "[", "J", "]"}], "=", 
      RowBox[{"Import", "[", 
       RowBox[{
        RowBox[{"NotebookDirectory", "[", "]"}], "<>", "\"\<\\\\N\>\"", "<>", 
        RowBox[{"ToString", "[", "Nmax", "]"}], "<>", "\"\<\\\\N\>\"", "<>", 
        RowBox[{"ToString", "[", "Nmax", "]"}], "<>", "\"\<L\>\"", "<>", 
        RowBox[{"ToString", "[", "J", "]"}], "<>", "\"\<\\\\Vb6D.rha\>\""}], 
       "]"}]}], ";"}], "\[IndentingNewLine]", ",", 
    RowBox[{"{", 
     RowBox[{"J", ",", "Jlist"}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{
  3.5757070720268717`*^9, {3.5765945555080557`*^9, 3.5765947441591873`*^9}, {
   3.5765948214677234`*^9, 3.5765948912022457`*^9}, {3.5765949865340133`*^9, 
   3.576594991541622*^9}, {3.5765950482477217`*^9, 3.5765950528653297`*^9}, {
   3.576596131557225*^9, 3.5765961502460575`*^9}, {3.57659618538892*^9, 
   3.576596217306576*^9}, {3.576596321015558*^9, 3.576596325383566*^9}, {
   3.5765963824796658`*^9, 3.57659641328972*^9}, {3.576596493723461*^9, 
   3.5765964989806705`*^9}, {3.576596606542859*^9, 3.576596614249273*^9}, {
   3.5765969926903377`*^9, 3.5765970109891696`*^9}, {3.5765973278101263`*^9, 
   3.5765973905222363`*^9}, {3.5766474204382553`*^9, 3.576647455179516*^9}, 
   3.576647695983139*^9, {3.576649069209154*^9, 3.5766491237468495`*^9}, {
   3.57664921505381*^9, 3.576649263367095*^9}, {3.5794128284746804`*^9, 
   3.5794128496847105`*^9}, {3.5794129062667904`*^9, 3.5794129128968*^9}, {
   3.579435030810815*^9, 3.579435076480879*^9}, {3.5794351347609606`*^9, 
   3.579435144630974*^9}, {3.5794351785010214`*^9, 3.5794351813810253`*^9}, {
   3.5794353507012625`*^9, 3.5794353772913*^9}, {3.5794944548327637`*^9, 
   3.5794944578127675`*^9}, {3.579496879481162*^9, 3.5794968816411653`*^9}, {
   3.583062272402621*^9, 3.5830622859434443`*^9}, {3.583062319592704*^9, 
   3.58306232310271*^9}, {3.5832293514025817`*^9, 3.583229358832592*^9}, {
   3.5832297049271684`*^9, 3.5832297164399886`*^9}, {3.5832299017995143`*^9, 
   3.5832299030943165`*^9}, {3.5832299666924286`*^9, 
   3.5832299902484694`*^9}, {3.583230109541879*^9, 3.5832301392599316`*^9}, {
   3.58323019545123*^9, 3.583230232548095*^9}, {3.5832304011843915`*^9, 
   3.583230426550036*^9}, {3.583231681860586*^9, 3.583231681930586*^9}, {
   3.5832339370647435`*^9, 3.5832339371047435`*^9}, {3.5843352395052967`*^9, 
   3.584335244122905*^9}, {3.587112478578656*^9, 3.5871125044279017`*^9}, {
   3.587113101940151*^9, 3.5871131301294007`*^9}, {3.587113480335416*^9, 
   3.587113481084217*^9}, {3.587113553234344*^9, 3.5871135586007533`*^9}, {
   3.587113610236844*^9, 3.58711372761145*^9}, {3.5871150237315273`*^9, 
   3.5871150552435827`*^9}, {3.5871168772183857`*^9, 3.587116916327655*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "Uncomment", " ", "the", " ", "following", " ", "lines", " ", "to", " ", 
    "see", " ", "examples", " ", "of", " ", "matrices"}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"T", "[", "6", "]"}], "[", 
     RowBox[{"[", 
      RowBox[{
       RowBox[{"1", ";;", "10"}], ",", 
       RowBox[{"1", ";;", "10"}]}], "]"}], "]"}], "//", "MatrixForm"}], 
   "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{
     RowBox[{"Example", ":", " ", 
      RowBox[{
       RowBox[{
       "check", " ", "that", " ", "the", " ", "harmonic", " ", "oscillator", 
        " ", "is", " ", "indeed", " ", "diagonal", " ", "with", " ", 
        "correct", " ", "eigenvalues"}], " ", "-", " ", "L"}]}], "=", 
     RowBox[{"0", " ", "case"}]}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{
    "Notice", " ", "that", " ", "several", " ", "seniority", " ", "states", 
     " ", "\[ScriptL]", " ", "might", " ", "contribute", " ", "to", " ", 
     "the", " ", "count", " ", "of", " ", "a", " ", "certain", " ", "L", " ", 
     RowBox[{"state", ".", " ", "Refer"}], " ", 
     RowBox[{"to", " ", "[", "2", "]"}], " ", 
     RowBox[{"or", " ", "[", "4", "]"}], " ", "tables", " ", "1", " ", "and", 
     " ", "2", " ", "for", " ", "more", " ", "information"}], " ", "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"T", "[", "6", "]"}], "+", 
       RowBox[{
        RowBox[{"Vb2", "[", "6", "]"}], "/", "2"}]}], ")"}], "[", 
     RowBox[{"[", 
      RowBox[{
       RowBox[{"1", ";;", "10"}], ",", 
       RowBox[{"1", ";;", "10"}]}], "]"}], "]"}], "//", "MatrixForm"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.5832299279919605`*^9, 3.58322994493039*^9}, {
   3.5832301169050922`*^9, 3.5832301305239162`*^9}, {3.5832302435617146`*^9, 
   3.5832302445289164`*^9}, {3.58323043445925*^9, 3.58323043459965*^9}, {
   3.584167066581096*^9, 3.5841671148787813`*^9}, {3.5842041733353796`*^9, 
   3.5842041745053816`*^9}, {3.5842643402291555`*^9, 3.584264384470833*^9}, {
   3.586851631463105*^9, 3.5868516331323085`*^9}, {3.5905592101183662`*^9, 
   3.590559429797952*^9}, 3.5977318294609036`*^9, {3.6798901230825524`*^9, 
   3.679890147552952*^9}}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"2.75`", "0.`", 
      RowBox[{"-", "1.1726039399558574`"}], "0.`", "0.`", "0.`", "0.`", "0.`",
       "0.`", "0.`"},
     {"0.`", "3.25`", "0.`", "0.`", 
      RowBox[{"-", "1.2747548783981961`"}], "0.`", "0.`", "0.`", "0.`", "0.`"},
     {
      RowBox[{"-", "1.1726039399558574`"}], "0.`", "3.75`", "0.`", "0.`", 
      "0.`", "0.`", 
      RowBox[{"-", "1.8027756377319946`"}], "0.`", "0.`"},
     {"0.`", "0.`", "0.`", "3.75`", "0.`", "0.`", "0.`", "0.`", 
      RowBox[{"-", "1.3693063937629153`"}], "0.`"},
     {"0.`", 
      RowBox[{"-", "1.2747548783981961`"}], "0.`", "0.`", "4.25`", "0.`", 
      "0.`", "0.`", "0.`", "0.`"},
     {"0.`", "0.`", "0.`", "0.`", "0.`", "4.25`", "0.`", "0.`", "0.`", "0.`"},
     {"0.`", "0.`", "0.`", "0.`", "0.`", "0.`", "4.25`", "0.`", "0.`", "0.`"},
     {"0.`", "0.`", 
      RowBox[{"-", "1.8027756377319946`"}], "0.`", "0.`", "0.`", "0.`", 
      "4.75`", "0.`", "0.`"},
     {"0.`", "0.`", "0.`", 
      RowBox[{"-", "1.3693063937629153`"}], "0.`", "0.`", "0.`", "0.`", 
      "4.75`", "0.`"},
     {"0.`", "0.`", "0.`", "0.`", "0.`", "0.`", "0.`", "0.`", "0.`", "4.75`"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{{3.5905592148919744`*^9, 3.590559430172353*^9}, 
   3.597731830280905*^9, 3.6305138591133614`*^9, 3.651280755307027*^9, 
   3.679889906106142*^9, 3.6798899897829285`*^9, {3.679890117812251*^9, 
   3.679890166801053*^9}, 3.6903526189224386`*^9, 3.6904412882597165`*^9, 
   3.690474791096056*^9, 3.695724926419136*^9, 3.705723992942829*^9, 
   3.7284918252452693`*^9, 3.728543363650528*^9, 3.741431878476331*^9}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"5.5`", "0.`", "0.`", "0.`", "0.`", "0.`", "0.`", "0.`", "0.`", "0.`"},
     {"0.`", "6.5`", "0.`", "0.`", "0.`", "0.`", "0.`", "0.`", "0.`", "0.`"},
     {"0.`", "0.`", "7.5`", "0.`", "0.`", "0.`", "0.`", "0.`", "0.`", "0.`"},
     {"0.`", "0.`", "0.`", "7.5`", "0.`", "0.`", "0.`", "0.`", "0.`", "0.`"},
     {"0.`", "0.`", "0.`", "0.`", "8.5`", "0.`", "0.`", "0.`", "0.`", "0.`"},
     {"0.`", "0.`", "0.`", "0.`", "0.`", "8.5`", "0.`", "0.`", "0.`", "0.`"},
     {"0.`", "0.`", "0.`", "0.`", "0.`", "0.`", "8.5`", "0.`", "0.`", "0.`"},
     {"0.`", "0.`", "0.`", "0.`", "0.`", "0.`", "0.`", "9.5`", "0.`", "0.`"},
     {"0.`", "0.`", "0.`", "0.`", "0.`", "0.`", "0.`", "0.`", "9.5`", "0.`"},
     {"0.`", "0.`", "0.`", "0.`", "0.`", "0.`", "0.`", "0.`", "0.`", "9.5`"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{{3.5905592148919744`*^9, 3.590559430172353*^9}, 
   3.597731830280905*^9, 3.6305138591133614`*^9, 3.651280755307027*^9, 
   3.679889906106142*^9, 3.6798899897829285`*^9, {3.679890117812251*^9, 
   3.679890166801053*^9}, 3.6903526189224386`*^9, 3.6904412882597165`*^9, 
   3.690474791096056*^9, 3.695724926419136*^9, 3.705723992942829*^9, 
   3.7284918252452693`*^9, 3.728543363650528*^9, 3.7414318785245323`*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
    "Module", " ", "that", " ", "calculates", " ", "the", " ", "scaling", " ",
      "factors"}], ",", " ", "s", ",", " ", 
    RowBox[{
    "as", " ", "explained", " ", "in", " ", "section", " ", "4.6", " ", "of", 
     " ", "the", " ", "thesis"}], ",", " ", 
    RowBox[{"taken", " ", "from", " ", 
     RowBox[{"Ref", ".", 
      RowBox[{"[", "6", "]"}]}]}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"sfind", "[", 
     RowBox[{"cx1_", ",", "cx2_", ",", "cx4_", ",", "cx6_", ",", "cx7_"}], 
     "]"}], ":=", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"sol", ",", "Sol", ",", "k", ",", 
        RowBox[{"c1", "=", "cx1"}], ",", 
        RowBox[{"c2", "=", "cx2"}], ",", 
        RowBox[{"c4", "=", "cx4"}], ",", 
        RowBox[{"c6", "=", "cx6"}], ",", 
        RowBox[{"c7", "=", "cx7"}]}], "}"}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"subbasis", "[", 
        RowBox[{"0", ",", "Nmax"}], "]"}], ";", "\[IndentingNewLine]", 
       RowBox[{"k", "=", 
        RowBox[{"Floor", "[", 
         RowBox[{
          RowBox[{"ns2", "[", "0", "]"}], "/", "1.6"}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"K8", "=", 
        RowBox[{"Sum", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"T", "[", "0", "]"}], "[", 
           RowBox[{"[", 
            RowBox[{"i", ",", "i"}], "]"}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", "1", ",", "k"}], "}"}]}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"K4", "=", 
        RowBox[{"Sum", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"Vb2", "[", "0", "]"}], "[", 
           RowBox[{"[", 
            RowBox[{"i", ",", "i"}], "]"}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", "1", ",", "k"}], "}"}]}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"K2", "=", 
        RowBox[{"Sum", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"Vb4", "[", "0", "]"}], "[", 
           RowBox[{"[", 
            RowBox[{"i", ",", "i"}], "]"}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", "1", ",", "k"}], "}"}]}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"K0", "=", 
        RowBox[{"Sum", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"Vb6", "[", "0", "]"}], "[", 
           RowBox[{"[", 
            RowBox[{"i", ",", "i"}], "]"}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", "1", ",", "k"}], "}"}]}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"K00", "=", 
        RowBox[{"Sum", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"Vb6c", "[", "0", "]"}], "[", 
           RowBox[{"[", 
            RowBox[{"i", ",", "i"}], "]"}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", "1", ",", "k"}], "}"}]}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"sol", "=", 
        RowBox[{"Solve", "[", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"2", "c1", "*", "K8", " ", 
             RowBox[{"x", "^", "8"}]}], "-", 
            RowBox[{
             RowBox[{"2", "/", 
              RowBox[{"Sqrt", "[", "5", "]"}]}], "c2", "*", "K4", " ", 
             RowBox[{"x", "^", "4"}]}], "-", 
            RowBox[{"4", 
             RowBox[{"Sqrt", "[", 
              RowBox[{"2", "/", "175"}], "]"}], "c4", "*", "K2", " ", 
             RowBox[{"x", "^", "2"}]}], "-", 
            RowBox[{"6", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"2", "/", "35"}], "c6", "*", "K0"}], "+", 
               RowBox[{
                RowBox[{"1", "/", 
                 RowBox[{"(", 
                  RowBox[{"5", 
                   RowBox[{"Sqrt", "[", "5", "]"}]}], ")"}]}], "c7", "*", 
                "K00"}]}], ")"}]}]}], "\[Equal]", "0"}], ",", "x"}], "]"}]}], 
       ";", "\[IndentingNewLine]", 
       RowBox[{"(*", 
        RowBox[{
         RowBox[{"sol", "=", 
          RowBox[{"Solve", "[", 
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{"9", "c1", "*", "K8", " ", 
               RowBox[{"x", "^", "8"}]}], "+", 
              RowBox[{
               RowBox[{"Sqrt", "[", "5", "]"}], "c2", "*", "K4", " ", 
               RowBox[{"x", "^", "4"}]}], "+", 
              RowBox[{
               RowBox[{"3", "/", "5"}], "*", "c4", "*", "K2", "*", " ", 
               RowBox[{"x", "^", "2"}]}], "+", 
              RowBox[{
               RowBox[{"1", "/", 
                RowBox[{"(", 
                 RowBox[{"5", 
                  RowBox[{"Sqrt", "[", "5", "]"}]}], ")"}]}], "c7", "*", 
               "K0"}]}], "\[Equal]", "0"}], ",", "x"}], "]"}]}], ";"}], "  ", 
        "*)"}], "\[IndentingNewLine]", 
       RowBox[{"Sol", "=", 
        RowBox[{"x", "/.", "sol"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"som", "=", 
        RowBox[{"Sum", "[", 
         RowBox[{
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{"Re", "[", 
               RowBox[{"Sol", "[", 
                RowBox[{"[", "i", "]"}], "]"}], "]"}], ">", "0"}], "&&", 
             RowBox[{
              RowBox[{"Im", "[", 
               RowBox[{"Sol", "[", 
                RowBox[{"[", "i", "]"}], "]"}], "]"}], "\[Equal]", "0"}]}], 
            ",", 
            RowBox[{"Sol", "[", 
             RowBox[{"[", "i", "]"}], "]"}], ",", "0"}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", "1", ",", "8"}], "}"}]}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"s", "=", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"som", "\[Equal]", "0"}], ",", "1", ",", "som"}], "]"}]}], 
       ";"}]}], " ", "]"}]}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{
     RowBox[{
     "Generalized", " ", "Hamiltonian", " ", "matrix", " ", "definition", " ",
       "and", " ", 
      RowBox[{"diagonalization", ".", " ", "It"}], " ", "displays", " ", 
      "absolute"}], ",", " ", 
     RowBox[{"relative", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"lowest", " ", "0"}], "+", " ", 
        RowBox[{"set", " ", "to", " ", "zero"}]}], ")"}], " ", "in", " ", 
      "MeV", " ", "and", " ", "adimensional", " ", "reduced", " ", "energies",
       " ", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{
         "normalized", " ", "to", " ", "energy", " ", "of", " ", "the", " ", 
          "first", " ", "2"}], "+"}], ")"}], ".", " ", "\[IndentingNewLine]", 
       "The"}], " ", "number", " ", "of", " ", "lowest", " ", "eigenvalues", 
      " ", "shown", " ", "can", " ", "be", " ", "set", " ", "with", " ", 
      "eimax", " ", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"default", " ", "is", " ", "4"}], ")"}], "."}]}]}], " ", 
    "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"eimax", ":=", "4"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"eiv", "[", 
      RowBox[{"-", "1"}], "]"}], ":=", 
     RowBox[{"Table", "[", 
      RowBox[{"i", ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "1", ",", "eimax"}], "}"}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"Diago", ":=", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", "}"}], ",", "  ", 
      RowBox[{"(*", " ", 
       RowBox[{
        RowBox[{
        "This", " ", "module", " ", "has", " ", "no", " ", "explicit", " ", 
         "entries"}], ",", " ", 
        RowBox[{
        "but", " ", "needs", " ", "the", " ", "list", " ", "of", " ", 
         "coefficients", " ", "Cc", " ", "to", " ", "be", " ", "set"}]}], " ",
        "*)"}], "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"sfind", "[", 
        RowBox[{
         RowBox[{"Cc", "[", 
          RowBox[{"[", "1", "]"}], "]"}], ",", 
         RowBox[{"Cc", "[", 
          RowBox[{"[", "2", "]"}], "]"}], ",", 
         RowBox[{"Cc", "[", 
          RowBox[{"[", "4", "]"}], "]"}], ",", 
         RowBox[{"Cc", "[", 
          RowBox[{"[", "6", "]"}], "]"}], ",", 
         RowBox[{"Cc", "[", 
          RowBox[{"[", "7", "]"}], "]"}]}], "]"}], ";", "\[IndentingNewLine]", 
       RowBox[{"Print", "[", 
        RowBox[{"\"\<s=\>\"", ",", "s"}], "]"}], ";", " ", 
       RowBox[{"(*", " ", 
        RowBox[{"Rescaling", " ", "parameter"}], " ", "*)"}], 
       "\[IndentingNewLine]", 
       RowBox[{"Do", "[", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"Hgen", "[", "J", "]"}], "=", 
           RowBox[{
            RowBox[{
             RowBox[{"s", "^", "2"}], 
             RowBox[{"Cc", "[", 
              RowBox[{"[", "1", "]"}], "]"}], 
             RowBox[{"T", "[", "J", "]"}]}], "+", 
            RowBox[{
             RowBox[{"s", "^", 
              RowBox[{"(", 
               RowBox[{"-", "2"}], ")"}]}], 
             RowBox[{"1", "/", 
              RowBox[{"Sqrt", "[", "5", "]"}]}], 
             RowBox[{"Cc", "[", 
              RowBox[{"[", "2", "]"}], "]"}], 
             RowBox[{"Vb2", "[", "J", "]"}]}], "-", 
            RowBox[{
             RowBox[{"s", "^", 
              RowBox[{"(", 
               RowBox[{"-", "3"}], ")"}]}], 
             RowBox[{"Sqrt", "[", 
              RowBox[{"2", "/", "35"}], "]"}], 
             RowBox[{"Cc", "[", 
              RowBox[{"[", "3", "]"}], "]"}], 
             RowBox[{"Vb3c", "[", "J", "]"}]}], "+", 
            RowBox[{
             RowBox[{"s", "^", 
              RowBox[{"(", 
               RowBox[{"-", "4"}], ")"}]}], 
             RowBox[{"1", "/", "5"}], 
             RowBox[{"Cc", "[", 
              RowBox[{"[", "4", "]"}], "]"}], 
             RowBox[{"Vb4", "[", "J", "]"}]}], "-", 
            RowBox[{
             RowBox[{"s", "^", 
              RowBox[{"(", 
               RowBox[{"-", "5"}], ")"}]}], 
             RowBox[{"Sqrt", "[", 
              RowBox[{"2", "/", "175"}], "]"}], 
             RowBox[{"Cc", "[", 
              RowBox[{"[", "5", "]"}], "]"}], 
             RowBox[{"Vb5c", "[", "J", "]"}]}], "+", 
            RowBox[{
             RowBox[{"s", "^", 
              RowBox[{"(", 
               RowBox[{"-", "6"}], ")"}]}], 
             RowBox[{"2", "/", "35"}], 
             RowBox[{"Cc", "[", 
              RowBox[{"[", "6", "]"}], "]"}], 
             RowBox[{"Vb6c", "[", "J", "]"}]}], "+", 
            RowBox[{
             RowBox[{"s", "^", 
              RowBox[{"(", 
               RowBox[{"-", "6"}], ")"}]}], 
             RowBox[{"1", "/", 
              RowBox[{"(", 
               RowBox[{"5", 
                RowBox[{"Sqrt", "[", "5", "]"}]}], ")"}]}], 
             RowBox[{"Cc", "[", 
              RowBox[{"[", "7", "]"}], "]"}], 
             RowBox[{"Vb6", "[", "J", "]"}]}]}]}], ";", "\[IndentingNewLine]", 
          RowBox[{"(*", " ", 
           RowBox[{"Eigenvalues", " ", "calculation"}], " ", "*)"}], 
          "\[IndentingNewLine]", 
          RowBox[{"(*", 
           RowBox[{
            RowBox[{
             RowBox[{"alleiv", "[", "J", "]"}], "=", 
             RowBox[{"Sort", "[", 
              RowBox[{"Eigenvalues", "[", 
               RowBox[{"Hgen", "[", "J", "]"}], "]"}], "]"}]}], ";", 
            "\[IndentingNewLine]", 
            RowBox[{
             RowBox[{"eiv", "[", "J", "]"}], "=", 
             RowBox[{"If", "[", 
              RowBox[{
               RowBox[{"J", "\[Equal]", "0"}], ",", 
               RowBox[{
                RowBox[{"alleiv", "[", "0", "]"}], "[", 
                RowBox[{"[", 
                 RowBox[{"1", ";;", "eimax"}], "]"}], "]"}], ",", 
               RowBox[{"Select", "[", 
                RowBox[{
                 RowBox[{"alleiv", "[", "J", "]"}], ",", 
                 RowBox[{
                  RowBox[{"#", ">", 
                   RowBox[{
                    RowBox[{"eiv", "[", "0", "]"}], "[", 
                    RowBox[{"[", "1", "]"}], "]"}]}], "&"}], ",", "eimax"}], 
                "]"}]}], " ", "]"}]}], ";"}], "*)"}], "\[IndentingNewLine]", 
          "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"eiv", "[", "J", "]"}], "=", 
           RowBox[{
            RowBox[{"Sort", "[", 
             RowBox[{"Eigenvalues", "[", 
              RowBox[{"Hgen", "[", "J", "]"}], "]"}], "]"}], "[", 
            RowBox[{"[", 
             RowBox[{"1", ";;", "eimax"}], "]"}], "]"}]}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"releiv", "[", "J", "]"}], "=", 
           RowBox[{
            RowBox[{
             RowBox[{"eiv", "[", "J", "]"}], "[", 
             RowBox[{"[", 
              RowBox[{"1", ";;", "eimax"}], "]"}], "]"}], "-", 
            RowBox[{
             RowBox[{"eiv", "[", "0", "]"}], "[", 
             RowBox[{"[", "1", "]"}], "]"}]}]}], ";"}], "\[IndentingNewLine]",
          ",", 
         RowBox[{"{", 
          RowBox[{"J", ",", "Jlist"}], "}"}]}], "]"}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"Do", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"redeiv", "[", "J", "]"}], "=", 
          RowBox[{
           RowBox[{"releiv", "[", "J", "]"}], "/", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"eiv", "[", "2", "]"}], "[", 
              RowBox[{"[", "1", "]"}], "]"}], "-", 
             RowBox[{
              RowBox[{"eiv", "[", "0", "]"}], "[", 
              RowBox[{"[", "1", "]"}], "]"}]}], ")"}]}]}], ",", 
         RowBox[{"{", 
          RowBox[{"J", ",", "Jlist"}], "}"}]}], "]"}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"dspldata", ":=", 
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"Flatten", "[", 
           RowBox[{"{", 
            RowBox[{"J", ",", 
             RowBox[{
              RowBox[{"eiv", "[", "J", "]"}], "[", 
              RowBox[{"[", "]"}], "]"}], ",", 
             RowBox[{
              RowBox[{"releiv", "[", "J", "]"}], "[", 
              RowBox[{"[", "]"}], "]"}], ",", 
             RowBox[{
              RowBox[{"redeiv", "[", "J", "]"}], "[", 
              RowBox[{"[", "]"}], "]"}]}], "}"}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"J", ",", "Jlist"}], "}"}]}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"dsplname", ":=", 
        RowBox[{"Flatten", "[", 
         RowBox[{"{", 
          RowBox[{"\"\<J\>\"", ",", "\"\<Abs.En.(MeV)\>\"", ",", 
           RowBox[{"Table", "[", 
            RowBox[{"\"\<\>\"", ",", 
             RowBox[{"{", 
              RowBox[{"i", ",", "1", ",", 
               RowBox[{"eimax", "-", "1"}]}], "}"}]}], "]"}], ",", 
           "\"\<Rel.En.(MeV)\>\"", ",", " ", 
           RowBox[{"Table", "[", 
            RowBox[{"\"\<\>\"", ",", 
             RowBox[{"{", 
              RowBox[{"i", ",", "1", ",", 
               RowBox[{"eimax", "-", "1"}]}], "}"}]}], "]"}], ",", 
           "\"\<Red.En.(adim)\>\"", ",", " ", 
           RowBox[{"Table", "[", 
            RowBox[{"\"\<\>\"", ",", 
             RowBox[{"{", 
              RowBox[{"i", ",", "1", ",", 
               RowBox[{"eimax", "-", "1"}]}], "}"}]}], "]"}]}], "}"}], 
         "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"data", ":=", 
        RowBox[{"Prepend", "[", 
         RowBox[{"dspldata", ",", "dsplname"}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"Grid", "[", 
        RowBox[{"data", ",", 
         RowBox[{"Spacings", "\[Rule]", "2"}], ",", 
         RowBox[{"Dividers", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"Flatten", "[", 
             RowBox[{"{", 
              RowBox[{"False", ",", "True", ",", 
               RowBox[{"Table", "[", 
                RowBox[{"False", ",", 
                 RowBox[{"{", 
                  RowBox[{"i", ",", "1", ",", 
                   RowBox[{"eimax", "-", "1"}]}], "}"}]}], "]"}], ",", "True",
                ",", 
               RowBox[{"Table", "[", 
                RowBox[{"False", ",", 
                 RowBox[{"{", 
                  RowBox[{"i", ",", "1", ",", 
                   RowBox[{"eimax", "-", "1"}]}], "}"}]}], "]"}], ",", "True",
                ",", 
               RowBox[{"Table", "[", 
                RowBox[{"False", ",", 
                 RowBox[{"{", 
                  RowBox[{"i", ",", "1", ",", 
                   RowBox[{"eimax", "-", "1"}]}], "}"}]}], "]"}], ",", 
               "True"}], "}"}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"False", ",", "True"}], "}"}]}], "}"}]}]}], "]"}]}]}], 
     "]"}]}]}]}]], "Input",
 CellChangeTimes->{{3.5766478662418385`*^9, 3.576647880344263*^9}, {
   3.576647935037959*^9, 3.5766480814130163`*^9}, {3.57664813499911*^9, 
   3.5766481670151687`*^9}, {3.5766482016160297`*^9, 3.5766482020528297`*^9}, 
   3.576648358552305*^9, {3.576649183775755*^9, 3.5766492102490015`*^9}, {
   3.5766501062173758`*^9, 3.5766502326555977`*^9}, {3.5766503009369173`*^9, 
   3.57665030229412*^9}, {3.5766504873104453`*^9, 3.5766504914756527`*^9}, {
   3.576650623881485*^9, 3.576650728557669*^9}, {3.579337412881236*^9, 
   3.5793374344112663`*^9}, {3.5793374894013433`*^9, 
   3.5793376206115274`*^9}, {3.579338126685237*^9, 3.579338222385371*^9}, {
   3.5793382648794355`*^9, 3.5793382991094832`*^9}, {3.5793401708101163`*^9, 
   3.579340181390131*^9}, {3.579341562579072*^9, 3.5793415694890814`*^9}, {
   3.579342031199728*^9, 3.579342150079894*^9}, {3.5793424827623615`*^9, 
   3.5793425097623987`*^9}, 3.579435480471444*^9, 3.5794355126414895`*^9, {
   3.579438249649983*^9, 3.5794382509499846`*^9}, {3.579581439856596*^9, 
   3.5795814460666046`*^9}, {3.583233961915778*^9, 3.583233968015787*^9}, {
   3.5842528835373516`*^9, 3.5842528864701567`*^9}, {3.5842529475754642`*^9, 
   3.5842529486050653`*^9}, {3.5842644076680737`*^9, 
   3.5842644185724926`*^9}, {3.5866633996584024`*^9, 
   3.5866634991553774`*^9}, {3.5866635778419156`*^9, 
   3.5866635885747347`*^9}, {3.5866636874633083`*^9, 
   3.5866638863792577`*^9}, {3.586663933881341*^9, 3.5866639848778305`*^9}, {
   3.586664051240347*^9, 3.586664054609953*^9}, {3.586664133141491*^9, 
   3.586664140005503*^9}, {3.5871198465261755`*^9, 3.5871199040862565`*^9}, {
   3.587119945026314*^9, 3.5871200095364037`*^9}, {3.5871202400637302`*^9, 
   3.587120242553734*^9}, {3.5871204303539968`*^9, 3.587120468994051*^9}, {
   3.5871205158641167`*^9, 3.5871205200941224`*^9}, {3.587120652764308*^9, 
   3.5871207594944572`*^9}, {3.587120812054531*^9, 3.587120867684609*^9}, {
   3.5871209073446646`*^9, 3.5871209350567045`*^9}, 3.5871209674867496`*^9, {
   3.5871210278868346`*^9, 3.5871210806269083`*^9}, {3.5905596065334635`*^9, 
   3.590559639995522*^9}, {3.6903526888427896`*^9, 3.690352832572991*^9}, {
   3.6903529581131663`*^9, 3.6903530372932777`*^9}, {3.690353135773415*^9, 
   3.6903531875034876`*^9}, {3.6903533148136663`*^9, 3.690353316883669*^9}, {
   3.690783340873699*^9, 3.690783354923503*^9}}],

Cell[CellGroupData[{

Cell["\<\
2 - Example of calculations: several examples are given to show how to run \
typical calculations\
\>", "Subtitle",
 CellFrame->{{0, 0}, {0, 3}},
 CellChangeTimes->{{3.5842531546658278`*^9, 3.584253198216704*^9}, {
  3.5866634503428917`*^9, 3.586663488141758*^9}, {3.5866637845734787`*^9, 
  3.5866637850570793`*^9}, {3.586663834275166*^9, 3.5866638350707674`*^9}, {
  3.587113915488981*^9, 3.5871139164873824`*^9}, {3.587119275225376*^9, 
  3.5871193006054115`*^9}, {3.587119977286359*^9, 3.5871199788463607`*^9}, {
  3.5871201663766236`*^9, 3.587120167466625*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "Conversion", " ", "between", " ", "the", " ", "tabulated", " ", "values", 
    " ", "of", " ", "the", " ", "parameter", " ", "B2", " ", "of", " ", 
    RowBox[{"Ref", ".", 
     RowBox[{"[", "7", "]"}]}], " ", "and", " ", "the", " ", "coefficient", 
    " ", "C1", " ", 
    RowBox[{"(", 
     RowBox[{
     "that", " ", "multiplies", " ", "the", " ", "kinetic", " ", "energy", 
      " ", "term"}], ")"}], " ", "used", " ", "in", " ", "the", " ", 
    "following", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"with", " ", "different", " ", "name"}], " ", "\[Rule]", " ", 
      RowBox[{"Cc", "[", 
       RowBox[{"[", "1", "]"}], "]"}]}], " ", ")"}]}], "  ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"hcd", "=", 
     RowBox[{"197.3269602", "/", 
      RowBox[{"(", 
       RowBox[{"2.99792458", "*", 
        RowBox[{"10", "^", "23"}]}], ")"}]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"B2", "=", 
     RowBox[{
      RowBox[{"+", "81.55"}], "*", " ", 
      RowBox[{"10", "^", 
       RowBox[{"(", 
        RowBox[{"-", "42"}], ")"}]}], " ", "example", " ", "for", " ", "130", 
      "Ba"}]}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{"B2", "=", 
    RowBox[{"74.36", "*", " ", 
     RowBox[{"10", "^", 
      RowBox[{"(", 
       RowBox[{"-", "42"}], ")"}]}]}]}], "  ", 
   RowBox[{"(*", " ", 
    RowBox[{"example", " ", "for", " ", "132", "Ba"}], " ", "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{"C1", "=", 
    RowBox[{"5", 
     RowBox[{
      RowBox[{
       RowBox[{"hcd", "^", "2"}], "/", 
       RowBox[{"(", 
        RowBox[{"4", "*", "B2"}], ")"}]}], "/", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"Sqrt", "[", "5", "]"}], "/", "2."}], 
       ")"}]}]}]}]}]}]], "Input",
 CellChangeTimes->{{3.5842646487508974`*^9, 3.5842646953325787`*^9}, {
  3.584264818806796*^9, 3.5842648642496758`*^9}, {3.5842650105667334`*^9, 
  3.584265134477751*^9}, {3.5842652003566666`*^9, 3.5842652007778673`*^9}, {
  3.584335277226163*^9, 3.5843354019327817`*^9}, {3.5866645180253673`*^9, 
  3.586664565792651*^9}, {3.651280776300228*^9, 3.651280825448039*^9}}],

Cell[BoxData["7.435999999999999`*^-41"], "Output",
 CellChangeTimes->{{3.5842651011404924`*^9, 3.5842651347429514`*^9}, 
   3.5843352662749434`*^9, {3.5843353607487097`*^9, 3.5843354030715837`*^9}, 
   3.5847845307801757`*^9, 3.584784561371829*^9, 3.586584383889912*^9, 
   3.58666301084332*^9, 3.586663415820031*^9, {3.586663452058895*^9, 
   3.58666348909336*^9}, {3.586663698040127*^9, 3.5866637205509663`*^9}, {
   3.5866637860866814`*^9, 3.5866638362251697`*^9}, 3.5866638896084633`*^9, 
   3.586663997669853*^9, 3.5866640565443563`*^9, 3.5866641419711065`*^9, {
   3.5866645429698105`*^9, 3.5866645667442527`*^9}, 3.586843530372237*^9, 
   3.587113747938286*^9, 3.587113806687989*^9, 3.5871139175481844`*^9, 
   3.587116612438121*^9, 3.587117105555987*^9, 3.587119303755416*^9, 
   3.587119869056207*^9, 3.587119907516261*^9, {3.5871199483163185`*^9, 
   3.5871199977063875`*^9}, {3.587120168576627*^9, 3.5871201928536644`*^9}, 
   3.58712103167684*^9, 3.587121082496911*^9, 3.5871831718280497`*^9, 
   3.5871832032933044`*^9, 3.590559175985506*^9, {3.59055962158749*^9, 
   3.590559641805125*^9}, 3.5977318372409143`*^9, 3.6305138652033696`*^9, 
   3.651280769623846*^9, 3.651280826673109*^9, 3.679890178208706*^9, 
   3.6900026465973983`*^9, 3.69002582819831*^9, 3.6901154946954994`*^9, 
   3.69026398405713*^9, 3.6902929790550942`*^9, 3.6903526329124584`*^9, 
   3.6903540239446588`*^9, 3.6903658388816986`*^9, 3.690441293729724*^9, 
   3.690474804376075*^9, 3.69077911267686*^9, 3.6957249284782543`*^9, 
   3.7057239962700195`*^9, 3.728491834525282*^9, 3.7285433705605373`*^9, 
   3.7414318834799957`*^9}],

Cell[BoxData["0.006513989750824118`"], "Output",
 CellChangeTimes->{{3.5842651011404924`*^9, 3.5842651347429514`*^9}, 
   3.5843352662749434`*^9, {3.5843353607487097`*^9, 3.5843354030715837`*^9}, 
   3.5847845307801757`*^9, 3.584784561371829*^9, 3.586584383889912*^9, 
   3.58666301084332*^9, 3.586663415820031*^9, {3.586663452058895*^9, 
   3.58666348909336*^9}, {3.586663698040127*^9, 3.5866637205509663`*^9}, {
   3.5866637860866814`*^9, 3.5866638362251697`*^9}, 3.5866638896084633`*^9, 
   3.586663997669853*^9, 3.5866640565443563`*^9, 3.5866641419711065`*^9, {
   3.5866645429698105`*^9, 3.5866645667442527`*^9}, 3.586843530372237*^9, 
   3.587113747938286*^9, 3.587113806687989*^9, 3.5871139175481844`*^9, 
   3.587116612438121*^9, 3.587117105555987*^9, 3.587119303755416*^9, 
   3.587119869056207*^9, 3.587119907516261*^9, {3.5871199483163185`*^9, 
   3.5871199977063875`*^9}, {3.587120168576627*^9, 3.5871201928536644`*^9}, 
   3.58712103167684*^9, 3.587121082496911*^9, 3.5871831718280497`*^9, 
   3.5871832032933044`*^9, 3.590559175985506*^9, {3.59055962158749*^9, 
   3.590559641805125*^9}, 3.5977318372409143`*^9, 3.6305138652033696`*^9, 
   3.651280769623846*^9, 3.651280826673109*^9, 3.679890178208706*^9, 
   3.6900026465973983`*^9, 3.69002582819831*^9, 3.6901154946954994`*^9, 
   3.69026398405713*^9, 3.6902929790550942`*^9, 3.6903526329124584`*^9, 
   3.6903540239446588`*^9, 3.6903658388816986`*^9, 3.690441293729724*^9, 
   3.690474804376075*^9, 3.69077911267686*^9, 3.6957249284782543`*^9, 
   3.7057239962700195`*^9, 3.728491834525282*^9, 3.7285433705605373`*^9, 
   3.7414318834799957`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
    "One", " ", "must", " ", "give", " ", "the", " ", "energies", " ", "of", 
     " ", "a", " ", "few", " ", "selected", " ", "states", " ", "and", " ", 
     "the", " ", "coefficients", " ", "of", " ", "the", " ", "generalized"}], 
    ",", " ", 
    RowBox[{"scaled", " ", 
     RowBox[{"hamiltonian", ".", " ", "One"}], " ", "can", " ", "assign", " ",
      "the", " ", "values", " ", "of", " ", "the", " ", "Cc", " ", "array", 
     " ", "by", " ", "hand", " ", "or", " ", "make", " ", "use", " ", "of", 
     " ", "a", " ", 
     RowBox[{"database", "."}]}]}], " ", "*)"}], " ", "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
    "In", " ", "our", " ", "case", " ", "we", " ", "load", " ", "the", " ", 
     "database", " ", "habs", " ", "corresponding", " ", "to", " ", "table", 
     " ", "1", " ", "of", " ", 
     RowBox[{"Ref", ".", 
      RowBox[{"[", "7", "]"}]}]}], " ", "-", " ", 
    RowBox[{
    "with", " ", "the", " ", "exception", " ", "that", " ", "the", " ", 
     "Mass", " ", "parameters", " ", "are", " ", "converted", " ", "as", " ", 
     "in", " ", "the", " ", "previous", " ", 
     RowBox[{"cell", "."}]}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{
   "The", " ", "assignment", " ", "is", " ", "done", " ", "as", " ", "in", 
    " ", "the", " ", 
    RowBox[{"example", ".", " ", "The"}], " ", "user", " ", "might", " ", 
    "generate", " ", "new", " ", "databases", " ", "and", " ", "proceed", " ",
     "in", " ", "a", " ", "similar", " ", 
    RowBox[{"fashion", "."}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"NotebookEvaluate", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"NotebookDirectory", "[", "]"}], "<>", 
       "\"\<data-sets.nb\>\""}], ",", 
      RowBox[{"InsertResults", "\[Rule]", "True"}]}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"NotebookEvaluate", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"NotebookDirectory", "[", "]"}], "<>", 
       "\"\<coeff-habs.nb\>\""}], ",", 
      RowBox[{"InsertResults", "\[Rule]", "True"}]}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"NotebookEvaluate", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"NotebookDirectory", "[", "]"}], "<>", 
       "\"\<coeff-fortunato.nb\>\""}], ",", 
      RowBox[{"InsertResults", "\[Rule]", "True"}]}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"Cc", "=", 
    RowBox[{"habs", "[", 
     RowBox[{"128", ",", "\"\<Xe\>\""}], "]"}]}], "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"Cc", "=", 
     RowBox[{"fort", "[", 
      RowBox[{"180", ",", "\"\<Pt\>\""}], "]"}]}], " ", "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{
    "Uncomment", " ", "previous", " ", "line", " ", "to", " ", "check", " ", 
     "the", " ", "180", "Pt", " ", "case", " ", "discussed", " ", "in", " ", 
     "the", " ", "accompaining", " ", "paper"}], " ", "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"Use", " ", 
     RowBox[{"habs", "[", "]"}], "  ", "or", " ", 
     RowBox[{"fort", "[", "]"}], " ", "to", " ", "run", " ", "a", " ", "case",
      " ", "from", " ", "one", " ", "database", " ", "or", " ", "another"}], 
    " ", "*)"}]}]}]], "Input",
 CellChangeTimes->{
  3.5766476932999344`*^9, {3.5766477984441195`*^9, 3.5766478010181236`*^9}, {
   3.5766504456895723`*^9, 3.5766504643472047`*^9}, {3.5766505939522324`*^9, 
   3.576650610129461*^9}, {3.5792607161098804`*^9, 3.5792607188398848`*^9}, {
   3.5793294400828495`*^9, 3.5793294413028517`*^9}, {3.5793375824614735`*^9, 
   3.579337589091483*^9}, {3.5842529848751297`*^9, 3.5842529849843297`*^9}, {
   3.584265145616171*^9, 3.584265151419381*^9}, {3.5866630220129395`*^9, 
   3.5866630248365445`*^9}, {3.5866642974253798`*^9, 
   3.5866643360198474`*^9}, {3.5866643918523455`*^9, 3.58666445130405*^9}, {
   3.586664498712533*^9, 3.5866645096793523`*^9}, {3.58666458811629*^9, 
   3.5866645887870913`*^9}, {3.5871193130854287`*^9, 
   3.5871195430857506`*^9}, {3.5871197550960474`*^9, 
   3.5871197582660522`*^9}, {3.5871210112268114`*^9, 
   3.5871210142468157`*^9}, {3.587121131116979*^9, 3.5871211377669888`*^9}, {
   3.587121508118507*^9, 3.587121512078512*^9}, {3.587183585509576*^9, 
   3.5871836348836627`*^9}, {3.5871837959539456`*^9, 3.587183797248748*^9}, {
   3.587183906214939*^9, 3.5871839216277666`*^9}, {3.587183994854295*^9, 
   3.587183999534303*^9}, {3.5871840312179585`*^9, 3.587184031327159*^9}, {
   3.5871840857712545`*^9, 3.587184086769656*^9}, {3.5871841462213607`*^9, 
   3.5871841493257666`*^9}, {3.587184284000803*^9, 3.5871842842504034`*^9}, {
   3.587184320770067*^9, 3.587184321752869*^9}, {3.587184490841566*^9, 
   3.587184493571571*^9}, {3.587184523632824*^9, 3.587184523773224*^9}, {
   3.5871845680929017`*^9, 3.5871845689977036`*^9}, {3.587184860562216*^9, 
   3.587184860718216*^9}, {3.587185000198061*^9, 3.587185001586463*^9}, {
   3.587185133671895*^9, 3.587185134685897*^9}, {3.587185178553174*^9, 
   3.5871851809867783`*^9}, {3.5871852534021053`*^9, 
   3.5871852579729137`*^9}, {3.5871853143826127`*^9, 3.587185314569813*^9}, {
   3.5871853748951187`*^9, 3.58718537542552*^9}, {3.5871854133803864`*^9, 
   3.5871854134739866`*^9}, {3.587185445454043*^9, 3.5871854457816434`*^9}, {
   3.587185631406369*^9, 3.5871856341675744`*^9}, {3.6305138935434093`*^9, 
   3.630513902423422*^9}, {3.6305139948335514`*^9, 3.6305139950435514`*^9}, {
   3.6512810189421062`*^9, 3.6512810621795793`*^9}, {3.690264182460458*^9, 
   3.6902641874504642`*^9}, {3.6902929969651194`*^9, 
   3.6902930109901886`*^9}, {3.690441258659675*^9, 3.6904412594596763`*^9}, {
   3.690444150405198*^9, 3.6904441587452097`*^9}, {3.6904441889152527`*^9, 
   3.6904441955352616`*^9}, {3.690444863252371*^9, 3.6904448664523754`*^9}, {
   3.7414319868508806`*^9, 3.7414320675797195`*^9}, {3.741432506155076*^9, 
   3.741432555295162*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0.005928622`", ",", "491.8`", ",", "1503", ",", 
   RowBox[{"-", "73970"}], ",", 
   RowBox[{"-", "32760"}], ",", "4168000", ",", "2073000"}], "}"}]], "Output",
 CellChangeTimes->{
  3.5871195407257476`*^9, 3.5871197585760527`*^9, 3.5871198700062084`*^9, 
   3.5871199084462624`*^9, {3.5871199497363205`*^9, 3.5871199807063637`*^9}, {
   3.587120170306629*^9, 3.5871201938136654`*^9}, {3.5871210145668163`*^9, 
   3.587121032556841*^9}, 3.5871210837369127`*^9, {3.5871211339169827`*^9, 
   3.5871211380469885`*^9}, 3.587121512558513*^9, 3.587183173887253*^9, 
   3.5871832043853064`*^9, {3.587183590423585*^9, 3.5871836352892637`*^9}, 
   3.587183768076697*^9, 3.58718379813795*^9, {3.587183907041741*^9, 
   3.5871839250441723`*^9}, 3.587183999924304*^9, 3.5871840321383605`*^9, 
   3.587184087268857*^9, {3.587184143038955*^9, 3.5871841504957685`*^9}, 
   3.587184285108405*^9, 3.5871843226108704`*^9, 3.5871844239642487`*^9, 
   3.587184455866305*^9, 3.5871844939927716`*^9, 3.587184524943226*^9, 
   3.587184569855705*^9, 3.5871848614826174`*^9, 3.587185002070064*^9, 
   3.5871851350758977`*^9, 3.587185181376779*^9, 3.5871852589245152`*^9, 
   3.5871853155370145`*^9, 3.58718537579992*^9, 3.5871854144411883`*^9, 
   3.587185446624045*^9, 3.587185634697975*^9, 3.590559177529909*^9, {
   3.590559623178693*^9, 3.5905596428503275`*^9}, 3.5977318388809166`*^9, {
   3.6305138685633745`*^9, 3.6305139028034225`*^9}, 3.651280830035301*^9, {
   3.6512810196991496`*^9, 3.651281062526599*^9}, 3.679890187045211*^9, 
   3.69000265099565*^9, 3.6900258318055162`*^9, 3.690263992437142*^9, 
   3.6902641961104765`*^9, {3.690292982125098*^9, 3.690293011449215*^9}, 
   3.6902933761129007`*^9, 3.690307108373127*^9, 3.6903526366624637`*^9, 
   3.6903534240738187`*^9, 3.6903540262146616`*^9, 3.6903658403837843`*^9, 
   3.6904412954097266`*^9, 3.6904748070860786`*^9, 3.690474848996137*^9, 
   3.6904748864661894`*^9, {3.6904749549562855`*^9, 3.6904750012963505`*^9}, 
   3.690475078786459*^9, 3.6904751476265554`*^9, 3.6904751805566015`*^9, 
   3.6904752280966682`*^9, 3.6904754149669294`*^9, 3.6905478964279366`*^9, 
   3.6905480417192464`*^9, 3.690548122536869*^9, 3.69054816626537*^9, 
   3.690779114678974*^9, 3.690779989194994*^9, 3.6957249298363323`*^9, 
   3.6957254376083746`*^9, 3.6957254784887133`*^9, 3.7057239987871633`*^9, 
   3.705724161877492*^9, 3.705740191738347*^9, 3.7284918375252867`*^9, 
   3.7285433743605423`*^9, 3.741431885849825*^9, {3.741431991010333*^9, 
   3.741432027546392*^9}, 3.741432068675933*^9, 3.7414325560595636`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
    "Here", " ", "we", " ", "run", " ", "the", " ", "diagonalization", " ", 
     "module", " ", "that", " ", "shows", " ", "the", " ", "outcome", " ", 
     "of", " ", "diagonalization", " ", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
       "and", " ", "also", " ", "the", " ", "scaling", " ", "factor"}], ")"}],
       ".", " ", "The"}], " ", "spectrum", " ", "is", " ", "given", " ", 
     "for", " ", "each", " ", "value", " ", "of", " ", "J", " ", 
     RowBox[{"(", 
      RowBox[{"only", " ", "first", " ", "four", " ", "states"}], ")"}], " ", 
     "in", " ", "absolute", " ", "energies"}], ",", " ", 
    RowBox[{"in", " ", "relative", " ", "energies"}], ",", " ", 
    RowBox[{
     RowBox[{"i", ".", "e", ".", " ", "having"}], " ", "subtracted", " ", 
     "the", " ", 
     RowBox[{"g", ".", "s", ".", " ", "energy"}], " ", "and", " ", "in", " ", 
     "reduced", " ", "energies"}], ",", " ", 
    RowBox[{
     RowBox[{
      RowBox[{"i", ".", "e", ".", " ", "normalized"}], " ", "to", " ", "the", 
      " ", "energy", " ", "of", " ", "the", " ", "first", " ", "2"}], "+"}]}],
    " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
    "Comparing", " ", "our", " ", "results", " ", "with", " ", "Table", " ", 
     "2", " ", "of", " ", 
     RowBox[{"Ref", ".", 
      RowBox[{"[", "7", "]"}]}], " ", "gives", " ", "practically", " ", "the",
      " ", "same", " ", "numbers", " ", "except", " ", "for", " ", "a", " ", 
     "few", " ", "cases"}], ",", " ", 
    RowBox[{
    "where", " ", "the", " ", "differences", " ", "are", " ", "of", " ", 
     "the", " ", "order", " ", "of", " ", "1", "%"}]}], " ", "*)"}], 
  "\[IndentingNewLine]", "Diago"}]], "Input",
 CellChangeTimes->{{3.5842065059130726`*^9, 3.5842065061470733`*^9}, {
   3.584252998727954*^9, 3.5842529990555544`*^9}, {3.5843379798178215`*^9, 
   3.584337983156227*^9}, {3.584785293329116*^9, 3.584785298258724*^9}, {
   3.5866630327613583`*^9, 3.5866632106952705`*^9}, {3.5866632663405685`*^9, 
   3.5866633276018763`*^9}, {3.587119563455779*^9, 3.5871197321860156`*^9}, {
   3.5871198093461237`*^9, 3.5871198170761347`*^9}, {3.5871200382864437`*^9, 
   3.587120159706614*^9}, 3.6903526503824825`*^9, {3.690352895403079*^9, 
   3.6903529245131197`*^9}}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"s=\"\>", "\[InvisibleSpace]", "27.698088346081207`"}],
  SequenceForm["s=", 27.698088346081207`],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.587183205945309*^9, {3.5871835922019877`*^9, 3.5871836366776657`*^9}, {
   3.5871837695430994`*^9, 3.587183799541952*^9}, 3.587183926494975*^9, 
   3.5871840019211073`*^9, 3.587184033245962*^9, 3.5871840889224606`*^9, 
   3.5871841556281776`*^9, 3.587184286278407*^9, 3.5871843241864734`*^9, {
   3.5871843902057896`*^9, 3.5871844614667144`*^9}, 3.5871844961455755`*^9, 
   3.5871845270336294`*^9, 3.5871845705889063`*^9, 3.587184862746219*^9, 
   3.5871850041604676`*^9, 3.587185137244302*^9, 3.587185183623183*^9, 
   3.587185260780918*^9, 3.5871853171594176`*^9, 3.5871853775939236`*^9, 
   3.587185416422392*^9, 3.587185448199648*^9, 3.587185636382778*^9, 
   3.590559179869913*^9, {3.590559624364295*^9, 3.5905596438175287`*^9}, 
   3.59773184107092*^9, 3.630513870963378*^9, 3.6305139085834303`*^9, 
   3.651280831725398*^9, 3.6512810637006664`*^9, 3.679890198638874*^9, {
   3.6902929882751074`*^9, 3.6902930139433575`*^9}, 3.690307119137742*^9, 
   3.6903526417624707`*^9, 3.6903527828429213`*^9, {3.6903528222629766`*^9, 
   3.6903528390629997`*^9}, 3.690352963293174*^9, {3.690352995773219*^9, 
   3.690353042143284*^9}, 3.6903533232436776`*^9, 3.6903534375438375`*^9, 
   3.6903540291446657`*^9, 3.6903658417298613`*^9, 3.69044130488974*^9, 
   3.6904748141860886`*^9, 3.6957249328095016`*^9, 3.7057241650636735`*^9, 
   3.7284918804853463`*^9, 3.7414318897364736`*^9, 3.7414320723459787`*^9, 
   3.741432558056367*^9}],

Cell[BoxData[
 TagBox[GridBox[{
    {"\<\"J\"\>", "\<\"Abs.En.(MeV)\"\>", "\<\"\"\>", "\<\"\"\>", "\<\"\"\>", \
"\<\"Rel.En.(MeV)\"\>", "\<\"\"\>", "\<\"\"\>", "\<\"\"\>", \
"\<\"Red.En.(adim)\"\>", "\<\"\"\>", "\<\"\"\>", "\<\"\"\>"},
    {"0", "1.207293677089927`", "3.128400193292096`", "5.307487053068339`", 
     "5.735418627136625`", "0.`", "1.9211065162021692`", "4.100193375978412`",
      "4.528124950046698`", "0.`", "4.333633972953252`", "9.249220259241483`",
      "10.214548725852403`"},
    {"2", "1.6505951945212638`", "2.173334881000233`", "4.086960976975689`", 
     "5.040461583078063`", "0.44330151743133683`", "0.9660412039103059`", 
     "2.879667299885762`", "3.8331679059881356`", "1.`", 
     "2.1791967000427346`", "6.495956333674845`", "8.646863940820724`"},
    {"3", "2.5573551775194137`", "6.107676971481905`", "8.494100097645331`", 
     "9.799896992174004`", "1.3500615004294867`", "4.900383294391978`", 
     "7.286806420555404`", "8.592603315084077`", "3.045470063473443`", 
     "11.054289465975042`", "16.437585106358362`", "19.38320302820752`"},
    {"4", "2.2443928488899973`", "3.1938449621050093`", "3.631598556577964`", 
     "5.130503836868265`", "1.0370991718000704`", "1.9865512850150824`", 
     "2.4243048794880373`", "3.923210159778338`", "2.3394893340528826`", 
     "4.481264346952704`", "5.468749336874398`", "8.849981345678579`"},
    {"5", "3.406932894374647`", "4.331029488324793`", "7.300928561381671`", 
     "8.506488906485158`", "2.1996392172847203`", "3.123735811234866`", 
     "6.093634884291744`", "7.299195229395231`", "4.96194831461506`", 
     "7.046526322163341`", "13.746027578702321`", "16.465531793551342`"},
    {"6", "2.967715321817333`", "4.312512048578842`", "5.101726502327261`", 
     "5.575451426903985`", "1.760421644727406`", "3.105218371488915`", 
     "3.8944328252373337`", "4.368157749814058`", "3.9711608814875725`", 
     "7.004754663331113`", "8.785065406054118`", "9.85369455788214`"},
    {"7", "4.378684584229153`", "5.657780722764982`", "6.5314429394575235`", 
     "8.602837565925315`", "3.1713909071392257`", "4.450487045675055`", 
     "5.324149262367596`", "7.3955438888353875`", "7.1540267344797535`", 
     "10.039413064640351`", "12.010221154255932`", "16.68287519449082`"},
    {"8", "3.8121505072227535`", "5.503808702942363`", "6.754123449056053`", 
     "7.342165110852734`", "2.6048568301328263`", "4.296515025852436`", 
     "5.5468297719661255`", "6.1348714337628065`", "5.876038605115522`", 
     "9.692082830548681`", "12.512544067312554`", "13.839049027647508`"}
   },
   AutoDelete->False,
   GridBoxDividers->{
    "Columns" -> {
      False, True, False, False, False, True, False, False, False, True, 
       False, False, False, True}, "Rows" -> {False, True}},
   GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
   GridBoxSpacings->{"Columns" -> {{2}}}],
  "Grid"]], "Output",
 CellChangeTimes->{
  3.5871196277758694`*^9, 3.5871197071259804`*^9, 3.5871197599860544`*^9, {
   3.587119854656187*^9, 3.5871198712562103`*^9}, 3.5871199098662643`*^9, {
   3.587119951176322*^9, 3.5871199818663654`*^9}, {3.5871200203164186`*^9, 
   3.587120195423668*^9}, 3.5871207501144447`*^9, 3.5871208851746335`*^9, {
   3.587120920276684*^9, 3.5871209405367126`*^9}, 3.587120972346757*^9, {
   3.5871210232168283`*^9, 3.5871210334768424`*^9}, 3.5871210853969154`*^9, 
   3.5871211399269915`*^9, 3.587121514078515*^9, {3.5871831767108583`*^9, 
   3.5871832062261095`*^9}, {3.5871835925139885`*^9, 
   3.5871836369584665`*^9}, {3.5871837698394995`*^9, 3.5871837998227525`*^9}, 
   3.5871839268225756`*^9, 3.587184002248708*^9, 3.587184033557963*^9, 
   3.587184089234461*^9, 3.5871841559245777`*^9, 3.587184286574807*^9, 
   3.587184324498474*^9, {3.58718439050219*^9, 3.587184461778715*^9}, 
   3.587184496457576*^9, 3.5871845273300304`*^9, 3.587184570916507*^9, 
   3.58718486305822*^9, 3.587185004456868*^9, 3.5871851376031017`*^9, 
   3.5871851839351835`*^9, 3.587185261077319*^9, 3.587185317471418*^9, 
   3.587185377905924*^9, 3.5871854166875925`*^9, 3.587185448542848*^9, 
   3.5871856367103786`*^9, 3.590559181008715*^9, {3.5905596248010955`*^9, 
   3.5905596441607294`*^9}, 3.5977318416309204`*^9, 3.6305138713633785`*^9, 
   3.6305139088734307`*^9, 3.651280831991413*^9, 3.6512810640026836`*^9, 
   3.6798901990168953`*^9, {3.6902929890251083`*^9, 3.690293014195372*^9}, 
   3.690307119387757*^9, 3.690352642652472*^9, 3.6903527830829215`*^9, {
   3.6903528225129766`*^9, 3.690352839313*^9}, 3.690352963553174*^9, {
   3.6903529960232196`*^9, 3.690353042403284*^9}, 3.690353323493678*^9, 
   3.690353437773838*^9, 3.690354029374666*^9, 3.6903658419538746`*^9, 
   3.69044130514974*^9, 3.690474814456089*^9, 3.6957249331505213`*^9, 
   3.7057241654206944`*^9, 3.7284918813553476`*^9, 3.7414318902722797`*^9, 
   3.7414320725927815`*^9, 3.7414325583371677`*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
    "Module", " ", "that", " ", "calculates", " ", "unnormalized", " ", 
     "wavefunctions"}], ",", " ", 
    RowBox[{
    "their", " ", "norm", " ", "and", " ", "normalized", " ", 
     "wavefunctions"}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Clear", "[", "\[Psi]", "]"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"F", "[", 
     RowBox[{"n_", ",", "l_", ",", "\[Beta]_"}], "]"}], ":=", 
    RowBox[{
     RowBox[{"Sqrt", "[", 
      RowBox[{"2", "*", 
       RowBox[{
        RowBox[{"n", "!"}], "/", 
        RowBox[{"Gamma", "[", 
         RowBox[{"n", "+", "l", "+", 
          RowBox[{"5", "/", "2"}]}], "]"}]}]}], "]"}], "*", 
     RowBox[{"\[Beta]", "^", "l"}], "*", 
     RowBox[{"LaguerreL", "[", 
      RowBox[{"n", ",", 
       RowBox[{"l", "+", 
        RowBox[{"3", "/", "2"}]}], ",", 
       RowBox[{"\[Beta]", "^", "2"}]}], "]"}], "*", 
     RowBox[{"Exp", "[", 
      RowBox[{
       RowBox[{"-", 
        RowBox[{"\[Beta]", "^", "2"}]}], "/", "2"}], "]"}]}]}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"u\[Psi]", "[", 
     RowBox[{"J_", ",", "Nst2_", ",", "\[Beta]_"}], "]"}], ":=", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Jtry", "=", "J"}], ",", 
        RowBox[{"whiche", "=", "Nst2"}]}], "}"}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"cev", "=", 
        RowBox[{
         RowBox[{"Eigensystem", "[", 
          RowBox[{"Hgen", "[", "Jtry", "]"}], "]"}], "[", 
         RowBox[{"[", 
          RowBox[{"2", ",", "whiche"}], "]"}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"Sum", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"cev", "[", 
           RowBox[{"[", "k", "]"}], "]"}], "*", 
          RowBox[{"F", "[", 
           RowBox[{
            RowBox[{"NNN", "[", 
             RowBox[{"[", "k", "]"}], "]"}], ",", 
            RowBox[{"lll", "[", 
             RowBox[{"[", "k", "]"}], "]"}], ",", "\[Beta]"}], "]"}]}], ",", 
         RowBox[{"{", 
          RowBox[{"k", ",", "1", ",", "whiche"}], "}"}]}], "]"}]}]}], 
     "\[IndentingNewLine]", "]"}]}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Nrml", "[", 
     RowBox[{"J_", ",", "Nst2_"}], "]"}], ":=", 
    RowBox[{"1", "/", 
     RowBox[{"Sqrt", "[", 
      RowBox[{"NIntegrate", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"\[Beta]", "^", "4"}], "*", 
         RowBox[{
          RowBox[{"u\[Psi]", "[", 
           RowBox[{"J", ",", "Nst2", ",", "\[Beta]"}], "]"}], "^", "2"}]}], 
        ",", 
        RowBox[{"{", 
         RowBox[{"\[Beta]", ",", "0", ",", "10."}], "}"}]}], "]"}], "]"}]}]}],
    "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"\[Psi]", "[", 
     RowBox[{"J_", ",", "Nst2_", ",", "\[Beta]_"}], "]"}], ":=", 
    RowBox[{
     RowBox[{"Nrml", "[", 
      RowBox[{"J", ",", "Nst2"}], "]"}], 
     RowBox[{"u\[Psi]", "[", 
      RowBox[{"J", ",", "Nst2", ",", "\[Beta]"}], "]"}]}]}]}]}]], "Input",
 CellChangeTimes->{{3.584265358525345*^9, 3.5842653699601645`*^9}, {
   3.5842654196930523`*^9, 3.5842655700929165`*^9}, {3.5842656254730134`*^9, 
   3.5842656506202574`*^9}, {3.5842657092139606`*^9, 3.58426571465837*^9}, {
   3.5842657708496685`*^9, 3.584265770943269*^9}, {3.584265808367735*^9, 
   3.5842658089293356`*^9}, {3.5843355130361767`*^9, 3.584335536342618*^9}, {
   3.5843361561446314`*^9, 3.5843361571426888`*^9}, {3.584336459319972*^9, 
   3.584336460475038*^9}, {3.5843368500243187`*^9, 3.5843368506623554`*^9}, {
   3.5847853949476943`*^9, 3.584785396351697*^9}, {3.587121197747072*^9, 
   3.5871211978370724`*^9}, {3.587121247417142*^9, 3.587121249397145*^9}, {
   3.587121372678317*^9, 3.5871213765883226`*^9}, {3.587122176829443*^9, 
   3.587122184679454*^9}, {3.5871222526195493`*^9, 3.587122263939565*^9}, {
   3.587122386499737*^9, 3.5871224134897747`*^9}, {3.5871247766291037`*^9, 
   3.5871247836691136`*^9}, {3.5905600458296356`*^9, 
   3.5905600793696947`*^9}, {3.59056013361099*^9, 3.590560134702992*^9}, {
   3.6903534917839136`*^9, 3.6903535237939587`*^9}, {3.6903535570840054`*^9, 
   3.69035363165411*^9}, {3.690353681184179*^9, 3.6903537153242264`*^9}, 
   3.6903537472242713`*^9, {3.690354035754675*^9, 3.6903540504046955`*^9}, {
   3.6903541800548773`*^9, 3.6903542444149675`*^9}, {3.690354277145013*^9, 
   3.690354400595186*^9}, {3.690354455205262*^9, 3.690354470635284*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"NIntegrate", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"\[Beta]", "^", "4"}], "*", 
    RowBox[{
     RowBox[{"\[Psi]", "[", 
      RowBox[{"4", ",", "3", ",", "\[Beta]"}], "]"}], "^", "2"}]}], ",", 
   RowBox[{"{", 
    RowBox[{"\[Beta]", ",", "0", ",", "10."}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.6903542587449875`*^9, 3.690354266994999*^9}, {
  3.6903543380450983`*^9, 3.6903543522651186`*^9}, {3.690354406605194*^9, 
  3.6903544483752527`*^9}}],

Cell[BoxData["0.9999999999999999`"], "Output",
 CellChangeTimes->{
  3.6903542675649996`*^9, {3.6903543414351034`*^9, 3.6903543526451187`*^9}, {
   3.6903544201652136`*^9, 3.6903544408652425`*^9}, 3.690354477695294*^9, 
   3.6903658508313823`*^9, 3.69044133362978*^9, 3.690474819626096*^9, 
   3.6957263317065144`*^9, 3.7057315206383886`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData["s"], "Input",
 CellChangeTimes->{3.6957266403801694`*^9}],

Cell[BoxData["43.257074222789704`"], "Output",
 CellChangeTimes->{3.6957266407091885`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"\[Psi]", "[", 
    RowBox[{"0", ",", "1", ",", 
     RowBox[{"s", "*", "\[Beta]"}]}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"\[Beta]", ",", "0.", ",", "0.10"}], "}"}], ",", 
   RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
   RowBox[{"AxesLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"r", ",", "\[Psi]"}], "}"}]}], ",", 
   RowBox[{"AxesStyle", "\[Rule]", 
    RowBox[{"Directive", "[", 
     RowBox[{"Blue", ",", "12"}], "]"}]}]}], "]"}]], "Input",
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmViYGAQB2IQfWLDu+2FW145XtvHshNEsxVf3w+ibZ4YHwTRWR2f
fkwG0jv6djNOAdLx7794gui6I3/BtOKD8vr8ra8cW+IrwXSa0UTD4gOvHJuW
bgDTahnvTUG0Z+o3MH3iyHRbED23rdEVRGcw/goC0QFnX4aC6LjrgSUg+tu1
IDC9YPGrl2vqXjtuW3zpFYhuvXBOZC2QPhQqJAaii0p3OoPobwm7wfQZE7fc
U0C6bGk3mF6hdKANRO+7cB1Ml3TKdYPoZ465PSDaaavUKhA9z0UWTJctbNkI
oXvA9Dae7GdgvtfRlyB6+fxr7Fydrx2lfx7mA9Fbfk1K5gbSpbfPpoPoAKPA
QhA903YGmC41elkOovuaBCpBNAAbo8yM
  "]],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], Opacity[
    1.], LineBox[CompressedData["
1:eJwV13c01f8fwPGLFEr2logoESEieVmVkRlJhJQiI8lKZZNVbipSVsge1923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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{
    FormBox["r", TraditionalForm], 
    FormBox["\[Psi]", TraditionalForm]},
  AxesOrigin->{0, 0},
  AxesStyle->Directive[
    RGBColor[0, 0, 1], 12],
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{"DefaultBoundaryStyle" -> Automatic, "ScalingFunctions" -> None},
  PlotRange->{All, All},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{{3.690354504165331*^9, 3.690354517215349*^9}, 
   3.695726340477016*^9, 3.6957266581591864`*^9, {3.6957266942902527`*^9, 
   3.6957267238699446`*^9}, 3.695729459068389*^9, 3.695729555310894*^9, 
   3.6957296149753065`*^9, 3.7057315326990786`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"NIntegrate", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"\[Beta]", "^", "6"}], "*", 
    RowBox[{
     RowBox[{"\[Psi]", "[", 
      RowBox[{"0", ",", "1", ",", "\[Beta]"}], "]"}], "^", "2"}]}], ",", 
   RowBox[{"{", 
    RowBox[{"\[Beta]", ",", "0", ",", "9."}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.705731556485439*^9, 3.7057316772073436`*^9}, {
  3.7057325456100135`*^9, 3.705732568146302*^9}}],

Cell[BoxData["2.5000000000233995`"], "Output",
 CellChangeTimes->{{3.7057315679340935`*^9, 3.705731677406355*^9}, {
  3.705732546398059*^9, 3.7057325684983225`*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"\[Psi]", "[", 
    RowBox[{"2", ",", "1", ",", 
     RowBox[{"s", "*", "\[Beta]"}]}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"\[Beta]", ",", "0.", ",", "0.3"}], "}"}], ",", 
   RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.6957267895227*^9, 3.695726789563702*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], Opacity[
    1.], LineBox[CompressedData["
1:eJwVl3c8lt8bx60yyiqrlJXZQkRJLrNBySwZhShKEZIiJERkJjObkD0fPPd9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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{"DefaultBoundaryStyle" -> Automatic, "ScalingFunctions" -> None},
  PlotRange->{All, All},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.695726832103135*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"BE2", "[", 
   RowBox[{"Ji_", ",", "Ni_", ",", " ", "Jf_", ",", "Nf_"}], "]"}], ":=", 
  RowBox[{
   RowBox[{
    RowBox[{"5", "/", "16"}], "/", "Pi"}], "*", 
   RowBox[{
    RowBox[{"ClebschGordan", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"Ji", ",", "0"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"2", ",", "0"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"Jf", ",", "0"}], "}"}]}], "]"}], "^", "2"}], 
   RowBox[{
    RowBox[{"NIntegrate", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"\[Beta]", "^", "5"}], "*", 
       RowBox[{"\[Psi]", "[", 
        RowBox[{"Ji", ",", "Ni", ",", "\[Beta]"}], "]"}], "*", 
       RowBox[{"\[Psi]", "[", 
        RowBox[{"Jf", ",", "Nf", ",", "\[Beta]"}], "]"}]}], ",", 
      RowBox[{"{", 
       RowBox[{"\[Beta]", ",", "0", ",", "10."}], "}"}]}], "]"}], "^", 
    "2"}]}]}]], "Input",
 CellChangeTimes->{{3.690293996135875*^9, 3.690294150386091*^9}, {
  3.690294204816167*^9, 3.6902942676562552`*^9}, {3.6902943012163024`*^9, 
  3.690294319506328*^9}, {3.6903545293953667`*^9, 3.690354651225537*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"BE2", "[", 
   RowBox[{"Ji_", ",", "Ni_", ",", " ", "Jf_", ",", "Nf_"}], "]"}], ":=", 
  RowBox[{
   RowBox[{
    RowBox[{"5", "/", "16"}], "/", "Pi"}], "*", 
   RowBox[{
    RowBox[{"ClebschGordan", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"Ji", ",", "0"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"2", ",", "0"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"Jf", ",", "0"}], "}"}]}], "]"}], "^", "2"}], 
   RowBox[{
    RowBox[{"NIntegrate", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"s", "*", "\[Beta]"}], ")"}], "^", "5"}], "*", 
       RowBox[{"\[Psi]", "[", 
        RowBox[{"Ji", ",", "Ni", ",", 
         RowBox[{"s", "*", "\[Beta]"}]}], "]"}], "*", 
       RowBox[{"\[Psi]", "[", 
        RowBox[{"Jf", ",", "Nf", ",", 
         RowBox[{"s", "*", "\[Beta]"}]}], "]"}]}], ",", 
      RowBox[{"{", 
       RowBox[{"\[Beta]", ",", "0", ",", ".3"}], "}"}]}], "]"}], "^", 
    "2"}]}]}]], "Input",
 CellChangeTimes->{{3.6957268527373157`*^9, 3.695726878491789*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"bedown20", "=", 
  RowBox[{"BE2", "[", 
   RowBox[{"2", ",", "1", ",", "0", ",", "1"}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"bedown42", "=", 
  RowBox[{"BE2", "[", 
   RowBox[{"4", ",", "1", ",", "2", ",", "1"}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"bedown64", "=", 
  RowBox[{"BE2", "[", 
   RowBox[{"6", ",", "1", ",", "4", ",", "1"}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"bedown86", "=", 
  RowBox[{"BE2", "[", 
   RowBox[{"8", ",", "1", ",", "6", ",", "1"}], 
   "]"}]}], "\[IndentingNewLine]", "\"\<------------\>\"", "\
\[IndentingNewLine]", 
 RowBox[{"bedown42", "/", "bedown20"}], "\[IndentingNewLine]", 
 RowBox[{"bedown64", "/", "bedown20"}], "\[IndentingNewLine]", 
 RowBox[{"bedown86", "/", "bedown20"}]}], "Input",
 CellChangeTimes->{{3.6903546288655057`*^9, 3.690354680625578*^9}, {
  3.690354734955654*^9, 3.6903548228057775`*^9}}],

Cell[BoxData["0.000020894622114207626`"], "Output",
 CellChangeTimes->{{3.690354637055517*^9, 3.6903546809855785`*^9}, 
   3.690354739755661*^9, {3.6903547988457437`*^9, 3.690354823405778*^9}, 
   3.690365856301695*^9, 3.6904413425197926`*^9, 3.6904748243461027`*^9, 
   3.69572689145653*^9, 3.7057325823751163`*^9}],

Cell[BoxData["0.000029849460163153738`"], "Output",
 CellChangeTimes->{{3.690354637055517*^9, 3.6903546809855785`*^9}, 
   3.690354739755661*^9, {3.6903547988457437`*^9, 3.690354823405778*^9}, 
   3.690365856301695*^9, 3.6904413425197926`*^9, 3.6904748243461027`*^9, 
   3.69572689145653*^9, 3.705732583243166*^9}],

Cell[BoxData["0.000032876153676200774`"], "Output",
 CellChangeTimes->{{3.690354637055517*^9, 3.6903546809855785`*^9}, 
   3.690354739755661*^9, {3.6903547988457437`*^9, 3.690354823405778*^9}, 
   3.690365856301695*^9, 3.6904413425197926`*^9, 3.6904748243461027`*^9, 
   3.69572689145653*^9, 3.705732584387232*^9}],

Cell[BoxData["0.0000344146717175184`"], "Output",
 CellChangeTimes->{{3.690354637055517*^9, 3.6903546809855785`*^9}, 
   3.690354739755661*^9, {3.6903547988457437`*^9, 3.690354823405778*^9}, 
   3.690365856301695*^9, 3.6904413425197926`*^9, 3.6904748243461027`*^9, 
   3.69572689145653*^9, 3.7057325852482805`*^9}],

Cell[BoxData["\<\"------------\"\>"], "Output",
 CellChangeTimes->{{3.690354637055517*^9, 3.6903546809855785`*^9}, 
   3.690354739755661*^9, {3.6903547988457437`*^9, 3.690354823405778*^9}, 
   3.690365856301695*^9, 3.6904413425197926`*^9, 3.6904748243461027`*^9, 
   3.69572689145653*^9, 3.705732585249281*^9}],

Cell[BoxData["1.428571428571428`"], "Output",
 CellChangeTimes->{{3.690354637055517*^9, 3.6903546809855785`*^9}, 
   3.690354739755661*^9, {3.6903547988457437`*^9, 3.690354823405778*^9}, 
   3.690365856301695*^9, 3.6904413425197926`*^9, 3.6904748243461027`*^9, 
   3.69572689145653*^9, 3.705732585251281*^9}],

Cell[BoxData["1.5734265734265718`"], "Output",
 CellChangeTimes->{{3.690354637055517*^9, 3.6903546809855785`*^9}, 
   3.690354739755661*^9, {3.6903547988457437`*^9, 3.690354823405778*^9}, 
   3.690365856301695*^9, 3.6904413425197926`*^9, 3.6904748243461027`*^9, 
   3.69572689145653*^9, 3.7057325852522807`*^9}],

Cell[BoxData["1.6470588235294097`"], "Output",
 CellChangeTimes->{{3.690354637055517*^9, 3.6903546809855785`*^9}, 
   3.690354739755661*^9, {3.6903547988457437`*^9, 3.690354823405778*^9}, 
   3.690365856301695*^9, 3.6904413425197926`*^9, 3.6904748243461027`*^9, 
   3.69572689145653*^9, 3.705732585254281*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"bedown2g0", "=", 
  RowBox[{"BE2", "[", 
   RowBox[{"2", ",", "2", ",", "0", ",", "1"}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"bedown3g2", "=", 
  RowBox[{"BE2", "[", 
   RowBox[{"3", ",", "1", ",", "2", ",", "1"}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"bedown4g2g", "=", 
  RowBox[{"BE2", "[", 
   RowBox[{"4", ",", "2", ",", "2", ",", "2"}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"bedown0b0", "=", 
  RowBox[{"BE2", "[", 
   RowBox[{"0", ",", "2", ",", "2", ",", "1"}], 
   "]"}]}], "\[IndentingNewLine]", "\"\<------------\>\"", "\
\[IndentingNewLine]", 
 RowBox[{"bedown2g0", "/", "bedown20"}], "\[IndentingNewLine]", 
 RowBox[{"bedown3g2", "/", "bedown20"}], "\[IndentingNewLine]", 
 RowBox[{"bedown4g2g", "/", "bedown20"}], "\[IndentingNewLine]", 
 RowBox[{"bedown0b0", "/", "bedown20"}]}], "Input",
 CellChangeTimes->{{3.705732676395494*^9, 3.7057327007428865`*^9}, {
  3.7057327495166764`*^9, 3.7057328143283834`*^9}, {3.705733003507204*^9, 
  3.705733040321309*^9}}],

Cell[BoxData["3.093629512248156`*^-7"], "Output",
 CellChangeTimes->{{3.705732690530302*^9, 3.7057327015549335`*^9}, 
   3.70573276828475*^9, 3.7057328151014276`*^9, {3.7057330274495735`*^9, 
   3.7057330413043656`*^9}}],

Cell[BoxData["0.`"], "Output",
 CellChangeTimes->{{3.705732690530302*^9, 3.7057327015549335`*^9}, 
   3.70573276828475*^9, 3.7057328151014276`*^9, {3.7057330274495735`*^9, 
   3.705733041448374*^9}}],

Cell[BoxData["0.00006849946391161952`"], "Output",
 CellChangeTimes->{{3.705732690530302*^9, 3.7057327015549335`*^9}, 
   3.70573276828475*^9, 3.7057328151014276`*^9, {3.7057330274495735`*^9, 
   3.705733042277421*^9}}],

Cell[BoxData["1.8568459459116827`*^-7"], "Output",
 CellChangeTimes->{{3.705732690530302*^9, 3.7057327015549335`*^9}, 
   3.70573276828475*^9, 3.7057328151014276`*^9, {3.7057330274495735`*^9, 
   3.705733042446431*^9}}],

Cell[BoxData["\<\"------------\"\>"], "Output",
 CellChangeTimes->{{3.705732690530302*^9, 3.7057327015549335`*^9}, 
   3.70573276828475*^9, 3.7057328151014276`*^9, {3.7057330274495735`*^9, 
   3.705733042448431*^9}}],

Cell[BoxData["0.014805864855266245`"], "Output",
 CellChangeTimes->{{3.705732690530302*^9, 3.7057327015549335`*^9}, 
   3.70573276828475*^9, 3.7057328151014276`*^9, {3.7057330274495735`*^9, 
   3.7057330424514313`*^9}}],

Cell[BoxData["0.`"], "Output",
 CellChangeTimes->{{3.705732690530302*^9, 3.7057327015549335`*^9}, 
   3.70573276828475*^9, 3.7057328151014276`*^9, {3.7057330274495735`*^9, 
   3.705733042453431*^9}}],

Cell[BoxData["3.278329875372201`"], "Output",
 CellChangeTimes->{{3.705732690530302*^9, 3.7057327015549335`*^9}, 
   3.70573276828475*^9, 3.7057328151014276`*^9, {3.7057330274495735`*^9, 
   3.7057330424564314`*^9}}],

Cell[BoxData["0.008886717049786181`"], "Output",
 CellChangeTimes->{{3.705732690530302*^9, 3.7057327015549335`*^9}, 
   3.70573276828475*^9, 3.7057328151014276`*^9, {3.7057330274495735`*^9, 
   3.7057330424584312`*^9}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["3 - Fit from data - Playing area -", "Subtitle",
 CellFrame->{{0, 0}, {0, 3}},
 CellChangeTimes->{{3.5842532157979345`*^9, 3.5842532405707784`*^9}, {
  3.597731899701002*^9, 3.5977319040710077`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"exdata", "[", 
  RowBox[{"160", ",", "\"\<Gd\>\""}], "]"}]], "Input",
 CellChangeTimes->{{3.6904748320061135`*^9, 3.6904748372561207`*^9}, {
  3.690474961036294*^9, 3.6904749613162947`*^9}, {3.6904750247363834`*^9, 
  3.690475042176408*^9}, {3.6904752346366773`*^9, 3.690475237186681*^9}, {
  3.690475405746917*^9, 3.690475408846921*^9}, {3.690779997012441*^9, 
  3.690779999285571*^9}, {3.695724945075204*^9, 3.695724950940539*^9}, {
  3.705724172908122*^9, 3.705724177190367*^9}, {3.705739528746426*^9, 
  3.705739528828431*^9}, {3.7284919078853846`*^9, 3.7284919112653894`*^9}, {
  3.728543382640554*^9, 3.7285433857105584`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"160Gd\"\>", ",", "0.07526`", ",", "0.24852`", ",", "0.51475`", 
   ",", "1.32573`", ",", "0.9884`", ",", "1.05754`"}], "}"}]], "Output",
 CellChangeTimes->{
  3.6904748376761217`*^9, {3.690474890926196*^9, 3.690474893246199*^9}, {
   3.6904749507862797`*^9, 3.6904749776163173`*^9}, {3.690475011916365*^9, 
   3.690475042606408*^9}, 3.6904750826064644`*^9, {3.690475150256559*^9, 
   3.690475182716604*^9}, {3.690475233166675*^9, 3.6904752375866814`*^9}, 
   3.690475378696879*^9, {3.6904754098469224`*^9, 3.690475417346933*^9}, 
   3.6905479011742077`*^9, 3.6905481272011356`*^9, 3.6905481709696393`*^9, 
   3.6907800000836167`*^9, 3.695724951231556*^9, 3.6957252289194384`*^9, 
   3.6957254438527317`*^9, 3.705724177433381*^9, 3.705739529533471*^9, {
   3.705740181493761*^9, 3.7057401959135857`*^9}, 3.72849191169539*^9, {
   3.7284931006386147`*^9, 3.7284931103786287`*^9}, 3.7285433858605585`*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"This", " ", "is", " ", "the", " ", "testing", " ", "function"}], 
    ",", " ", 
    RowBox[{
     RowBox[{"i", ".", "e", ".", " ", "the"}], " ", "sum", " ", "of", " ", 
     "square", " ", "of", " ", "deviations", " ", "from", " ", "input", " ", 
     "experimental", " ", "data"}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"f", "[", 
    RowBox[{
    "cx1_", ",", "cx2_", ",", "cx3_", ",", "cx4_", ",", "cx5_", ",", "cx6_", 
     ",", "cx7_"}], "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"c1", "=", "cx1"}], ",", 
       RowBox[{"c2", "=", "cx2"}], ",", 
       RowBox[{"c3", "=", "cx3"}], ",", 
       RowBox[{"c4", "=", "cx4"}], ",", 
       RowBox[{"c5", "=", "cx5"}], ",", 
       RowBox[{"c6", "=", "cx6"}], ",", 
       RowBox[{"c7", "=", "cx7"}]}], "}"}], ",", 
     RowBox[{
      RowBox[{"Do", "[", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{
         RowBox[{"sfind", "[", 
          RowBox[{"c1", ",", "c2", ",", "c4", ",", "c6", ",", "c7"}], "]"}], 
         ";", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"eiv", "[", "J", "]"}], "=", 
          RowBox[{"Sort", "[", 
           RowBox[{"Eigenvalues", "[", " ", 
            RowBox[{
             RowBox[{
              RowBox[{"s", "^", "2"}], "c1", "*", 
              RowBox[{"T", "[", "J", "]"}]}], "+", 
             RowBox[{
              RowBox[{"s", "^", 
               RowBox[{"(", 
                RowBox[{"-", "2"}], ")"}]}], 
              RowBox[{"1", "/", 
               RowBox[{"Sqrt", "[", "5", "]"}]}], "c2", "*", 
              RowBox[{"Vb2", "[", "J", "]"}]}], "-", 
             RowBox[{
              RowBox[{"s", "^", 
               RowBox[{"(", 
                RowBox[{"-", "3"}], ")"}]}], 
              RowBox[{"Sqrt", "[", 
               RowBox[{"2", "/", "35"}], "]"}], "c3", "*", 
              RowBox[{"Vb3c", "[", "J", "]"}]}], "+", "\[IndentingNewLine]", 
             RowBox[{
              RowBox[{"s", "^", 
               RowBox[{"(", 
                RowBox[{"-", "4"}], ")"}]}], 
              RowBox[{"1", "/", "5"}], "c4", "*", 
              RowBox[{"Vb4", "[", "J", "]"}]}], "-", 
             RowBox[{
              RowBox[{"s", "^", 
               RowBox[{"(", 
                RowBox[{"-", "5"}], ")"}]}], 
              RowBox[{"Sqrt", "[", 
               RowBox[{"2", "/", "175"}], "]"}], "c5", "*", 
              RowBox[{"Vb5c", "[", "J", "]"}]}], "+", 
             RowBox[{
              RowBox[{"s", "^", 
               RowBox[{"(", 
                RowBox[{"-", "6"}], ")"}]}], 
              RowBox[{"2", "/", "35"}], "c6", "*", 
              RowBox[{"Vb6c", "[", "J", "]"}]}], "+", 
             RowBox[{
              RowBox[{"s", "^", 
               RowBox[{"(", 
                RowBox[{"-", "6"}], ")"}]}], 
              RowBox[{"1", "/", 
               RowBox[{"(", 
                RowBox[{"5", 
                 RowBox[{"Sqrt", "[", "5", "]"}]}], ")"}]}], "c7", "*", 
              RowBox[{"Vb6", "[", "J", "]"}]}]}], "]"}], "]"}]}]}], 
        "\[IndentingNewLine]", ",", 
        RowBox[{"{", 
         RowBox[{"J", ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "2", ",", "3", ",", "4", ",", "5", ",", "6"}], 
           "}"}]}], "}"}]}], "]"}], ";", "\[IndentingNewLine]", 
      RowBox[{"e2t", "=", 
       RowBox[{
        RowBox[{
         RowBox[{"eiv", "[", "2", "]"}], "[", 
         RowBox[{"[", "1", "]"}], "]"}], "-", 
        RowBox[{
         RowBox[{"eiv", "[", "0", "]"}], "[", 
         RowBox[{"[", "1", "]"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"e4t", "=", 
       RowBox[{
        RowBox[{
         RowBox[{"eiv", "[", "4", "]"}], "[", 
         RowBox[{"[", "1", "]"}], "]"}], "-", 
        RowBox[{
         RowBox[{"eiv", "[", "0", "]"}], "[", 
         RowBox[{"[", "1", "]"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"e6t", "=", 
       RowBox[{
        RowBox[{
         RowBox[{"eiv", "[", "6", "]"}], "[", 
         RowBox[{"[", "1", "]"}], "]"}], "-", 
        RowBox[{
         RowBox[{"eiv", "[", "0", "]"}], "[", 
         RowBox[{"[", "1", "]"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"eb0t", "=", 
       RowBox[{
        RowBox[{
         RowBox[{"eiv", "[", "0", "]"}], "[", 
         RowBox[{"[", "2", "]"}], "]"}], "-", 
        RowBox[{
         RowBox[{"eiv", "[", "0", "]"}], "[", 
         RowBox[{"[", "1", "]"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"eg2t", "=", 
       RowBox[{
        RowBox[{
         RowBox[{"eiv", "[", "2", "]"}], "[", 
         RowBox[{"[", "2", "]"}], "]"}], "-", 
        RowBox[{
         RowBox[{"eiv", "[", "0", "]"}], "[", 
         RowBox[{"[", "1", "]"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"eg3t", "=", 
       RowBox[{
        RowBox[{
         RowBox[{"eiv", "[", "3", "]"}], "[", 
         RowBox[{"[", "1", "]"}], "]"}], "-", 
        RowBox[{
         RowBox[{"eiv", "[", "0", "]"}], "[", 
         RowBox[{"[", "1", "]"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"eg5t", "=", 
       RowBox[{
        RowBox[{
         RowBox[{"eiv", "[", "5", "]"}], "[", 
         RowBox[{"[", "1", "]"}], "]"}], "-", 
        RowBox[{
         RowBox[{"eiv", "[", "0", "]"}], "[", 
         RowBox[{"[", "1", "]"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"e2", "-", "e2t"}], ")"}], "^", "2"}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"e4", "-", "e4t"}], ")"}], "^", "2"}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"e6", "-", "e6t"}], ")"}], "^", "2"}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"eb0", "-", "eb0t"}], ")"}], "^", "2"}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"eg2", "-", "eg2t"}], ")"}], "^", "2"}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"eg3", "-", "eg3t"}], ")"}], "^", "2"}]}]}]}], 
    RowBox[{"(*", 
     RowBox[{"+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"eg5", "-", "eg5t"}], ")"}], "^", "2"}]}], "*)"}], 
    "]"}]}]}]], "Input",
 CellChangeTimes->{{3.6900026971782913`*^9, 3.690002736890563*^9}, {
  3.690264524560937*^9, 3.690264529160943*^9}, {3.6902646537361646`*^9, 
  3.690264685296209*^9}}],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
   RowBox[{"flexf", "[", 
    RowBox[{
    "cx1_", ",", "cx2_", ",", "cx3_", ",", "cx4_", ",", "cx5_", ",", "cx6_", 
     ",", "cx7_"}], "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"c1", "=", "cx1"}], ",", 
       RowBox[{"c2", "=", "cx2"}], ",", 
       RowBox[{"c3", "=", "cx3"}], ",", 
       RowBox[{"c4", "=", "cx4"}], ",", 
       RowBox[{"c5", "=", "cx5"}], ",", 
       RowBox[{"c6", "=", "cx6"}], ",", 
       RowBox[{"c7", "=", "cx7"}]}], "}"}], ",", 
     RowBox[{
      RowBox[{"Do", "[", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{
         RowBox[{"sfind", "[", 
          RowBox[{"c1", ",", "c2", ",", "c4", ",", "c6", ",", "c7"}], "]"}], 
         ";", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"eiv", "[", "J", "]"}], "=", 
          RowBox[{"Sort", "[", 
           RowBox[{"Eigenvalues", "[", " ", 
            RowBox[{
             RowBox[{
              RowBox[{"s", "^", "2"}], "c1", "*", 
              RowBox[{"T", "[", "J", "]"}]}], "+", 
             RowBox[{
              RowBox[{"s", "^", 
               RowBox[{"(", 
                RowBox[{"-", "2"}], ")"}]}], 
              RowBox[{"1", "/", 
               RowBox[{"Sqrt", "[", "5", "]"}]}], "c2", "*", 
              RowBox[{"Vb2", "[", "J", "]"}]}], "-", 
             RowBox[{
              RowBox[{"s", "^", 
               RowBox[{"(", 
                RowBox[{"-", "3"}], ")"}]}], 
              RowBox[{"Sqrt", "[", 
               RowBox[{"2", "/", "35"}], "]"}], "c3", "*", 
              RowBox[{"Vb3c", "[", "J", "]"}]}], "+", "\[IndentingNewLine]", 
             RowBox[{
              RowBox[{"s", "^", 
               RowBox[{"(", 
                RowBox[{"-", "4"}], ")"}]}], 
              RowBox[{"1", "/", "5"}], "c4", "*", 
              RowBox[{"Vb4", "[", "J", "]"}]}], "-", 
             RowBox[{
              RowBox[{"s", "^", 
               RowBox[{"(", 
                RowBox[{"-", "5"}], ")"}]}], 
              RowBox[{"Sqrt", "[", 
               RowBox[{"2", "/", "175"}], "]"}], "c5", "*", 
              RowBox[{"Vb5c", "[", "J", "]"}]}], "+", 
             RowBox[{
              RowBox[{"s", "^", 
               RowBox[{"(", 
                RowBox[{"-", "6"}], ")"}]}], 
              RowBox[{"2", "/", "35"}], "c6", "*", 
              RowBox[{"Vb6c", "[", "J", "]"}]}], "+", 
             RowBox[{
              RowBox[{"s", "^", 
               RowBox[{"(", 
                RowBox[{"-", "6"}], ")"}]}], 
              RowBox[{"1", "/", 
               RowBox[{"(", 
                RowBox[{"5", 
                 RowBox[{"Sqrt", "[", "5", "]"}]}], ")"}]}], "c7", "*", 
              RowBox[{"Vb6", "[", "J", "]"}]}]}], "]"}], "]"}]}]}], 
        "\[IndentingNewLine]", ",", 
        RowBox[{"{", 
         RowBox[{"J", ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "2", ",", "3", ",", "4", ",", "5", ",", "6"}], 
           "}"}]}], "}"}]}], "]"}], ";", "\[IndentingNewLine]", 
      RowBox[{"e2t", "=", 
       RowBox[{
        RowBox[{
         RowBox[{"eiv", "[", "2", "]"}], "[", 
         RowBox[{"[", "1", "]"}], "]"}], "-", 
        RowBox[{
         RowBox[{"eiv", "[", "0", "]"}], "[", 
         RowBox[{"[", "1", "]"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"e4t", "=", 
       RowBox[{
        RowBox[{
         RowBox[{"eiv", "[", "4", "]"}], "[", 
         RowBox[{"[", "1", "]"}], "]"}], "-", 
        RowBox[{
         RowBox[{"eiv", "[", "0", "]"}], "[", 
         RowBox[{"[", "1", "]"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"e6t", "=", 
       RowBox[{
        RowBox[{
         RowBox[{"eiv", "[", "6", "]"}], "[", 
         RowBox[{"[", "1", "]"}], "]"}], "-", 
        RowBox[{
         RowBox[{"eiv", "[", "0", "]"}], "[", 
         RowBox[{"[", "1", "]"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"(*", 
       RowBox[{
        RowBox[{"eb0t", "=", 
         RowBox[{
          RowBox[{
           RowBox[{"eiv", "[", "0", "]"}], "[", 
           RowBox[{"[", "2", "]"}], "]"}], "-", 
          RowBox[{
           RowBox[{"eiv", "[", "0", "]"}], "[", 
           RowBox[{"[", "1", "]"}], "]"}]}]}], ";"}], "*)"}], 
      "\[IndentingNewLine]", 
      RowBox[{"eg2t", "=", 
       RowBox[{
        RowBox[{
         RowBox[{"eiv", "[", "2", "]"}], "[", 
         RowBox[{"[", "2", "]"}], "]"}], "-", 
        RowBox[{
         RowBox[{"eiv", "[", "0", "]"}], "[", 
         RowBox[{"[", "1", "]"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"eg3t", "=", 
       RowBox[{
        RowBox[{
         RowBox[{"eiv", "[", "3", "]"}], "[", 
         RowBox[{"[", "1", "]"}], "]"}], "-", 
        RowBox[{
         RowBox[{"eiv", "[", "0", "]"}], "[", 
         RowBox[{"[", "1", "]"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"eg5t", "=", 
       RowBox[{
        RowBox[{
         RowBox[{"eiv", "[", "5", "]"}], "[", 
         RowBox[{"[", "1", "]"}], "]"}], "-", 
        RowBox[{
         RowBox[{"eiv", "[", "0", "]"}], "[", 
         RowBox[{"[", "1", "]"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"e2", "-", "e2t"}], ")"}], "^", "2"}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"e4", "-", "e4t"}], ")"}], "^", "2"}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"e6", "-", "e6t"}], ")"}], "^", "2"}], 
       RowBox[{"(*", 
        RowBox[{"+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"eb0", "-", "eb0t"}], ")"}], "^", "2"}]}], "*)"}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"eg2", "-", "eg2t"}], ")"}], "^", "2"}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"eg3", "-", "eg3t"}], ")"}], "^", "2"}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"eg5", "-", "eg5t"}], ")"}], "^", "2"}]}]}]}], "]"}]}], "  ",
   "*)"}]], "Input",
 CellChangeTimes->{{3.5793295157029552`*^9, 3.5793295236829667`*^9}, {
   3.5793299512635655`*^9, 3.579330005963642*^9}, {3.5793300434936943`*^9, 
   3.579330084593752*^9}, 3.5793301275438123`*^9, {3.5793301642838635`*^9, 
   3.5793302607539988`*^9}, {3.5793305742654376`*^9, 3.579330678705584*^9}, {
   3.5793307215656443`*^9, 3.579330721745644*^9}, {3.579330887305876*^9, 
   3.579330949455963*^9}, {3.579331015026055*^9, 3.5793313263764906`*^9}, {
   3.579332413148012*^9, 3.5793324932181244`*^9}, 3.5793333676523495`*^9, {
   3.5793340031232395`*^9, 3.57933400360324*^9}, {3.579335644310623*^9, 
   3.579335651930634*^9}, {3.579337389671204*^9, 3.579337400271219*^9}, {
   3.5793378502318487`*^9, 3.5793378530718527`*^9}, {3.57933796458501*^9, 
   3.579337967295014*^9}, {3.579338091925188*^9, 3.579338093895191*^9}, {
   3.5793383443295465`*^9, 3.579338365859576*^9}, {3.5793401913501453`*^9, 
   3.5793402006001577`*^9}, {3.5793403652203884`*^9, 3.579340367170391*^9}, {
   3.579340534361625*^9, 3.5793405347716255`*^9}, {3.57934246039233*^9, 
   3.5793424632823343`*^9}, {3.57934253180243*^9, 3.57934253213243*^9}, {
   3.586584970107742*^9, 3.58658498032576*^9}, {3.586587742683072*^9, 
   3.586587784180732*^9}, {3.5865932233325663`*^9, 3.5865932721606517`*^9}, {
   3.6902931408025713`*^9, 3.6902931456025777`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"numtrial", "=", "100"}], ";"}], "  ", 
  RowBox[{"(*", " ", 
   RowBox[{
   "number", " ", "of", " ", "trials", " ", "within", " ", "a", " ", "single",
     " ", "reinizialization"}], " ", "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"outloop", "=", "15"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"acbest", "[", "0", "]"}], "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"1", "/", "10"}], ",", "100", ",", "1000", ",", 
     RowBox[{"10", "^", "4"}], ",", 
     RowBox[{"10", "^", "5"}], ",", 
     RowBox[{"10", "^", "6"}], ",", 
     RowBox[{"10", "^", "6"}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ftest", "=", 
   RowBox[{"f", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"acbest", "[", "0", "]"}], "[", 
      RowBox[{"[", "1", "]"}], "]"}], ",", 
     RowBox[{
      RowBox[{"acbest", "[", "0", "]"}], "[", 
      RowBox[{"[", "2", "]"}], "]"}], ",", 
     RowBox[{
      RowBox[{"acbest", "[", "0", "]"}], "[", 
      RowBox[{"[", "3", "]"}], "]"}], ",", 
     RowBox[{
      RowBox[{"acbest", "[", "0", "]"}], "[", 
      RowBox[{"[", "4", "]"}], "]"}], ",", 
     RowBox[{
      RowBox[{"acbest", "[", "0", "]"}], "[", 
      RowBox[{"[", "5", "]"}], "]"}], ",", 
     RowBox[{
      RowBox[{"acbest", "[", "0", "]"}], "[", 
      RowBox[{"[", "6", "]"}], "]"}], ",", 
     RowBox[{
      RowBox[{"acbest", "[", "0", "]"}], "[", 
      RowBox[{"[", "7", "]"}], "]"}]}], "]"}]}], " ", 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"cnt", "=", "0"}], ";"}]}], "Input",
 CellChangeTimes->{{3.5793494802694263`*^9, 3.579349480929427*^9}, 
   3.5793503371316576`*^9, {3.690025863766344*^9, 3.6900259080218754`*^9}, 
   3.690115516299735*^9, 3.690116450807186*^9, 3.690117526063687*^9, 
   3.6903678448834825`*^9, {3.690448980834153*^9, 3.6904489847641582`*^9}, {
   3.6904490493882575`*^9, 3.69044906546828*^9}, {3.6905481390718145`*^9, 
   3.690548140679907*^9}, {3.7057402510057373`*^9, 3.7057402576741185`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Do", "[", "  ", 
   RowBox[{"(*", " ", 
    RowBox[{
    "starting", " ", "from", " ", "same", " ", "initial", " ", "conditions", 
     " ", "this", " ", "doloop", " ", "search", " ", "for", " ", "the", " ", 
     "best", " ", "set", " ", "of", " ", "parameters"}], " ", "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"Do", "[", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        RowBox[{"ac", "[", "k", "]"}], "=", 
        RowBox[{
         RowBox[{"RandomVariate", "[", 
          RowBox[{
           RowBox[{"NormalDistribution", "[", 
            RowBox[{"0", ",", "1.4826"}], "]"}], ",", "numtrial"}], "]"}], 
         "*", 
         RowBox[{
          RowBox[{"acbest", "[", "cnt", "]"}], "[", 
          RowBox[{"[", "k", "]"}], "]"}]}]}], "\[IndentingNewLine]", ",", 
       RowBox[{"{", 
        RowBox[{"k", ",", "2", ",", "5"}], "}"}]}], "]"}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"Do", "[", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        RowBox[{"ac", "[", "k", "]"}], "=", 
        RowBox[{"Abs", "[", 
         RowBox[{
          RowBox[{"RandomVariate", "[", 
           RowBox[{
            RowBox[{"NormalDistribution", "[", 
             RowBox[{"0", ",", "1.4826"}], "]"}], ",", "numtrial"}], "]"}], 
          "*", 
          RowBox[{
           RowBox[{"acbest", "[", "cnt", "]"}], "[", 
           RowBox[{"[", "k", "]"}], "]"}]}], "]"}]}], "\[IndentingNewLine]", 
       ",", 
       RowBox[{"{", 
        RowBox[{"k", ",", 
         RowBox[{"{", 
          RowBox[{"1", ",", "6", ",", "7"}], "}"}]}], "}"}]}], "]"}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"Do", "[", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        RowBox[{"fxx", "=", 
         RowBox[{"f", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"ac", "[", "1", "]"}], "[", 
            RowBox[{"[", "j", "]"}], "]"}], ",", 
           RowBox[{
            RowBox[{"ac", "[", "2", "]"}], "[", 
            RowBox[{"[", "j", "]"}], "]"}], ",", 
           RowBox[{
            RowBox[{"ac", "[", "3", "]"}], "[", 
            RowBox[{"[", "j", "]"}], "]"}], ",", 
           RowBox[{
            RowBox[{"ac", "[", "4", "]"}], "[", 
            RowBox[{"[", "j", "]"}], "]"}], ",", 
           RowBox[{
            RowBox[{"ac", "[", "5", "]"}], "[", 
            RowBox[{"[", "j", "]"}], "]"}], ",", 
           RowBox[{
            RowBox[{"ac", "[", "6", "]"}], "[", 
            RowBox[{"[", "j", "]"}], "]"}], ",", 
           RowBox[{
            RowBox[{"ac", "[", "7", "]"}], "[", 
            RowBox[{"[", "j", "]"}], "]"}]}], "]"}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"fxx", "<", "ftest"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"cnt", "=", 
             RowBox[{"cnt", "+", "1"}]}], ",", 
            RowBox[{
             RowBox[{"acbest", "[", "cnt", "]"}], "=", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{
                RowBox[{"ac", "[", "1", "]"}], "[", 
                RowBox[{"[", "j", "]"}], "]"}], ",", 
               RowBox[{
                RowBox[{"ac", "[", "2", "]"}], "[", 
                RowBox[{"[", "j", "]"}], "]"}], ",", 
               RowBox[{
                RowBox[{"ac", "[", "3", "]"}], "[", 
                RowBox[{"[", "j", "]"}], "]"}], ",", 
               RowBox[{
                RowBox[{"ac", "[", "4", "]"}], "[", 
                RowBox[{"[", "j", "]"}], "]"}], ",", 
               RowBox[{
                RowBox[{"ac", "[", "5", "]"}], "[", 
                RowBox[{"[", "j", "]"}], "]"}], ",", 
               RowBox[{
                RowBox[{"ac", "[", "6", "]"}], "[", 
                RowBox[{"[", "j", "]"}], "]"}], ",", 
               RowBox[{
                RowBox[{"ac", "[", "7", "]"}], "[", 
                RowBox[{"[", "j", "]"}], "]"}]}], "}"}]}], ",", " ", 
            RowBox[{"ftest", "=", "fxx"}], ",", 
            RowBox[{
             RowBox[{"Print", "[", 
              RowBox[{
              "i", ",", "\"\< \>\"", ",", " ", "ftest", ",", "\"\< \>\"", ",",
                " ", 
               RowBox[{"acbest", "[", "cnt", "]"}]}], "]"}], ";"}]}], "}"}]}],
          "]"}], ";"}], "\[IndentingNewLine]", ",", 
       RowBox[{"{", 
        RowBox[{"j", ",", "1", ",", "numtrial"}], "}"}]}], "]"}], ";"}], 
    "\[IndentingNewLine]", ",", 
    RowBox[{"{", 
     RowBox[{"i", ",", "1", ",", "outloop"}], "}"}]}], "]"}], ";"}]], "Input",
 CellChangeTimes->{{3.5793458876453657`*^9, 3.579345975915489*^9}, {
   3.5793460374255753`*^9, 3.5793460375255756`*^9}, {3.5793463533960176`*^9, 
   3.5793463567660227`*^9}, 3.5793463928060727`*^9, 3.579348087689458*^9, {
   3.690006925661147*^9, 3.69000693061343*^9}, {3.6900069908698764`*^9, 
   3.6900069959171653`*^9}, {3.6900070282630153`*^9, 
   3.6900070399736853`*^9}, {3.690007085634297*^9, 3.690007092568693*^9}, {
   3.6900072257023077`*^9, 3.6900072511077614`*^9}, 3.705724899344672*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{
  "1", "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", 
   "466.0962719651107`", "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
    "0.0358696538172643`", ",", "43.503394069497496`", ",", 
     "1273.568351119682`", ",", "1600.7662640235033`", ",", 
     "30135.66468189447`", ",", "1.3847217460304054`*^6", ",", 
     "366015.037544498`"}], "}"}]}],
  SequenceForm[
  1, " ", 466.0962719651107, " ", {0.0358696538172643, 43.503394069497496`, 
   1273.568351119682, 1600.7662640235033`, 30135.66468189447, 
   1.3847217460304054`*^6, 366015.037544498}],
  Editable->False]], "Print",
 CellChangeTimes->{3.705739545751399*^9, 3.705740207968275*^9, 
  3.7057402690097666`*^9, 3.7285434034505835`*^9, 3.728543859121255*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
  "1", "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", 
   "139.35569489368214`", "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
    "0.017217531875061223`", ",", "47.02198566505375`", ",", 
     "1860.099528944407`", ",", "2523.2964151802357`", ",", 
     "245876.62234741502`", ",", "179166.63702907393`", ",", 
     "1.2982322753034905`*^6"}], "}"}]}],
  SequenceForm[
  1, " ", 139.35569489368214`, " ", {0.017217531875061223`, 47.02198566505375,
    1860.099528944407, 2523.2964151802357`, 245876.62234741502`, 
   179166.63702907393`, 1.2982322753034905`*^6}],
  Editable->False]], "Print",
 CellChangeTimes->{3.705739545751399*^9, 3.705740207968275*^9, 
  3.7057402690097666`*^9, 3.7285434034505835`*^9, 3.7285438621112585`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
  "1", "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", 
   "2.5893166395784823`", "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"0.00004048636553474637`", ",", "228.91824579468908`", ",", 
     RowBox[{"-", "2093.6767358536363`"}], ",", "14664.968889558017`", ",", 
     "45204.21381666567`", ",", "1.9116475476874404`*^6", ",", 
     "768616.5110287105`"}], "}"}]}],
  SequenceForm[
  1, " ", 2.5893166395784823`, " ", {0.00004048636553474637, 
   228.91824579468908`, -2093.6767358536363`, 14664.968889558017`, 
   45204.21381666567, 1.9116475476874404`*^6, 768616.5110287105}],
  Editable->False]], "Print",
 CellChangeTimes->{3.705739545751399*^9, 3.705740207968275*^9, 
  3.7057402690097666`*^9, 3.7285434034505835`*^9, 3.7285438787532835`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
  "1", "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", 
   "0.4788844830885279`", "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"0.0016380739589996571`", ",", 
     RowBox[{"-", "201.03666449324092`"}], ",", "924.1777009175522`", ",", 
     "1867.63569732469`", ",", "64898.29883793124`", ",", 
     "933654.8669571384`", ",", "1.193429027696149`*^6"}], "}"}]}],
  SequenceForm[
  1, " ", 0.4788844830885279, " ", {
   0.0016380739589996571`, -201.03666449324092`, 924.1777009175522, 
   1867.63569732469, 64898.29883793124, 933654.8669571384, 
   1.193429027696149*^6}],
  Editable->False]], "Print",
 CellChangeTimes->{3.705739545751399*^9, 3.705740207968275*^9, 
  3.7057402690097666`*^9, 3.7285434034505835`*^9, 3.7285439038633184`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
  "2", "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", 
   "0.32747713768427095`", "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"0.0009315609740884503`", ",", 
     RowBox[{"-", "199.84657169493917`"}], ",", "1893.1608336807294`", ",", 
     RowBox[{"-", "3225.3017265923604`"}], ",", "190878.84716858555`", ",", 
     "2428.4260463329097`", ",", "3.012457756071974`*^6"}], "}"}]}],
  SequenceForm[
  2, " ", 0.32747713768427095`, " ", {
   0.0009315609740884503, -199.84657169493917`, 
   1893.1608336807294`, -3225.3017265923604`, 190878.84716858555`, 
   2428.4260463329097`, 3.012457756071974*^6}],
  Editable->False]], "Print",
 CellChangeTimes->{3.705739545751399*^9, 3.705740207968275*^9, 
  3.7057402690097666`*^9, 3.7285434034505835`*^9, 3.7285439630354023`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
  "3", "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", 
   "0.2027431768380636`", "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"0.000778017934526424`", ",", 
     RowBox[{"-", "316.3543525110442`"}], ",", "5023.039488546212`", ",", 
     "6226.694627995873`", ",", 
     RowBox[{"-", "185982.91099595936`"}], ",", "620.6552897215101`", ",", 
     "645685.7470712529`"}], "}"}]}],
  SequenceForm[
  3, " ", 0.2027431768380636, " ", {0.000778017934526424, -316.3543525110442, 
   5023.039488546212, 6226.694627995873, -185982.91099595936`, 
   620.6552897215101, 645685.7470712529}],
  Editable->False]], "Print",
 CellChangeTimes->{3.705739545751399*^9, 3.705740207968275*^9, 
  3.7057402690097666`*^9, 3.7285434034505835`*^9, 3.72854408890758*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
  "3", "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", 
   "0.19680020579646557`", "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"0.0009563885888164692`", ",", 
     RowBox[{"-", "594.3858660597017`"}], ",", 
     RowBox[{"-", "610.3486278003147`"}], ",", "1998.6543564942958`", ",", 
     RowBox[{"-", "154140.93930602173`"}], ",", "5357.034226578713`", ",", 
     "2.7773689736072854`*^6"}], "}"}]}],
  SequenceForm[
  3, " ", 0.19680020579646557`, " ", {
   0.0009563885888164692, -594.3858660597017, -610.3486278003147, 
   1998.6543564942958`, -154140.93930602173`, 5357.034226578713, 
   2.7773689736072854`*^6}],
  Editable->False]], "Print",
 CellChangeTimes->{3.705739545751399*^9, 3.705740207968275*^9, 
  3.7057402690097666`*^9, 3.7285434034505835`*^9, 3.7285441429876556`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
  "3", "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", 
   "0.15900421425337366`", "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"0.0007438614856487902`", ",", 
     RowBox[{"-", "375.5306166869477`"}], ",", 
     RowBox[{"-", "5251.096588810223`"}], ",", 
     RowBox[{"-", "2128.615427274375`"}], ",", "231175.26914106612`", ",", 
     "2053.997364162983`", ",", "2.4418987862436967`*^6"}], "}"}]}],
  SequenceForm[
  3, " ", 0.15900421425337366`, " ", {
   0.0007438614856487902, -375.5306166869477, -5251.096588810223, \
-2128.615427274375, 231175.26914106612`, 2053.997364162983, 
   2.4418987862436967`*^6}],
  Editable->False]], "Print",
 CellChangeTimes->{3.705739545751399*^9, 3.705740207968275*^9, 
  3.7057402690097666`*^9, 3.7285434034505835`*^9, 3.7285441450376587`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
  "4", "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", 
   "0.09318191293560361`", "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"0.0011462461771993959`", ",", 
     RowBox[{"-", "846.3987367455205`"}], ",", 
     RowBox[{"-", "3083.838650339418`"}], ",", 
     RowBox[{"-", "5566.032636324183`"}], ",", 
     RowBox[{"-", "101521.85308394775`"}], ",", "1688.9236937866654`", ",", 
     "6.013395485528765`*^6"}], "}"}]}],
  SequenceForm[
  4, " ", 0.09318191293560361, " ", {
   0.0011462461771993959`, -846.3987367455205, -3083.838650339418, \
-5566.032636324183, -101521.85308394775`, 1688.9236937866654`, 
   6.013395485528765*^6}],
  Editable->False]], "Print",
 CellChangeTimes->{3.705739545751399*^9, 3.705740207968275*^9, 
  3.7057402690097666`*^9, 3.7285434034505835`*^9, 3.7285442313757844`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
  "5", "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", 
   "0.036155933587834144`", "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"0.0011256046740057313`", ",", 
     RowBox[{"-", "550.6613205415332`"}], ",", "5747.982451535149`", ",", 
     RowBox[{"-", "4698.062962023017`"}], ",", 
     RowBox[{"-", "342706.07686228555`"}], ",", "124.96045665761605`", ",", 
     "2.673466400026049`*^6"}], "}"}]}],
  SequenceForm[
  5, " ", 0.036155933587834144`, " ", {
   0.0011256046740057313`, -550.6613205415332, 
   5747.982451535149, -4698.062962023017, -342706.07686228555`, 
   124.96045665761605`, 2.673466400026049*^6}],
  Editable->False]], "Print",
 CellChangeTimes->{3.705739545751399*^9, 3.705740207968275*^9, 
  3.7057402690097666`*^9, 3.7285434034505835`*^9, 3.7285442837058573`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
  "5", "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", 
   "0.02775236674603198`", "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"0.0009545755946008327`", ",", 
     RowBox[{"-", "1036.921782658833`"}], ",", "4533.86630357272`", ",", 
     "5983.7201375532695`", ",", "41446.974818157396`", ",", 
     "2605.8094815077325`", ",", "1.1433948945030103`*^7"}], "}"}]}],
  SequenceForm[
  5, " ", 0.02775236674603198, " ", {
   0.0009545755946008327, -1036.921782658833, 4533.86630357272, 
   5983.7201375532695`, 41446.974818157396`, 2605.8094815077325`, 
   1.1433948945030103`*^7}],
  Editable->False]], "Print",
 CellChangeTimes->{3.705739545751399*^9, 3.705740207968275*^9, 
  3.7057402690097666`*^9, 3.7285434034505835`*^9, 3.7285442927158704`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
  "6", "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", 
   "0.00422789129486897`", "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"0.0008823700343204996`", ",", 
     RowBox[{"-", "821.5580540746441`"}], ",", "4436.891102142057`", ",", 
     "14713.360126691534`", ",", "2701.7460251042494`", ",", 
     "4970.037453949273`", ",", "5.9688110242492305`*^6"}], "}"}]}],
  SequenceForm[
  6, " ", 0.00422789129486897, " ", {
   0.0008823700343204996, -821.5580540746441, 4436.891102142057, 
   14713.360126691534`, 2701.7460251042494`, 4970.037453949273, 
   5.9688110242492305`*^6}],
  Editable->False]], "Print",
 CellChangeTimes->{3.705739545751399*^9, 3.705740207968275*^9, 
  3.7057402690097666`*^9, 3.7285434034505835`*^9, 3.7285444456791005`*^9}]
}, Open  ]],

Cell[BoxData["$Aborted"], "Output",
 CellChangeTimes->{3.728543853701247*^9, 3.728544652346221*^9}],

Cell[BoxData[""], "Print",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{3.705739545751399*^9, 3.705740207968275*^9, 
  3.7057402690097666`*^9, 3.728543532378769*^9, 3.7285437184510307`*^9}],

Cell[BoxData["$Aborted"], "Output",
 CellChangeTimes->{3.705740050013241*^9, 3.7057402649675355`*^9, 
  3.7057408750264287`*^9, 3.728543618820891*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"Cc", "=", 
   RowBox[{"acbest", "[", "cnt", "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"f", "[", 
  RowBox[{
   RowBox[{"Cc", "[", 
    RowBox[{"[", "1", "]"}], "]"}], ",", 
   RowBox[{"Cc", "[", 
    RowBox[{"[", "2", "]"}], "]"}], ",", 
   RowBox[{"Cc", "[", 
    RowBox[{"[", "3", "]"}], "]"}], ",", 
   RowBox[{"Cc", "[", 
    RowBox[{"[", "4", "]"}], "]"}], ",", 
   RowBox[{"Cc", "[", 
    RowBox[{"[", "5", "]"}], "]"}], ",", 
   RowBox[{"Cc", "[", 
    RowBox[{"[", "6", "]"}], "]"}], ",", 
   RowBox[{"Cc", "[", 
    RowBox[{"[", "7", "]"}], "]"}]}], 
  "]"}], "\[IndentingNewLine]", "Diago"}], "Input",
 CellChangeTimes->{{3.5793472823933277`*^9, 3.579347289963338*^9}, {
   3.579349398439312*^9, 3.579349432229359*^9}, {3.579350918108476*^9, 
   3.5793509315184946`*^9}, 3.5842533164805117`*^9, {3.584253766556902*^9, 
   3.584253767446104*^9}, {3.6900257010330367`*^9, 3.6900257729341493`*^9}, {
   3.6900259466390843`*^9, 3.6900259494362445`*^9}, {3.6900259937297783`*^9, 
   3.690026010399731*^9}, {3.690264881706612*^9, 3.6902648873766203`*^9}, {
   3.6902649848587575`*^9, 3.690264985018758*^9}, {3.690266348067811*^9, 
   3.6902663503878145`*^9}, 3.6902931644926043`*^9, 3.69029321143267*^9, {
   3.6902969998259044`*^9, 3.690297003516115*^9}, {3.6905481855364723`*^9, 
   3.690548218487357*^9}, {3.6907830080256615`*^9, 3.690783012359909*^9}, {
   3.6907832817663183`*^9, 3.6907832856845427`*^9}, {3.6957251784445515`*^9, 
   3.695725240353092*^9}, {3.695725511633609*^9, 3.695725591454174*^9}, {
   3.70572422217094*^9, 3.70572422252096*^9}, 3.7057243385795984`*^9}],

Cell[BoxData["0.00422789129486897`"], "Output",
 CellChangeTimes->{{3.579347285533332*^9, 3.5793472903133388`*^9}, 
   3.579348064159425*^9, {3.5793493918593025`*^9, 3.5793494325493593`*^9}, 
   3.5793504309657927`*^9, 3.5793508433483715`*^9, {3.5793509424185104`*^9, 
   3.579350951378523*^9}, {3.579352153888322*^9, 3.5793521649859405`*^9}, 
   3.584205050865268*^9, 3.584253768460106*^9, 3.5865866382554073`*^9, 
   3.5865876715829725`*^9, 3.586588538738714*^9, 3.586589420473458*^9, 
   3.5865933317839565`*^9, 3.5865956308507957`*^9, 3.58659828896911*^9, 
   3.5865983934580936`*^9, 3.586601140686432*^9, 3.6900044496795287`*^9, 
   3.690025677387684*^9, {3.690025712068668*^9, 3.6900257315987844`*^9}, {
   3.690025768556899*^9, 3.690025773984209*^9}, {3.690266328267783*^9, 
   3.690266350787815*^9}, 3.6902678012596855`*^9, {3.690293152372587*^9, 
   3.690293171602614*^9}, 3.6902970265584335`*^9, 3.6902972533784065`*^9, 
   3.6903084568472157`*^9, 3.690369800488863*^9, 3.690442901601366*^9, 
   3.690443050321574*^9, 3.69044467291397*^9, 3.6904506212149715`*^9, 
   3.6904757226733637`*^9, 3.6905481455491853`*^9, {3.6905481784720683`*^9, 
   3.690548219163396*^9}, {3.690783275173941*^9, 3.6907832862635756`*^9}, 
   3.6907833688963017`*^9, 3.6907857385888405`*^9, 3.6957251325119247`*^9, 
   3.6957251898522043`*^9, {3.69572522159402*^9, 3.6957252408861227`*^9}, 
   3.6957254476419487`*^9, {3.6957254862741585`*^9, 3.695725516251873*^9}, 
   3.6957255612224455`*^9, 3.695725595697417*^9, 3.7057256958502293`*^9, 
   3.7057271558997393`*^9, 3.705727378372464*^9, 3.705729993742055*^9, 
   3.705740053001412*^9, 3.7057408771585507`*^9, 3.7285436214208946`*^9, 
   3.7285446575962286`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"s=\"\>", "\[InvisibleSpace]", "33.474379763199565`"}],
  SequenceForm["s=", 33.474379763199565`],
  Editable->False]], "Print",
 CellChangeTimes->{{3.690548182372291*^9, 3.69054821941541*^9}, {
   3.6907832752879477`*^9, 3.6907832863825827`*^9}, 3.6907833690083084`*^9, 
   3.6907857387058473`*^9, 3.6957251345260396`*^9, 3.695725191302287*^9, {
   3.6957252216990256`*^9, 3.6957252410011296`*^9}, 3.695725447748955*^9, {
   3.6957254863811646`*^9, 3.6957255163598795`*^9}, {3.6957255936823015`*^9, 
   3.6957255967224755`*^9}, 3.705725695980237*^9, 3.7057271560547485`*^9, 
   3.705727378506472*^9, 3.7057299938900633`*^9, 3.70574005314542*^9, 
   3.7057408772905583`*^9, 3.7285436215908947`*^9, 3.7285446577462287`*^9}],

Cell[BoxData[
 TagBox[GridBox[{
    {"\<\"J\"\>", "\<\"Abs.En.(MeV)\"\>", "\<\"\"\>", "\<\"\"\>", "\<\"\"\>", \
"\<\"Rel.En.(MeV)\"\>", "\<\"\"\>", "\<\"\"\>", "\<\"\"\>", \
"\<\"Red.En.(adim)\"\>", "\<\"\"\>", "\<\"\"\>", "\<\"\"\>"},
    {"0", 
     RowBox[{"-", "3.2726831712627105`"}], 
     RowBox[{"-", "1.9271626674774982`"}], 
     RowBox[{"-", "1.262003265240895`"}], 
     RowBox[{"-", "0.8481349369551526`"}], "0.`", "1.3455205037852123`", 
     "2.0106799060218155`", "2.424548234307558`", "0.`", "19.130955296742`", 
     "28.58836211707494`", "34.472848057569976`"},
    {"2", 
     RowBox[{"-", "3.202351058573369`"}], 
     RowBox[{"-", "2.2897706518801075`"}], 
     RowBox[{"-", "1.7810485793147963`"}], 
     RowBox[{"-", "1.1747090069549897`"}], "0.07033211268934147`", 
     "0.9829125193826029`", "1.4916345919479141`", "2.097974164307721`", 
     "1.`", "13.975302060442143`", "21.208442842268905`", 
     "29.829534249518712`"},
    {"3", 
     RowBox[{"-", "2.196277828092396`"}], 
     RowBox[{"-", "0.8715992571619017`"}], 
     RowBox[{"-", "0.0673278784751008`"}], "0.5415786438457952`", 
     "1.0764053431703147`", "2.4010839141008087`", "3.2053552927876097`", 
     "3.8142618151085057`", "15.304606985500653`", "34.13922634041224`", 
     "45.57456288773432`", "54.232151847281855`"},
    {"4", 
     RowBox[{"-", "3.0457268704271403`"}], 
     RowBox[{"-", "2.096929529900151`"}], 
     RowBox[{"-", "1.5333267821861267`"}], 
     RowBox[{"-", "1.3360799354966508`"}], "0.22695630083557017`", 
     "1.1757536413625593`", "1.7393563890765837`", "1.9366032357660596`", 
     "3.226922840183136`", "16.71716654603978`", "24.730614829663374`", 
     "27.53512103809649`"},
    {"5", 
     RowBox[{"-", "1.9563358596754088`"}], 
     RowBox[{"-", "1.139940694522256`"}], 
     RowBox[{"-", "0.4815322250338217`"}], "0.18597878092738163`", 
     "1.3163473115873017`", "2.1327424767404546`", "2.7911509462288886`", 
     "3.4586619521900923`", "18.71616337478212`", "30.323879024661554`", 
     "39.685299353333306`", "49.17614187799363`"},
    {"6", 
     RowBox[{"-", "2.8123476587025076`"}], 
     RowBox[{"-", "1.8317471296321344`"}], 
     RowBox[{"-", "1.2041622563132826`"}], 
     RowBox[{"-", "0.973542922558636`"}], "0.4603355125602029`", 
     "1.440936041630576`", "2.0685209149494277`", "2.2991402487040746`", 
     "6.545168273182909`", "20.48759786294524`", "29.410760403091135`", 
     "32.689765183927136`"},
    {"7", 
     RowBox[{"-", "1.6429469418499334`"}], 
     RowBox[{"-", "0.7664978411982217`"}], 
     RowBox[{"-", "0.0694276644500158`"}], 
     RowBox[{"-", "0.010917182164338934`"}], "1.629736229412777`", 
     "2.506185330064489`", "3.2032555068126944`", "3.2617659890983717`", 
     "23.17200731067697`", "35.63358520359492`", "45.54470759269732`", 
     "46.37662462246322`"},
    {"8", 
     RowBox[{"-", "2.510896279199064`"}], 
     RowBox[{"-", "1.5018279142362676`"}], 
     RowBox[{"-", "0.8085680276446968`"}], 
     RowBox[{"-", "0.5772498800831527`"}], "0.7617868920636464`", 
     "1.7708552570264429`", "2.4641151436180135`", "2.6954332911795578`", 
     "10.83128123036025`", "25.178473805391718`", "35.03542051270471`", 
     "38.324361207310055`"}
   },
   AutoDelete->False,
   GridBoxDividers->{
    "Columns" -> {
      False, True, False, False, False, True, False, False, False, True, 
       False, False, False, True}, "Rows" -> {False, True}},
   GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
   GridBoxSpacings->{"Columns" -> {{2}}}],
  "Grid"]], "Output",
 CellChangeTimes->{{3.579347285533332*^9, 3.5793472903133388`*^9}, 
   3.579348064159425*^9, {3.5793493918593025`*^9, 3.5793494325493593`*^9}, 
   3.5793504309657927`*^9, 3.5793508433483715`*^9, {3.5793509424185104`*^9, 
   3.579350951378523*^9}, {3.579352153888322*^9, 3.5793521649859405`*^9}, 
   3.584205050865268*^9, 3.584253768460106*^9, 3.5865866382554073`*^9, 
   3.5865876715829725`*^9, 3.586588538738714*^9, 3.586589420473458*^9, 
   3.5865933317839565`*^9, 3.5865956308507957`*^9, 3.58659828896911*^9, 
   3.5865983934580936`*^9, 3.586601140686432*^9, 3.6900044496795287`*^9, 
   3.690025677387684*^9, {3.690025712068668*^9, 3.6900257315987844`*^9}, {
   3.690025768556899*^9, 3.690025773984209*^9}, {3.690266328267783*^9, 
   3.690266350787815*^9}, 3.6902678012596855`*^9, {3.690293152372587*^9, 
   3.690293171602614*^9}, 3.6902970265584335`*^9, 3.6902972533784065`*^9, 
   3.6903084568472157`*^9, 3.690369800488863*^9, 3.690442901601366*^9, 
   3.690443050321574*^9, 3.69044467291397*^9, 3.6904506212149715`*^9, 
   3.6904757226733637`*^9, 3.6905481455491853`*^9, {3.6905481784720683`*^9, 
   3.690548219163396*^9}, {3.690783275173941*^9, 3.6907832862635756`*^9}, 
   3.6907833688963017`*^9, 3.6907857385888405`*^9, 3.6957251325119247`*^9, 
   3.6957251898522043`*^9, {3.69572522159402*^9, 3.6957252408861227`*^9}, 
   3.6957254476419487`*^9, {3.6957254862741585`*^9, 3.695725516251873*^9}, 
   3.6957255612224455`*^9, 3.695725595697417*^9, 3.7057256958502293`*^9, 
   3.7057271558997393`*^9, 3.705727378372464*^9, 3.705729993742055*^9, 
   3.705740053001412*^9, 3.7057408771585507`*^9, 3.7285436214208946`*^9, 
   3.7285446580462294`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"numtrial", "=", "15"}], ";"}], "  ", 
  RowBox[{"(*", " ", 
   RowBox[{
   "number", " ", "of", " ", "trials", " ", "within", " ", "a", " ", "single",
     " ", "reinizialization"}], " ", "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"outloop", "=", "15"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"nnmax", "=", "10"}], ";"}], "    ", 
  RowBox[{"(*", " ", 
   RowBox[{"number", " ", "of", " ", "reinizializations"}], " ", 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{"Do", "[", "    ", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"acbest", "[", "0", "]"}], "=", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"1", "/", "100."}], ",", "100.", ",", "10000.", ",", 
       RowBox[{"10.", "^", "6"}], ",", 
       RowBox[{"10.", "^", "6"}], ",", 
       RowBox[{"10.", "^", "6"}], ",", 
       RowBox[{"10.", "^", "6"}]}], "}"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{"ftest", "=", 
     RowBox[{"f", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"acbest", "[", "0", "]"}], "[", 
        RowBox[{"[", "1", "]"}], "]"}], ",", 
       RowBox[{
        RowBox[{"acbest", "[", "0", "]"}], "[", 
        RowBox[{"[", "2", "]"}], "]"}], ",", 
       RowBox[{
        RowBox[{"acbest", "[", "0", "]"}], "[", 
        RowBox[{"[", "3", "]"}], "]"}], ",", 
       RowBox[{
        RowBox[{"acbest", "[", "0", "]"}], "[", 
        RowBox[{"[", "4", "]"}], "]"}], ",", 
       RowBox[{
        RowBox[{"acbest", "[", "0", "]"}], "[", 
        RowBox[{"[", "5", "]"}], "]"}], ",", 
       RowBox[{
        RowBox[{"acbest", "[", "0", "]"}], "[", 
        RowBox[{"[", "6", "]"}], "]"}], ",", 
       RowBox[{
        RowBox[{"acbest", "[", "0", "]"}], "[", 
        RowBox[{"[", "7", "]"}], "]"}]}], "]"}]}], " ", ";", 
    "\[IndentingNewLine]", 
    RowBox[{"cnt", "=", "0"}], ";", "\[IndentingNewLine]", 
    RowBox[{"Do", "[", "   ", 
     RowBox[{"(*", " ", 
      RowBox[{
      "starting", " ", "from", " ", "same", " ", "initial", " ", "conditions",
        " ", "this", " ", "doloop", " ", "search", " ", "for", " ", "the", 
       " ", "best", " ", "set", " ", "of", " ", "parameters"}], " ", "*)"}], 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Do", "[", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{
          RowBox[{"ac", "[", "k", "]"}], "=", 
          RowBox[{
           RowBox[{"RandomVariate", "[", 
            RowBox[{
             RowBox[{"NormalDistribution", "[", 
              RowBox[{"0", ",", "1.4826"}], "]"}], ",", "numtrial"}], "]"}], 
           "*", 
           RowBox[{
            RowBox[{"acbest", "[", "cnt", "]"}], "[", 
            RowBox[{"[", "k", "]"}], "]"}]}]}], "\[IndentingNewLine]", ",", 
         RowBox[{"{", 
          RowBox[{"k", ",", "2", ",", "5"}], "}"}]}], "]"}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"Do", "[", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{
          RowBox[{"ac", "[", "k", "]"}], "=", 
          RowBox[{"Abs", "[", 
           RowBox[{
            RowBox[{"RandomVariate", "[", 
             RowBox[{
              RowBox[{"NormalDistribution", "[", 
               RowBox[{"0", ",", "1.4826"}], "]"}], ",", "numtrial"}], "]"}], 
            "*", 
            RowBox[{
             RowBox[{"acbest", "[", "cnt", "]"}], "[", 
             RowBox[{"[", "k", "]"}], "]"}]}], "]"}]}], "\[IndentingNewLine]",
          ",", 
         RowBox[{"{", 
          RowBox[{"k", ",", 
           RowBox[{"{", 
            RowBox[{"1", ",", "6", ",", "7"}], "}"}]}], "}"}]}], "]"}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"Do", "[", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{
          RowBox[{"fxx", "=", 
           RowBox[{"f", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"ac", "[", "1", "]"}], "[", 
              RowBox[{"[", "j", "]"}], "]"}], ",", 
             RowBox[{
              RowBox[{"ac", "[", "2", "]"}], "[", 
              RowBox[{"[", "j", "]"}], "]"}], ",", 
             RowBox[{
              RowBox[{"ac", "[", "3", "]"}], "[", 
              RowBox[{"[", "j", "]"}], "]"}], ",", 
             RowBox[{
              RowBox[{"ac", "[", "4", "]"}], "[", 
              RowBox[{"[", "j", "]"}], "]"}], ",", 
             RowBox[{
              RowBox[{"ac", "[", "5", "]"}], "[", 
              RowBox[{"[", "j", "]"}], "]"}], ",", 
             RowBox[{
              RowBox[{"ac", "[", "6", "]"}], "[", 
              RowBox[{"[", "j", "]"}], "]"}], ",", 
             RowBox[{
              RowBox[{"ac", "[", "7", "]"}], "[", 
              RowBox[{"[", "j", "]"}], "]"}]}], "]"}]}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{"fxx", "<", "ftest"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"cnt", "=", 
               RowBox[{"cnt", "+", "1"}]}], ",", 
              RowBox[{
               RowBox[{"acbest", "[", "cnt", "]"}], "=", 
               RowBox[{"{", 
                RowBox[{
                 RowBox[{
                  RowBox[{"ac", "[", "1", "]"}], "[", 
                  RowBox[{"[", "j", "]"}], "]"}], ",", 
                 RowBox[{
                  RowBox[{"ac", "[", "2", "]"}], "[", 
                  RowBox[{"[", "j", "]"}], "]"}], ",", 
                 RowBox[{
                  RowBox[{"ac", "[", "3", "]"}], "[", 
                  RowBox[{"[", "j", "]"}], "]"}], ",", 
                 RowBox[{
                  RowBox[{"ac", "[", "4", "]"}], "[", 
                  RowBox[{"[", "j", "]"}], "]"}], ",", 
                 RowBox[{
                  RowBox[{"ac", "[", "5", "]"}], "[", 
                  RowBox[{"[", "j", "]"}], "]"}], ",", 
                 RowBox[{
                  RowBox[{"ac", "[", "6", "]"}], "[", 
                  RowBox[{"[", "j", "]"}], "]"}], ",", 
                 RowBox[{
                  RowBox[{"ac", "[", "7", "]"}], "[", 
                  RowBox[{"[", "j", "]"}], "]"}]}], "}"}]}], ",", " ", 
              RowBox[{"ftest", "=", "fxx"}]}], "}"}]}], "]"}], ";"}], 
         "\[IndentingNewLine]", ",", 
         RowBox[{"{", 
          RowBox[{"j", ",", "1", ",", "numtrial"}], "}"}]}], "]"}], ";"}], 
      "\[IndentingNewLine]", ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", "1", ",", "outloop"}], "}"}]}], "]"}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"ftt", "[", "nn", "]"}], "=", "ftest"}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"actt", "[", "nn", "]"}], "=", 
     RowBox[{"acbest", "[", "cnt", "]"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{"Print", "[", 
     RowBox[{
     "nn", ",", "\"\< \>\"", ",", " ", "ftest", ",", "\"\< \>\"", ",", " ", 
      RowBox[{"acbest", "[", "cnt", "]"}]}], "]"}], ";", " ", 
    "\[IndentingNewLine]", 
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"Mod", "[", 
        RowBox[{"nn", ",", "2"}], "]"}], "\[Equal]", "0"}], ",", 
      RowBox[{"Print", "[", "nn", "]"}]}], "]"}], ";"}], 
   "\[IndentingNewLine]", ",", 
   RowBox[{"{", 
    RowBox[{"nn", ",", "1", ",", "nnmax"}], "}"}]}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ffinal", "=", "100"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Do", "[", 
  RowBox[{
   RowBox[{"If", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"ftt", "[", "nn", "]"}], "<", "ffinal"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"acfinal", "=", 
        RowBox[{"actt", "[", "nn", "]"}]}], ",", 
       RowBox[{"ffinal", "=", 
        RowBox[{"ftt", "[", "nn", "]"}]}], ",", " ", 
       RowBox[{"Print", "[", 
        RowBox[{
        "nn", ",", "\"\< \>\"", ",", " ", "ffinal", ",", " ", "\"\< \>\"", 
         ",", "acfinal"}], "]"}]}], "}"}]}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"nn", ",", "1", ",", "nnmax"}], "}"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.579330142233833*^9, 3.579330143133834*^9}, {
   3.579330411234209*^9, 3.579330473674297*^9}, {3.5793305595454173`*^9, 
   3.5793305712354336`*^9}, {3.5793307046656203`*^9, 3.579330875405859*^9}, {
   3.5793323807679667`*^9, 3.5793324096880074`*^9}, {3.5793325026681376`*^9, 
   3.579332617368298*^9}, {3.5793327592584968`*^9, 3.5793327722985153`*^9}, {
   3.5793328456886177`*^9, 3.579332862528641*^9}, {3.5793329049187007`*^9, 
   3.5793329120187106`*^9}, {3.579333134120022*^9, 3.5793332270001516`*^9}, {
   3.579333286550235*^9, 3.579333457872476*^9}, {3.57933359644267*^9, 
   3.5793337667829084`*^9}, {3.5793340232832675`*^9, 3.5793340302932777`*^9}, 
   3.5793340618533216`*^9, {3.5793354533203435`*^9, 3.5793354568403482`*^9}, {
   3.5793356210905905`*^9, 3.579335621610592*^9}, {3.5793356700606594`*^9, 
   3.5793356745306654`*^9}, {3.579335839176978*^9, 3.5793358738070264`*^9}, 
   3.579336118043413*^9, {3.579336338225723*^9, 3.579336339915725*^9}, {
   3.57933647962993*^9, 3.579336527779997*^9}, {3.579336705300246*^9, 
   3.5793367900503645`*^9}, {3.5793368422204375`*^9, 3.579336911010534*^9}, {
   3.5793370707607574`*^9, 3.579337074800763*^9}, {3.579337152580872*^9, 
   3.579337189190923*^9}, {3.579338582057884*^9, 3.5793385922378983`*^9}, {
   3.5793390086484814`*^9, 3.5793390087484818`*^9}, 3.5793407620339465`*^9, {
   3.579342547372452*^9, 3.57934255327246*^9}, {3.5793430237521296`*^9, 
   3.5793430680021915`*^9}, {3.5793431206822653`*^9, 
   3.5793431792023478`*^9}, {3.5793432236524096`*^9, 3.57934331674254*^9}, {
   3.5793433658126087`*^9, 3.579343438972711*^9}, {3.5793434713527565`*^9, 
   3.5793434818327713`*^9}, {3.5793438461132812`*^9, 
   3.5793438511732883`*^9}, {3.579343953007433*^9, 3.5793439784474688`*^9}, {
   3.579344868802887*^9, 3.57934487123289*^9}, {3.579350149908394*^9, 
   3.579350162790413*^9}, {3.584338447693843*^9, 3.5843384497530465`*^9}, {
   3.5843384860231104`*^9, 3.5843385241027775`*^9}, {3.584339353376637*^9, 
   3.5843393538134375`*^9}, 3.586604923180015*^9, {3.705725805951527*^9, 
   3.7057258062175426`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{
  "1", "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", 
   "0.24666188614459877`", "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"0.00019467155446285597`", ",", "2078.686884883437`", ",", 
     RowBox[{"-", "27722.443481070735`"}], ",", "379542.6537375829`", ",", 
     RowBox[{"-", "288243.19328736694`"}], ",", "65036.1460920315`", ",", 
     "159815.89618097755`"}], "}"}]}],
  SequenceForm[
  1, " ", 0.24666188614459877`, " ", {0.00019467155446285597`, 
   2078.686884883437, -27722.443481070735`, 
   379542.6537375829, -288243.19328736694`, 65036.1460920315, 
   159815.89618097755`}],
  Editable->False]], "Print",
 CellChangeTimes->{3.705726029906337*^9, 3.705727630028858*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
  "2", "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", 
   "0.2758104342128521`", "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"0.00021631211539958122`", ",", "193.45287661269043`", ",", 
     RowBox[{"-", "8156.9557029321395`"}], ",", "1.6920317861967857`*^6", ",", 
     RowBox[{"-", "1.6555550171390874`*^6"}], ",", "388864.52697015856`", ",",
      "449464.5317019736`"}], "}"}]}],
  SequenceForm[
  2, " ", 0.2758104342128521, " ", {0.00021631211539958122`, 
   193.45287661269043`, -8156.9557029321395`, 
   1.6920317861967857`*^6, -1.6555550171390874`*^6, 388864.52697015856`, 
   449464.5317019736}],
  Editable->False]], "Print",
 CellChangeTimes->{3.705726029906337*^9, 3.705727850104446*^9}],

Cell[BoxData["2"], "Print",
 CellChangeTimes->{3.705726029906337*^9, 3.7057278501064463`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
  "3", "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", 
   "0.2592506270067233`", "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"0.00016038403052414106`", ",", "1648.9798208063783`", ",", 
     RowBox[{"-", "5130.179122599083`"}], ",", "805693.5164177632`", ",", 
     "9.453895026830226`*^6", ",", "1.9005604816352418`*^8", ",", 
     "1.9086406525419103`*^6"}], "}"}]}],
  SequenceForm[
  3, " ", 0.2592506270067233, " ", {0.00016038403052414106`, 
   1648.9798208063783`, -5130.179122599083, 805693.5164177632, 
   9.453895026830226*^6, 1.9005604816352418`*^8, 1.9086406525419103`*^6}],
  Editable->False]], "Print",
 CellChangeTimes->{3.705726029906337*^9, 3.7057280604234753`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
  "4", "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", 
   "0.2611130599901837`", "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"0.00019339735878298929`", ",", "190.32599286689197`", ",", 
     RowBox[{"-", "15106.36224362602`"}], ",", "2.0129847175950897`*^6", ",", 
     RowBox[{"-", "1.2486323050578786`*^6"}], ",", "141022.51250612264`", ",",
      "266702.641480961`"}], "}"}]}],
  SequenceForm[
  4, " ", 0.2611130599901837, " ", {0.00019339735878298929`, 
   190.32599286689197`, -15106.36224362602, 
   2.0129847175950897`*^6, -1.2486323050578786`*^6, 141022.51250612264`, 
   266702.641480961}],
  Editable->False]], "Print",
 CellChangeTimes->{3.705726029906337*^9, 3.7057282705754957`*^9}],

Cell[BoxData["4"], "Print",
 CellChangeTimes->{3.705726029906337*^9, 3.7057282705764956`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
  "5", "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", 
   "0.3800267431961122`", "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"0.0004048899291618343`", ",", "123.09881246683868`", ",", 
     RowBox[{"-", "428.0936335889727`"}], ",", "554377.7014541146`", ",", 
     "157436.4605381245`", ",", "7.722392992379555`*^6", ",", 
     "2.92414115479763`*^6"}], "}"}]}],
  SequenceForm[
  5, " ", 0.3800267431961122, " ", {0.0004048899291618343, 
   123.09881246683868`, -428.0936335889727, 554377.7014541146, 
   157436.4605381245, 7.722392992379555*^6, 2.92414115479763*^6}],
  Editable->False]], "Print",
 CellChangeTimes->{3.705726029906337*^9, 3.7057285049629016`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
  "6", "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", 
   "0.27064237505883193`", "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"0.0008427314812615793`", ",", 
     RowBox[{"-", "2.2655631334204935`"}], ",", 
     RowBox[{"-", "2582.4674434066555`"}], ",", "101046.17125610015`", ",", 
     "1.3960681212875978`*^6", ",", "833515.2897812681`", ",", 
     "1.8408397856822424`*^6"}], "}"}]}],
  SequenceForm[
  6, " ", 0.27064237505883193`, " ", {
   0.0008427314812615793, -2.2655631334204935`, -2582.4674434066555`, 
   101046.17125610015`, 1.3960681212875978`*^6, 833515.2897812681, 
   1.8408397856822424`*^6}],
  Editable->False]], "Print",
 CellChangeTimes->{3.705726029906337*^9, 3.705728742412483*^9}],

Cell[BoxData["6"], "Print",
 CellChangeTimes->{3.705726029906337*^9, 3.705728742414483*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
  "7", "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", 
   "0.2611609844762215`", "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
    "0.00014430212759792126`", ",", "117.32071078551242`", ",", 
     "20228.803238261153`", ",", "3.4546216529248795`*^6", ",", 
     RowBox[{"-", "2.3201493546813764`*^6"}], ",", "220804.98823540437`", ",",
      "319151.60961094114`"}], "}"}]}],
  SequenceForm[
  7, " ", 0.2611609844762215, " ", {0.00014430212759792126`, 
   117.32071078551242`, 20228.803238261153`, 
   3.4546216529248795`*^6, -2.3201493546813764`*^6, 220804.98823540437`, 
   319151.60961094114`}],
  Editable->False]], "Print",
 CellChangeTimes->{3.705726029906337*^9, 3.705728974614764*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
  "8", "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", 
   "0.27196822247086966`", "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"0.0003459574717948195`", ",", 
     RowBox[{"-", "43.79409531302673`"}], ",", "13067.040055968799`", ",", 
     "706489.9709163415`", ",", 
     RowBox[{"-", "3.4118938066566777`*^6"}], ",", "1.084738962207467`*^6", 
     ",", "976890.7005534946`"}], "}"}]}],
  SequenceForm[
  8, " ", 0.27196822247086966`, " ", {
   0.0003459574717948195, -43.79409531302673, 13067.040055968799`, 
   706489.9709163415, -3.4118938066566777`*^6, 1.084738962207467*^6, 
   976890.7005534946}],
  Editable->False]], "Print",
 CellChangeTimes->{3.705726029906337*^9, 3.7057292082801294`*^9}],

Cell[BoxData["8"], "Print",
 CellChangeTimes->{3.705726029906337*^9, 3.7057292082821293`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
  "9", "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", 
   "0.2615460927440928`", "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"0.00008067892838943884`", ",", 
     RowBox[{"-", "25.41939450775687`"}], ",", "4550.711038068158`", ",", 
     "1.1777659524389619`*^7", ",", 
     RowBox[{"-", "1.6433027644388901`*^7"}], ",", "1.8558581757562347`*^6", 
     ",", "93329.11990207691`"}], "}"}]}],
  SequenceForm[
  9, " ", 0.2615460927440928, " ", {
   0.00008067892838943884, -25.41939450775687, 4550.711038068158, 
   1.1777659524389619`*^7, -1.6433027644388901`*^7, 1.8558581757562347`*^6, 
   93329.11990207691}],
  Editable->False]], "Print",
 CellChangeTimes->{3.705726029906337*^9, 3.7057294380922737`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
  "10", "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", 
   "0.24901424714200898`", "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
    "0.00023158746073158163`", ",", "339.94768405269303`", ",", 
     "690.337214309087`", ",", "1.2006708651374131`*^6", ",", 
     "2.4580637384093623`*^6", ",", "2.2195054840820325`*^6", ",", 
     "41140.69949710996`"}], "}"}]}],
  SequenceForm[
  10, " ", 0.24901424714200898`, " ", {0.00023158746073158163`, 
   339.94768405269303`, 690.337214309087, 1.2006708651374131`*^6, 
   2.4580637384093623`*^6, 2.2195054840820325`*^6, 41140.69949710996}],
  Editable->False]], "Print",
 CellChangeTimes->{3.705726029906337*^9, 3.7057296680414257`*^9}],

Cell[BoxData["10"], "Print",
 CellChangeTimes->{3.705726029906337*^9, 3.705729668043426*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
  "1", "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", 
   "0.24666188614459877`", "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"0.00019467155446285597`", ",", "2078.686884883437`", ",", 
     RowBox[{"-", "27722.443481070735`"}], ",", "379542.6537375829`", ",", 
     RowBox[{"-", "288243.19328736694`"}], ",", "65036.1460920315`", ",", 
     "159815.89618097755`"}], "}"}]}],
  SequenceForm[
  1, " ", 0.24666188614459877`, " ", {0.00019467155446285597`, 
   2078.686884883437, -27722.443481070735`, 
   379542.6537375829, -288243.19328736694`, 65036.1460920315, 
   159815.89618097755`}],
  Editable->False]], "Print",
 CellChangeTimes->{3.705726029906337*^9, 3.7057296680454264`*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"Cc", "=", "acfinal"}], "\[IndentingNewLine]", 
 RowBox[{"Cc", "=", 
  RowBox[{"{", 
   RowBox[{
   "0.0005260281180704149`", ",", "418.422692847427`", ",", 
    "2975.4762711554404`", ",", "127867.23094588332`", ",", 
    RowBox[{"-", "137104.73857401646`"}], ",", "1.2552609673723854`*^7", ",", 
    "193469.21702914432`"}], "}"}]}], "\[IndentingNewLine]", 
 RowBox[{"f", "[", 
  RowBox[{
   RowBox[{"Cc", "[", 
    RowBox[{"[", "1", "]"}], "]"}], ",", 
   RowBox[{"Cc", "[", 
    RowBox[{"[", "2", "]"}], "]"}], ",", 
   RowBox[{"Cc", "[", 
    RowBox[{"[", "3", "]"}], "]"}], ",", 
   RowBox[{"Cc", "[", 
    RowBox[{"[", "4", "]"}], "]"}], ",", 
   RowBox[{"Cc", "[", 
    RowBox[{"[", "5", "]"}], "]"}], ",", 
   RowBox[{"Cc", "[", 
    RowBox[{"[", "6", "]"}], "]"}], ",", 
   RowBox[{"Cc", "[", 
    RowBox[{"[", "7", "]"}], "]"}]}], 
  "]"}], "\[IndentingNewLine]", "Diago"}], "Input",
 CellChangeTimes->{{3.579330753075688*^9, 3.5793307670257072`*^9}, {
  3.579332887108676*^9, 3.5793329233087263`*^9}, {3.5793329637597833`*^9, 
  3.579333028789874*^9}, {3.5793339761632013`*^9, 3.579333985003214*^9}, {
  3.579335569100518*^9, 3.5793356080705724`*^9}, {3.584253831827417*^9, 
  3.584253835150223*^9}, {3.584784763922585*^9, 3.584784774000203*^9}, {
  3.7057300285970488`*^9, 3.7057300289300675`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0.00019467155446285597`", ",", "2078.686884883437`", ",", 
   RowBox[{"-", "27722.443481070735`"}], ",", "379542.6537375829`", ",", 
   RowBox[{"-", "288243.19328736694`"}], ",", "65036.1460920315`", ",", 
   "159815.89618097755`"}], "}"}]], "Output",
 CellChangeTimes->{
  3.579333029159875*^9, 3.579333884823074*^9, 3.579333991233223*^9, {
   3.5793355530704956`*^9, 3.5793355729605236`*^9}, 3.579335608390573*^9, 
   3.5793357398708344`*^9, 3.5793359402591453`*^9, 3.579336119953416*^9, 
   3.579336466409911*^9, 3.5793366573401785`*^9, 3.5793370887107825`*^9, 
   3.5793371365708494`*^9, 3.579337319631106*^9, 3.579342931732001*^9, 
   3.579343087622219*^9, 3.5793457348151517`*^9, 3.584205713384881*^9, 
   3.5842073904970264`*^9, {3.584253822951001*^9, 3.584253835540223*^9}, 
   3.584338090188015*^9, 3.5843409872203484`*^9, 3.5847846867960496`*^9, {
   3.5847847662469893`*^9, 3.584784774437003*^9}, 3.584784861703557*^9, 
   3.705726858245715*^9, 3.7057273911331944`*^9, {3.7057300157663145`*^9, 
   3.7057300299421253`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "0.0005260281180704149`", ",", "418.422692847427`", ",", 
   "2975.4762711554404`", ",", "127867.23094588332`", ",", 
   RowBox[{"-", "137104.73857401646`"}], ",", "1.2552609673723854`*^7", ",", 
   "193469.21702914432`"}], "}"}]], "Output",
 CellChangeTimes->{
  3.579333029159875*^9, 3.579333884823074*^9, 3.579333991233223*^9, {
   3.5793355530704956`*^9, 3.5793355729605236`*^9}, 3.579335608390573*^9, 
   3.5793357398708344`*^9, 3.5793359402591453`*^9, 3.579336119953416*^9, 
   3.579336466409911*^9, 3.5793366573401785`*^9, 3.5793370887107825`*^9, 
   3.5793371365708494`*^9, 3.579337319631106*^9, 3.579342931732001*^9, 
   3.579343087622219*^9, 3.5793457348151517`*^9, 3.584205713384881*^9, 
   3.5842073904970264`*^9, {3.584253822951001*^9, 3.584253835540223*^9}, 
   3.584338090188015*^9, 3.5843409872203484`*^9, 3.5847846867960496`*^9, {
   3.5847847662469893`*^9, 3.584784774437003*^9}, 3.584784861703557*^9, 
   3.705726858245715*^9, 3.7057273911331944`*^9, {3.7057300157663145`*^9, 
   3.705730029951126*^9}}],

Cell[BoxData["0.22974271146624026`"], "Output",
 CellChangeTimes->{
  3.579333029159875*^9, 3.579333884823074*^9, 3.579333991233223*^9, {
   3.5793355530704956`*^9, 3.5793355729605236`*^9}, 3.579335608390573*^9, 
   3.5793357398708344`*^9, 3.5793359402591453`*^9, 3.579336119953416*^9, 
   3.579336466409911*^9, 3.5793366573401785`*^9, 3.5793370887107825`*^9, 
   3.5793371365708494`*^9, 3.579337319631106*^9, 3.579342931732001*^9, 
   3.579343087622219*^9, 3.5793457348151517`*^9, 3.584205713384881*^9, 
   3.5842073904970264`*^9, {3.584253822951001*^9, 3.584253835540223*^9}, 
   3.584338090188015*^9, 3.5843409872203484`*^9, 3.5847846867960496`*^9, {
   3.5847847662469893`*^9, 3.584784774437003*^9}, 3.584784861703557*^9, 
   3.705726858245715*^9, 3.7057273911331944`*^9, {3.7057300157663145`*^9, 
   3.705730030877179*^9}}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"s=\"\>", "\[InvisibleSpace]", "46.423898459711516`"}],
  SequenceForm["s=", 46.423898459711516`],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.5842538356182237`*^9, 3.584338090765216*^9, 3.5843409878131495`*^9, 
   3.5847846873576508`*^9, {3.58478476682419*^9, 3.5847847749830046`*^9}, 
   3.5847848622495575`*^9, 3.7057268592267714`*^9, 3.705727392178254*^9, {
   3.705730016873378*^9, 3.7057300310061865`*^9}}],

Cell[BoxData[
 TagBox[GridBox[{
    {"\<\"J\"\>", "\<\"Abs.En.(MeV)\"\>", "\<\"\"\>", "\<\"\"\>", "\<\"\"\>", \
"\<\"Rel.En.(MeV)\"\>", "\<\"\"\>", "\<\"\"\>", "\<\"\"\>", \
"\<\"Red.En.(adim)\"\>", "\<\"\"\>", "\<\"\"\>", "\<\"\"\>"},
    {"0", "1.3342430840123771`", "2.6508968492971747`", "3.2638775955082058`",
      "4.1275727982089165`", "0.`", "1.3166537652847976`", 
     "1.9296345114958287`", "2.793329714196539`", "0.`", "2.195961986871336`",
      "3.2183130808753746`", "4.658814664041122`"},
    {"2", "1.933822572708664`", "2.5711239044510847`", "3.339507996526729`", 
     "3.9415297346074327`", "0.5995794886962869`", "1.2368808204387076`", 
     "2.0052649125143516`", "2.6072866505950554`", "1.`", 
     "2.062913831705877`", "3.344452154083119`", "4.348525424484225`"},
    {"3", "3.2225519736289954`", "4.764401559385501`", "5.4064258526302655`", 
     "6.421065287125327`", "1.8883088896166182`", "3.4301584753731236`", 
     "4.072182768617888`", "5.086822203112949`", "3.149388738635002`", 
     "5.720940325746614`", "6.79173128065531`", "8.483983023124473`"},
    {"4", "2.5642105006594753`", "3.239947491351078`", "3.9148820470792938`", 
     "4.0516915517921275`", "1.2299674166470982`", "1.9057044073387008`", 
     "2.5806389630669164`", "2.71744846777975`", "2.051383410932742`", 
     "3.1784016019000663`", "4.304081463290554`", "4.532257221954863`"},
    {"5", "3.9055959613995426`", "4.619610402490039`", "5.513676428078952`", 
     "6.15032309394633`", "2.5713528773871657`", "3.285367318477662`", 
     "4.179433344066575`", "4.816080009933953`", "4.2885937992613155`", 
     "5.479452483641988`", "6.970607605597462`", "8.03242956226861`"},
    {"6", "3.2226036370094917`", "3.9369462594614877`", "4.637007850573916`", 
     "4.7853296464376704`", "1.8883605529971146`", "2.6027031754491103`", 
     "3.3027647665615385`", "3.451086562425293`", "3.1494749046588075`", 
     "4.340880941588535`", "5.5084685664331206`", "5.755844933803963`"},
    {"7", "4.612223970408331`", "5.35850805309801`", "6.100374069060225`", 
     "6.282681355441458`", "3.2779808863959534`", "4.024264969085633`", 
     "4.766130985047847`", "4.94843827142908`", "5.46713312945966`", 
     "6.71181227002263`", "7.949122801734301`", "8.253181379151014`"},
    {"8", "3.9067457799727023`", "4.659407313926904`", "5.3859434978446545`", 
     "5.53957860673901`", "2.572502695960325`", "3.3251642299145265`", 
     "4.051700413832277`", "4.2053355227266325`", "4.290511507579956`", 
     "5.545827188226026`", "6.757570080728096`", "7.013808180581071`"}
   },
   AutoDelete->False,
   GridBoxDividers->{
    "Columns" -> {
      False, True, False, False, False, True, False, False, False, True, 
       False, False, False, True}, "Rows" -> {False, True}},
   GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
   GridBoxSpacings->{"Columns" -> {{2}}}],
  "Grid"]], "Output",
 CellChangeTimes->{
  3.579333029159875*^9, 3.579333884823074*^9, 3.579333991233223*^9, {
   3.5793355530704956`*^9, 3.5793355729605236`*^9}, 3.579335608390573*^9, 
   3.5793357398708344`*^9, 3.5793359402591453`*^9, 3.579336119953416*^9, 
   3.579336466409911*^9, 3.5793366573401785`*^9, 3.5793370887107825`*^9, 
   3.5793371365708494`*^9, 3.579337319631106*^9, 3.579342931732001*^9, 
   3.579343087622219*^9, 3.5793457348151517`*^9, 3.584205713384881*^9, 
   3.5842073904970264`*^9, {3.584253822951001*^9, 3.584253835540223*^9}, 
   3.584338090188015*^9, 3.5843409872203484`*^9, 3.5847846867960496`*^9, {
   3.5847847662469893`*^9, 3.584784774437003*^9}, 3.584784861703557*^9, 
   3.705726858245715*^9, 3.7057273911331944`*^9, {3.7057300157663145`*^9, 
   3.7057300312462*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"Display", " ", "of", " ", "potential", " ", "energy", " ", 
    RowBox[{"surface", ".", " ", "The"}], " ", "user", " ", "can", " ", "set",
     " ", "the", " ", "parameters", " ", "vlimit", " ", "and", " ", "xmax"}], 
   " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"V", "[", 
     RowBox[{"\[Beta]_", ",", "\[Gamma]_"}], "]"}], ":=", 
    RowBox[{
     RowBox[{
      RowBox[{"1", "/", 
       RowBox[{"Sqrt", "[", "5", "]"}]}], 
      RowBox[{"Cc", "[", 
       RowBox[{"[", "2", "]"}], "]"}], 
      RowBox[{"\[Beta]", "^", "2"}]}], "-", 
     RowBox[{
      RowBox[{"Sqrt", "[", 
       RowBox[{"2", "/", "35"}], "]"}], 
      RowBox[{"Cc", "[", 
       RowBox[{"[", "3", "]"}], "]"}], 
      RowBox[{"\[Beta]", "^", "3"}], 
      RowBox[{"Cos", "[", 
       RowBox[{"3", "\[Gamma]"}], "]"}]}], "+", 
     RowBox[{
      RowBox[{"1", "/", "5"}], 
      RowBox[{"Cc", "[", 
       RowBox[{"[", "4", "]"}], "]"}], 
      RowBox[{"\[Beta]", "^", "4"}]}], "-", 
     RowBox[{
      RowBox[{"Sqrt", "[", 
       RowBox[{"2", "/", "175"}], "]"}], 
      RowBox[{"Cc", "[", 
       RowBox[{"[", "5", "]"}], "]"}], 
      RowBox[{"\[Beta]", "^", "5"}], 
      RowBox[{"Cos", "[", 
       RowBox[{"3", "\[Gamma]"}], "]"}]}], "+", 
     RowBox[{
      RowBox[{"2", "/", "35"}], 
      RowBox[{"Cc", "[", 
       RowBox[{"[", "6", "]"}], "]"}], 
      RowBox[{"\[Beta]", "^", "6"}], 
      RowBox[{
       RowBox[{"Cos", "[", 
        RowBox[{"3", "\[Gamma]"}], "]"}], "^", "2"}]}], "+", 
     RowBox[{
      RowBox[{"1", "/", 
       RowBox[{"(", 
        RowBox[{"5", 
         RowBox[{"Sqrt", "[", "5", "]"}]}], ")"}]}], 
      RowBox[{"Cc", "[", 
       RowBox[{"[", "7", "]"}], "]"}], 
      RowBox[{"\[Beta]", "^", "6"}]}]}]}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"fmn", ":=", 
     RowBox[{"FindMinimum", "[", 
      RowBox[{
       RowBox[{"V", "[", 
        RowBox[{"\[Beta]", ",", "\[Gamma]"}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"\[Beta]", ",", "0.3", ",", "0.", ",", "0.5"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"\[Gamma]", ",", 
           RowBox[{"Pi", "/", "6"}], ",", 
           RowBox[{
            RowBox[{"-", "Pi"}], "/", "3."}], ",", 
           RowBox[{"Pi", "/", "3"}]}], "}"}]}], "}"}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"minv", ":=", 
    RowBox[{"fmn", "[", 
     RowBox[{"[", "1", "]"}], "]"}]}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"vlimit", "=", 
     RowBox[{
      RowBox[{"IntegerPart", "[", "minv", "]"}], "+", "5"}]}], ";", " ", 
    RowBox[{"(*", " ", 
     RowBox[{
     "This", " ", "parameter", " ", "sets", " ", "the", " ", "maximum", " ", 
      "value", " ", "of", " ", "potential", " ", "to", " ", "be", " ", 
      "displayed", " ", "and", " ", "labeled"}], " ", "*)"}], 
    "\[IndentingNewLine]", 
    RowBox[{"xmax", "=", "0.10"}], ";", "  ", 
    RowBox[{"(*", " ", 
     RowBox[{
     "This", " ", "is", " ", "the", " ", "maximum", " ", "value", " ", "of", 
      " ", "x", " ", "and", " ", "y", " ", "in", " ", "the", " ", "plot"}], 
     " ", "*)"}], "\[IndentingNewLine]", 
    RowBox[{"cont", ":=", 
     RowBox[{"Table", "[", 
      RowBox[{"i", ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", 
         RowBox[{
          RowBox[{"IntegerPart", "[", "minv", "]"}], "-", "1"}], ",", 
         "vlimit", ",", "0.05"}], "}"}]}], "]"}]}]}], "\[IndentingNewLine]", 
   RowBox[{"ContourPlot", "[", 
    RowBox[{
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"ArcTan", "[", 
          RowBox[{"x", ",", "y"}], "]"}], "\[LessEqual]", 
         RowBox[{"Pi", "/", "3"}]}], "&&", 
        RowBox[{
         RowBox[{"V", "[", 
          RowBox[{
           RowBox[{"Sqrt", "[", 
            RowBox[{
             RowBox[{"x", "^", "2"}], "+", 
             RowBox[{"y", "^", "2"}]}], "]"}], ",", 
           RowBox[{"ArcTan", "[", 
            RowBox[{"x", ",", "y"}], "]"}]}], "]"}], "\[LessEqual]", 
         "vlimit"}]}], ",", 
       RowBox[{"V", "[", 
        RowBox[{
         RowBox[{"Sqrt", "[", 
          RowBox[{
           RowBox[{"x", "^", "2"}], "+", 
           RowBox[{"y", "^", "2"}]}], "]"}], ",", 
         RowBox[{"ArcTan", "[", 
          RowBox[{"x", ",", "y"}], "]"}]}], "]"}]}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", "0", ",", "xmax"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"y", ",", "0", ",", "xmax"}], "}"}], ",", 
     RowBox[{"Contours", "\[Rule]", "cont"}], ",", 
     RowBox[{"ContourLabels", "\[Rule]", "False"}], ",", 
     RowBox[{"ColorFunction", "\[Rule]", "\"\<Rainbow\>\""}], ",", 
     RowBox[{"ColorFunctionScaling", "\[Rule]", "False"}], ",", 
     RowBox[{"ClippingStyle", "\[Rule]", "None"}], ",", 
     RowBox[{"ContourShading", "\[Rule]", "Automatic"}]}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"bu", "=", 
     RowBox[{"Chop", "[", 
      RowBox[{
       RowBox[{"fmn", "[", 
        RowBox[{"[", 
         RowBox[{"2", ",", "1", ",", "2"}], "]"}], "]"}], ",", 
       RowBox[{"10", "^", 
        RowBox[{"(", 
         RowBox[{"-", "3"}], ")"}]}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"gu", "=", " ", 
     RowBox[{"Chop", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"fmn", "[", 
         RowBox[{"[", 
          RowBox[{"2", ",", "2", ",", "2"}], "]"}], "]"}], "*", 
        RowBox[{"180", "/", "Pi"}]}], ",", 
       RowBox[{"10", "^", 
        RowBox[{"(", 
         RowBox[{"-", "1"}], ")"}]}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{"Print", "[", 
    RowBox[{
    "\"\<Minimum with depth \>\"", ",", "minv", ",", 
     "\"\< (MeV) located in : \[Beta]=\>\"", ",", "bu", ",", 
     "\"\< and \[Gamma]= \>\"", ",", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{"bu", "\[Equal]", "0."}], ",", "\"\<--\>\"", ",", "gu"}], 
      "]"}]}], "]"}], "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.5793300966937695`*^9, 3.579330145073837*^9}, {
   3.5793301827538896`*^9, 3.579330193483905*^9}, {3.5793302670140076`*^9, 
   3.5793303281440935`*^9}, {3.579332345567918*^9, 3.5793323727379556`*^9}, 
   3.579332884178672*^9, {3.5793329371987457`*^9, 3.5793329424987535`*^9}, 
   3.5793330312998776`*^9, {3.579337034090706*^9, 3.579337045720722*^9}, {
   3.5793372185309644`*^9, 3.579337303071083*^9}, {3.584205729437309*^9, 
   3.584205813037856*^9}, {3.584250403168594*^9, 3.5842505000291643`*^9}, {
   3.5842506666218567`*^9, 3.5842507244511585`*^9}, {3.5842507558384132`*^9, 
   3.5842507660720315`*^9}, {3.5842508033560967`*^9, 3.584250807396504*^9}, {
   3.5842508650854053`*^9, 3.584250898594264*^9}, {3.5842509459559474`*^9, 
   3.5842509462367477`*^9}, {3.5842509921320286`*^9, 3.584251045094122*^9}, {
   3.584251156447117*^9, 3.5842511601287236`*^9}, 3.5842512033563995`*^9, {
   3.5842512857401443`*^9, 3.5842514178255763`*^9}, {3.584251456778845*^9, 
   3.584251535574583*^9}, {3.5842515722034473`*^9, 3.5842515734982495`*^9}, {
   3.5842516324195533`*^9, 3.5842516447903748`*^9}, {3.584251745706952*^9, 
   3.584251791103032*^9}, {3.5842518250486917`*^9, 3.584251850320736*^9}, {
   3.5842519754173555`*^9, 3.584252069969122*^9}, {3.584252162212084*^9, 
   3.584252163850086*^9}, {3.5842522138793745`*^9, 3.5842522191209836`*^9}, {
   3.5842522901323085`*^9, 3.584252315451153*^9}, {3.5842523505824146`*^9, 
   3.5842523539052205`*^9}, {3.5842523840288734`*^9, 
   3.5842524814198446`*^9}, {3.5843381371284976`*^9, 
   3.5843383315360394`*^9}, {3.5865895575976987`*^9, 
   3.5865896705886974`*^9}, {3.5865957389287853`*^9, 3.586595780627659*^9}, {
   3.5865984430661807`*^9, 3.586598600969658*^9}, {3.5871203128238325`*^9, 
   3.5871203381038675`*^9}, {3.5871216227886677`*^9, 3.587121799098914*^9}, {
   3.690010158546057*^9, 3.6900101593831053`*^9}, {3.690267947480874*^9, 
   3.690267991820936*^9}, {3.6902680506510186`*^9, 3.6902680999610877`*^9}, {
   3.6902683238914022`*^9, 3.6902683989015074`*^9}, {3.690268451746586*^9, 
   3.690268492286643*^9}, {3.690297297166911*^9, 3.6902973995687685`*^9}, {
   3.705726890258546*^9, 3.7057269038623238`*^9}, {3.7057314193705964`*^9, 
   3.7057314196336117`*^9}, {3.7414324751734214`*^9, 3.741432476078223*^9}}],

Cell[BoxData[
 GraphicsBox[GraphicsComplexBox[CompressedData["
1:eJyMnQuczVX3/6d0EfGIVEIXTVIUUorKjlIJJRUpEskluadQI5fcjftgMOZ+
v1/OmZlCEhWVVErRjZDkSSG5ld+Z8z3vvZ+1zjP/5+/l9Tqvz+zvd3/3Xnvt
tddae+21r+0/ovsL50ZERKy8PiKi4veq7e0bbm//d7uI0D8PRxmJoy2+rO8f
dfv+EaPK4yxeHNlpUWSnJIsvDz6favHK2Ip/mRZfHXw/1+LHLhzb7cKxBaq+
Iou/rHi8YYmq32dxr9c39Xx9U6nFK4LfK1ftjTLyN9pi+ifL4yymf2D6B6Z/
YPoHpn+yviKL6Z+s32cx/QPTv//en2jVn2jVn2jVn2jVn2jVn2jVn2jVn2jV
n2jVn2jVn2jVn2jVn/B+6F/6A6Y/YPoDpj9g+gOmP7K+Iovpj6zfZzH9AdOf
ytqtf+V4xKnxiFPjEafGI06NR5wajzg1HnFqPOLUeMSp8Qins263/qX9YNoP
pv1g2i/rKbKY9sv6fRbTfjDtr4yuup36l/aCaS+Y9sr6iiymvbJen8W0F0x7
Rf1jQvJ1cmYYHXU79S/tBdNeOQ5FFtNeWb/PYtoLpr2Vjaumm26X/qV9ki+K
LKZ9sn6fxbQPTPsqGzdNF90O/Ut7wLRH8oHPYtoDpj2V8Y0eF00H3Q79K+dH
kZofRWp+FKn5Ec4Hmu663/q7+pfvg/k+mO9Xxnd6nDWddT/1d/WvnG8+Nd/C
+UiPo6aj7pf+jv7le5XxhR4XTSfdbl2v/vXk3TD768nvafa3bNguf+C/xadm
55+YnV8W9tyiYLsWmVe6VTTYZzHvg3kfzK/XnlhzW6uKf8UWUx+Y+sDUp9/3
6JZg3wfzPpj3wdTj0TXF1gemPjDvg6nHo3u6LQdT/l1FK4Zl2/eeqyBj3XwT
HIZLU8yRilX0+UL7Hu3gPfrBe3yHcZT6+LSw8UUfhP6Ug3kOelAO1vxBuW4H
WOvb//15p3dr/tL64H//frTSp6ap+qPD+A66gplPYOYTmO9r/kbvkfMjJjiO
dcdEm4LAX09MilX0jvPK+xZausr5Havmd6ya37FqfscqesSp/sfZ5+BDvg+W
60iCkusJSs4mKDnl5peeH6z77wee7tkj1q5r8C/P0x6wXD9S1PqRouR6ipK7
KUpvdfOPdYTvU8739bwDM//B9Bcs5W66bQfzlu+B+R5Yz3O+p+c9GPqCobOm
K+sIf+eX74P5PpjvgyuTO5XRUX9H//I9MN8D8z09LvCBrkf/Ut//ouvTgXrP
rHd6oe4X48r3KKdeMPX+d7k2TM3/KCVftf0+LExuSTvUzTdtH+lxh25SP0lX
+km60k/Sbb3QifokvxWp9azEYuoDQ0ddH3SmPsm/JRZTnx4XWZ6q5FqBxdQv
5YzjI+rXz0s9oMRi5IjmW9ol9Zlypc+UK3kdZcsZZ8qln2Ks/a1a0b1uyP9Z
5uEgo5RbzG+w+oZL7PMafxscj5Um+PjpxearivJHEkP9STQTK9ihZ06ofamm
Q8Xr2wtD7e5jf4Pr3ItjTfDxuVNCfDvFtoPv8XfaC86a2jZjatsy+/zggRX/
/Cb42bEL7PtgnteY/vF3+kd9TwX5e5mtD0w5z1Mf5WDK+Y7Hf/H2fTD163Lo
Sn2UgynnOx4fpNnnPPmSYfHdGRUvZpl1e5qu2zMw0Ryr+HNkXoj/kkP6V4E5
mFDzYMK7acHfa3zFtp7GQfFSYseZdqyvqK9pnh0nqUeONcHu7H9OyasoM6ji
7z1m2XFFjkl9fZaVd9ARfofewWYdWWj7yfOSLv4wrOkPHaA/fCz1pAxbT4Xv
O+LddFsP8zzI930SLJ2oV/sHoBf0Y77TT2l/ZNh5zzyS+vtYS1c5Dn0sffmF
PvB9UN963WfpiXwD8zwYvqMfQb6omxrkryYdnN3JekR76Je0L2NtOXSV/o0E
W853wbRfr3v8nfZKusVZLP17sRbzHuMGfcC8j7yFX6U/zq2jzMu9FcO8rihs
3WNewndyPPuoedPH9p/xB/Me81Jjxl/a144vpD03y9KR58G0k/GkHEx7oCPv
QWfoyXhDBzDljLdcbxNtvdIeSLR05H3oznhp/yPjxPzneeQDz1Mf9VMf/M/z
YORGUs0KCVpg62WdL6pY/0ZkBeVDx316vIep8RgbNu90P6W93MfKAS1XqYf3
kFtSX4o3QXa5bKknv65JtuMLPRhf2sE40H/mCXKNeQVmnjAfmCd8B72B74C1
P4vn36xob0axfR6s9T49TmDkNHwAfZA/rHvQH8w4M7/AjJv2Z/B3af+PteOj
5x+/+u9g5hX90POR8aYfjBftZ11hPoOhI5j2V6YH8L5e77R9yXxA/kFv1kXp
Byqw7aAeKeemWfpKPu+j+H6Y9LMExo/v6HWY9ut5D5/yHFivY9LvFWMx4yLX
t1i7HjFOzD/pV3H+CTD1wG/S75Jq60Hu0G7orv0I9FfaqRl2Hmm7TfORtOtL
7TxnXmg+ke/FK/9BvPLTOPtS+g0SbTv5u7bvpH8i1fIV40a7GB/GAfrCx3yH
cef7cn1JDdODwdAFOkIX6Ag/givzqyCnqRd68j25XxUb5jeHL+mnlg/6V/qJ
4i09KvNLIcfpB/SSfrkU5ZdLtfVCT8aTesFSbqdVymdg3j9UYc+8l2G2fvzx
x11Gu7gB7W+R+nSMLYd+lCNvpfxZZOuV8zvayjkdh6D9y/xdyrmYsHGDX7V/
GEx9er+dcZT7/AnKj5Gk6klWeprb79b7Enr/Wcsvxo33wcwnuW+YYjHt0/qH
3r/WfCn1keKw/Vz4lPfhJylXC5Rf2PmhwHI/qUDtJ7l9P62H6H07vq/7Tbu1
H5P5Ju0Zt//K/EN+6f1R5LDUW51eq9d1vS/OPNNyVeopYy2/guE75pfkk2GW
3mDGFQwdwZL/hyn+H6bsv2F2Pur2oFfQHjDtAdMeMO0B0x6wnN/TlP9umqWP
tvvlflOK2l9Kt5j2gGkPmPaAWdf19/S+ptw/SrdY+mljlZ811urryA2+Bw6S
/8KY0HPOf4UcqGyfVO+LguV8TLDfpz5+mdeV7buA4WeeR97o9ytbp/g+8w5+
A3vtKQ/Vm2nrZZ5pPY36tJ0Cpr6K9e3jj9370IX+8Mt4gKkPTDv1d8G8L/tZ
ZvlM7xMh7/Q+CJj6pd1fGLYvA9a/el9F7wvpdvAcuLJf6tW/Feb77NNTPTv5
kYVWzrI+I1fh6+DnWy0O0TfBPs96zPOst8hVjbU+D6acceM7cyvgiSyvnloh
P+Ln6J8ZIX4psc957XF8oP3m2Ff0Eyz1mz5Kvjo7VfvnkUfS7+X0IujHuqX9
Q8gbuR/gMHoHGPkA1v4/7bfR9Jf6TnyYXNL2sR4vuV+crPxJqRbzfTDzTOvV
Wh5Q3j3YnjI7rlquUT/6BvWDmd9gvsf70J9y+qvlibZTNF9RDp1oF3TU7QTr
ftBeMO2lX7SXctpLOeNCPbzPr/47dKce2od84DuMO8+B5XwZZvUluV4nhtlV
fFfGr7s4Os0nWh7yfeShbh/6mze/Z1i5FWzvFTNNg4rqv1ti5QTlwX2cBqu8
ep9i3BLMLcGNpmyLWZ9Y97z++0yziufKc4J8O+PHkP+v1iRvH+rzOSG5Mcm2
y9Nb3jRBcVF3fkguzDGlQT5aanZW4M3zTFTF45krQuPjt+X/qqh44EKTWNGu
yNVWH0Fu0q93gu+t9vTl95Z79Byd6tXbc1VoHNPtc/QLjJylXsqD7TgZ582L
PzOtHjQyuOyE4grWhPzcZXmmS8V7a5OC39/WFv5O8vZRZ+eH+DPZBIe9bYHF
Hj+G7JUXU4P1PzO3yPM/D/X83P9+sdj2IzgOe4ptO1kfGLdzPevXYuRMkN/e
zzZnAtVWq1lm+4FeAvb4oMzUCg5sni1nfJkHwfKXZnjrbKcl3rwYO9/cV0Gn
diu9cR+0yBun3fF2XdDjIeN34m2/5lSQZUu8uaKiopnZtjzYr1+zrDyHf6E3
8w35Db2D/WiXHGx/vayQv/9QWpCe7XYWe3zwh+eHuKaVow/zL+ifuMfRs1rF
z/zcMLsQegWbE7HYthM9Hj67vwLelxFsX5UqPitPxXo/J8POv+HB9vjMyeBz
y8P2IZFLrPvMO55Hzki/pNsvY31Frsk4zGTTpqKh7y715oEvWelnTr/R+2vI
Y299SQutd25/DbkPFvu6V2YF6V97pT/Ej34rB+BT5AV0uis44CusPAuOW80s
K89pF+0Fe/I1xc5H3qNenpd2f7l9DqzXc7l+J6r9Fuev9uhdaOthvZD7rsW2
nHroF/a+tjvQk5knrAtgTz6VWnmN/sd3kI9g+DRI3hnJYfsF1I/fRO6Duv0D
5CLjCJbfLQuL49L2lFy/ysLWL7kvWKTGyWHpNy5Xem2K5Sv4BOzV7/z7zAfW
d/QS+AYMHVnnoTPjDEbey308F5eFXgAfevQpCfNrY+9BV+Qb6wUY+QYdmXfa
z45eLu3lRDufmH/0A7rAB/K8oLPjaSd01nzB+LO+s44y3owr8431hnHS6xr9
Zt5AV+gAXcU6GhgH6KvjMpg/2i7QfgIZp5Bq6UP/pL45xfIX/mzpBx6m/HVR
yp7gPGWKLWecKJf+vCjbXsqlfy9K+S3cec7/7v+Lsvotz0t/YJSdB5RL/6CL
p6Nc+gujlL4epfzq0xR9olUc3jTl33TnIbV/kXJJj2jV32jl74xW/s5o5e90
5x+lHR8XZmez3jP+lEv/qDsPqf2T+nyk9lfq85Laf6nPT2p/pj5Pqf2blCMH
6S9yTPdfx/3ouHd9zk/7R/V5Su0v1ecrtf9Un7fU/lTK0UuCn22dZMdLn5OU
+zmJYb/IBXl+ze0z63OB2v+qz+Vpf6yOL9b+WcplXI87JynPz6TaX70vJOOQ
U9X5MufP1euAjsMDa7mJnghGz9DtpR0yrig97O/yPJjzF8tz7C5OCHmjz0Nq
f5E+Dynj/TOsvOc57Vfm76wz2g+rz7Hxfa0Xst7p9jDu/F2fa2ActB8F+mu/
ij7vqP1FyAX0Le3vAVM/mP5pv7E+R6fj+vX5Sr0PqM9J6DhyMO2j3TqOnH1/
7QfX5wYr83PrOHN5Hs3F8ejzkXpfUX9X++f1OUntp9fnGrUfXp9L1P59vW+q
x0meKyoJq1fTRZ+r1P5/fS5S7wtQzvhJO9UX9pzuhz5nqfcZ9Ll59B/kv4zz
jwnbT0TPk3FHs+x8ZV2hXO/DSXldaOcd+q/ev5Lx5vlhcUWVyQX0Z/wpch/D
ncuozO7T50L0uQzklYwrzLT2D/yv97X0PhlyEfsF+1b7vYVfKEDnoFlQ09l/
fBdMvTq+Df0c+5lf+Ad9Jtj9vgutP0aOf6z1Z1KOvQGG3xh//o6dJOMNkpSc
SrZ0knaci4fEL4W9hF2FvcRzjBvf9ehRaN/D/gJjz+IXwZ6kXvoJxo6Xfq0p
tt96f4tyMPOH/kN/+o8+in8M+jM+2JVgrYfjt2Rd4rt8j3bK+MPYsDguxg87
mfrwc+o4NjDvsz5q/wR+NtZlHeer98/0OSB9ngL7HbpIu9H512gXWO8bST0h
Iyzumu/rOGwdh0w546nj9qmf76EPMf+1/Y5c4X3tt9Fx3No/gP+JeReUN9n5
1h8NX8tztG6/jF/aV9nf9b6ajrtlPut4O10vdKY+fv/X35GbWj+jHL5j3Crb
59N6n963A+u4XtZvypEn+MsZF+Q98l+f/0Sey3Oorl/QjfbKff5i+zztopx2
gSU/llm5iHyT8d1ltr/6XJr0/xQoeV0Qtm+s9WwdJ6zjzMB8Hyz1I1eu98d1
PLn0GxXYcuirMc/TPr1/qtd9fS6HcvZHmI+Ms7Zj9HyCLxhvymU+MjcPpH/S
xVXL84KOz5j/lck56Rdz36G9YP1L+/S8kuuzs2MYP56Hfnr/nefl+Ub3PcZB
/zJe+u/MGxk/4/RM9lfQ95FrfF+f9wGjf7BvIvXeQquvUi7zPUyxcoJ9Tb0P
wj4GegLyXq6D7jwofnTWRb4ThDnzPX2izwL7Pv2j3ddXPF41zuq951S8N3qV
19+k0D7B0hTbv6DfunOukmduf5r+o9cG6zmYYh6q2E9r6PQi9Cywju+hHDqw
34Y+w7rH31n30G/A0j52ceT6HLteT9i3YVx0fIHWwykn3gA9jl/0JDD6Gf2n
XJwvtHRPtOsO/KzjOPQ5QTD8q5/X5y70uSe5z5Bq9W3oh34NZp3hO+jbjA/6
poyr9tl+IUeD5R/MNb9WPH1ouaVnsNnvLrP1MZ78aj+f1K+SLH/C9xV03BxR
rPRGp1dIO7vQrp/wNVjGk5bbfTDK5fpXZulGOfaefp76kM+ME/KAcWHe63M3
yDneqyyuW8dxQAcw9NX6JPzAuqP3xeFbMHICeovxnuroqc/ZSPsqVsUXOj89
z/M97CXsA3nuLF7t+8WHxe9pPzjPUy9yQusR0AO9Fb0AuuJXQU4x7+FT7B5J
lwT7PdYfHTej91WZV+h14Mri8rReIc+B5of5XZm/fJf+wSdg2ge/MU7IPX1u
Bfy/zsnxHOPNL+Onf+E/cGX7IswnxgP6gxl/sI7LrEzv1HYe6w/zgfGGn3ie
caNcy73K9kWkPZus7Nkky0+8L+3bZFuu4wpYL+mXtnt5Xp4TSbN8wvsyjiRd
lbs4Eh1XBmZeIQ/luYNZdj8WvgFL/6jLT/bf/T1Ryj8aGyaHZH0uf6vcT4y2
/BmMh0yJseOgzw0wv6EL5TqPoxx/Fx8u/d9pyv+dpvzfaWF+WeQP85hynbdS
87HEbr3lecab72s5ovUNHdeK/s64o29QrvNXMv/4O5jvg/m+xKl2vul9I96X
fiG/smudn5/5jfwM6vuBdRj5SHtl3HmRiit3+wfIL8nXcRaj57POwJf6fA3P
wTf/3a+faNdxfmWeDBfvyrjpc6/QE8xz/Eq70PkXdNyS3u+U504SrXyAD/V5
bbCMX82x9Kec78PvldnFjBPrpI4nYDzA2DXo3zyP/oVdgP0HRr7JuC+foqdP
xR34rBznfeQKcg75ht2CPYp9A5bnNCap/CExtn7kG/wPhk4yLsH5l9GT5Lrl
8utgR9B+6K/z98lz1n7bfzDvgzW9kLfQH0w56zByW+u9cr/C+dMYXz2O0BN+
k3ZoYlh8MRg/LljniUGv1naVzp8m98/Kw+LdpN6XZu0gxkPGtfntc6zP6EmM
r4zTc5jn6TcYvYv6GV/kKOsw44k+DdZ5UZjv0AP+YHyQ03wPzK/O80I9Syu4
amNm8Lkfu/mt/cd4g5kXtB95wPfYh4P/wZQjT6iX/lE/co3+gymn/8xb6I18
1HHe/LJewLfMazD6MvRkPWC+wQdgxhd+BENnMHQO5pFriF87y7ZLtwOMPq/n
Des57YBf0XfQV6gPOQjmu6w/Mj4o0X4PPuE5xlvmufGH6eH4FVgHwd64pHp5
2Zo67L1XpOw6v9pn8pslwe9mhX79Vm/R+3F6X53n4AvoBl1YR2TeDrcfoOPs
aae8z2Cams+zVPzDLNsP5I2M+8hQcRcZtr3QV+5nLFLxKu4cv+4/zyGn+aXf
YPgV/kPug2k/35P27Vjlz4iyfEb9xAvAx9BLy1/eoxyMfEMe8DyYeaf9cWDm
nfec385v5BP6KPoMWO9b87y2w8HyfHailf/abyPtnHA7HTrrOGfWe+gGv2o7
WdpJKWF+F/hE5mfJsPwOXaXcyQr7FflHAvTneeaLlsv/3W+WZfcPGDfWV7BX
b6kdR+QB4ynvG5mmzvvNsljGC8fZ8WZ80Vd1Xhh5PsrlIZLxlM7vQL/pH/2m
P+hjel0G066I0D/mF1ja99GW3+S9Qs4ORB/S+UT0/j5yROet4j3kLHYFWK4X
zn5F/oo8iv/ht0XuIB9kHGKiyjNWYDHzgfGVebxm2ffRN3gezPNgnSeJ74HR
18E6Lyn1g3UeTeoHU7887x0TWi+dP0XngdJ5aKW/ryDseZ13AQy9kSM8r+Nq
wfrcJOX6l3ZQP7/oAZX9Xf/qvHjUix0Nf1aWF0/HQVCu93F1PTo/Hphf6gmu
S2tD+ZDaJoT6k2CmB+vJ9vpx2tvf7/hIoRlX8foVXh66/d+VWL7XeUkYD+w3
KQ/d+VXWQ+w25j3yl/kn7Su3nyvzjZfb9VTmFSu1djWYfawgHd5JCZaf+Yt9
JfjTF5Kjk0Pr90zvu2unmE8qmt02lCdz02yvX82XmZ8q5EStBV6e28+ZHwtC
/V/hrdebV3v9z8wK9SPRO9/6R27ouaTQ/Az56QZ7eZ1afxqKU37A2994a7W7
f0SeB421cp51Teufnrx08bXI66C+9F2m0pPdfpD01zm/A3o56xHrM99H39fr
OPyAvi/jY7U+NkzJnYgImQ/FrS/yPE5p2Hqp9R74V8oxlz9LyzGdT0ufW0Nv
kfHRbp3V5yRkPE5K2D6GzjMl5Wih2sd1cpJ2MA563eN9KYddfgnmldy/TgvL
t6X9JjquhnLpp3Hrqo7D53kdR8a6q+Pe9fkA3pf5uvOV39bto+k4depj/PR5
QZ3/S+dz0PnAdN4OynVeVforz7m4uDj6r+P8Zdymi5fT654+RyLjQV3clN73
Qa/V+0DUhx9Ert/ldn4RrwtmfjMfKIfu+nnsPPgPTP/A0B8s/b1T7PfQS8Ho
Q9RPOfWDqR8M/TSmPvqj7TGdtxrM98F8H8z3wXxPY5H//50l3vj95fJg6jzz
GiPnqI9y7DrkO8/TD/yW2p7T+1t6H1NjbdfpOF0wfMl3md86r0tlcZ06b47O
q4P8kPkL/GH6WmVxoJXlsdHniHRcqy5nvvJ3fv/X33XeGNqn8+z8r36CKed5
6pV+EF9Y/lie5+/8/v/+nXbzd7DOq8rf+f1ff/f6t9jqvUE9ZtMK7zvN00N8
FW/t9eC8GBvv6VHtsk1QbborwXxfMd8a5ITkLH6OQk+f2+TNr1HNSz09r4Fn
P7V+ytmLyE/0Ffw1/F3vdzO/ZF4PF0+APqfzWDBfdDn6F3oa7cK/QTn+a91u
ytHrqJd5CaZ+7CPqA6M/yPMiRfY9mV/Kxblr/z7rj9QfiLvxm+Br6xaF7I9V
ofdD+bTfDsm30+xPko8w19xaUV3tkN+4S77Xv2GevV6vCXGzmdZ+8Pxzc0N8
G8rjezIUf/An+RcXhugcZzIrurlmofdbFvLTXbLQBIvnx3n5kF6M8fhobpIp
rPj+S6F7TDqF4sBOLffqSyROkPy2qSH+XBkal3T7Xdrt6TmrLcaOxz7xxiEp
1J987/lBSd482h3Kb1THy8NWZVpBqD7OyRbb73p6QkheXe7t6z1xNqT3jfDy
oWZfEJIn9b18mSnjS+04ePzPPmqOxSkVzR2T69lzk8rNh0F5xH255bYfnpwq
t3G5rJfB9kbOt/Ya/jToIf1oWVY+YN8iR/R+IfZcMF9QrrMvmefMY29fYZ4d
t+B+y2Vpwd93r3HnHUR+nLbevsy7fr/1n9FPub/r8snouHTkAna/JxdLrZ+E
9vJ99Emdd4N9WuQDckHLEfyGfF/7VZEHYOx9vk+53OdJte0BI4/YbwMzPrSX
cqmvRlk9BH8s/MC4YffiT0cPohws7xPMsOXIL415Hjrjz0W+BYvrzlfn9uOV
/zDW1qcxdrA8d+b8/dBR39sh79FMVnapy4On8wawXulf9D59Tl/HYek4Nu3/
o73whfZfa31Sn//n7zLPUEbYOX2+B9+wvun9S/iL+nS+WI3luISfW9Xt0/t6
Mr6xxM4r/GGVxYXKfJsuLxP1sf7q9Zt4Y/x3lMv9bxefIM+7+W25jEdw56z0
+X59r4i+d0Sf96cceqHH0k8dH6yxPjcj48Cd/k7/oQv9h27oH5Wdg+FXn9Pn
79jh2h6hnv+lh0Mvba/o/AL6/J3OH6DtDJ1PQN67VBym/+s8A1rf1+f+5T50
+Lnrys4JaTtB7wMxb3Q+Am3/6DhCTWedr0D723U/wHpc6Ye2d3SeA22/6DwF
Or4J/wzt0/sGOv5F5z/Q+U/1d/T7Ou+Ctrsol/t9w9R6O0zln5+m9uen2XWF
dV/mn05VcsPtEyOX5TlZh6UfIzwvm77vA/kNludtM1T8VqHyixWG+Uf1uUJ9
jk+ea3F+Q9YZ7CW+K/3ePmv/oGeBeQ7/FPTX+QcYt+D5tCuWe3L9O5dvAH2A
53X8O/Je7ncWWj2a/Yjgn99e4M2706vMdRXf2+vyQKEHYbdgP6GXIYf1+S15
3smd4wgO45WhPJErXVwdfIO9hJ6Afs8+iszjkmb1A2lv56t9c+7TyAvTk3le
5Jf9Dzta271635n36Ad6CfYX6xN6ZVAeNHfnpbGnmN/oIdhX8F9l6zb6F3yg
1ymZ57DMjgfP0y6wPCfuzktrzPPSD+jyKGKfyHyaLp6D52UcYo6tj3km9Z4c
217K6T/vMQ6MD+uN3Ldm/XLnL3Q9YOoDU5+MT/PZ55j/lNNe6CL3T0Jxs0M8
/XxzbqHlC/zn8BtyO1g+cLIn3yLnefroB6u87x9y+SLIYxvsb0NPf9/W2tnn
2KNB+/OS0PnK+bnWb0G8XbD936TY/iAPiIuUeTiSvPtMBy618471UJ+r0ecy
qN+bZ2k2vs+z86aG4smme/6/gwtCz6+w9JbnLt35TBl35PZj0ZOD499gruef
eiq0n7veiwuc95U75814eXyPHqr9zmVKT3X+SfgY+rAPHcxHvJ39LJ9tH5h1
gXEljgh7m/gmb547uwa+lHkt/GFxrTKvSoKtH7tUxzFBT8ZL0tedy6F9Os6J
8YY+YH1+j/WedYX5gF2tzw/K+yVcHjyth8Df8vyCiydFruh8YfocK3pdk4pq
zmZa/qJe5CPyDwzdWd8ZV9Zp1j/aqfOoyjhQd16E9U7aHS5/usxvmmjXHd6H
/vA78hLMeNNv5jPrFP5W6OCNb4qNs2MeEIfrtSfF+rnQS/B/enHPtNdn+Rv+
kOdp/aH2urw++C0rnp90ODNI7+Nj0etLbLu97/rtvoTcX/bZ+Cr8k/iv6R9y
iO9DX/y2yCPkKf2ADsgFxgu6M59Yj8CMl84rTfwa5YwXmPeJy/Xm02jLN/QX
fkEOQGfoqv1+xGNDD5kP2O0r0l78nIw38kuf78f+kHGJCXZ8eN77npObzC+P
HuOt/CJeRd7nTT7bVCtfZL4f8uUmWn1d5nedYueh3r8m/gX6a30frO9lpr9g
vi/va04N26+mHuY57+OPAVMu40JdPi3mu2yPy1tBOc8jb3ReCn3+ROeL1e1n
nGivbh/l0m6LV36keDtfaQdyVt/vV9k5eH1PKOU6/6v2/+q8PLo/YJ23B/nP
+kr7wMxHeV4w0a6n/J3n9T3DOi5J5tVLVXlR0uz3wdCD9+m/ji/Q+Vx1Xm2t
N+j2ow+AWY+oT59r1Odx9X4r9dEu9CDeA/O+zN/is3wn7zt28Q1gGQfr4qbB
yEMZn5pp5THt1PaE9t+Cdd4s7Dx9rwGY9qDf0H99b5G+J0fnFQLruASpDzi/
pD63q+MYKMdPpe8R1nYjdrQ8zxpaJ3pkWjtDn3PTeT10Xl3opP3COj6E+rWf
lf7qX56n/zouQ8cJ6/yu+l4kyrEX9PkF7dfVfmn4Rsdx6DhleV+Hy++q4z50
XLOMXwv3h2o/qvYb63yvOm6EX5lffqyVX6z38Lu839LdOy7zXw1T6+dYOz8o
R95QDr9QznyhnP6BkUe0j3VE+1fR3/g+5fpeAvhX3vNdYMtpH+VyH2eW8gfH
2XIw/A6GvvIcvLsPl1+9Pun7brXdouM4ZZ5wdx8k9EMOUJ+8Z4T9KHc+Ra8n
Oi5U33crny+39gPt0OdZtDyX+bRcPl3aL+NvXJ492qHlFfOG8QXLfMM+FQdc
av1Neh9H7uMttPEO2LnoW+yjYV/LPN3xthx9XN9jLfM4p1m7FztW5nHOsPa6
jIvmXLqLP5D3VWbbuCKZp6PM+nnxz8i8v2+quK5ZYXm6gu/Pd/dU0y6pzzr9
U+b1SLHtoV+MOxj70ZOPGeqcuMsLo+O6dZ42ee+sywOMXabzHcnzeY6u+p4U
HffB+FKu8woz/4lPkvGr+SreJV/tU+fZ7+n8AVLvL600bzHjzvPQQX8HrPeF
dLugd2X7QLRX0tH5ifFH6v16yumP3q8X9TZ1+Vx1XLocH5fXRd5bWGjHSefN
13F+eh9Z5ntw+9I6Dyh2vDw/7fLFMU6Sri4fq9zncvsPMv4Bv3exnc+0T+4/
lFp/Bv4T/H7ozfABdgftQg+n3fK+qkKrz1Au4x0LrV5JOXKc+sE8jzyQ/mmH
qR+MXSPz1Ll4MugBlvdallu/jNeOQrVOF1o/I+XoechD/FT4985W/Bu23Ku/
ibMfkffB9Wdhoue/G55n10f0Wfx65DUgbs5rd7mVj/ocJHGMQXqMd+dUg/SK
cHmfpP4W0lv7uv00vsd6SByqx58lFsv7GVLN8sDT9VoXWXpjb0MX9jsYb70/
K/cF0+24y3goZxczb/EfevRl3XX7H/hlwLRb6z/y/E+WXT9pP3G3xM+y3gXJ
1HRpWH8YV7DMr5hiv8+6CGZ9wt6mXMYtcq7f5XuQed1dHBJ8y3jL86bc11ps
+UvuT5L3pdi+L/O4Of0CuS3jFkttu/X9ftg18Lv33VKrX3LuEXmFfERe6fv5
ZH/ybXtlfFi5pRvlyFPK2S+RdlOsxdrPS7wjWMdtoAfofV8tv7TegJyDXowb
6wuY/iPn0SvAjA/2Js/r+/WwJ5n/3vfdfru+10jee5xs1xPsG3k/o8PyvE++
ne+0CzpKXG73YyrLS4ZcQB7RL/rPuoBcRA7wHcrByCnaCaZcrmuxKq9AQtgv
eqCOa9V5LaTf3t0rhRyQ91lkKT/5WJVXcJjF6POyPNrG+VKO/52/M8/YN9Dn
bJk3lBN3rPOAVJaHDnmFns88ALPOQkedx5P1DzpK/TTRYn0fjcz7tMquT2DW
FbmOpVss7x139zODdRwy5fpcF3JC3l+VFqaPybysKVYugnUefspZj8HwuY4L
Qg6CZbxXpt3Xl/PKr87ZuDw2nJeETmC5/+PK4V/kJ+X4A8CU87yMU+6j4tXH
Kj2uj+2XxjyP34H5I/fbnL8KzPiy3yXj7R1mftEfymW8/RQrn3Q579Mfymm/
xjzP/OOXeaLlFXEr2DH6HD18zXxFXul7F7SdLfWRTEs/1gPku74PSt4jm6Ly
36RaLM/zuzww+pfnaY+Mr/CrfanSMH8XWNrd+Wr9zbfzSt6v7uK4dVykXsdp
j7bvqVefs4eOms7SHnPn6CujA1jHldNeyqX/zNWvz2vrcwMy7tPtG/2/721x
+wisH8gvmUeuxMp39CbkNM+D5X13yVYP0vkwdb4EvT+IXAbrdRn7IXiPe4EX
/3OggRtHeS+Dw8FpV3e+/YXe9Jf+gXlPY3lPUng59ECflnkr421/kA/wGVj6
J0tUnocSSx/or/czWWeY3/qclfavyXMTyWp+JVs6wr8yn3ixXaeoT8ZZuzgS
+EOf55bxsE6v1n5m9ELGGSztlExLd+2HqWzfVftpwHwHfVGfK6H/PC/jrV3c
C+s/78u8rMVh+7HaPpH3Grg8FfLeJufv0vchSPtthl2PwFpPpZx1CX4B63Nf
+pyezAfsMPMNuqIPgClnvMHUy/M6vlXn45B+Kuf/k+d83H1+wccjFpudFf16
d7pX7lscGleXH6lBxWc2T/TGLXO2XceZt0H2WrfIxqujZ7OO83f878wvyU/E
tRVYusn7LHNs3JL0Y5fb/QcdZwwmvs+bn+kqPiWUb/fXFVY+BZ//MM7sr+jG
R+gX8dZ/EPzu4XhLH/QfMP3x7BJ3ry84SL/7k+38Ca4Pp7KtXP3P9e6JxmV2
Plc8N+N0iW2H936JXQelXhhr+VbaGS7eF/+WznMHZj1FL2fc8QsTVwu/sE+O
fkG7ZT6DDLseaizz/KdYfkCOow/wHeLQ4AOZn6/cPgcmXo3nZT/LrZ9O5nGG
z1yeEGnvsU6H+7O03qfv54CuYK03Ug5fsf5LPgvVP3iq+aLi858usP2T/pJy
S1/6i981WG+my+eAnON78Cn1yPXB5XHW5xP0PpHcl8y3fASGfpX5kfT9IzI/
tcOUy338cqXvl1s6gvEbBus75dkROxJ9No6H9rE/AmYegaU96Px/8BUY/wvy
SJ7vXWHnAc+jDxEXi59Wz3Owzjej/YXyHr8Mu16D9TkxypHj8L2ME3PrN+sR
mHVI6z36Hg6tJ+lzvJynYD0A419ET5N5vHNtnLS+9wYs/SlJKg7B6avQl3L0
UH1OmnkCln5C54+ED7Q+p++Pk/uPGZYPtd0s94ddHDv6KXyk11EZj+fOrYDx
42q/O/4z7Avkqt7X1vfa//f8WMNUnH1EBPTBHyHzJgckhfAHRan8lhER0v8T
ZfVHvi/zcQ1T/p8oldcyIkLO7yhlT0ZZewe9UuYDm6bio6ap/kdbfsCfQvup
T/qrpim7cpbyj0WruIVZyh8WHXaPjex/tOUb2iP18VmKftFq336WkofRyr+1
yM4vnR8Mv67Mh7bI0kfnC+N5mR9tkfIHxlh68Lz0ny2y9JDnKl1+WTDPQx8d
zy3L48PiotHTGH9937kuB+u4ap3XUZ4/jVX8FRe27sj1YaXit1h1/95KxV9x
Kp+RO0eq46+pT/JfnIpzWWnpq7Hsf76tn/UROQjW8ej6XhnoJv0wiZZ+uhys
1wV571GS7b+8b8T5+aUe6c4JUZ+0153dqe9b0vsR+n2ZFztf8VWitQPkPY1u
v1Hfa6jzdrKO0D7tZ/1fefF03hMZj5hun+f7/B066vtRJF+l2vWL9bSyvCTy
nuMsq6fr+31Yv/U5eTDjou8Flud1nL9Vxh/41flMF++t72lC36Vcnvcstv4Y
9D25z+rijXR+YrC+B1rfC8X3WfdkvkK/itMPv3dX32NE+3U8t86jIeND3HOM
n47v1vfigKEvz0MP7A7q0/HZOk+FvKfXHxZXreO15b0RLg4bvZl62RdDn5Xx
t+5XxnW6uG38ssRnsU+D3wv/qIzndecamT/4K5jn6LPwM+XoxTquQp/nl/sY
pVY/RJ/Ev4V+SxyJPMfm9gngb/irsn0F/EfYy7QL+tMP7DUZZ4y/zMW7cK4Q
TDvRk2U8oosXkX4vZ6/hL8JvRfwY8bj4qbAz5X6YyzdHXA31wD+yXrfPjj7N
Prun302yeHsofpd1mv1N+MvDXS326n3Bxv+Sf5z+Yx9Iv7m7tw++1Pfi4d+V
55ZWhd2jo+N5WU9kPKrzk+s8BNpPpu/lw47DDtNxY9pO43u0T8cHSzs1L8x/
zPO8r+NP9N/lfCtQ56cKw+Yn6xd+GZ1nUu435Fm5zfehmzx3Vajmj4vvleel
ClX+h1K1X+EPq1/n5dJ5NnV8rlyvCpT/w8kHfc8i9VAu76Vx58X0OLG+4Fei
XzpvN+1hvaE9YOEXHlum4s+d3JT7bu4cBO2S9/IWqX3JYvs8dNH1yX3LIis/
6D/Ps47KfUK37tIffU+7Ppcn/VLJSu4nh+nBOl+JxjpvnL7PTs6HgrC4Lrl/
7uKXeZ9+6DhJeZ+Ni1fWepCORwfLc1+Oz+FHuZ64+HLK0Sd0Ob/67/RXY/iG
/oDl/U7lVh8gLhS+xx8izo/1yDSrKsjSPUXFC7h7FlkHqC84re5ONLUr6PRN
rrVj8EcF378hMWwd0Oc0pB9nQZidqO8103FIOk4JftFxq5TLfQC3Pku7KKQH
V42W+VAnz7XrqIw7cPfL63PHMo+Rs9vIi4A9hN3HeAbZYYqL/4VOMi+zyzvo
8W+hkgcOS7ldZvUnymX8FPsUJTZeGP7U5xWk3uzOJ0BXsDe+rj70M74nz9u5
cvY3WDcZd73vDmac9T497UZ/4O/6Xl4w5YynvCfU5Uujf8x/mZ/OyWfGUZ/H
0vcK4k/Bb6XjspC7+l409n3l/XsJYffZ6/sYkf9gfe5fxs27e9XYP4Zv9bko
6Q8qtfsn8D10Yv5CF+SHvida5wFnXuu84HqdoFzmy/Pb7zH/oDP6MPTQeYGQ
c+w/0x+d11z6j8LXOeQC8x35wfjKvDIpFuv7k5Gj6L20g7/rfMP6/mMdNy7v
GSuzehN8if2RWPGZA+SDcffUyLzGKdYOoh/63r3K7oVGL9VxCdo+0H4seT4u
w8YhYJdAd7DOu0s539d5p6kfvgRTDp+C9f0RjDf7mvJcl7MztJ2g9XR5vqNQ
5Qlw5fAbGL2KeaDtAK1ngyvTw7UepO9xkPfMuzg/9FD0eJ3XkzgB7b+ScQrO
H+O59ZfYuBLkInoEfKTvaZX3mafaX/yHzB/yM+EXgP+ws8HUh7xDPmo9CrmI
/1SeW8mz6yR+AjD8jF0DPZB7Ur939OFcF5j1Ue+3yjjbJBXn4LCMiyy0/UQP
QZ5Af/Z5oS95lqAnfl7yXMm4EIexcyrGpV2+F2/SvZ3f+ueQW8h9MHyk74GX
+ZNTbD/YT2d9YDw9v93UML5C32Yeee0mTrLInh9ELsLnYMrhD9Yj4t9k/je3
f6Xj41iv2E8gDojx1fcw83e9zoDRH5DPOn+hPjfBe2DerywvLusV/kX4S8d5
e/IAfy95C1fbc/w6rhX+ZZ3Wefjwp2EPyfxMUep8Q5RtP/vN8nxDlNqPiIiQ
5xmi7DoQIf4V2HKpf0epvDQREXI/u49qb7Rqb7TyG0fbfV8wfkD0Hf4ucZzV
Q5FzxBVI/2KMum80Ru2nu3xcMk6xwGKZPyTG7uuCGS++z9/BcjziVP/jbLmM
H8+x2JvfSXYeo5fAVzyv74PV994hX5ADMg6lVN3nm2rjYCiX96SVq3wdiRbT
XuQT/ZB5TTOtX1zaqUXW/y7tEqf3yHXZ6QvyvK7LW04/kOu8r/OOg6ED+Xsk
vVwecn1PHusK661cZxxGHwGjh0j/nsuzA/8Tf8L8IF8NfAaG/8DkW/Pee83y
HfOO+UK9lOv8l/zSXjDjK/ULx7fwC3zFc8hX3tf5MPV9xswT5KXO6wLWfnQw
/MnzOv8Y81LneaQexlXyueMvzc86jhv9AHkCH+p9LrlfX26C7NbT5UXGXyHp
6vIJYK+zHoJZ7/AboVfIuHv3PPt/0o88y7aTcnkebZrlD+QkdGBfEYy+wC92
O3YC7ZD5kWIt3aU/LhzLeB+XL0fmk4hVeUcS7PfYd5P7jAm2fo3l+u7y70i7
KcFrx3exMs5vRazV7/ge4yXllcvXyvjJPGMpdv6iJ6K367wrYOl/z7BYx//q
+uQ5I2ePyjwiWdZ+kvlDiRfIthj9Hnkg941cfniwjKdw5WDKyWtLfDh0AtP+
yuKSZf7XQtVf59+W95JmWbuGfsnnsm059ep9NOgv1510u94xXjJ/m8PohcgH
xhtMfax7Mt7FxeEyn8G0R9+jLO+j9oXFT9NvMO8j7/S9eIwf84tyMHor80Xv
M2q/moxndfng9Tkj+qvjn2XeFneegPUDLPMJubgOff+2zLfttxh9EvmCHAUH
h2vdYu88Rb1EK3/Rj/ke2KN7qd3HwM7GH4FcRn4FybVukbVPgp9v7TB2CvOH
9ZB5H6RT1Vyrx6D34SeQcVbu/AN8QZ5n7EOeY51gnaPd8n7fJGuXY7+j1xCP
in4h4xYT7bzFD8D5hv+MV+943K/e86n8sS5/iIxHc3FP0h/gzm3oPBc6Lybv
S3vc+XF1ngTsHvQ/+in1w0SrD/Cr40ZZN7HPwdoOk3nSllk7mHUP/cKTbwlW
LjN/dP4R5iHzFv2YfuO3YT3AnwvfiPsrIxMtRg/V58CgL/SjX8wT+In6yM/A
uqzzysHX+FHYP5B5zbPs3xlXvS8o8zD4rd+N5+V9CUWVrsvYQ3yX57VfH38a
/ePv+ly9jPNNts/zS794T+sher+T56XfMMf6DcHkpYIPkHOefBht+Qi7CP6H
L2X8udM35b2WDst49DhLV8pZ98Gcc0Ne8p7cf1hl+w2W52+SbDnfk/fVpSn/
q7Mj8E+zX8z8kuc9M60fFowegHxmfkn/zjBLD9Yl+g+G/swj5KLObyDvxQ4/
T67Px+t8VshXmYc2U/mVM6xeJOMm3bnx4P2j//buV9xWVmL9eB5dw+/RJr8T
fCj9V32svQ6WfquuFhP/Bt14HvkMho95X/qZXrDt4nnsNbCMr+iq7LUXrL6A
Pce4w8fIa+Qn8kvuPyVburBfDr/KezlcPhgZ5+Mw6yrxz7wv97HD7zFHL0Av
Yb8eLPPXOcx6DOYeG/SgQRVkuN/pI0GyzVhs9bHgfBy82Lu/+tMEy/cyL1eM
pSP7QWDp1y5Q51pD699L6d553k6h/ILL0oPzPG54ifU/cL4tWN34Rdb+xK5G
DiCn5L7kajtf5L32rpz5RTn+m+C4xK22ehFyiziJ//RPT/qo2Js3x9PkPuB5
GVY+wTdyfNz55SDZli6xehzjzjySfr10Wy/yV94v6MppJ3aJPCddKvZddqzI
CsYl9arm9D15PtjFq8g4o1K7zlFv8PMRU61+Sn3IKfw/1Ie+B0YOwQdg5Li+
t4z4Ap4Hs54y7sxL9pfQm5gHjDN8wHjqe27QT4i7oV/S75lh/VqMN5h9F8af
+nmf9Y59V74HZj2lX8xbec4t0bYD/Q6MHg3mfdrJeuzxn8uHJe9FZN8p3+qD
YHmPdrFdH2U8YpmK4yhT+UvKLB3A0EHnDZb5zceqfOUuXzvrAfICLM+TRVt6
sK4hd8DIQTBySPqf51r7FDuZ+czzYNor7eICZdcU2nUS/Q6Mfqf3i/Af0t/K
zoVJe2WlbQ8Y/pH3q6VaPtL72vqcEvakvtdHxre781g8B6Z97HPJ+OYUu36y
7oD1vWC0U9/jjJznO/h5ZB63LIvhP5lfJ0ndc+kw8wc6MF+kHyFVYXePGnJb
3xei9wP0PZRgfY5A7ocVqnP0zq+Pni7zy7r7BJGPYBn/XG71AviOX70Po//O
+X7sVOQZcgW9m+8T38P6jL9M55GRedgKrfyGTtCZfROdnxK6oxei1/G83Ecg
L5k7l8W6TnwLdEJuyPtwZ9j4L/4Olvl7pli/EfNfnndaZvU+Tz9bbscJvwf6
Nhh7A/8J7yH3ZT6zRIuRKzI+KcnaT2DkqcwL4M6RYmeyHqNXgmV+UxfHTb9p
Dxj7TsYTu/0Mea9UKC/o5cu8cTubbOeFjs9EbqA/sD6BmYd6ntI+GedRbOcp
9IM+8hyjO2+j82MyL4LPJyRY/UjGfeZYPTMol3a7vFfwMf3V+4XsI2k/Nc+D
dRwc7ZVxbm4/QZ5PcnFXMr9Inp0/fAe+pV16P5py6Cvv8fNZvVLfq4Sew/qh
86LpvBXQTebN8av9Xaefo8cht5CrYvyGhZ/7k+uS375PHIDMx+TGD/ro8x0a
02/sDcqpT+5L+MPyGcp8KSVW/0NuI1/RB5nv2A3efvM8q4ehD6FnYYdKf4O7
x45yMP514raQB/wdTDnfox34C+S+baLFcp8/1q77yEuwvjfDa+c0+8vz6Aky
btLlNWPegOX9s/6we0vAlPM8flbsJTD6h5TDxdbPiF8UzPxg3aFcxg24fUfa
IfPE+O16STuQ/9LOildxX07eYjfpPDzSnnCY72BfaDsdLPeBnF8C/tb00+dT
kJPozfg35f20eco/nafyaCRaeqMHgVl/ZbxMYpgdIMdnpbo/wN0jil+F9Yvx
RO78Zzzof+6LIne0XAKjZ0u5naHiiDLsOQ7sUDB6hzjv9LE7z8D6IMehTN1r
5eLcoEdlcW7QX++bIDeY/8gP9pfA8v6fJZbufAe6Mw7IGX6x1xh/MPKGcZL3
va62GD6UdlC23R+R8QIp1t/JPgfyinFmHwr6s27K+9NdPiT8tWD8ePAJWN63
G2vtdewB4r3AxGtCT8qxE6Af9pi2l3TeeZ1vFKzvscaPBD/K9dvFx6NvyHxH
7r5r+AkMfyAvmM/IB7mvm2Tnt877qvP0M47YmchF5oO83yXHYvQP/Eo6XpJ1
Er8fmPU7WM3BBRYTL4zexThCJzD2BvMCjJ8OucG4g6FXsH8bY4P8+UO3NLW/
7O57ho9lvnmn/8r4ngKVL7vA8i/+drDcJ0+166+8J9Wv7hVx8flgmY/Gr8bT
PY+/BL6EDmDKGV/WL9ZLj1/wZ/rsfgF+OOgv7b4SFU/rs/YH8weM3EfvA0s/
bIzlb+Yt48/8QJ8GI7eQf4wv8g+M3IFPwKw38lyFOx8E9trlzhOgR8MfYPgD
fzb14jcFM67yfvKssF+pn2VZ/U/7nWgHmOf4Hu/r+H4wz8t7wR2W963ovCOz
1D2qsyx/EJcCxk8BRq9H76IdUl+fou7RmKLiXSap86vR1t7DLgAjb3lfY+Qz
/lr4UOsJ8JHkwxIr5/meXqeRy6xH8AF2vr5/CP2beSbvBcsMu08XOYeclvOs
4H/GlevzVMhF2st3Kdf5xGk/7cavhtxAr8DfL/Nyh+e/ZXzAjA/+f22PYQeA
8csjH5D3Mm7N3XvFeg9GP8BOxU7R99pQjt1Luczr7fIJw+fE04F5D3qib8An
nH9mviDHsSNlXiSHeU/m44m29IXfZRzVLFuO3xY7gPFinZF5ORKVH8aV45ei
XMb/vWnnoZ7nnl4x2bYTerGOg3X+K9ZLmZcj1X4fTD/Rp4grkef+9L3WScqO
SbJ2C3wn8+sk2PVO0jHDzn95L1Kq3T/Teqn04/vsc8x3+B99DH1aYuI5XLwL
8ws/v95f0vev6ryLrM/E+2Avwgf4EWRcsbsfDn7X9/jwPOOk80YzLvIejHKl
D2mcaf318Avtg1/kvpDD6EPUw7jLuMcSaycyr8HIAcaJ9qPnM7/0fXfQF/lE
/6GTvDfAxd/xvt5/wk+JPqvzc6H/s87IeM7VVg4h19GDma+ePj9b5X+Jtf4U
9H0ZN19i+YX5gf4q14sES3fmH/sBYBkPnmr9K/J+vzy7bqB3wO+MF9+X+a6c
fsavtKNS1Lkat3+FP0z609z+EX4AvX/JuME/+h4YeR+Dz+prMu6o0PKBzJcf
Z+UuegD6FXYWmHFifUOv41fvW+HXJO4IeS/vT5oamg8zrd9En7uVeU0XWrrK
/ECZKp4szo6vzBfq4s4p57sy7iZRxeWmWHkAxh6G32SexHS7Lsl7gZyfDP1E
xpnNsPordAKjb8r43eIwvx96GP0BS//WWKtHefW9au0i+AD5Is+T6/P2rhy9
UeaLS1LntJPC9suRJ9SH3su8k3pumtVzeV77M+gH9Uo/dI7dB2Gesp5Kurlz
FPJeQYeZH1I+uPwD8C2YdVraf+78Ofwi7yvwWXmHHoc+iz4t7z1x8p5yeU6n
TMUdOcx4IC/ByEt5jsBn9Rr0WXlO0WfjxeR9JH4rb/CPgPGfIG/AyA3WKfQP
eU9zvF3vsL/AzHMw8xu5jJ8MLO/RjLfjwf4Dfmkw65XeJ0QPknEA7j4lfY4C
eqJPgJG7Oq4NzDjDP8g3MPod/hrkAHwPph7kIfQGy++kWvrL/DJlKo7E6U8y
30iafV7aw6792Kla/6M/8Aflkl+WWP6iXJ4/jrXtQx+jfWD8gsxTea+8X53L
8yu/TJFdh7Ej9D2jyH30F/zt8t76dDsfpZ002o4b7YUuYBmf686H6vj/yvzS
kq7xtj74Hj2Y/jF+2Bcyr3Afqw+DkQesR4yXvI+gTMmVcoWdPo/+gb2D/oE/
GjkCZt5J/3OJletSf06y6z8Y/YD1in0A6MLzEaF/Mi6qq+Vvxo39A+QQ9bGO
4tdEnmi/Jhj9nXUP/Z1x1fq7zI/lzhGAdb4ceU+SO/+IvQXmeXn+tlzFnzos
9dYSu/7o+Faexx7Q9yHLvIeJdh6ht4ClXz3P+tXl+SmH4Ud57sTFp0Jf9DXm
DZhf+BN/DBg/h+RPFx+IngBmHZbtd/tVyDn4G70ZPQU9CT0SfiF+Dn6lHviR
OAfoTLyHjMtyWN+TB91lvlbnj5PxmEV2nUQfkvqLi2vRcRLITfhO0slh7C3k
u7x/qChs35r2QC/4E3sZLPPK51j9XZ7/cuclZd5Rh5nPrN+UI2/l/p07P8k8
Yjzgf9Yp5hfzDqzz+Oo4LeiMvNT3quv4EuQh9cn7q9y5LNqPXqP92tjH2E3E
A8rzi+Vh5yyon/kLxv8D/diP5nvwPxj/CvRifZD7JeTlzLbzjnUULP1tK6wd
hp6K3QvW6zCY8ULOybigHGUXuPO00u/i4gIYV+wfsNwnd/uF7Bexb4Yfhf15
5B36vDzPFaXky3iLeZ7xAct9kEQ7Luw3oP+hF6FP6Ph4GTdQqPwLDst1zN2z
gH0LXdBnwTJuqtTqbfK8GvmgXLwb/ibtL5bnGp1/mfGU9lCByp9ZEJafDLmM
PBD3P7Z3/jIZV+Du8WO8kKNyfjtMOeMEhh8Zb9YRMPST+42xVp4yPmB5PsH5
6Znv6GusdzLfg9v3hZ74V6CntI8cxp8k7ZsEa8+Ic3RNXd4+7ER5r6yLLwbr
dV3vS8lzNj6rR9A+5Ag42Ix1i8LixvCbwH/Ma9oPxq7gPewK+Aq6gfU9nshP
1m/kJ5jvYW9CX2mPZtr2ynxWWVYPo7388n19roPnZdxaltq/X2LtGeQu9hcY
e4X4PRnfkaT8zs5/JeN1cm170StoD5i4K+SzjMd267T0x5RbfyjzQfpHMlTc
h/Y/uPzN6LvwM/JM2+dgxhN5Bh/CJ6x78BH2IOsDdraWN7Rb5s3OUOvNAitX
pT7t/GHe99x6LfN8j7f8C0bPlfceF6k4XYflvlGOpRv6mYwHcfFXrEPwJ+ub
9pPquDb0GuxhMOsS6x3+XXl/zEorV2RcmU/JtwKrl8h8Nm79kf4ULU8T7DwA
Uz/yju/KeH+f5RPkFJjxgD7IczDzXeofw+x6w3wGM591nk6wvB8sya6b8Af0
RH+X9546DL/BH/An7QfTfuQ57ZNx7KOtvALLe0ASLIZetE/myXPtxz9He2gv
WMa9jreY9onzJQH6sS6DZZxqKP40xtsPH1dY5MmHn0NxfeeG8leN9vYhX0wK
yaFVnh4x6YNQfvxFXn7Yt+qG8kW09/h4R8dQXNDQpR6/vpjsybX6oTjC8SF/
wTovbr1/vVCejKEveHJkzmivfS9OMxdUkGHuIstHwfnVY7z9xQ8VFI//Gunx
xReveXz+/gSP/s1nhOj8pAkOy+z+XrueHCL3Z/Z3s/6yIPv8NNLKx+C8ajhN
5qdts8z6GYNkHTDbyt3geDy03PJv8O9R7jz+xoqfvZOsfopdHmz/0pDd+qu7
Fy7Y3zbp1q6FrzkHH5wvPWbJuOu9CXa/Jtju+zOD9IjZ7fPasTQtSLdqC4rN
nArCvL/SPFHR3Joh+/ou797f5s+H5N9Kz7/67wOhffwDSUG67e8bOsdTzzsP
OW5N6L5s483j7JmhexyOeOduii8pN8kV8+TlUD6AvllmbcW4D1ni9Ts3NF8W
hO73Lswxc8eveOzI2Dl2PEYvSGv29Ovzrb+vrOukTZEtXL7bFj+/+82LK5fa
8ju/eeyDX25JsuXli/7J2ZGZZMs3r3k28/KPXP7bmkvPm3XeWJff9t5RzyfW
HOzy2bZpO7L/oJgC+3zS0JS8Kt+WWFxnQte2y6evsuPbv9nZrNG1XP7axW99
HJnfOtNixu3nZgdvbFdjganX4827L+yUaf/OOM5teNORA2fnmWpPzy1qdo07
rwxfrI39Z/yV/V2+2/l/vBN7zQgXZx/9wC33juy81MqHZY1uGnbHtcvMB3MH
HJzpS7T6i83TemL3yNovLzMRy0+fM+pCl+9m9F/Ly5++wu1r85t/z49HH3h8
tRk0IvK+uq2S7HfQa248WfTQ9r/izMKHXt762LBMW27PfUR/fyx+ZJyZcMGY
T6Mucu9FnOrauEaGy0/7WWZ0rynXu/u66H/RmH/mNquSbAqn9hgU8arLX8tv
bu4l+YVF7nzz539/037DeWlmw0dbOh4dmGn/vuPjpKGNcl1eT+o/8U5a9UmT
08zci944vnahy3db/PGnyYv7lYflG1065ZEhe05kmm2Xz4/bujrV9hP7p6jl
+XUffDfT9C8cvOuD/8iHS/k7W+fMGPZirnnvibtSF/h89u+3nd/z3yUDXJ7P
xTuPdTvU1uV1oB0jZly8v2GGy68Wf8eKFtXWFZj997Xr/fYfLh/uql+nFjRY
4u5JnHfdhSNnl5dafPMrj9+Y/VC5xfbc5NE1Ub8/4vL5HzAZ9a/MKzLTVo/7
qd9D7j6sG28ZW7zxK5cXD3/aXRtPPTQstcikX/LvTh/t8tly/BEjkr9fuLd3
ken6xbkdGwcw5XW+zf53v1bl7r6t5R9c8c0QFxdNfy/daYrWDy6x7V5292++
fe1K7HvvnL7q226mxJy+MD7qwNvu3i1+u0YU7p7avMS8N2TDoSpb3d9p39sv
n4wpDNQz551Jg18pKLXlxwJK481R5RZDn+Wfnlvjq7ouH/CVce0abmjk7hFY
vPjpi9+83G/fm9Jw1z2PX+Q3WX/2vGD4LPddfl/+JXu0ucBvpubt27djaanK
s1pupsyOvWNnoL4jLfN+WTy83JZDn6a9nzv19neOjw5/G2mqHCw1/bO2LH97
RIGth/YO+PztyF2fuH5+dmG7rx496b47ZEdU/Yk/l5rxO145cjrGtYPfYT/2
OXrO4VKz64p7/rxlgft7++ajFj151VwzYHbChTtOTTATbt956+8B+fHUM1uu
bbn8dZPVfOdNSUtyzJiC82bf//Wr5nDpk5vODCkw533fZWjTha+bZslZiSO2
rjJtR9dpXP2Zuea6mDVH/D1SzaM5wxe02jHbbD/nyoSzj2ea88bed8dLTeea
Z6LjJ1W7oMAMP2/p6n9vnmVSh4545a/Fq0zc8atGTLkvxjz0yoCzCX1Tzfjo
HQf2fLLEpE3flF0nwF9N23Rq+/iCGLM74bVdz7YvMD03Ve+wtlGMeezexi+m
RCSZ2OpnPv6iYJV5/JYGO7fVzDTz/n5gdYdmq8zw+2ptvOmeArNkY96v/fqv
MjUO9/iqSf0Sc3Zmk8Yj28SZdgvM4Ekmyf5mZWWl9Xoy1TQeee51VwfWw9y2
53YfNC3TpG4qfPjIbUmBcf+7abfiHHOgzfmJCW8lmsJa/Zf+eH6BeeKO667a
8WKiOX6416/pzZPMhJvOHbFnR6rpuuvx0sUBu7fjwCoFV5WmmqM/dE2OebrA
9K6V/PZra1LNFxc+/Hy/GZn29/j9Tx25qnauGV2tYPjeQL/nf7BwT4cqJaZm
6hT/yhcyTc1fE6P//iLVXPbckSWjI3NN93U1p529O2APnPBXbbsvx9yTlzRv
3R73O3dGcYc6DxSZS1ZcNrHwrlxTc3zZQ1Om55gPe7UY+OzlBSb51fs7r3ne
/Z4Zf/753QPPv9W75Xu3jS4wGc32RdwSaEe9337b9FuLIvP51b/tvb9Frnnp
4auP9763yDx+6f2ftMsqNdFrPrjw55uLTMup+Y2yRxUY39qeafvqlZghbRv6
zcZSs+/sy7ee3yBA96YtuiycmmlS2ne/reu/fWZZzZg3H60V6MeZFZtXfe0z
p6eu3PjQveXm1U5H76253Gd+arcrYd8fxWbQ+KmR16woNevOLjvkG1NgLly0
5vaHlpebxqUdnk3b4TOZfxzc/eMbAbv5pWrrqn06zf4ez09Pa37eIvNP5Inc
lCdizet/juwTd06x+XHO7ym7LkkwHY9Vb/5uRIrZXfWNG33dC83Xo1tPrVUt
xTRP9L333tOFZugfz+3oWyfFRLU51Ofz/oXm8tzfY5fdk21WHIntGXXUbxbc
33ppvZGx5lzfTf/qu3qaGf6vL8wrl8SaYWMmbk49Z4bdb992ZnP1Ab2cv+rl
H/64MMcXZ3pN2Pj3ZefGmiNL+67+cH2COX5HjTrfPR1rxkd+98zkXwJ2wuo/
Jv/Q1O2r/3bx+4lT2gbs1SoP/XN533RzeUnfn+5+odzqsdtfnLa164/J5tsf
vvxyQ4ts8+GEo582DPRr1qSly99/PNvs/OD20z+NKDQ1Hl//wZVdss2tHx7+
8+Zbi803P+5/Lmdotml14Td19wfsux9qNrrssZeyzS9PzGj4+/d+89qBujWL
BmablNWJR37MKzMtvn/s0/6B8ofr3vVXnUD/2iX1+D5luMv/W+2L7LZ9rss3
f4269KEJz7l8vvSjaE2z5ztEF5hzZzX44M/HC83kHQuqFZ7NMydbVI+d/WKh
6f722n9VDeBeUYdWX3J+sanbJ3nGbaPzzb0Tjg8atrfEfBx3x/jSZ/LNxHdv
G37JXr/Z3un53zPPyzdvnnf6nM2vlJku/0zsMnZGvnlkVNbdX/ZLN8MWfPZ8
h5sLzYVFN6w+eyTPdDz+c624roWmYf2va3Z5KN/UOWdi7IGOhabRI+fviGzi
fmdUe//xlgsKTZ9rT8w7FXi/8GC7J5rWKjZjn318W8Mphaa47+8nOtcuNX9d
93D+HYHnZx2/ZW6vRL+5Nrp6g5tiC82W4Tvr1ihNV+trumk689yRrQLzY9XY
h+rvu6nQzP6i00UDBgX4vHeVO/bWdr+1xx3tWdS+2PT4bXTNkshi88eDX/59
Yn+JKb/rhazZjxdbP092n+5vX7re5R26+9JfMiauc/iTLW8sPbDG4WcnX/Zm
97cdPnxH7qg15Q5P+u2+vo3LHL4kdWeXBf7/yGv0zKi2p0ocblW7apMBxQ5v
/HB13a2FDj/5xu1V7ixweP/tH/+emOfwq4f6f1891+ELk09+NDbb4eW9FpT/
kOlwk1o3pHfKKDV3vftZ5zM3BMblh7tXp+wvM6/uuebdGnf6zMkTMTmfTCwz
M15ZvLfwlxLzy4DrZt34SZnZYa7+MW9wqbVrN8795ZZeY1zeNtbjGdWqJycm
uvwCp//sOGrm1fkmv8exre3iw/MbL6nuX3L0qnxz4xW3zl98vTtfMa/N19Pr
HXd+bfS3j16eP/q26EKrLx6bvz3nX9f5TLutX35eWtXtS+JPr3P1+blTnis3
Zu+9TbJPuPzEvRJuOl31c7+tl/2gVg2iPp9XO80M+uWi65Y8WmoW3f3Cq4sW
zTJdR60vvC+AR5TWeyAyeZYZu+HPr8Z9uthEXntf2kVNEk2b1Rt/XXw2xURu
vPXvdtsKzaDLT/965XWpZkubpy+48/1CM3/67QP3bMwwZ3qV18wZ5TM3bu4y
ospHGSa/7ObZK4f7zHvVB4yL/CzD9L886fw5Q32m9yOvTe64I8PUfeWyyRMG
+8zxBYtmD/wuw3y4ffaZIS/4zPwvMhfP+CnDvNbq7Ku9+gfqu+zdVRm/ZJhb
Fo05+lDfgJ4aeU+XCZsmm/tiox8/XHeWadP45MWv9y01F6ys8sKhbZPNrj+/
mXBFAN/cNOaWe9dNMecm/zM25dkF5qb6e3313lxpRnY6nTHFlJkjn4z8vmjy
SpO+b+FFCTeXme7jx+ztv2e1+W7M5BT/LWVmSYtTw67vGG8WrLvnx4zmZeaG
hKcmf/Ryook80+fa7MDz+y5I+2lAx0Rz4J67Zl2asNK0a7khetWxNPP6jE13
nBiYaBZN3lP/rsg8M3Ha4WnXmkST1XXIwod+yDWnrnjh3Xr3J5q7X33vuT0/
55pXcnaeuaRTotma0LDF67/nmiOm253VHkk0/ba8erbuyVwz/ItNY859PNEc
PfrZ1vxz8szBgXfln+qZaKY3bLa6U7U8M/BUwcEjvRPNFQ9OH/ZT7TzzU3Tj
xr/2C3xv5I93R9XPMxeu2HnDhAeSzZDixyckX1RgqtT8bedruWnmzaLPexQl
F5t69V/bFLcuw7S+5MTsz2MD8ujqyJkdAnL8serx0eXvlJqMXmvW+4YE1rfu
g+Knrg3ItcVPnGwyKNvsiW1e2DUgLx7YeqjlqgHZpunuvzZcHpAXMVWnvfiv
/tlmTJP123cH5MPeDg2Tp/TNNmtGzNyfHZAPraJ8u/7snW3OK+12YmxRqZlS
2vXSIU9nm67/XFHt3oA8+OyPfV2+7ZltYjrurl8tIA+uaTZx2qNPZpvv52be
vD0w/0cMvGzdhu7ZpvH2UWZ1YP6/k5B3/PZu2WZE/baPDU4vNTV3PdA8s2u2
Ke1/7vO3ppaaZ+v+MKhB52wTkbXl5TNJpSb30VcT5j+UbR76Y9H09xMC32/4
UUz7m3JMTvNjJe9eV2b9gJe9caKs2vp0iw/X6Nerrt/hD1dtPnl1jsOJTW9d
cVOSwxPeWtH29uUOd+9UZZeZl25iNl2X9NJ57p6539r3+XV9TYcfXLf0trr1
HE5ouy1qyHUOn/Jf9MHamx3GfhjU+Mo+XW4tNwVJV/4cO8bl417y5ReXL2mY
Z+UDcTKR5z08YEtMuckePG5m6/LFYXHiT3+5/dlxvRPM4AuerH5vsc/80LrJ
iIaJy629Manumch125aZY8V/X3DBnz61D1ZuBrR49YF58xfZfcx6W7tOHDQ6
yXy6vXOHzDnLzMi+r2R0uizZREVklT89z2cS35xXv03PZFM6sffSOpOyzE2n
x5e1GOw3LWv1yX/l5GyzckOPXX9GLjQ73nvhrlkJfrOo9Momn5wfY+XiE/v8
i84G9NABn19yZ16rVBP76Igp90QUmqPbW+9YP22ZMRsub3lnYB4uPGfFiXPr
LzXXtZz75L7IZDOv6+IPq0cuNS9+uyU7v1myWdL57eeWzykLu1/n1Auvrm/3
aUBvu+vms0cDesikDz8d+NJ+v1mx6+b0Qw+XmR4Rv41u1MTJ2zG1+o/ZnbTY
zB3Ysl30Fr+l6/g1d3/ffmKZpdeJl0bfX39qidkZtezua1/JMZMOZUx+eGe+
qdagW9Vhd5SbEc1/fTP3tlh1z0usmbfv8t6pRwP2y+9VH97UfZmp+0Kvx9om
rzbv1m5xQ3HbbNPh/O41fF2cPvB9p09HNfqn2MRcX71GzY+TTezyHVcVXJZh
8r77bOekxHRTfcFF3x5qk286D+l5eUKjJebT5LMrdm5ZZsZ+FPlGg11unV3b
ecyfM1a5+OuNH9R9YMmuPJNx14wD1x4sMY2P5MXGDgnoT9ve6vn6dyWmzuxe
ZVdemWdqt416fkofvzlR5fChK7rkmY+/PO/Rzj0C+vL38Y3SAno3vx/nH//7
sZezTE7+qxsn+YvMvb9dW79JepbZU3XEkaE5Tu998Pi8p667K80cbvfNkVEt
ks2Y8ZNfyfk6zfz9y5vFi+5NNof9s1rX3OryOXQ4r8/A2km55pfyPUNPbUsz
f9zSasyIa/NM79Jf6tT7O800iG3Y746APO3d5On4BtPnWX0Af92ZYQ9/OLvK
ywF97rXm2zssteX99p2zamN7F9/Afsgjqz55YlRrd552yOLfR86a4+6xGhBT
Z+lti+JNcquN3X7LXhp2vmzB4qbfPNE80dRf8173Qw+4PI+s/28NuHBudpMk
4x++f1pqwN5mf33vK5tyx7RMUvex5pvCozNjN89Os/PzsvS/Jsy5KcU8/eEj
0y96yt3Pwz7JtAPRib1jMs3Aq2u8+u1vycr/lmJ2XtX7wM1RmbY93zdbNvLi
Ls7f1q5Lq0PTZmebfefu+NfBSJeHNfXNiMiNtQtVXsRC89qCVpMfuS3X0m/e
OXuXfrMo13TuXP3QAwPKLb9Rf6PiIcenL8+zfv1jp/YnXdOlwNxX1unxmzo6
vc3m8xjz3Ig1Tzg97fn4cz/Ie7PAfu+25THrjxYVWHnif/nBC6t/7e5tv/Lq
X3+r9mK+2f3RfRltAnot9TQa/nuDt+PdvVHM/9snxuRM31pgHnnY3Ld1lpO7
0PHF5J8WbxhUaDI/6X165nuOjtDlinZ/n0l8o9C0HDyjyUOniqwcor17hsw7
8XPvItveflec91ZZsjtHUmdDwZPL9rpzIutKvrh9VEOfOfrD9INP/eTyLFK+
+5Irn2k32W927rrgo+eeTDA5Dfq+P/TBoea1wpu/vfThBDOlZWm/07+PMAm7
71x+e0mKGb1jxq5lnz9vJvT/KfnA+ixzIHpVyu8v9zcf/9hp2dClWSZmxTvN
739mrMl7uN2l732XZ04N/mDE4XVDzIT3Vvy2cVueub/XhEVdt4w0Nx+p8Xzv
DwpNWZeBP5/f5jlz45NRmTOuLTb5tafv73/xULPh757nftew2AyfknHnikMj
zD9Hs158c3uJubSj/7PuBwaaLXdPK2/zUYn5InLD+0/2H222LazV9bqBpWbx
osPlE5a+bG6654Vb6rSKNzes+bnF4KlTTOeGJ/e9/VWyOfTxc30e3PGm+X7g
1gsGvJZsjm5p1vmrcTPNL8fPSRh/KN18/fLZY0OenGZKP7zy5ROtAvrB5fcU
P/X1FHPsM9/essfzTL/dI5tFHZhico6VjKwfsE87DelQv1XsNPNoXou9l+wu
Mofu+C7uieemmk9+W96kd1yJ+eixiUVrEqeYl2d2zqtVJ8VsK0x9YMNti8wP
CevLnj2UbCYOPHfzwaxFptFbTY49sCHLNGj6znv3H1lgvm23Zc/3h/PM7HcK
Y8+eWWieH3nFlh8X5pm5je9f0/GxgJ7e+7Ut9ywrNt0/HHL4kW8WmyFPNnls
Tct40+/HHZ0e3B1Yjy+q9cvcD5JN5I1vvNf8t+VmT5UWRdGjMszM2Rv3vtJ+
ubnx5z1HnivJMq1OTf3w340D5RMPrj/+T56JK+nQJ2VorOm5vWPjzh3Szep1
B+/J+SnevN45f3OLzCxTNLpV/+g2iaZRixo14lID8v2Bl/4pOi/BdNja6mRZ
00TzftVvXz/6RYqZ+HHDpoteSzenFo5N7/lFsrnsha+ua5iVZWr+Pq1BRq9k
03ncPc/9NCzd/o6be03zp97NMsceG5fdsF66qdX7y4Qnny81v65J3bR5VsCO
uPjyGf36lZuhqSUNT1+daX77bkrSmG9SzPHuX2QeuDHHjDt9YNJdzUrN6rLG
s+5MyDFXfZ+z6+ax5ebVu1ueWBXAswe2PNg2oK/WSPxm2NiL882JQcs+2zA1
23S899DgfYF1/eaJt3zUvYKeMy6e3+L7fNPgULXS3/OKzbZVbWMXH8k3w386
cCymdalZsXBQ7R/qFZgf166Z0vX5DOPz75z+T26hGfvhOes/uTjHrL0q8/nE
vEJTfcO+jgtmFJvNKZecN6a40OT8K/Gu34qLzZUP7Zo15MNCU+PhxB9Pdygz
53/Z7ZvpRwrMDz0Lu2UH7NYanfrE/hmwY8f2fHdY8uSAHdup6+t/zy00//yV
XBLXN89MbX2qz0VfF5mPxvx1utfTeebsqA17/1lQbI79cfu2tIhScyLv63qn
ahSbGz9fP/6bJL95b2vXkR8MLTb3vFr7unOql5s/HthWde2OItPuo187XFVW
Zn4/cvxA/E3FJu3R9YeWDiwzM4c3Mje8Xmxyrrt937ZzMs2dKfWmX5vhM50a
72j9dbVM80Tm4q2H831mf5PxM3+ok2lG5tW4fF2pz9Rud2mPlRfkmFpLni7a
8LjPlB37fn+/hoXm7uYzXly1qcS892OVo92XF5rUaf3H1NlaYg4/+MbPt5wq
MOOv+nniHS/5zJXbq/b3LSo2C/JbPrA1vcSsXT+uQXT9YvPvDe/OOX6Vz8x+
ZvnKX270mf4dX3mkdG+JSVrb7WzzzSXm4Z/WHhzZ0Wc+TPxgQNkl5SajzeGq
16WWmE8OfNt688dlJvnIN61rB/STn/pc+1zkzDITHRVTo/SWgH361JFH/PeV
mdwpG6+6fozP5N6+/at2zQrNmOhuq5Zm+M2xE8vGzlxQaPyzk249nek3B268
o1uzvwrMhl5Vnup5X6kZuP1Y6fDYYjP943q33jrWb+4eM3bhOTcXm4KbY5+K
3+03z92/ufoFd/vM1vH1rilL85srM14Z2Hx/QH5d9tKmeWf8pn+1uKYTWgbs
ls/qdeg3zW/e6frGVc0O+U1h9B2P5gf0xh2L+w+sEngv9sEnLvy6VqnJ3Llv
6aE7S81FV6VecXH3MvPDl53qLD7tN180ar/qhfll5nhk6ZTRa/1mzRdfNJv+
SZlJ2997xysT/ebi2rd8PfnigF5+Xu/6HZ8ts78T1j7y8W1Xl5sJT9W6fnfA
Lp6yfFl+t0NlZnTUB+03jS4zs8f8uOil8jLzYtLEZzNTy8y8iNJvq08vMwPr
Zlxa7ZsyE7Xs52uiA+14deKr22YG6n942OFeC9NKzPAH9xTsWLfSvN0/7tJF
L5eYPgM71dn0V5JpXaVa3tjCQP/fue+anceSzOCf43s1bFNmCk/9HTMwoMed
+uBwvSEBvCTrw0cH355s2t4R8dfoPmVm+QXd6s2PSTNNrzxZ/eF6CSZlQ9Ff
HSvi63J+nLz1ugRT9Y3ry8Yfyzaft/vwr+63JJiX7lo+LjfAh9d/lj9sx50J
Zttf1drsviLHHJtTLyL12gzT3LdgRq/3S0xhp1kZ1+7NMqPbfT8sq3qp8V11
0eS2w+ebjU+0varV84+ZSbPuvi9lcKm5wH93o/Nb9zRTRtZrtiyAO/Zan35L
aj8bv3ViR71a8y5daopfb/RL4Qs+q6cT19Nw/+ZpF3eKNZtzNr/Vsoc7X/D5
4fP6nmxVZvU+/9R5B0/c6u4zLqt90ZY9mwJ6y12jpu06mGTKz7njyDv3llk9
jPier/tde/aOJ5KtHvniY40fzJmRbu26lROXdTyxIMPc+MnXzYZ3cPkYnn/8
y4mrokrMrVP6Db20KEDfx9++aEpgvcrvNevQ6Y1pZvvhPwpjf04y3w7oUF7z
zizzzPHqK7cF9K2e575xaZOAPnZk95is5gFc1ub3ETOmZtl2dRxy7zlbYvPN
gcuOfvPQu8XmrxuXXvL+yVyz/pGbHus/otjcWb1Fr1vfyjU3TR/x1pfTfObk
tI7b91+RZ5IWlo178OVSMzfzmV337M01h9pd9EVUL795/YY+iw9cXGCef2fS
rw+0LzOPDI2/o/dVeSZxxg2l/X7MMI/Wymuf/FmBufClUV9OjMswTc4+PL/q
7gLzebdupeOyi80TJ9oP27a/wCQf75o+Lr7YvLtl/sYugfKrYhu8fmBRkcla
17fTiF+KzJJVfYtmv19stm++oGRXfJG5KWbT+ZEDc0y3frt+qDenxJxKePrb
Od1yzF7/4idy5pWYXvFfn907vcREHXgx8pZ6Lp/xXcffyp2ZutDq07UfbNR0
3jXu/rVvTm5M6X6r25etOvfpJgnnFFk9d8CVVw8edNDlV/B3bXUocnK5OXlu
67SCE36zfHzxoy3WLTI9664puq3DKvNu/e/2Pfdshvkt9odZr59JMFc+tcHX
9occc0uLHef/GJlpal238vSp9j5Tbe2Fd129co7ZOjJj/7VHlpr+9ac9OWjU
QvOH+XqNab3axEa0W9Ky7kLz8lNN2icsjTP58af/nNhuoXni4Srt638fZ1qO
u2Hua9fEmO/rLJgTc3GCeXvrD8+1WbHEfLu+zuw5rRPMK+MuTuq7fbk5M+76
Oz6flGru3TdgzpyDy82YfkkNzi5ONV9cfep0+U/LzdM1dtx3b/9U0+Xfr13W
smasiWu81H9e11Rz+cO5x3aNW22Od3xhb83OmabdpfVPzv0j0bz0+d+Rnbfn
msiJ126puzLJnDNkwncnGhSYPnvOHF2enGQ69Bi4sEdkgVn6wNcNG+Qkman3
de9Y0rTAfJpV/GB8SZLZ2KLdyUtaFZiq/5o/qtHaJHP+VTfljqi4x3P89Dnn
5yabaUPXv3x9boGpM37croNpyaZD1rLIn/IKTI2u7R5N75FqOjVsPHrzhCLT
cfYlq7Y2TDfzW03pd8mZYjP49/r9f22cbqIiov6Z8lexmdOjcZOqLdLN0E9e
XXnsSLHJW9Pit8g26abXitF3Dvyt2HzW6K6S9gF96sFBw77c8UtgvZ7ZccKz
ndNN69sGj+60r9ikmkNNZu7PCfTj98caHS01u6t0GPXRezlm7sq23d84XWqG
DklaPPW9PJPw5Q/F/UeWm4i+d55+KGKy5bvM2bE7UvpNMkNP/5H68wWzbdzr
hCMTTszr5+77eHXxU00PN8g0/bPfW1/1TPh9IPldrv70gZ+zLO68bFXtbd84
/PPuej16fezw1GbLYvesyzKD29acvOWaeNPr8bYx/xzKMu3ubhtzaft488mv
3dfO/T3LXNpuYOaz/eLNvW8O3XflsSzzq1m0NmNyvClp8GaNzL+yrLyKq31q
X2RmtrmhvOsbX/wSsFvP/WfwmR3FpnarBQMv/TnNfLJidNaKL4vN3zmfd31y
b5r5P7K+PJyqsHu7SEk0mSOlQpS5QUXL1IDMREhKkjlJxpJEKfOc2TGdwXHm
SYVUKiJTKUOGIpUiMkV8+72un32u733/2tc6ez/7PON67ns9a6+1pPH1h1Y7
DUbkRfdnDJSBRqOjcmcLDdoL7aQ7P5XBRdcW38BmGlRvyeaV6CmDzHlDsvAb
ZDwkNkz3/ywDtYWD2hHdNFAKta67PFYGJ3OvbW7roUFUd2bC+HgZuGhTRnZ9
okG3do9D8EQZBPf8rA7qQ3hj/naFFX/KIClcKb2hnwZxSxcn706VAVba3Wvr
IA3GFRgurN8EaM6OfGmK6Hl/P5aC+wQB5MsG9IYReYLJ+SU2iexjFL3HN/ex
IWDxEaMekd8/Ljogvp8Nf45Vh19H9jWVVyspJEQOjK81kJ8iQHT7+T0nDyD7
fUedwHtE7v30tLQfkYOlX7RGTxNg33fZ7SEH2TDn+jJr/wwB4qYiszdpsSGM
8PrcECJ/XjEogkfkhYlG+fRZAhwR1E/UR/bdm4ebfxrOESBFHLO2G5GXIlvo
fxD5+w6eOwHIPjPId9R3N9Ie3ZCJnlZknzJddc91YowARpFHNF+os4HN02b/
+BcBrGLvxLLV2LBzpbRZzE8COCY39RFUEfyw5GZgMUoAt4diBwpUkPr9I2lt
+UEA36JzcSnKCC5ZmFP+8o0AQTjsYPReNrz9a7CzcoQAkZTfWiF72HB4Ll4i
+CsB7nMOJ3orsaF0plNIf5gAaU+jhs4psmHjtCyv4BAB8l6/OWK9G2nvH6/Z
d58JUN4qmnJcgRs3dfffadWXmzkQnHBj8KRaKmQ77Dktl18IA/ZXdBv0sDAi
FZjasxLhyzwDoV66WLgt80aXsIIBfERLhiBgQVp256+QJTpI2NWNEXWwwNwZ
mnNykQ5KKzWVzLWxYCHfelL8Hx10CMUXx//zHd3u3dND81x/8z7zX9huZJ91
XSGiOzfAgN0zh0nCvFkoL//QVb8iuDgbTn3zKCh+wf0+V2c8V3UqMAPhT1Oj
OQHFsPVT8YoN9AyI27zxvT2umJsPJ1p9Pn1HOZAvEGyuni1D8KjU7f1/qNzz
M7ZVS9VVBhQQg3cN6BFQnFI4tFYCtuLhhcx1dk4eE1iaOyMOyeJhy2aZNsEi
JjRHag9ryuHBj6/+x40SJgy9tTVVUcTD81kfvrFyJsxv9aPvVsaD5KjoNhcC
EzZ735PaqY4H374nWq2VTNhdVXR76348PGtzs9KnMuEo/6Nv4oeQ5+uFvGkM
BC8X8LzXy2XCgbBbdr8l02FICI9XVWXA6cRdV8QOZcNu13HP3teFcHVKhO73
C9FXNaVBeTos1M6D5stsFr9fuwsLKkIZDx77sNH7i1GNlNQLHGh/vt+jdA0e
vvEJFZUictctT6NaUTzE3KyoFnLnAO1WqlwBPwEsS2ghNy5xoDnFPLT/Gx7q
NKvjr84Xo/acZbtMVZj56xcnOVD9O+eHXCoFxHzPG2DsOXDz3HBAxjkapFV3
xk5ZcPMSWn5o39FEYsJoCE+v+nsCJL7fco96hwWv/B+sOOPKgX+NA7H/1LFg
Yv7PcwGpn9P09RwLfSy8S1DSSckphmuxTvJi82TIe6PWcj+uGKaKFFdt+sWN
Y79etrgiMJcNzt/27BNzJ4FRAom2y5QDIRO1AzHbufGBFa50hjnXcf2xl3Zt
dnvpzQHRwnBDx5cEUGwMLi7y5UDObrGkdysrYAOp9LVHK6KXHtiGiS1WQM78
tklXbypYeszjWk9w4LW3keIPQRow7Ndbdxlz0O8DijY7zr5A7t9654M9xMyG
y77+4YXppai+l1H40LM4XQb2Rj+vtBVy8yGYrH2uGhXFzRuQ1fFMtd0Ei9rB
ltdT3gG3stItCF91rMp0t8eCMh6zk/ybG4/O/2OkwUFlbl7c7c09FmlsOlgt
dlJxMzhQv/a43+gUHR3Xp7qvfnQRWWDbmWN5G1+J4uys61+MGwlEGO5YBxF+
bAgX/xAQ86MCOIZSR+KTmXCjqTb76MZiMJDTccmIw6I4fl0ips9tDQ6IxAad
b3WFUPDlzDrceSy0Re4pjc0pgy0iFr+karnnwQImgr3tCN7t3nl1/JtsGTqu
y/bOoZWLgj3iJAhmXzjV418CPJcdOx94kqC6Tu3SEWUc1L+8KbnqHxVWKf2m
dQjigOSaYpuwigZhqxMSZgtK4UUWtfP+80q4qvGGcTwJ4b/GLtt2fMBBXHFR
x77QStirxWq5VcyAk0Gym5U24+Hxfr7TPYJUUAxdZe1Ax8OhGBGz66MUtD9t
Lp0Wa39NgXVjFVTSfgL6PUcTu8rStBkDvQ0Rpw94l4L9xaNBGceKITtyM4cm
WQrGX5IbunnKYaP2+iTNiAroYDqLWRnGwhu99Rt6JyOB503MW+sHGNTeru4c
OdbTWYD6/0bQZdYJPCtB/X2X+cdbwbrQwFuRYNN20EfyPhktv9dF/mpVaiVa
vsnL+e6PBgpa/tKTG6kRK2no/Xy/4pZHDDoqT4X+XkW7kY/6uy/P33jLWv6o
dwkQ+oFhPdpRit5ftsd+r29klkbEwgofcR+P7zj0vlJqyF0fuXL0/ECffcfT
wJSAysv9e1p6Vt/43wP4NjfqVihGQe8HpqjMVT2KQ7//aYb5v1c6i1C/ouX6
5S/oX3gylY7OLyG2rXXGhlTga27NXK9ahj6vTjnz0+IyHpVXX6LEGsuWo+cW
Ak775/LTKtD7y/X7J15254NEBmoH76XQqyWep0Lt+9zh43gyN9+vf4Trqk3U
/8r/SwGcn2aAdTM3jtXcwojZ6NuHkNCKryaEcc+9MpSULgezSlH5gr9PeNka
bp705fEvWHniLkmUmyfvof0+N9Uf2bCOzc6fkcOj5Zf3BX+hUDgymA+mgp0T
AoHcuNxDBebTuM949P3L7XUjtW0HwVyuf3CLn9WUew4ckbj0Y9UHMlp+ed/2
0lwZm/y+CKauJTzvEcCg4+LBervdcW8Ret10vaC2Y18RWKcG8EzwF6PjlV5t
fc9IvggebbadP8MqQ8svt1fPsIuqScDAKUzxvqcbceh9y2SzpC/zZageWm5v
wC7/b5i8Iq79vyvNy1y3CMHRjcQQxUq0/HJ7q0kICa7FoO31tmKNxDILIZSf
YmuVT0afl6CK/J77UYn+3/I5CbMh1WReAYOOR/eu/vREuRIQUamoUC/lnivZ
bRUgWmwqR9u9XF9hl0ElnmulEJYTR1jjXoE+j/oLDRStcCCVwQUfsjV1Pxnm
hNK6MvO55+Sekknrv5kVgzpO3PX7A25+rOX/WTouL9PohEXrp6gt6UJvKIf8
f7LpsRgcWo/l6yVS98vuQSwq6yifVD9zGw8GNEVhhacV6O/L/SASs7niWgYe
rJgtub2XMei+xKjQu8WDdO1yO5avqV1wt/o6EbpPVOi3buSe0zjh1McOslho
+WW8c4p08kudLjd+7lftEk55Ewktx17aOOD4mwTpseuMd8fjuet0eT7rS40O
nSSDBZNnM58jHXz4TT57ZlfC6QWt0eg4BOcxY6jFfURQP1ij01HBzRuz7M/o
a+LJmgnnxneSyGy+u92RCuVL1+rW6DDBNbDb0EeYAo8tfX/afGCh6/7RJ/bU
Q3euH/by+dkGUsblV9+5cV014j3N1yL7yWRQEX9wEActv24kM8jSiM09p/+/
+ghxSstq/lHQesa/CWkzuURD56NlG8P1qiYdfc9pnYNvh6XpcCuXtPgGaf/9
D4X82D/c87a5SOkHUu+4eV5M/8S8VLrN9Z9XNJlJXnuNBj+TmUrMRa5f+zIe
L/+wRWN4B9efPrzrm7SfGQ0+usTiJqgs9L2kS9IvkuVYEGFXf2nvEzpI5Y5O
Ud4xQXjH9H5BIQb8aei+4h7NhMOTqx+dPssADdmkhksaHLR8ZfR8odhJNtcf
///6wzrnddPIPDeuxrWVtD7MX64/fNmkromiPwPsH6lcGD7Drffye92e23bq
PeXKBjftgxNsuf7xWyo5N/8GMaAkvn+gaCcTLW86nZwoOsbtp+XfxaNYmbqL
XD/6hf5uT6lrDCh1jl9Yf4mFPsd6XJPb9ZMrn7jvKL85mvu/y/MF2L2xRQSu
rP0oYevWQwgfmZ51fWrCQcsbn/uMqRTmwOWH5YLGQUwoCLyTyveRDcJRq6Un
KUy403h5ziKfDSrKO5jlo0zQu7/59i1XhLf7BisHK3C/wzh6cCFc5xj3O4jS
aRMp6m6uP358Tri/6UYWNJ7hD47N5Nar2zapPMaRicrL9RJL/WY3GMNtZx1h
QL19gevP/7KVXCjAz4Jfp3evc01mcdeJ/J/3tSJsVF6+7jAed72E4z7neyLZ
zVCUzfX//33yrJ04CzIsNA8YunHQ5668jct/ms5G/3d5/rgxVFo8rnDlRd+Q
aNP/+IVYE444PKDDZLBs8lU9Ntp+o/NvyDUNbNidsL6irZKBllt+77D3s46t
/BwoxqoPT7zkvne5HtZvRi2faHHrdV+E/8fKZO53ClJJBr35KzggX/0aZ76f
g5Y32/4i1KWC287l3/tWqa8wQviIh+xNgbONOSgePFiTmL7ZNwcIOh7K42OB
EPin81XfoRwwCOH9FV+Ug+oLhyNiSwUOeHT+L6WsPrJXCIfed5lxljraQoSp
e/LsDx6lALmJsobqZFAPypToR3jb0FrBK7YHyKi+Sdku7hB3Bll3RT5xPjIc
4MikxDAnSRDk2aDQux3hpwoOsgxerr+CC6VeLE2Aipb3ayLFz/+moDL7A++S
NJUK/Dvf1B70YIG+n/09h0cUUKmJW/1qEgv5HRkCZxpoUH/XgXIijwL8pSqT
F/1p8GHulc/2BRJ0dWUmnLjJgEWfPQVdCxRY/TmszBzhix7fs8sGd1Ah4E3b
vg6k/1SK5LdtHKDBuIbU4jMXDgQqr83y02fAnDtFCv8dmRfDvuG6yHzfzKuR
glvLAeHxqy8bplNBstnv4uSPTDj7PfqpqXgq7NTnuVuamgX+M0kxwl5suGay
rfXR3SwY/6q09t0FNkTyfxC1mc2C6HfiU0WZWeDtW4+xiSkBzY/l87EVNOic
0jRIUyqGmL9R2wtLaaBF++69qFwMXjO/71T8KIAnV14bmRwvh93rssm2ewqh
34N5ehuCs7dTCbb3woqh4nxJ/8FrlWC4IkjfMa8EPv4Us5dSokDznet9x9XK
Ya7SYazpBg0SHm0QeXmmHLY5NA2cu0qDjX6lkXviK2GHpbeDaj8bRiznp+gp
aeC5Kt7sqHMkuB7pLg80TAOK+ItDcZm3wfF3b0nT+lxQ3Xs0xl3NGkhnMvMP
zORA+YpfCiOjF+DSoe03lLZkAUvY/MuU/n1oCsPQthdmgeBd15tnBgtR/izf
HdwTfbkQwk8/2W4/Q4Txsufp2EUMvBe+RxRC8FpcpOvFsFWlsGd1igw8JYPb
eVbImH0p8GdJzu6cI4O+66WdYXKlUNYy4l6aTYGjLLWnLmklECXvXkU4UAh+
LwNLTh3j2l8DT/eZPNyOh6H5qeiYVG4+P4u/IgtN74iw+/RE8G31cojJDGnN
fEGEfe/PD70TxUFMh3fZX6tKqA0f78e8x8Jb+5Cjju8p0PZFjvytrwxdP/c+
mhOqPcpg+kGuMjGTCr3KWaeuJCA8d2EiX/03FSKb/I9eCCyDSkUxvFMvsv8k
Lnko+peB/0qN7cq+NEie/zVm5V4GNDmX3/lpVHDK9Oou4cGBnfV5zTcjVBj4
OPWwcRUOAtYv/cz4RITYcLLAnxY8XLK//MKllASYFaNL/Ip4KDyouf7yhkrI
v2KxV/daBZx6hA3aeLgSBPI79k+6VaB2sZT69JkCNQLkXKiNuDyMgZfbiwny
ryuB5Gucy5LgXif8FNxqzCshwVZNfDV/JfR/XRRm/iDCdr522/YaEnzfo8Ve
4OOg6xrsBkoetpChtKNHJ+UnBdo/i0bwraJAwMTSNpFfFCg5Lbw/JZoFq5UV
An7TybBhhYM/rwYTcqL6D9zip8I5oak8A4RvFCm97nOpoIIgKOtZz5MhdD5U
/ysi/xljXg5H+j9jsXDtg1oqjM5qGj/hUCHcR0Mah6yjzJwK79v1VDiIzxBK
JtNg8+CxC3FBdMgq+nNspo4GM57vDTf/wIPkWK9fTjsdxuZefb5PqUD16nIc
h6NfW4W/l7PRds1Jkx8LOHMg/ERlvtqm5XgtXNyG//ZCfOkNC9bUHx9QRNp1
7E2v++UrbCClaX3jRXCf+Hy+uacFG50vY9vOyB7x4OKk2Oi8l4PfWKDk538k
GkOFi7p3zZVOs6HY/+dBHwSnPTg1NWkhxEbXj3XLyzyNNjbsEfiRqPeZCnoe
PaWFHWz0fO3frJivEZUNgkLPe/XuMOBi80TiQw02cFzNXGPcGZCXKHicKseG
f7zip54lZkNHdU6ATvwtkF13p6204H/zIa5Xq1r/p78YLHjXrduWTQLjhCpe
vBE379dJQzqfkwAONvdnD3y8QoNP0KB9SgYHj+zJMXFzDBRHL88/1+GkqpEn
5aCnHmGmHFyM4vZlHpMzR434lU4AnnMWJ2fzSXBrF/b5k2kCXLpo5P1ujovz
l+PtPJNdKVxzlQArr06Y+x/g+oku29kMHe2q/uIJcPcExR+3koniRvbspNDH
5wzIjrr8o66e+z63VQ2lW/hJqN2nQLlmeoaPBJ5Kk092MP83v2L8/Sdfpgcq
oQBPLRhWLAfmI2Cemaegdr/PA9ccnc0pUJ5/u4uOJcFYU0pH3RIXz0tstuvX
G6eA2PcAgkglBXwt9n2Q+0tBx3t9WOPHle4U9P+ocxmPXvhRwC70pyjDhAGU
vxd+16yigknW40GXVUy03sv9rRraXmhlQAFrekdjzHVuvsfl836pmi08K4wo
4Kxoo2bzn3ybJgvvtyN6ad/2yMqdJnS0H5ev8/fmDxta0iD+md/KRA4dncfL
9au48A/fKk4Dwsa1148JcuPzz1ftb5DyKgFy/8vjakSED2lY7/EKLYGBXYcy
7pVSQAt/Ja4qtgQ2eeCH+pF9/V2buhY2vRRk7f606ZUh/VO45/JhVxasiv6j
pOR7E3p8NIMPn2HB1ayPCZqEaFCzilr6tYcNTiWrl3rtCuH1C/lmN99cuHaV
LWxWgIX7b6bLxjxyYY6vgOmXgwWT9vqIELdcuPkw+kxyJhYEuzLsec/nwipl
7wVqKhaa+i+pxzvlQmytVUFHIhYSvh4QELfPhQ02h/SnHyDzmX3O2MqUiOqD
RiL90hoLrtyCWRv12Iorv8t0LvC35cpdcbRH8vZc+RMCFLoduPLn62f/JJ3l
yl+9qBuPu3DlUZc1yvMXuPK4rZMR2Y0rTxlT3Nwuc+U5WH17ixdXXtznmP/W
hyvzKJGr7lzhymu28XUeCuDK60QcJn8FcuWNa0kbSoK5ssgi794zYVzZcW+q
4FflIvScamKrepTyEa58f8PbuYCTXFl2pc+VKluujL2ivTq4pwR+BuZPL2yk
QvLjpe/XBksAeNe93SNGhVD+Z2/9R0ogOSmo3EGKCoN7t0inbkyGS+51BU3s
NNSO2LDB4f5u1XTUThcXGmnp/jgVrGSKVbzecfOFWhzHE2WZWaDVrHuvvwoD
7pu+dK6rzAIpP3sr7ycYdB4/o6xfQdrAjXupO3hz9yZkvYF4ypzJi3J0/X08
f1T5eE8UnM0dJt+6cxf2VimWROOi/ycPdA251OaOKTcPtPpcRhmbeQ8O8kWl
K8dGoXHlnfxL4rpy/zcviITQFl71uodgzS4Rua6UhMbx2EaW+vf8JR2Mu67E
kiXw4MUHPojGQO0tEkvXrpy9z4Se65fkq47gYef2Oi9+eyZqZ1nWDzUjj0fb
PInA8aywFyhhoucKGGFm+KTS/+YP9dPNe11kXAxWK/1fHhjnxmFYfk47OKPX
XIoI1/nFxOfvlaD6+OzGOTOJGAx8q/n98eVNBOcMt/+9lVIKm5+Gn8FVIvu6
lxGp/EEpTG9YOs3GUmF4rNq1+U4pfHSOtHmJoaL9Tgw3Vj/czga6kfVN9VgK
PK4uji5DeHHV28ZOG0Tv3P7AumD9HuFXb39WfdmN8N9+gZaGt2yQ+DtqwzNN
gRb3V+uutHLzEddjGF+nLTio/nuxPSbMJ4QNHksh1hFuNFC1m5boHGDD+UZV
xo8AGmz9q/Dy42c2HLWaejY2TgM6ZkFLd5abv1g1O8Z+zJ4DfC8yk2esEJzR
c8AgqLYUdp1jOb7L/N/8qE9btJqN3Lh5Nj5RzLx/deNAg93teNOG+V/x9plg
N0v5afoGBx1qByfWDNKhK61I3GCmArRejEhlv6bDXHeaikZ7BThovutbf4AJ
PL7bNsoNVKDjMyujfdQ2rxKw3q4jP/Zy49glMqk6dy5lAOkpRGMfFsEPzrld
kjv+N3/pObPbo9aBRZDVEE+5vgMPhleuW9bXMoB24oeCpAcVJCstEyKQ/vZL
Pq//KZcKfnKCDz+0sMFfw3fwx4YsdH4vf1dCz9Rm9r1/iOL59VfVzDNTioFR
1T8SZlfwX98HFABxxmQjaJbATHJQwOWJfNQuuny/SlOHX2a4FK7Yqyzu7C9E
z6F4PYSfaozkwX3FLvcEwzKwfP7lZHENAVqHKk7ZbmHClUx1Bk4RC9s0lnSP
hFHBKpTYKeCFhZG9DZiLXlTw7OBYNCE8aqX76Sb7EiKkGZnxjCDzIN7tF373
MyKERHha9bKJcDuT4ltvT4faz42rNh4mw/BeZ8Uzb+jALOd7NNlaCal6zmnu
hkyw8PC6ndDJPd8cF8bZrnXIgYsXyQ1nzidBJqVhXH1FFggH7fCZsUtD27fz
aWjZx8sYaNLeek5fMR9+fDhA636MgaogjbC5w/lwaeDwnUImBlTzry51+laA
McbpXPQnMhy+1fpB6FQFrBiVf6vxhQxGpN4Jia0E2LL7+q+edCocoB/l/WtS
CsGtm4+Jb0f4J+32MZcnxbCqT3d3XBj3+xTFjiA9M7EKUM8leJwSxMHMpIJq
yb1KmFXUOoP3LAeXpPyaja1E0HL4PGGxyELXf4LaLHlWlA1flZ+oVM9WgP+H
DJFXX1gg6LfR1qwCqccp6L/wmwWLche9ZpcIqJ/Q/oM98czgSJB/d/Zg04Fs
VI+6li9a44a5+UaX55XaCjdpH/0sIDy9o/lyezY6z5bPN9yOX8r7eSMD7ENN
As+upaP7yKawrLyAoQfoPO/PuNouXl0CdXVqTINwbjzqFSvW3uPJKUVxr3Xm
6LoueiV4BGxYreqL8MiPgd7pHZXwc0Mzlj8Ki47v8vOcXKduwz1EeLvh3g7c
Lm7+02X7XPtaBZN5hJdKi0UbXZumofp4uR/vVXcMuUhx7aPzX/5ljZ6jcuM8
lbqKv9tJgRf95/vSpLh55pbx/Pz1osEb77nP7z6npNHSTAUH2GeyfombB16E
L8o0OZUbZ2TZvtV/0Pv6XCUNladl/twz96BDJ9+xnVfKuXa1Zd7V6f/ToP0v
N04M76eWzlWWbMAez47U180H6cyi6ZQTqei5lUI771fbsDS49Hlwdl9qHrp/
v7tVEj7ATEfHsXOi2DT0ZRr0uf+xGRPPhbOfR4+vNygGqXoJvt++RaCg/6v/
1N1cdNzOxN2QO/axFJXV/T+5Ojhzr8t8KGz+vsNRATyqz3O8TvdIauJg8Hlr
t/NwEXccoh9Y1wfjoQFzLv3zKW7cn5NbPZrdWBXo+x6+cCQdzSKi+82Dy31j
BefJ8HmlqX+aFAuG2m9jY08mw4PvNqJ7JFmQ/9ehYcErGZz381m6GrFB6Kf/
zuRvJWCg0ZS6XY8Nawr0CWFKJcAjIbewJ4ENoeQctxW6mWAWZG37IZuNzt8t
fpUtblLcfKzL/x+Ym/XDzrUEKmsCH+45xgTjxEUf1rkSNJ6zbVHIVureEvAT
uxYaIsuCb0ppLRcPlUNTYJLroioLPt84tjHxTjlsfClx9KcZA7CvjY1ufMKj
8ff4DhkfUeqvhD9DNgcsZtjgfaTx86WYSuCXv0vgWWRDj0T3zrZXlaj9OFhV
XO+INxuuKt4dZCD7WSW+6rDMOTasvYGxyMzLBvrZg7sU9W6h/Wnd+wUTsw0L
xSMbYt+yMfAzdF/b+V4C3MrR4I9rw0CKme9q52YCCIpse3ovm5t/aTnOIoen
N7K6nACV1e+Pn1YugycvWmM33UB4PLIH+eOZwI6472rkUQqaPa93y+9jw1//
VVLGjnmwymPwpwrCs4+PZW0N08KA0qeUGJYyGyysnqcWJBRC81FNYZtYbj7Y
5f6UvlzuY7eYge6jh1i6g2plFRCqYr5OAuGnXmlBJ5/GF4PWGgNm72dk3xCd
f1ynzc1fFcvYImyMZYD5bcfvqkbceM/LceGMeRg31mDY8Ez6rlXrDyYa5285
Pqe8zFK5KS83XyN+5V9Babks6FrqfX9ViQ4pWyXSDkbgoKEgXLpJiQkHJKLi
nsjjQEQmqnlelgm/+ds9nm/EwQbjPwo6pdx8sLauhwi/8jIgjyp3XOFpNphr
zNlTxPLh1/isP/luCZzoOLkgnpIPri1R0SrI/FrtJV5U/ZoA2MWtgbuDqDA+
ffg5TaQCuh/Y+RI9qbDZsWtmNx8WPlBPP7kVSYToLdOafI+QdazY3yFcioEn
Q+cfWCeVQZpLXHjmTipsUr/e3EIshUOb6sUGzlNB+1IjNmcbASSOijbZAxNW
eg2m0NYg66y22zyYSYXeSR3V2EkStMmdDR1nUVE8pcVsf5VEKIFes71uaY7M
/8nDFrIgXZTZTYAMBinh8FluHNelu0t2O63JcIth/+YmhQDHeWu8sHvI4PXk
B3XNCwK6XxOGj4k+Vk6BHQ82BUY+y4eW+6bhaTkp0HnKcOue9UWgeK6fKXUt
H+77z7bcIhbB9wvr1a4+KwQxnTDP7zuLYRdfWdO5mXzI9cryTbpQCg5mz/cG
JBRDmIN0X2NJCYqPlufdNZkxp+j2YvDve0Vd5VEGP0u2qzbUYuDj0zaeVMly
9HmUtzMWu/VMSiArMlZ/s2oZTCv7ncx7XQKh6ZelWQ5YeEzVdu5QwaP7V+ZK
PtLebAJU016XxL9mof1xhnit6cIdOsp/Xtas3V3vQ4c8M1tGZOA9iLezzTDG
YcDaTsVd530ByCVUSOI/lKK41MerzkxwJR6EQivGtvzAo3prsfjHNi/DJHTe
TZ48se1LMgYdH97TnaWvRcpgY4TAt8XXJNTusnyfcVoyXOMKGT1/zsozSugz
JqP2Ex7ZyNv/iQ9kpmMYha8rBa3hUhf1ihgITi/POv+xHJKfhUj+0Y0Bvi3F
+3oMi+CvUalD80gq5K+cUFK/WQjhnjMu6/rSwQOXf2dWAguUm/M/pMdToP/Y
M6aiUgVk6f85KVCXCqGEJR9MCgF6A5vG75anwwP3olW1LRSY8bTqe7MhDeZa
pwwiXyCyb0YjBcF7Ci95FS+0F8JxSZax+elsqJHfFmcwUwI+rnlr80xzgP6k
majUVQ4W0hXHphF+6GQZXaaC4KbM5leqsY+zYVNXZ+aoXjpsvKBt7fW7CC49
Ein09k4H0+tN/UvCGNg5Ji+7HkqggH4zrz2jEN6ULDYxXLHwXLWyXle4CB7u
/Dw6EEQAoWvfz2tEFILbIf0pIxwJ4nukFxoZRUCK3n9sZyIW9pjEPx0ZLoHu
7wsqU2E4SB/nHB0+XAJKJU8O5HUQYIeqj+ruOyXQXLqjIT8Yi153Y4+NPI/D
wRsfybWWbeVwjUbrLP1CgPHgdTZe2lhwdCYKFbXS4IdlYvSb4ziQW/AyOFJF
QK9dJuOafLMEaHusuatflQwH1bVbcvjIsOW91i0vPzK874yn3RiiwJNTjz6V
uZKh9ZT0h4odZBD2HJdsQHiggmRZ65vTyHpdV1xrN0GBxUfGUm/XUNGrU6v7
qwvCVAi+wljXt5YKNvzVWLGtHDiV6lNU9IYC7Ls5rLYIDnQonG3vCaaA8O0n
NA1ZDoQoH+kM76RAcLxnvOsLNojuSPhnokmF/POvV+3LIYH1D8GYjkAE10ke
GSTokBG+6VOU4EkDmu/s6YwqFnTprtgneZQGxFP141hXFvRd0MhenU6DRwob
g2SFWNB2d0Q44QcNtl0LONz4kg1npGeuBZjQ4LfE5+JpKw700r7tfh9Cg6X1
eVtrVnPg7RNVklA9DYKFyZMXH7HBjiP90X0THe6Pb+zd6UqDN0JDMnoHGUBq
FEz2R57LrRdnb3dmwDOrDaNtp2lwD0TP1jQxYCOrasuSBwdWaA5Pfj/AgKXQ
M3s3KXFgk9+JwQ/XGaC0PiLo4Xc2DHfLZlog+5PXzkUoqKWAelgo34w2Czpy
emzykPEImj7x589RFnQmC7lI69DA8Q3j8+khJhTOOlyLHaTBT2aemLwYC1YL
PdiueoMGMRgfz1thLAgPNnHz8mRAdfq28ntI+Sg7N9vWtwwwCXQPml9gAq+s
5U1yJAMaCWFm0iYssFaPP3pKnQHhOZBwK4cFLGL+q/XAgrmGqwJ7hTkQ71Q1
9CGeBfX4Kk+Vr2zIfw/6e2xZQFfbv75nGwfOvrqboYrgs6mjPzmdZzjwcvhM
kegAEx5slyL9TuUARVdt+2fJQrhxg7qu+xUBAg5/YUnIFcKjqMWA0icE2Lcv
y9xMrRD+xhr3+FEJ8O+r61CcRSF057fWGlQTYJQiThn6UQw/Y65kF+tSYPrk
lgjrt8VwZxJjOaBAgUiJpaeJvCWw5tCDfX6GFNjpvUZhdlMJxNAi7iVrUCAs
Bsv3H/9tp9SVn6T/0WGNmIql4X4smBqOF6+coUNqKS33kAoWYOqTx/A4Hbbt
PzSiooAFtbIm1cbvdCA8r9bctR0LO+weT5G+0OGgjWGEpCQWhPkJj9I+0cH6
9Iaol3vZKC8PtXhPd1r1EFy8VdzOBCL8Z3CbxsyZh/Am/p2TU0gpeC+1a/zL
osOqnsHDn5B1kkitubIrgw6uf3oML9G434lZv9p2y1amAibWxIcWkDBo/GSN
IzKs+WelaNzrZbvz6XUvxBVMOfDi8HF+FUMW8PKM78rtiwOX8L42n8oS8Ppc
abztGwUmBFuco3YiOEbMO8VRnwHRC4k2vh1YWMOgp5y3Z8Cvbo+I/ruJ8NBi
nbCTWQ7suK9wylU/CXrk3+nHKubClGGa8uSlRGT9q72oa82GuCOn8netLwCM
QrHK2iE8rG3psPo5nQ9leTnrv7bg4e7Fs2uYffmAF0779fwxHjz9m+cty4tg
5IB8sPgSET4o9r8/MoqByjuKlWE7ybD5wsB9gQUMiOdsshmTIYPQ370Ss07F
0FH1PWjgOffcQ7RhPKN5LxMyCOPr3vgTUBxZ/9Z27RMZPGCs/i12ZzHh8Ril
8MkuPJTrm9O605lA3bBeq1oJDxUaRe7dKUzAqnq+rVbDA2XHpFR3IhPyzesv
1RzAA3PzsZauOCak+e1YrEFw5mOezDtdCG6NTbyZXquPh6cTI1pdMUyIIHXt
fXoSDy8HD//8GMUEnjlS1H/83wM2H6QVhXH9QV5n2Vop++CBPEKSb+nj2qmU
uhT1BEa5cmljsaPhLFfe9mTr9Zur8Kh88sE/8RM9OLB+Rw6xcWOC2VM1e9o7
HMQ+bo4qPscEmxnXrG1vcVBTPBo/cYYJjsqZHx68wsHUfYEsPRsuT9XB/kr9
vYLDzRvvw3j0Vj8H5ZcDzoZ1R96UgOrAwW8803ko3lvu/0hS/g2Fu1TYG6Pt
/SuSgOY1Yf0a8BHpLUbjoetH8rmH5pWj/F0oeT2L2sbNN/DQ5Gu2oFgu6q+b
neS2OOTBQmWdNUtfAjZmov6xy3YKMw/TcMMjD6CSp+aHSk0uyhsSDF1qwvYW
oOtxGV/yla0x67rBzXf5rMFg9yGEz+pv+jOvK5CD5glZfo/KHrGnB8nceBu6
fXvOOfqXwMkEs3Mnb1SiuLBLol3kTzQHxZXLOO0P9YCpmwD3+0k9b2XbbZ+5
uFIrN22EKkgAcTPD0NnVpSiPKZdLFdau4caZXbZLnBDtaIqM5MaV+Hrwcijb
nIDWo9l6dn8jH/f8bh2v6O3Kk9x4HHK4V5Mdi9x6u7z79SYxkRtP47heb9Ir
BRIqZz91D7kvQoG/rFVJn4Ow6HuX+6Nl3KRQMoCEys3KB7FbjCngRgs6lWnN
jVu7bCd5Wnth9EQ8Nz7HNYeaHE4CCXZ5BonaRdPR55ftu4mKmVOWN8jQpiR/
pHULA/3/B1rKG3UHWShuJY7GxVuPcPMaBgcrruy4yD23Xl43J3RS3l1G9AnP
UdLggx9ce8+yX5GmVlziT+T5bw32i+eTuXm1lsflrsrzZ3sOIvhFqdd4yrgS
7ddlu9N0XoKs9gXueSXnNaa/Q5Prb/hXCl5XJ3D1tYNAiF6WDA38GjVue8Zx
4+gut9+6y0yj6xQ3HkiFlIdH5msKNBz8t7SwmYHaKab7gP+3HAP932X+kT2/
psiymwYGizdds1K4ebyW6/vd1nD+KrIffjZcpAwj+tMih5gg9xTBD/+GvuiE
EMCSLtDqg8iizCbx9FsEsGpyF2YicqUvw3j0LgGsh5/bLiLyCYW8GwaJBLBZ
ks06XofgsL475OwMAthKRHQlIHJQlvfn33kEOK3eI92JyBstbcSMSglgZ3zo
3LZnLMCu1TYqrCCAvWtGkTsi69XtDJ+hEZB5OPmZhMgfQ9eRzB4RwCHdQn4W
ka9qTg6U1hHAsZJ4Wfc5CwRGu0T+IXzZ6aUA4R4iF5fUnbBpJcDZfvefLYis
fRYfSvhAAOe556qSLxB8JZpC5OlHeOfmHVfPv+DaXV/v/9i1/iJXjrChpzuI
s2HGnNl0isrN87Nsp3wY064kHMuGfR57pXvSiP+Vp5UMEYo68wVqHFh/AVvd
ElAIK1RsGqQ9Ph+1MUnS6lhTCFp/pJyPfAiB7yGF+W/LMNBn+070mecJEOI/
vjfgP/H/cwNufK+4DGlXyVsIaWQQNfA60lAMQKnbk0Z6QAa1y55ljd6e0DrM
srCyKgDKIT7ShZZIuC11LnP6RBkEsUi7k6YjoCmWnXzIEAt923ymP+XcgiN7
xvlCdfEQpzZf46UdCeMftLLVBJH97Pw1YV6FOzBeEtztgaGD4XGxbplXkWA+
TY8apWJgvdTvwcmRBKCGqAxE2BVDS7OwWrdbGuy9XX6ws6YMDqkJWXXpJMGr
5oGEV+FloHbscqGlRjJ0tezQV+jFQlJYwpNmySQ4T+/r8KzBwlaHd/wv05Lg
cuLveXt1hM/4a+SYaCbA1b+xNpyLRPDyufD3clM8GNvPsKRPVsLXvfSXDNs0
2Ory4tKDITIcMR10/3shCTgOSQSeXjL8ed8tdxCXBNbFSmui4zGQ6URf2haa
AfGq/wQ7CsuQ8Vu7ysgiE+527n79vBwLV0XZs2OMTPA7kaTTlUwExrGE017J
GfCOllchva0SKCL3F/Xv5kDbnNiQGrJelr4YKFp75wCndH33gkwZnD8fXr4h
Lw9a3YqDriJ44L637cfo1HzQaN4p2ByJh5EjS3VHzhZBSXruowemRFC0mzlj
cCYPNpr8utRsTILonKluGasSWPm7KDHPrQy9Pvs7MrHjAg7G/hU9fre7DE4L
itrW3seCyJiucDGzDNp/O+RHluLAnEXdcuJfKdwPyQl/1IWDCk4mM8geB19e
v3oxmovsGxV/ot6+KoeZCb45BwYeGO/UWToDWLBPPt7y7xQeehp/WWtNEUHZ
N190+yYCvJXe9NkznwjX2Q2R3pwKYL/LfxYbXwm8HUuPaakEOPa7fbHFnQhJ
ggZ56zgs+N2ypaNNhQQ1+z9lpBLZEOd0nLp4nQy8wqLYO0fZYBSxoUhomAxX
qNabnrSxoLuv5eA7Swqs3ZR3p9qMA4OJ/m6DyD63aU1K0hjClzyi7Ea8VCkQ
+J0S+1eGDUFMJ5eyMQoMN2AE+kZYEHFRuyT4NgVkQh473OtCxqs/UOTjMBV6
hg0CbwhVQor2vr41D2mQd+XXb8VqFpirbZ+9bkGFR2U/dMedWaD+dweOTELk
OAvd7CQWZBhUS1kuUsGI58Uj7WNMKM43Urn4mgaXL2z9a3MOwdGOL9Q9EDzj
pCiNjRxkw1QdQ08qnAq5xXsuVYiyIWUL68WmJhroK+/h9WGSIUbJsu77CzpM
btt8KHYvFQKP2yj3HqKDeg/sj91BBRH+RXFGPx1s9KJifwdSIcPZrnG9MR2u
qchaLCDtyDiuygr2oIPCTUvBsQtUGJxe/Bv9kw4c+RIRq9V0+O2Ukaq+jw5D
v+sPkfsQvreC0lX9mg5317nRbxRQYWfwu0m+HAZcJFG1EsapcLz7ilRVJQMk
gdpo6E1Hr/ra+FffeRmw9nTorfLtSPkJzGbtXDq8KIg8cPoeHfo/Xmko0KCD
F5t2c+I3HYj+F3fc/coAUMW/lFSgw1ygqIFeLAMmlebKziH7Ni//p76vWxlw
YW7y6EdNOuy5ru2Vf4kOT5XabvJgEZ4pLPfP0o4DJS+Tr8SeowOjMW3f8S42
JN3m2fjvBB3MbgjxuyyxYIczzi2MxQCDgMnmobtsOHdi/yjnNQOOP6V/TP1E
hgoFKd2/CK9hCapUWkZT4ciJ9+pxykwgzj7EFgxSIf/h/cIJPSboULLSjC5T
YcPAA/rJx0zYNTzlUbCSDq+qJG6tFGKCxo/UsNwXNBATt3J+heD1kmu+V/ur
qHByb2FQrTUL3q69MhxeR4VJK5519TYsGBMS+nzKFRnHPQO7PA8ygU9Bh9G1
SId79x6965hjgB45LO05oi9Nl8Knv9syoTFu8dY2QzrU7fi7NonOhNef9ies
/cwAt76KPPoSwgNYfWcskxB5NW+btxUT+q6d3puswIBbUbpNBZuYELnGTzI8
Ael3ZsBmfeT/JR6c9jqH9KuYZlytM4kFimYXEqey6bAudPtV2TMs8L9dPTNi
yUSvT0eFjish/7u+vzoGI8GE6rIjBbs9mLBZPlm5xJUJupYnr3+VZkJi2J3T
QyQmiFh9Ved5xAKn2LdHPs4j9Qhy+O52nQXjrk5RgbpMeHk+9LwPwitwIdqC
vnYsuIX5dsNNnAnjWk1jgQUsyJcbOXTgLhNgX1uXoT8L6kQ2DIheZMIqjc87
NLXYQDZfExSOY8KF7IeZPjNIf2ptucrvzoSdlJjcgUNsRC9RTKt2MMFJZKxW
9SYbNvHL4XAUFhSNu602/8iCnxN7SDGBLHjBd24ForPB39y5b1ctCzY7n7yl
iUdw3lu5hL1HmWCl6Cb75hQHAjOJzsL/GKB9vtdiKJ4Do48XgvOR9zePVDk2
9LMhY1v02VuNTAg2MdCtiOWAhVyEVXkxG3gHp/6da2WB6rlf6554s0EOG2No
zM+Gd5/2qDzbz4aI3UY7DIEN1vYOF3csIviTtGX0y3U2tLbey46sZ8Ht/aOM
6Eo2vF04q3/+Dgd2Sa4k0btYEBL/yumtJQdC72WkHRdC+L3exqWPQRyY1JB3
boxnQy2u6kUKou80vUv2ROlygCdZU2Pvd0S/3tlT8+0aBwSw/ftIi6ngXfV+
RbVbIawufKc/NpANJQ2BETz7y4G3pYBRdKwAEjJfud3KwYPWsyc4PdkCMD1K
SXD9iofGjnDPX/oFYFDT4KrfhQfn4SN7ci4WwCHdL1qyTXiYmPn740RMAag8
/Se0ohYPXwtLFy/IFEBTl3au1CQehB8w+aIPFoAIdX5tDz8BIPClYLlFATjG
VgXlyhDA69wH4dceBVDkEjLktI8As9LKeXcmkP18/pbhkiYbHih++fpzigCC
f178mTjABpkDORp2cwTYPSpQOvyfOEH6VjdqFwhg+MXctkubDYbma18prqiA
cz1pfM1If3c61m5O5a2AsI6PjKf6bPC8HHR2YXUFZLyRucQ4xoZ/11SwbgIV
QH3uKoY7ieiVyKGJZqEKaHqMrc81YcPOhFwdrU0VMEL/eT3JjA2sbOt7RSIV
sIqooXDHkg3G5QLtAhIVsK00qDPIhg2faE+3XpOqgCN5j+962SH1WbgemnOK
DL8iKDu2IXrpaKn0K8ctZHg8lKKmms6GQ89lh9VWs/7//EWiLLgnISoinMj1
U7r4U01T9FAJ5D1O6DR4nAWF72ibVU1KofTlk8ZkahaEqh6cChQvhdsxPbYV
d8iwkHm55DMbwQG9vhfe5rPA7/3xO5PDOOh7ewckyCwwMucR6LfHA6iUOVNj
yDAvW3JIyY0Ipu9fee9A9t3XhneiK4yIMH7fjCVrQoU/hX57BALI8PKZq+TE
cTqci1ZZZ2dCBh0VbKn2xTIY8rWQuF5JhicLF7fp+5RBC6hJb61A7k88v3VH
jQS1d08NWNwmw8/Pz2z2BlDhkFvzW+ltVFAWI1oWFVKhe73Wyuw9VGiecb6c
YUSHbN81i2+luf5hTndhOMuWBoOEmwrqXtx8yqTXcVXsXTSQSBgTKLCjovyk
59HrIIFpNmiZ21zQPs/NW718P/7F5PEz1mzYssY2Z8UxOpzuON/W5c+BvQqt
CRBAh8KgD7xJodzvqEZr7itUd7NB5ZSzHHUW0TcchRDZ6hRQYzpGm9zMhaIU
5T8nchGcJfq6Pjo+F1Q/X2/Hp2FhNuAAf21uLjzRrKUKxWOhp63Y6C8hF0zu
rE25Eo2FWvVND/Y9yoWPHVb+7TewUJx0841vQy64y+VaHLiOhcXz9evU/HIg
y+JtwvG6crgUtzn81s0cMDu7tube23JoZjqPtsTnwCpPg7GGnnI4MIB3ks3L
garrN7YJfS+H/HUzb/wrcuBKFMvcfKYc1hww0Kl7lAPySb8jkldhoTepnoKt
QfjF7T/XzvEQIcXxdBdGAgPnq/jFA46TwKp7LO7TLgwUHfa7ePAwCTY7xsIW
dQwMVL2jzCuToK1rx4StDgZkj2gv1ciSwKFr4uo2pPzd+vrmHXYkcIsWdT2/
EwMf21jn8j1J4K+mZV2sgoG9fdhxyZskCO92MBg6hIGbPx5GpieT4F7MDU2F
Yxhonbm/eVMpCVxEPglOCWLAUEB9baMBCdJqR/kWeTAgeZWv7rYGCV55zy+u
niuCXx8/hh5G/n9BQmB2w1gRPNOr1JzYQIIM9lS1lxEW+DPdqoL5GfDO0fbY
hDkWfsO8kcx6Bogs0RuDT2OhayTp4zNhBlhhRKyWnLDwLFnew0OSAcnHrn2I
dsVCxeHHs+u3MeDtSLuzoCcW0j9b3qPvYkCd+ec8kfgKeF+VVNvGYYPBwlGi
2/44aNFtdPznkgkm4vLMDUvJEPyOf7BpIA/cBtxEdESTAcd/5G/FgzzgHfK8
tBKSYR3fAezI+TxwIcqeUzyRDuPy7fcu+2DAdsLMONviIcTf+P3JbbQUerZc
l61D5oPdihyv9bXlsHb9zskV0QjPmFEOAyYy/itbnkN2DpiO1d6/UlEOF/+E
Z9wk5cCrYevsIkw5JH9VvPzkeQ4YfhrGtWWVQ3XX+0MLH3Og5l0IhzexHKQ2
kMNPBueBVPigx7mbOBgS+4GNvZEHB2aft1eH4YAkI/+u4XYeWF4r15EJwUGI
/PmVgvfywHs8tvzGdRwYqOQqm8bnwV1v7029ATgQOtB5JiElDzAjZmHa/jjo
1Nkc8zYzD55cVB/K8cVB4TFT6kaEB33oFzaf98KBp+m9T5aYPJh0mmY7eOBA
0/aZQGp5Hmz4+GFH1SUc/HNaPNBRkQdKto/iJC/ioP7iIVdRah4cb82bDj6P
AyOzZrvZL0g/vvW8tAupj/hKuFqTg4FL6aB1YBMZrknH7hgrwQD77haXfEEy
tBxsb5OpxIBA6NTd1fxkULbeGmXGwoCTdwvJl5cMDjVPjXCWGFCISxC7LkOC
qgXvxB+ixZC4w34HIQrRb/J/6e5biqEpPnmDTyQZas3vdn2WKYZ1cw0LKhFk
MAgRWeGysxiML676Ph5OhnpMkVyPQjHce6vTSQ0lg9EbFRP7vcXw8nDQ82vB
ZHgz9ehKh1ox8JWRKQcQPvQ8y2iKIlYMeivvZvLeI8OdWU1KsHQxuLmkqfHG
I++3l/GBHcUQW1P0micF4U9sfsXVu4uBKEO6wJNJhjrxyS9vlIuh9cbj+ZW5
ZLgd1FuYqlkMUz2v01YWkUGv86WTw6FikNTuVF5ZRobNe/S09JF5pSHp+Lxk
Cx3Wv9wlsVmqHIwNZcazeejwd5G52ml7ORw8YSSguoYOwweMpkrlymGX8bVd
z9bRoc23+/OYUjlsMi04areRjuBHn7ZDauWwaN5g/0OEDoRPS7VRCO74YTV1
NUKSDnYjRPEVG4gglj40tT2DDaEugqspPytg19MNPRIFbDC59Mt6oq4COHa6
j/MQvEa/76zt6EeA6xJV2pfrWHBtpMhA+yoBLmwX0B5+zoJ9x4eMtwYSwGy3
w5GLL1nwp3i31WIQAQ6r4Q8PvmYBfaX3mb5QAshp/T3k8gYpf47kUnuDAJt0
jQ99akbKP5lwL7pFgIUT2VpOCJ77s+WA3+0oAoyYfz/Y1Y6UDw657hpDgHa7
wwft3yPl3z++YRhLgJpz9w+8/4CU37ciWi6OAHj3rv023SyYSjaIW51IgAw/
pf1tvSxgjMWkfk0mQGRQ6D6LfhZcN23IfpVGAJ+IBs3mQRYcIAhhcJkEsL+7
RfPUEAtm+C1x97MRfJPoqdHwlQUe4VSbNaZEkNi38ZSkCwdcN7/qVDcnQnCp
zvvZ8xw4i+11cLIkwgcxL5cPrhywOzrZG2NNBK17Wd9Zbhyw7OA/T7ElQubc
i2uZ7hww8ZT50m1HhBnPycXrCI8+tmKf+2oHIpzu2R572osDkGH0Xc2JCExT
M+EDPhw4vPecj6MzEURrwvJE/ZD9se7aeLQLEQLVcApTVzigan8/gHyBCB1F
7ykdVzmg+KtguusiEfYJr9KmI3h01x1GCJ87EVLvqNenXueAzJbGBVUPIkxO
OVsEBHNAktwf4eBFBCv3uC4rZP8VPj7NE+1DBOoHzkWNcA6s71kXQ/Ijwibj
r7823eQA/1XZtV3+RPB/JBLyO4IDRsQV7eeR9vYt8u46o8yBrr6e1aeR/tr/
x/uGujMH3Pey1222IIJs6WqxB04c+BOcurHZighCpwsrvzhwIPKFr+h9pH/m
Vh8+cfQM8n+bjbcctyfCEKu9LxPhoTnOctt4HInQetkn+Lct0j7Cil3VZ4nw
RHLNJhMbDjBnuneHIv2BayjElVhxwNCQpXzAlQhpYYf1Fy040JqUojGB4Kxb
ezu67Mw5cK7X52DlZSJ49foEUEwRvqFopO2JtN8uYY3gOoSPhF7fpSfvSwQD
KCq5aIy099nSscErRFAZP6xTfZID6Ru6jfMDiLClqOOd+AkO7HBimjtcJwKf
la+v/zEOkLHJNmIhCI7j4V/TaMABnSnvM21hROihFRXs0kfqYyQa0SdfCTtN
1/8Vz+SA2tSd1GvViZC6gElh3sgBhyOX117ZmAhyC+qkmeFs2B8/MX92Xz6a
33z5fKR89v59axweQgy1N8SP58Nk0CR+Fx0Pr31N4Y5kIaxx7hWVfk8A0qZS
oVO7CqE/53eFdhcB0ukL3cKqhcD5yGd49hMBQu1s8N2HCiFVfEv3jUHC/+W3
LYTY/p6dqxsJoJrnKVj/BAPlg4IxXWpkuHFjS0oQot95el9Tj4qTQSBbYY8z
ot+D9USuvpYgQyZz33NDIgZ+lTqr2yC4e2e73tk9TAy4CeDGP0mRISrL5euX
OizQU3N7cf4MeOBwwdS8BgsKG26XJfgyIFX6Io3zCAvZ9939ArwYkPPJTXIX
GwtCq0217C8zAFPoHpFAx8KtSI2VOm4MwF/wGJolY2FyQbxB9gIDGLw7a+2Q
8sv5e5dx/qc/l/6tkHsIp4bcvhiMp6D5gmV37UtwO5gBpRuEN4XoFAPhYcUK
ufAMOJxnnNB5oRjCMlqnJXjLoMTv9hX5jTSoH3+v9ziGe7637CdUddfy5uRJ
JurPs+9tWLr+EDIP/z3ll6kpQvNoL5/nWZyYu2jryYGtMqlNUcxKYG5elfgi
nQX2TlFJqtcqIa7m4S/bIhZkqvSqdyL6lydAc60YwqN3rXwfnxxAAO/Hirq3
q1lAaW/+ZoLo206+7UG/HrPgaNnLY6vDCKBnLlbp8IgFjcG1RbU3CVCRJThU
z0Heb8L5F3qbAGKDPNKabBYMbaWe2Y/o18g9c1YFTBYEjOMZY4h+/XFtLHYd
A+HNz4o34eMJcLp6qDaIxoKE9Fyfi4g+rV3TM/MZ4f1Sl9Nfy6QTYI9lm4oF
wnNwhxPkPmYh8yz7ldvjSkS/Ct2NTM0lwIov1bm7iSx43hfRa1pIAE9lRnsa
gQVW1OBD/CUEeHedILASz4K+O/7pdeUIb60t0vP5Tz6hMJEd+vcJ0Ofwyero
QxYaJ9F+1QrtjfoMCHka9r1WlwA7T5R016+mw12JN/2UdSVgeuVk2dp7OHjq
oSFzObsc+G4SNG+cI0PkgoX1eQyiXxq+hUo8ZcDONaLk5qdEOPl7aL3tYwSP
pi3Q1iL6M5F8UddLggF20lEP1T9VgnHdMezBLAY86gr8vUsID606dT8Hhaiw
os3FoKkUB3JU/XpVNwo8uPWCpPMIAz4VUSkeIaXQJFM7qnO6DDxEAo5P9VRA
m/5eF3mvMtDCpdTHtVbAigpjh35kftXzvtymheyDX2ydPeP6y1F/M5us3OZt
PAXoPL7kffhMcfVDcJ75ZqnimwJsSg3ms2AJeh/DLFCPeY5Bz4mXzzf3rxOP
ffIqDZIsv/BrGWPR55fPnyxn5rQr3yZByR3+w449leh97+8vLt1/SUTft8zn
3pwMPDpPTAO8sMHXV99o8M2r/5NuWDJoYEb+H1dvHk/VF/WPN0ilQUSplDES
yRhCyyzJWJkqpKhkKtIkKZJEZpnny72u686TOUODqaIMkRAZI0lE5Xee5/nc
c3+vr3/ua9nn7HPO3muv9V5r7bX2e+tfVOh9aGrRtCUOVB0zu14o04A/xkD/
z3A0Gue98nXJ3zsoG74FP01KInPjvi3VVw85ThShdngHb4Xw1m+lKM15/osD
mYdSPNOh2KdmZxGiLzhx8O/OT46ZQB6oBLlEnd/K3Ud4VaH9Ii8tBywti/Ml
7PLRuDFe3F+5ySefm8f5Xxy39fBsuzNiRyWnr21i3StGr+fE0+X2OFfujMhB
8zT8rjRofJ8rADKUyeXacX858dvtP8SKbgojciSsSKj7HJa7f/s/e/toJ356
Qq0InmVZH9azxaL3ceJXGy+M4B/EYWDs8mBupjT33IUdy+FG/6xIkG/Ib258
Nx86m1fsmNCjgHN81EArwhec71E4cfdnUxAOjY+G9mgXfNUpAu+DTRfV64rQ
/3OeN1yavXGDLQ793iFdFWu4gwWRh2NHdLbgUb7BzMvtiAkgwaqzB8ee1CPr
zKX+mkUQESqbs+XK7QtBcnv6i3gWEeZM7ayaNQvh00br3HhVLJwzXZBu6cHD
9bQ0OTMbLJwvelC8gOgbzvMLeTKExCq5dXmsPN7f29TDrc8jc/VQzLV1RNBc
ZjVNbUD0RGCf7zNNAlw81eGVLkxA43qc682lLSvj+MhAHZ8dyN5fgsaTedvG
g+LNaSC++iV/WEQp8MxuCtn8kw7hr3sj47cQQWWpKRSzhVtvh1OH7vkRbZmH
PSSYKFm/qwNYaH+zJhSNve+4tHHOyU38a6ign3YiUD6fBKb/+pthgAL07meH
d6WQYFnYo+enEwXCpQ2wxhZkOERgfQ19S4P44rq+djwJVgY2npCn0uCAGuHe
WBIJKN9m87cY0EDYM0LC9DAZssQ/ulmwGHDlZGCBLNKfvMhjZyUVbn0fzv5Q
QukSf10MGW43ZJGKvFlo++T0r7+PG7n5tyRfng8289z2BdM5tzYxNtruF/nt
kHsmN8+MM19/65O27aNQgZku8K0knoDmGXDGTf2kWFHBDm4e8nxvrer3YG49
oLXqHhIOQ9x6QJ8/zB7I8KSi9OPwne92v6LBvtmc0MV2GgzeJ4beDqIgePLk
0efZNDh3cgMjw44Cnm912w+a0uBmWd/AjlEKCJZeOqV9mpvny/n9ebq5lL+d
+/+PUUGCXfe5dXeOZuy/tLmZBt6jkubH8Nz7Dlgt5d/0Y6Lftwv8Di394dJK
+va3B3dy8+Q5499ha3U79xYV7DysRY43MKHLPn7rNQQHXHWWGvK6zoRKl2pT
G28amF7tlI1QY8DI8Q08h0rp6H4H59MnaM8EaHDMd8+1EQ9uXh/hr7rucDk3
T59z7pTN3JDGKwEqPBzKzbP4xc3jixMbqT4UzKXp/euzXJq5+xY4+xKuPFS8
O7mKew6xtV7K7upQOnTXNIlGI3YnZ58xZ1yMTmT9eirNrU90anZJvmkvHe6/
O1Cbe4mK4iXO9ZurLc0lK7n3017Ze2214O6/WnJOv1gYwQCPgo9zlrU09H7O
b+6nO/T9HXSU9r353s3+HLf+jrRk5B/3CoQ+qOcc7MW9z6Hjl6z8JiZKc8Z3
/3QcnyXyff03fq7/nMhGv29fzfs1gQe4dE6t9kx3H4tbz+i/8ebR3z5WWEdD
aaPpnfoqCJ49rqdfc/wxG9xZZtP4lQz4cr/W4oYlG1oDX527r8MAkQymaeQ+
FqSdab/o48aEhaanh3W/MaFM4U9AeSb3PGLX5Ky37rZMSM5KPRQfxt333Xj2
ydUvTkT0uzlyr8il9nv3KwYkydWccMmhoNffrmkP+cbPzXPizHfnkkyY82vu
fjPhCVFf9SImMLVfnD0YRkPvX/fsWoh2NjdvCs3vFKgwE/7ArQvVk+5CFotg
wqfQpvjfkXT0/nfpg/1bTjJQmjOu3VJ2CpaIHELrLRCjzCdNufP0ZYvG9chB
BvywKZMd9+fW8eI8v/bvxbsxp7h06yulp+5vuPWcBmeOPDDbwISjWMrfFnsG
ej+n/x9NkgNPTnPp+NfRr1NbuPTMj8WEIC1ufSSGgdNl4zssaDM8W7z9EgPV
CyUGF/nstjJR+nLL8kVdUW7dJc7/93h9M8m7yqULX2RgbD9x6zA1hwqklCJ6
hUPvffmrywmRu1OCEVmDWBZ63zHfkPk2ETZKJ7vqbcN+psFhryiGNMJH92SP
UVTzaEBxujvs8YFbH0s0Y88bCwXuudwHk+eKZiLYkFOxqLG3l8vXnPkocSK7
6aSyUNpJuK2j7h8LLE/wdv4IZaDvyRmv7oDfeXPLXLrpNualSjZ3HIjq81d8
nNlwJeXXovhZJvq80yH8lovfufRndcM0J2XuuHD4hursJ77blUsHFBn4LNVw
6R0e1cHfRNlwLlvH8PFx7jhyxqm8nq9BaYlLY2jalTkGXPp1R4ZJRi6ix8Ok
12jt4soJVI6FvJH2PMOtjzV/uCdCpZcFr6b/qeQRGej7q/I4kmzluPWwOP1v
HYpMr7Jmw/lnbYfHbHLQelh54T0LBiYJ/0++fSKc26ugeU0sFK7ifJ/eckpF
2zm4lHxKvRszlgc65M9SBam5aN4aWl9v+YZ90MsC6CBUnbbdRUbxI6f9llib
zSPJIiB+yH0ScrAAVLcc4y/vLEL18ytfakZmCBayPtq9xBNKUfzXlRAXslDM
3XfHkf/JiU5KK7zw6P1f5BNO++8pgayygJF5D27eJzuM9OD6uyKo+b0iclyC
iL5PgsgeQ579ZPR+2x3Zi0MvEH3+OsEuLIWIyq3Dtq/WJ9Zx9/E1XK0OUnmI
B+yW3tUzR6hQfX7M86YkEUZlGnTIAwyIjP2585E+HQ7ZauSfHmeBtmc/feIT
HTru1Tj8q2WBmPPxKn15Jpo/yxl/jU+xZWvfPAPB7/uG9fW451Tec14ySp15
Bk9TNslfqihAv19rIEiz3iMfMJW5vusyqNx6A0FGzFXHWOj4o3bAXOTdexvJ
IKOTWitLLviPf7jz5JVwjndzKxnE20CDHlYMTnfqhyYRPrx+cyb99eY4wAiI
DD96kgn1OhUPO+ZiYdfKfAEj10wIr3RzXyMcB/TqmBt5cZmg3fy947FOHDQ3
ZRUHYzKhJ9nk6dnIONiY0KCXKpP1H66Lg2NiPNYXlzIh2Gl1/iFPChhefdA7
sJubd9wup1h5Y38uUOjaznKPU/7DuznAYyrnEe1PAZXj6gtdr3Mgu9ZRXPgZ
GUTnBbbbPkP4782bAZpvOjzLy4ra+rwIgjp1ly+HpYOB55vKPoSW/IwXFUtN
h2/KK6ZxtUXw+uuOw+8J6ZDyW0n8OmKn+E49sn9cmw6Gz8/Z6CH2xrZfcwFH
OtNhKiL+wQbEjro24Xv5pFkONFZsfXficDF8U9l2qcWBBOcN7D03teEgt3X8
cv1+xC445OstOY2DEPmjUeaniCDqY7PJ0qgYqsZeq1ifIYERf4qDgT9i95ok
e41IkeC4q8+vvMcEOHHU8M2+CCIIyvsiMIgAhOHVnXkxRPCf0jVRphBAzfhR
qPMtEsh4H27I3kOEOgncD4EpbhyUExfduNlT9/7KUnC6Ili7DsGP1iL7vt4+
QoLW0YTik78QeebVatulRILJ12IfI68ToGtLq9XMTTI4qa8YSZIqBczkzzM6
58mwyWtcpyapBCxSRr+6MLm4PbI36M2oDtcOuJFdIPjZngVy+2MTX6hQQCh4
FjPw/6vvdOoxb1cjol859MmVs1f3uLNAJb/xZIjr/+y7qvD8bMMC9dVF6dPz
VHA6rlWjGcmCFaY/38y/p0Jw8PmSlgfcek5WFQ/klnaxUbpoFLc31pAF1/mV
5Ds8iDDslaRQ6IyFexeTtTGXqRAze329rygOxR+f49oks67jIGF2kp9VQYdz
J1rPNypiwdPyDOEhMR9o/SG/tr8vgS13hnR8o/PBICp2a8oIYi++TD2kc5EI
K6fbC27zlkDHjYzsIQcyjDyruHVVnQD5J9vojiOIPRa3WuRRNx52K/B613RR
gT9NrrS2FQ99aiPvlYwp0PS2u7trNxEWjl8O1btFBvO3nlW9TiRI+CxdzlNN
hrzXDa+nXLj556fe2J4tvEYC4hPDS7VP2JD8r1M8zrQUDp8eLpaKZYOVt6by
v+hS+PSM2JwaQIT733NuXl1Ngcyxj7XGIWT49t1qq8UcmVvPfkNe1TchCuyI
jyXb7KfA/66uzRRIFSWWv66jg69Drjk+igxqpQdYgkNUGCpkXdzgS0XxTrBy
tIFHBwtUE/voOXp0lO9K26Kjtl0pgKodrEMtpWSovCVdJXm7ANI34LXay8nQ
LF4+rfi4AG79zdTpfkWG4W9uLZYuTLQ+gUBQiPQORRbqr9G5Of2W/24GtAx/
PrCiBAsSBr+21EVmwM7r2Xt6mFjg3fjXOjAlAy7xuPAz6rAw8WF1nFxhBtAT
9qyIe4OFt9l873qpGbBaqu/7lR4s0C8LCMQ+zwBrSuaAyQgWxEVFnj5UyYAt
GSwFtytYuJIVJHprDwGkDzx6DYfYIO32e3usOAGONr0yV1Nnw6e9gVuLJAng
dZmvdZ8aMg9jPzZXSRMgdu1x692qyDwQfPk+yBCAholuE1Bhw7qrk2sm9yHr
y/DNSV5lNjxXu7xytTwBlga2dC4eZMPtheE/Ow4QQCzE1nFaEdHnFW4LSgcJ
YLAnsecLYhdM3Ps8a6pMAI+KD2e7EDxVYHhm2lmVAI+dtvc3y7PhzNru8esI
3xEWHNye72eDcNOpr1EaBHibnDZEl2NDy9O2gXwtAvxU6/Uo3seGcFurT2Xa
BNjevnssS5YNR7Y1d73TJYD2VZcrCTJsmO8++n4UCODMn/vt0V421Fc9Oy/4
oQBoPhFOyXwUSJtVq3nTWAADaVYf6SspcHVfm2h0TQFsfrnN6cMCGZXfvMk2
96t48kHwbKlLDj4FxQvbqkQeD+5LBlpo9q2r2/Phi5AlQ+x4Mlh08XxpW5OP
4sUvjASpotf5QBc1cfzZSf/PnsyHMHcHMS/eQpSPOXklIWk488+KFOj9Y9N3
93Mhys82ds/12xcwoCSujO07ToH7Ch/nbo/FQlPVvyObNqeB18mzfsTJWNhz
On3nio2cuhh0wG8TCl//iptPnlBWo61+kQFzdk/uFO0pBoWmgdGMdAbk1L99
HyldDNVhNUsOGQwwV9mm6LO/GGyPZG8WzmTAr+zTj2yUimF4/q7EO4TO3ZTb
r3aoGG6Sz6hFZzHg+J2vWiI6xbDhirapWTaC80blE5b0iyFLeqfTmhwG5Nld
newzLQblvgWv5wi9cLxP2mr4CVx3saTe3JcCb0NWjHjWY2Bt+qFFzHsKdN/S
c7nbjIHQrG1VGW8pMHgtpDPmPQb+5f66n4DY4RNXaqzyejFwG9NhHPmKAj8v
rHhFG8LAHJax/n49Bf6e1dN7OYmBqyXJLTdqKOB4S5NfA+nf8736NLGbAjFX
Xo72NCF4wnSnkWU/gofO2tWGtGPgaNm/lMmvFFiyGk7f24MBjQNfvkV+o4CS
QcD1xkEMyOS8NJD7SQF3tdVWvuMY2La15NnLRQrEXSYr7omlQYxn7BSdzPUb
qFg5fImeYIGQnc3dlkwqKl848t5uuv9FcUQJbMuRaXxRT0PrFIqMx+2JmMuH
8Ndssc1GZCi5+PPK9fF8GJUzlQxRJoOg63uXCfdkqM8YFO1EcCzbX7qzswUH
637IzwPCZ9+Mrq2e/oCDbcr5krwf6NBcuudSvHcqWI+9mGgWzoTE4apzeMEc
cNLVll0dg4G7+QqXy05mwzrer7GL7zDA2xKhf6aDCWHCI2vnzfGQERyzw6CJ
CYK0qM3aPHhUT9/uzpK9TqBDI71ScWmUgNYn4LS/15rY89GJARVgWftxexZI
6C7l8fXnwE+ICLz/MgvW9pcbQUYO6NSvK7eVzoHggd4/vgu5KL/m7bfCfkbk
PYfmGb/mdYlKQXHis0Qvnqsy3PwkZpmSXHdHIeoX/ieK0T6bWAKSr2uNJv0L
0fHltFe/DHs4uKsUzYPo0GatznErQetsZZqGXv7RGALzgxd4w8RT0XgYp33b
pke1XR7PQLhu5Wqp4wWon5qTV/ZloUDFKaUI1stH1RaNce2E/7NvsJBu/CO0
8VspCLpFL5jfwEBLuPmFS1cpoF1NIYxmYv6TCxR4vDVlyuQVHsUdnLzJPe+G
Cp8qUmGg+ZiQ2wcGynccO+57msHN0gt0+OjhalBUzbVLA/0ZPt7HuHS7/0RY
+fZiqDPOLfuQwoABhdVvDwsVA6+C2VRzEgOmh3fuKttSDGaCMxL18Qz4m6Xi
obWpGKIWUk6VxzBgg8MxMmt9Mbzp03tMiWLATgG3Pxq8xSDYMFqBe8yAfY23
TJmrisEOH/s9J5wBd7I2eakIcOQS15+yYaclbjEewT//q5+TYAA/uXPlRDrc
/V87KAOa6+qX5bdhIE53dS+uOx3ebbWdM9NF6I6vok7rM2DyZbV0uCIGThSq
Jv67UwQCj11sB4owaB7clpTzw5vMMHBjlW+UziwRrRdbE7zaxfI+FY2bceKT
NuuKyY4IP9R+7hSois0Fy5i3Gd6PS0Bxh6X7eFkuxL/+5LDgV4L6ebMu70yU
WubWZ6xoKC3YZJoPSXjrdvIjFlhM2B1vu/0MrgnjnItuM8Dtx/2w1r4C4BX6
LNu2DpGbnfqk01PIur8tp9EtnQfXdmlK3FYtgTQRkc76J3RQVz/E6rXEw6p7
e6OwiizUrl03J2bw5wcdkfv31s00PUPtjAM3vJYGxkpg5EqZ6+cXOeDZrfdc
/V8JmOVH2jv24eDzsQVrMUQfdM5FDL8exIFhs0jPL08GuB995H94BAeFFlru
rT4MmE17uBI/gQO+N47TmGsMSBfDXPmtSgM1guy59hQWvN/vNuhvTAPr72xn
rUwW3DZ3s6l4y4A+luaRoB8JaHxFm9c1MH0YwWUzpidbupJA3ax+x95TiF1T
4iNR8zsDIip23zD5UgCmV/q2r+5JhTWWfB3DvCkgsv6w0g9kXR8+4ULo20IB
Xo2heVVPPODzvh8sOMAAr33+dnlAhqdVz89TnHDQo6elPPebBHLqSzebb+HA
zO+e6JI7CXoTX5WKESkQrnfzLu4rEV1Hx5Lk6vytmGjdKY5/0P7s1Weqi2SU
djwnX6PIRNajrF+Sr3oyMLdr7nBw80X5yCzGw+VHAx02HsvMdOzm8BEdCL9t
25wV8uBKb3CsvkMOOm9xFL+q1NW5kKSsfjU5OBedt+OpNU8sRzCAj+wYh78F
YCLJM0v1wEEEdKm9O4wHhf3po91lTEg63iXyLYVbPy4w9OS4Km8Ymm9tEXFQ
3RFyYHflNadatG5GDjofDYp9xbLieGDtD5Vo/YpD4/SvqdJFLzbRIXngaEd5
YDGo9sguCdUnQb7P9vuPCgMhvv2lUO//5H/99/djZrB6NaKPQ4uZlTPpD4F/
Z8RfM+MC+J6Uckn4QTB8zTNhDa/OAy0Jo77Cqjg0HmjtN+VdkxQGq/7sUhsU
L0Txc8XN+JaHlQXAJm5bPVQbAz2xnx5ceESEjbauJTlrY0Dk8cmVUoOJkGhZ
cndUKw4IbY4neNOSUH8E5/uVlz5ON32JBdeO61jvK3loe9woRfkhAxl3Ce8u
p4AUOCwvL7ohMAfGCs8SPGaTYKmUHklB9KCblmSonlMqHJ6K0fmaiuBFZsfX
ovFkbj0U/43vl7OfQQVzqzDzTQk0T0zeH78QBz+NVerUNxDQ5/11Cpg511oC
9kX/9OmUFCBoPH03fB0PTFeVVZUrkwHjQB869ZIIeQeUJPadfAaKYW4hQtIU
WM4rPTZEi0NxYs/3rjbtW7HQuLy8E4/QnP7ZCpZr0njyUNzK4a+9Znurr/dn
ouN9zpryZ2RDKkg+8rzwIqAQvf77px8Hxu2Q9W7eOmSvkgO6mz+5LyhgEbzn
p9W8JQvWPV9I6dlLQK8va9vepphIhPfJxqutjmSB1OBEiE4MFXpipE/+JmeB
yczSy3tnk2BUikwVN8qDcNwT9aU36cA3pMpWv5kNJmOakh1WGah9xLgXrK+n
ioEBK56Ft97ZULrwJiT+HLeuX7i7mZgkMv6ceeX4e74vzF189y0X5Wc/i8en
NQeyYe2gcbrnKu65j/GBzl17QrHQvGdQ8CUvgteXw7bWe5SAvIdf9JRqNli8
Tt64NrAEvZ71+OvRPsRO9pl/vmxelw/ksQw1XTIeLtrfnCiOykPj6AnBj77b
bMyHp8w0iVt7s1D7AHvm6a3JvFxoxYhnqasXwpNTPB0hXzGAlTOZPbkvH40H
hi0eftMTkg/3P8yompO4dTRTPQ9ozQsRoF2Q7J+N4IfUVVcezAzhob14qiL1
UiE0dJLUK0LZIP6+S2cDMm7DDMadpw0ZsOuz8NdjmYXo+9EOzO9IvFEIU1Yz
owK3M1E7Q3klzYZEw6A4iMPPZ/PKxV/+w6HvN3LvxpTSvSJIaacbdqwggB1j
YCVbAQ8HbK0F1dUpMPlqjPGUyo2/t0s8L5vgx0OrwT5Z6ndunJrjx3x/U652
83YCuDwRe5plzYRrRfn89/W558E4/Ewf2mlSCr6bPoTLvcehOJLTz1vTqS8f
z5RCyuITnqhPBLS9wd2ntcyVDit/bJrP2MWt79O40VjV5BAJ9TODtX7MW0ES
uh5IB6Xwbc0ksBrbVC/tyhkHElirm0mLv8JC1W/hfb6nkHXXdfvwmzY6REdP
yD9LIMFRe+OQBkRfX92WfAjbRkL99T4PfIJb1MnQoXbC5X/yGzjxbY0+Rcvx
HdxzOTj+dzPCdbPnKRRgf4rdf6WFez4M531NjRvtivu58WP5HyR5td8UVB85
zLhf2CxFg22xgseV3cgojuLgkb3jxyvG5bh1nh+lD7cMrqHBZ4mjcZqI3eft
18t0fEwBrbZcwQB1BmyteXBozzQFrr2NJZt70qHrecIzkzIqN940nE/Ie8Wl
pb7+wkTepsGQEc+wyRUWFHv+xFyKpkCWjSTJW5AF02c7Puoj9tSGcrEDfmrc
c0g43/+2379M7ggN9ft/dyR/VxClwtTY4Dm+AO65fAUeGbHPnnPPi0HjIBUj
34WXqRA2bHVC1xEHu3y9V+66RkP56d6+OEsPN8Qui30T1fICh9ZNgy/dFxcQ
nGCho3nMcY4OuulLDVvdS2DerO4w7wL3vJmhF1G9sS+5eexj/S9UzUe45+bc
ynUNtf7KHd/JXw7bdcfoIDfjVE1nMOBCVWbTb30a7CElVh1xZYDf8vlmvxQa
vL0j1me6ngGVqt0lF6dpcAZDmA4n00GZzzx9nynCt+v/FbU60KEWszjYn01H
x9tcVIQYyeDSR+3dtrQaMcDnVrp5lx8L3E4o3/95mgbXDUyaEmVY4BQZvlKz
kAaGPMshxF4mRL1qMd/9HcHZYye8OuKZUP/lpusvLToQ19bc+32UCWINGy3a
Q+lgKXz43qt/DLjPjLfgaaUD/eargyukuHExzvxpCc0oSTzh0hejcoTrd3Lj
QIr3/T7s6qJBtUtjTNxVrp/zgEb/cq4wN67Gmc8ZiOrdz8O1B+LHm0YK8rnx
0oiB6Jer4hjQfiZ8vXApN67NGQ9B5mu3G1VMuM5X73YQz4KMz734MmR+7dih
KiMIf5Yr7e5dhfD56PbZxngFFuxvIxjaBzDAyn7bL8FvTKiNjxTppDLArkqi
wonAhHL5e7Yxswwo6DshZezNBK8NFhMFqkxwol/2LlRgAkNNI9cwgAmZCnT6
swkGBFROONjSmSC0+S7f3lXcc3E440Op9Cn7Fs2l1QTKJzcsMrlxM/7fX7Iy
GTAsqDyk582Nox3d1HoAc5cNfIuFkm7zDDCeH/qnZcqGTVtibVoOMCGcqF7V
sIUNzfYQr3+BCZ+1Tybrf2RBQJN4WUMaE/ZUtVwdXcNG34cz3qE7Vsjk3uDS
uRWmxCMDTPj2SKLuRSQy/rqH2P+aufP+x2x2LvsCC3hi4HBkIh2N03H6ZUXI
T9lbcGlKY5bQCwILHgvO7z6F48Zx01fqE48e5MYR3xmP7Cqf5PINKh///Y5j
+HPP07Gzry1TtObGCfMPdNTkIfMcVrFVX+Q+N27YvMot5IoXG15JjAiwe1mg
YftXQ0uXDWfbzJ0mNrDBJ0X246tNCD9GSbBOa7NBW/1HilAf8t7Tdr/5r7Bh
x5G023+909F6Lukxa25OI7RArXWE/o/r8PjNaYWHmAI0HvloeXWDF7EQpaPO
xV2yTSyAuhF9io/jNVCtLdIXdi4A+XffSJradyDqm5zjdTIWvf7U8NQuJrWY
29+FbTmDiVi4J7/PRlT0OoT3uLiSH2OB/dGnS178BsQuW300qipBr9/i+V18
z8dSlD7nZfOejCuBP7LSdn/O+YMEj230rVoy2m7N9iB+EKei9Li0VYcXgwwp
3blnHbYFAKXhh/meEjJs7eINsLx6E0YXp0a+uyPyobJbbLfZDXjnulARfp4J
EdvrallbgsBS50js36e5aLzVMXv9LsnKfJTWPhW6SfxwLlQl7+erXfMY1Hdj
w0ynciA66Prx9jNPYKxEqcTrDx69PmST49QpsVKUnqjU+UPuxIPFnQOp5qmP
4OXPlbWvDpLQdh7Rb8f3byTBXbaSiqnmY3h3RG3b9YtktN13U0DP8VYKSq8n
fA9xcCfDu+3B8f5S4dCLxb+zKiSjuImjPyVOhWykRWSg8r1pe9IllctZ4OBm
RIPFdCBdaTzrhMlFr7+8+1nASEIuilO/bMIOYl5gwGht1dafjDzUD8HxL3xI
+BtMFiqEE4J/1m4JZqPtHHybuHwh+dM37j7IlKfVTP/QYvR5E/267AtSOMg/
oXK85RITxXEVEl2nvAKZcG6oKunWEhYmhSLKUu4zod1xv6qtBg6EwmDI4hwb
YnyGFVfJ4SB0yw/IROibBf5/IhNx3PMGN+3xVUVwKOe98Cz/uPqT3Hq2p09Q
TS0OEmB9aKZizC02/Ck0M61eSYDPnT6jO2+zwcha8mDjBm79Y1/+HvdAUe75
e0cuTgW96OXWBTpyveu+owwFDDvWxWD+Yv8fPISDGZp6gJoeBbr2NqY4Id/H
eQ8s35uZi1u4++12WtuJfUhgQoiZ4e36NRQUfxZmLqV7RtNQPKXefzPS8C0d
oiLWdNyMKEHlHMdPOKDQwHdviI7irXU/+B0v7+Wes1H6orwtyouO0hX3wzVl
N3HbNSuqT68rYqB1agxGHb4sunL3i4gqy/OlIXTRwe/mwuMU1L46u8O3UaaD
Ajoqj39d3JuC+v0ePJ0W4M/KhkXJKVadJxW1Vy4Klb67+pYC5oeSrt2x5p7H
5DI5t2mCmA8Sg8kLJERuF+1PtH91sAgC615tf3mJBTV/sDfnLhXBKm0Zz91B
LHReOP5L/Q5zlvYBMhCp+YLGngXA+2mXbaImGRzTAs7gbQsg6oj1JlMgw5eX
tSljB/Hw5VZNJR+inzh1hibC1sss9LDAlspOIb8thZXFn3r2t7EgUDCttf9z
KRwQK3HgfcOCGbLxYo9lCup/KUnbWV2rwo3DlFy5eaFgLxn9Xg7u91wluSF7
FQYYfdPfVDVLIeSkofHyYgHI7RNu5ysrBXjEO3YZXwCKLSuMHL+RoSQ3sItt
VQCPzjde4xfIBJemf7YSklhw6p9omXmVBR3+SjF/sorQ/g/fV5aV4Cni7lvN
DN9Z68M9B0LsoXpLV38haHg6Fvm+JUNr+9uJV4OFQCknjW66QwYtdjDm7FZu
f3YaG2nWFO767V9++otXGw8+L134P1eQQW3Dw8DDgEfnr36hukjSBA+FR1UX
vETyIA7/1P6YBRHAV0/PQDoPBmXf6fFbEqErySJiu1IeqBZs3f8eoa9WOL2d
1M6DMHG7ralWROD7clGk1jQPOjJS/py1JqLvoxrUWO5MIIJjShvuW1opXDzm
KDQXS4TEAE3HJwWloBYquZj6lAgBaidfX5shQSVGf7PcWsTuxy01vmkiQyif
+1W7NUQ0nrp17NDMliQijIrmpBTpc9fNvQytDHsTFlwR2l8YaYjoKfqrlXxn
WHDz6W/8UFsplLVI734vxkavHxMMSNgYwa07ZBdo5+69qwjy4yR2bgOuPy6M
oLlrSIMMsgqhzdXlRFhTktM5p0NG54u1WfGCqSwZHW/MkRN3eBD7bMVPq13i
GDKQJj82iiiR4chOrNjQawoc5zFTbPUkg1FshFWRJR2kOz5tq96OzOvBjd5T
TYidcsjp9400Mogsa1Y4vUfsnqY1j2VzyaDLWpMnyssEWUehqEohMowbzJs7
Ibg14Md0x/oM7vO/uT+r3l1DAdOL8z8vtJHh80DawaFqCvq+6jIhncUXqPC+
ur0tYTcZPIZE3Vke3Lrs9pK6P+PnKKj80D3mXHuVlwoTSv2mfqfoUG3r5Lp1
mALVisK0N7Z0VG9x9nfvmlHKMc1lQnSevHiQKx7w/camGzFcO9VhtFvwkQcL
EhO6N7gj/OiwSb1P25YFj9THSNa3yQD59RerTrHgycxMzWpJZN17M0VCRhA8
hjH0ed1HAde/1aoSp1ngg/+0/3/OV/fbEEtqcmXBgRGn+z+uUWFl56PiJl8W
CAtWBhxEvuuJW/3YPW/Wf35HChj/e3t+fwcLuniPX2rjo4IdM7luopMFe9tp
48ekqJBQesVBBsG1PK+u8TPs6aC5hDEYi2RBXZvoHcxFJtQ0eJjPbPWD9xei
Qz3ESbDKpN/ZjBcLl65+GKz8QoJvjMlBq/VEeLI92Lj6RSH0eJJYVSfJcE5p
6e4ykwLXBSTtDBBcMHo5qc8yl3uOIacOIHn/oMuQHRnCLn/f4BlBg8S5FXxz
l8hAuFl+MfMWd182x870+fPjwYqjZFDEzdViluig0P4mseM1GXJEVfvVIukg
YoPt0LQhw1K+4XTIM64e4cTRimuelX8IRvTZxDVXcTkKbFzZZnMoggopicej
Lp2lwL3Ggse/EqiwHqORr6BIA+vOaJrVMyq4XMldseVMMaxT2eYQNksDvez0
t38xNAgxjP029JANPxbdbv36SYPWkVdGk4fYoB+U4R2/jw7CVWz998bcc0gH
G6w/9WlzcclrcW1ng/853+nTDdrlYxhQ6LfRkikng+q90yO7DjHQ+vNs+9t7
SpQYkKovrJkwlQy6jptsGwpSIBKrlpVoj4GxKykqa4JSYLgh2O6IGtJPQnxM
wlw66o/ixHsomp0xUlWFqP6ni9QVnrpHg4qWpaHYH4i+WSKYp6mwgLmsOSn1
Cw9f3fhfvVViAUU5cJbxGw+jr/2M1iJ2BuE8ddHsLx7GldpqdA+wAJv0feWn
FSXw7ZmqboA8C/JfHljvx1MC0/8S2cVyLMj67bll9boS+OH+S31AlgWp8tjt
yRtKYK7ZnrIdsasTzw7vkeMvgXlVtqKlNAtiYiRlKgRLYDFtJz5MkgWRz10O
WG1D8PfKINlycRY8nM1QG9xRAsuXPuXP7GGBu+PN7LXfCJDZ0siWRuyyBx4Q
g/tLgOfHXTXlV7Ih8ixQVwRnAFXyzn25AizE0ZbN+qIyINF/q4xVIRaebajp
L0/PgOv1+MYALBay3EJupBZngJ2wkW9aMRYK2Hqbb7AzQMOjd2tNCRbwW1Zi
Tr7KABFmAGu4FAv8Eh1/tbzS4duh1AF6dRE41rvZ1Z1Jh3NqfqWWFETOXpwu
PW6RDh+UTe+MFBTBN76gtR266WB2cM/RkGdFoFm6ztVFMR2qFOaEdkQWQahN
Emt0Tzqo7G8eIAcVQcHY6Rce0Xmw8kP8NXEBEgwdfEBZfpQHk9VhgdcQnL43
EJuV8iAPOosDb9evJYF7RWuk8t08qE26FLxtNQls5wPxk//ywO3TtikvfxLU
mSvSqL/zgGS1JmTIhwRqOcMVt3/mwb/nswJnPEmA+ZnRoD+dB8fVBvPb3Ukg
bHaydd14HqQVvlU3P0eCYPeHcHxzPqw+3XOpKoQEo9bbfwrx5kNwfEh1zi0S
8JxxIEaZE8BBtUFDyZkNl4+s2r50jACHpnUDH51hQ6t4SfBlhBbCM2h9TmxQ
W233tdOMAD88Ds6qO7IhdXjZwgSh30lilaPt2bD8EkenHSUAqU/cb+gUGy4U
n9gthdBP01JLtU+yoTHqb1icKQG87QS/xduy4aBv0eSyCQHMBZ/Ij1uzIcnG
5qQPQu9vXe2pb8WGRdWl8l5jAqyLDMKmWLDBdRtGyhyhvxrPfZ02Z0PDguUT
thEBGlb67DU9xgb5noUfsgidX/n1fNZRNsRW5jklGxLgwS2XvDkTNvzKPl7L
g9Cu6l39x5H1fvrBLzl/AwLAjLVYgSEbnl/IiRtA8PFuwuuzS/psyLynrB+4
hwB7s198l9Fgw0nfxz8fiRPgykRu1wuE3uAyUJQqSQCyxt0aD0021FpqncZL
E2A+1AHLq8WGW0fiNlfKEED3rWpsIUIrKY49b91HgFBR/psmh9kwslv/ev9+
Ary+NO7yFaGzNqXu+6FAAH56g2k4In9O/f3esxqxM06tzD0oo8OGjd+Oxggr
EyDdImj7C4Su680xkFUlwECq/bI7Yuffbl6Y01QngOxXlZE1R9igXGGNO6aB
jLfK5jcYhB7FY8+c0SIANXiMYQxsyE5fscVHmwC/G+uzhhH61BOHunu6BNDb
nhP+UA953h1SYBwQIPz8HZ+9yHjUeq7bn4+MTwvRzq4BobuMykRbj2Ghz/fl
YfllGthcDbeos8VCnuO5PKUlGjRm2gaznLDgbri0/tA8DQwb9xAJbliQO5B0
VRuRzxW/xj/neSJ22raD3XrTNDgkxdyScg0LpBWv9UwmaND78vWrHKT/XuUT
Z3Gr6UBrGRK8iPR/gfqq7SQPYr+0L585gPQ/qXbk6Io1dLjQvbNo9hwW/BnU
SjxC63xWn2FfxsKShpyqPS8dhIattUOuYuEBOwu7CpHza/cuHw3dSQfBSMMn
LRvzUf1j04HR8wvOh5X3PB7U2LGg4ZRZY5dcIWAN2nZ/iS6CjTH1xi553Ho4
Iaam+2UTKZBTKMJuWYtF9SYad+h910ydocDCGdLdTw8LwYh2Ynl2FLl/kUnA
YAvh05xHuPlnCtwyt6t/7xAL5ycvlF6/mIbGuRJF2+6eskuDwMigG7Gjsf/t
j0pD9ZNcru9mp0kSxJTCeYx4FIzKmKf71j+DXnyMYOS5ZLi84uOGqXP5cFDw
zETsQxaswf4Ixhjj4Nj++H9OD1jgdHx8cnw9omfCIu19jArAeV3D8kxwCZof
6av28oBuUgnIthDPmlfko3biT+GfYhsFCuAzYxUfQawUvZ5guta+TqQUHHwe
3PBLwUCaePljMRIFQs3lBaWzMLCG4lFhTKBA6b73JZ35GPAzFJy+UkyB7jV3
TZ/gMPDxfaVEfBEFeL7sHTxCxICRx+WTrAIKKNW0Bv2gYYA4L/SoD8EpFeYf
Drkg/ae+Ln1zm0KB4nUpdlOZSH+llPQMGgWeNTgF3kX6N01gXKxiUODhg93J
G5H+99wsU+1nUeAa9NPTSzHw60zV8spyBMf9yfuwH+m/Rb+2SaqSAoHrZxPa
qzGwGsT/Zb2nQPN3kT6lKgzwrdv3NxyxOyW7jux7WoEBgXcH//g0I/NXfeHa
RBkGRNI0luxeUeBNYWTFUTYGxM7D4pF6Csg8JfEWMjEgo2D6WwbBw5y6354v
+V5VI/Izt+bmhy8Irp6YukdvskPk44alg5YvEby8OvyzCSIvOfa0cvl6zKM5
Ftzftf3TcBcVLMj06a+zCD7FHFjkKaYC7pbv9u4JFlqX6dD5852GyP0JZePz
ireooC04+D7zBBumrtN/q+ZS4YyN10V+BzZqH30QyeApXsOE6huZhweulIKG
ptCc1xIDMNqtWCshAjRht7VQtJig/+FiVxSOADcCKnEpokx0X4FujOyI530m
sm6rZ16sL4HuqozjATeY8PDkuX+RUiWgVhPj1+PHhJlfQfb159iwcHyifoSG
hT2LrxM13Ugg8vBWdJ0AG+IUpGS2J5Fgg3eg/wMeNpAW/tdQh9d9X6s3I/I8
xOpjfzpi/1B0mwe+IPKQs+4YHTuSzpqy4d7GR2CSTgEi+fTkDYQu8f6tG1FI
gTL7tOPXEJqDv1/8yvBMM0PkeX3Vtp5raWAxEO+wYJIB3b4Cdqud01Bclrvp
un9fdg402K1NkVXBoPnK6cT1jTGWyLz2O894HMxB1+X3Vf4CfD3F8LS/eM+Q
MxU0p7Fp0fE4ODF8MIxWQAXbsYDvAiU4wMUfdviXRQXFQ7pN29KKoXXdbdFb
+2jQ8OJJr8cbPAxoPW2/PEmFrwLWc70TeFh3KTXWYoQK3cJncX89iWC8NkBh
6TYT3We17Qexh/cRE97v1lCM/lP637gx4fRI3hXH36VQ9C+kVEOBBQVdiT+u
IHb1ui13nF8g+IxT1/uJX7XfTy/EfpHmPzPWToDZwaOOIYh9FDvzJTrnDwHK
Nttoepzlni/cEnP+atAzBhrHnaybM7wTiIUcTFa4Zk4+vJhSwt9X4eYtd5en
vaRkEcEv/djUlHoRiIg9TL7mR4RwyR0/otch67dOtldxOxHsVf7G4PzZYPov
gT0ZUoLOA54lEFvslA/Xd+IextvnonL2X8m630bGpWA/kWKfvUhD7eWE2l1r
nNoQO+DFtguS+URgUAWLBrq4+aZyNrvWrImnw06DHY15IUTYUDVE2qTMgHYd
ZnaseToqh/snjm4Z8c5G/ZycfSX9Ux2S/lvzQGHFOXEbXA40bzZ/7pKQi/JH
cvmeo3nlubDxnabol5M5qB9Uz9voV/WPYpC+2hicJkEGy97dGZ/X4GFsKU5v
cTcZHc/7ivY/G13yYXBzInlGsQg8zHTUFTqLIb36yxd9wzhQ4rtRs/nQE1j1
KeS57plYtL465723yR3crLY5Gs3bLx8zmWHVRYBo4wvr3Pk41P90VE9CV6Q/
Ab2Ok99CGdBkWW6MB7rPRb7ASRY8f/tn59SWJHCzbbPfUMNC8/85+zwv/o3a
u1EsCY2vjDIxn4v2JoJ+oXta6xR3n9srnz9PJ0sTQHClRFdwewZsrzqtbcDD
PReNc66TxKvbb3SkM6EiNVGL3zMR5QOb/hN6pvcRu+yvkGNqYyZqhy1khoUl
zmVB0L73dQa93HMWOXk5ij/OnZWtywZ3U2Nn6iMS3Hwk7OWSlgOMUSu37FNk
2NW4P0DjUB7qH3A2kw4OL8+DyO5V0ulbM2GcnsDYJpoP727JpFqNZ0DM1gDs
vvhCeGCWWRKTlweF8QffdakVAaieztZVyEf5nrNPovb8mhOjkkWwbcjmi9+Z
XKi+GPXkZzIO3Qclv/hbDnpwcAA7fkdEsxA+yO+VzrhWCg/LJhJsKgtROc3h
+5+exIcdjoicfuCfn95WAMri+JESJxKYkF6Qif4F/0899gL4N/Jn7w0vElgl
8knNmWL+q+tCgl3He7QFrIpRvwtnf5cpVj79fBMFgi9hV+zww8FG57evHnrR
gH5T4Mv1Ae65qhz5kbKewr/FmwGq4lqn9lYVALHpjpSf6EmQw/t3/61H7NoH
Zn5d/k4geXjzOtHaQgiQCljiOeQKBQ9/8zs2IHgyeJWaQIQTmDusUlSow8Lh
4PSXi3QXwG0eTdx/uxDi7KP23ly6CULCtadXpxTCQqqM7sYOf2ho+CXs97IY
eKT6SrtenYS8LLbNubYSUHLZNEjpNYd7AaVzUy9KYPfHDQX3E9yBBhH/rscV
Q/fObYdaXAIhq9h88f50KSidk3KnaKjCp3vxsX5FpbDmqAyupeUWEAvdzke9
IsPtg0MhGWedwC73jdf2/VSIKJd6GaUhCbGC4Zb311Gh67VvGz35Nvxtz157
vAZ5ysZGk+h3NyF19NfJTR5MNL52+GOR8A2pPBiROb5KzzcYzAYJxbZ1ufD9
VNiN7R9DYWOJjYaWdT4sBm0tJm+KhIAX2zKOGpbA5X3GAsrz9yHpmmq0gHcp
6A7vt7tsdB/WbtzVanGBBIyIAQMvi2A406kltfUICbw/by+p1AqD8X1ap60S
EPst5MLekaUncF5ku1nXVwLI+Jk0+D6MAIe3olHkRDLoVT4demERAt16wkuH
flJgPCj2TVNKCHhe8rI+kUqBy3RZBeeaSHjEf/Dx6xIK0BniLeGbH0N1f5RH
5eYE9Hf3LymKq2QOKofOz/r/q2/KhpPr26c/7o+DLKnX0u56VFR+aGgf/upJ
TwVxh4Zf0w9ygGf4q9FkJBm8w7UmbszkwsSvC7/4M8kw3Om5tL4nF8Xfn0qv
vP6Umg9VA4fXHzXHonLT8E1NZtRTMizIdOiVHMbBXunRt6kIvnItes6MV8PB
0QTFklMI/uD4WTjxpryxVUm3+EuAUMGITUTwoakj1vU+CQ/C6sqDCT4YuJv+
7OjiezxkjY6stsooRn+13T8fXs4thnvr/tzx0SoB/Xz3uGciePhCtlIpXFUC
4nhnoX0eZKjDGXQSEbstr0dMa0sTGfqtuzeUIXZefG9/5dYbbFSvon5hEeE3
1w2JIJk2VM5/nvvb4spPSHxJhIRYXsoZS0RfFsvHBfmS4CQe+4lXggie8FyU
vJUE6n4pKSd0iahfdJTaPyI5SYSzx163Bp2hAvFd+ysvAhHqdAd3Zstyz2Pg
xEU65/mSBDLIkNXHfwaPjLf4ZGn1mvdkSPm9Y7DgNg5mh/dYxPqQocsOPM6u
xsHAksy+5QgyGn/SWGF2yDCPDL/f//XUj8aD2uaNi/b1ZGCuyJC7/7UECpeV
r1RHkWH+Tovw66oSODizo+pZPBl9X+nYpw9O1JLBjTU4s+oCFYRSpEMt8rn9
F2tdMww2ogNPscGLrU/xoNInYC3nRQd6k5XKwxUEwJ8MGZ+XpYPFeG2ZC6UE
+gZ1EjPV6ODy889bno8kCNWNmbNArj9StWzlbUCGZoY1c+1mBqTx8u+LyCSB
r4/+50kKA97tS2ojiiJ2ihPmQ/tuBvCWH/2lIk4BeZ6enUFI+zGG2NbcIDL4
LZM1xjdz89+nkgoGzWfzYOXzxN17NWnwSc0ox+tvHkjeiVFOnKJBdIRhSdnK
fLjFn7J8zZWF6gv76CV/+ytslL4XJF2TgeAhy9SeVw66hXBtG5FP05cNly7y
phaHF4Jd6zEJ1kU2vBuWvcg+VwRRcmqmqpfZ0G5RePqwThG6z7Ur94nNIoLv
Mz+Qat/L4f/7PwOm+3H/DlCKIWpgfSwLwfNCxZSlJFIxHO1NkVTbzYQEaq0A
zYQE29/eSH4zy4TDZ3VlolVIkNi9Knj9Apdvws0nL4XwsBAc9kXQWZCE5hm0
1+RLpc0/RX93DSyMesjRYK19+2sQyIRC8p01W8/RYHfgSM5SUAb8OCPzYFiV
BaA1E3ZaNhPd56BkZLQ3QykDQA6UT2uxUDygFyjTmNGY/d8+iiIUn/XefnPj
dCcWnQ/G7sb1KxE9ypIj6twxoMFsJnN4MbYQkpf07l9Lw0CFUTumXKEYln/u
n1dRROSbvTKmXQMPW8NniQFTZNAeVlxeq4WHFbhfZZbOFDSuytGbWxTXjCuf
IcAa4b9J73vyQbn98/P4KiKaB8VHlWlj9hCBb6Gh/IcXws+OvITzLO79zKfD
rn7mRDiTaxmXa0mB2XHxsxPiRFAiTmXKYynwepw2OqNPBJWMR4YiD5goHgjw
jorpsmbCfD37QLoBAYSyDE49L2RCp9oWpztdpfCs0WPvj2QmGJqMSc5HlALe
tviHuBW3LoTsiVcvg9cy4F53Xa2SARFKoz9pMmURHJwnW2aVQATLLUdtzI/g
4I/Z86CLFST0uTK6Z65WZZFguiXqqAuNAFphO78eLyVB7hNpc/lyAgxSFtaf
J5AgK+7jC6WpUlBhxmeMRJDAbs0QX6tvKWSKvPv1J5kEjhq3yhwR/loyPn/6
khIZrnwQjtqlQIJHembuiyqI3P4Vsum6ExUCzTNeNNeS4Pe++qfJlylwTEnr
c2YfBby8Zw9Gn6JCs/P6mOArFBhbHxZz8QYVDp7yDp+/RQGF+PfxjSsJCK46
7WJ0jYbiu0XSoEkvInc59MZs9a9RMywIuEZSndxKRnFtx+XFrXhFRO58U6tQ
RNYVpPzJmhQiw1/+R+nlPmw0/jHDNuqo38QGgjHVc/xDBKQvflg8PhIH7Xds
/NiURyi+/r847yPwaqFd1jSMh5POtfgc50j4X7PEJQ7+PtH29FHMhVGFYyf5
dfFw/SZrSKMnB41rcfBi4dWwN5vd8aCzzmhhRX4uus4Xrxi/EPtEBuIhF6E3
iH65K5UC9eYUMO/Ir03UIYApJnB07g8VojMKJ8zFSdB69vdpxn4aigdZvsWl
SRVUlD84/od6p6l1F5B1PVz5N+XEChoo584GbZhB5P+uT/OaKjQ0f082Jbfv
dCMVjQNy7t/l8+9gYj8ZjfucDwoZiexjgeT51c3Ef+FwZvfFlqbdCVC+7cU5
knM4FIRccHZ3SQCLayYPsxCc3i0BWywT8LCj4zOd8jIY+jc8f95XFAmWkW+M
V+y6B3U9Mi/F70dCfKIOtsU0CZUDbmvlH0/GxsMUQ0oo4zFiL3gNHbxvloXi
iOr/5ecsuMS+43mmtQiwtZ0JtgWZkO2/JaH8F0IvFk0MLWeCu99a/Ts9Raie
5kvwCzj6m4nG/90y7XTv3WRD1GnWMyftUlA7217yKY4NC2Kx4BhQCk/VBFRs
QtmoPfL9SvH2K6sReVXl45skmA6FN9W1XkoVwb96q0chb9OgLI6h8kGzCJpp
ycHhtzKhwTNKLTscB6ZurJI1IZkQ+UHk8pEoHNTyf/wYFp4JVnqYzE9xONCt
XFrHE50JQnjltqBnOGB57tYITciEbuEqXtFMHKiKgPuqtEzICjmmXZ6Hg9IG
14T7OZlwYaLD1wmLAzn/B89XFGWCnN35gt8EHBSIF0zfI2TCdM10VwoVB2Kt
DbuXqZlAkw/apMnGQfqdEfPgsky4nbzOoLMKh9id62//rckEWJkUGFiPg/iO
/digl5mwxksCL9yIA8bPrl2nsrMBs1GgU+cnFhQuSdS5a2fDUMee7V0COJg5
qEgP5MuBb8tfbVNe4WHaT+dW++ocWJEZHi5ciYfu80m3XRezYethmbJ4Mh4G
jL1d0gNzIPx/5SyeW7et8U2xFD8J8tXt84cRPft/di0JCiL+qOcX5KP7nxUM
sS7fzuRDZWFlaGc9CapxBIkNAiUgkUiO8JBlwX0HlqWcCx3tl5NvuifFc1+/
WD5ah67b54kkLSoH1ov+1oxC5pEj1zl6KVjp2E99CgU6Z8Rk9F3xYHj9w3jG
de45ux0Ox6zjo+jw3SqIEeLLQPFxubnjKjc2C3a6peiUiySDAcOm7/RJJppX
9+WY6LqJABY8/jOhWYHQjv4ukv0IzT7Nf1wdoW2Tbn031CmALcr5zhFhJNS+
G78XNfJxDR0e7516dxaZN+9k5TjKDjpYE3aYxbux0et8ZNWqUhC8HF9hqJqd
hYNdXhJ5GhfYMLH0r+vCrWIwUfKyD0Tood5M3stPi1F9VzWRy/fRqRQO61+N
lrmYC2Z0ExdxaU7dvlyg7enrWLkW0QviDj7xlzhygQ0Ckaf2FhlSQbhaZznX
kg13pgcC5loIaF3+fLzXz7CSEnTfJGc9Cil7zuwwY4KKzT5D/V0lEE81TJOv
ZIAFkxJ0MgOP1mXh+CuvHwqXMm5kwGH38jPC2SXoOdIuu1zPrbyLh9/Z738L
fmHAHaF1uGnk+0eizz7uxGGBeeGT0Q1yPtTlqPmv30wGTwOdjTXsfPDeJfpT
WZgM11acrofq/P/sCjK8tynFq3dwaY4cH31quWf+KwNmGSYuXjdIsDD2MlLt
GRuaZNiLXa0kqCNfmj3/P/vkruKufJDm7uvnyOnATbw9UbvZUJ9sM8UYRHCD
XZfv1xwWVOCsBN49JqJ5kRz/adIMv5MdQr8Mtu05pobo+XctDGYVC2IH10wF
7yCC0+4ROauz3H2lJ51yz/B/J8DG6n8vO5S5fkIt3Cn6QjULliM2rB4/VAKb
eaZDglgsdFw1fe9W3fZmo3RTgEOrrycbYgNckzzD8PBHKwJT5scGz7trhILU
EHvrwnWD7y+wMI/56LEfWQ/Uf/4t2xHcZr9V/Y1MKB3KUq45wAgy7iExGlJx
dKhRufrFYx4L26bGssWy6aC/L4AQsAYHX5IPbtuVQoe6NfElK7biIDRNsp4H
WU8mX4j4KHEcSGUJX5u6h/RXVBXK60qB5vixZdWjbHA6MPhkjTgVRLZsPjZq
zgZnS6MVroMUqKcVe7xA2seTCHpd7ykwifdNuIzQ80kWb7t708BNOdqy/X0+
KJzVphb/TEXjIJx8Wfq/qNHZ7/movA/rcf2zrigfvgndJv29nI6uk/EStSmT
ilS42+QZnKLIvX9HkVFnTgEG1ff9OQLNjSWFaH7wzUuWtmf8qGBhKHl6OLYY
9ftz7Fq1DTV3Q6uoYN1oEx75FAufbXkWKZJUVG7wiQcJBmtQobGjbJz2owi8
+glBb8yosPfEH4nVclgEb9kGzmpT4Xmsa5GWTgmKoznzKn4gUlYhjwb2Kx5E
BqwvBekn33WNaUx4RnnQMkshoPuiOXxjxDe0AVfP1ZfuG6V/6+qwwK2rrNzr
PAHu/FtZdLSDCU1rJV1SthLg6+q4g82PGRDNV/Xtb2ceapdy/Gnyu8aXrldj
UX+Y0eCzw9UIvhaPW9v7TqMA5XvOeLxpti5cuUyBy/VNy7f0cGgcQPrYnoXb
n7AgwU+KLOKnQui9ecKBaq6fgeO3tZ5xc7BlFaF+YEEs/tR2nyJ4OTcxmnEj
D5Xzc7cP67fzYVA/s4k/0bN3AIN+94mBDeRPD9jouAzwdfM8vofI15lak7nr
BHhh/P29RggbXqpeGNoeRoBEkSADyiM20Pu/8wutK4VLPDkifg/Z8H5Nsa/i
ZwJ4F72ISRpmgOl+o2jeB3ioOt5o4c7LhGtrb1t2rCyBwKjZSxeTkqFP0aRu
6PFTOKdZ2oZzxgOPc0BlcjMZ1T9401mpY5/JsGpLsM7uB3kQanzUlXjJD2LE
fV8L8Beg+YqD2k1JSk1YNB8yvjbH9rozZz/4XThxJTPL4EMJ2u7v6A0Ol4rR
dg7/rjCnER/8f2R9eTzUX/R3QoqK0EJFiAqhJGU7CSmV0mZJUSp7WROlyK7s
+27MDMbMMLuZFikSCZFSoQWVrewlimd+v29z53k9z1/zOvNZ7v3c5Zz3WS/p
GpgpHBP5GkWBeMkv02V5V1DcI/3yXOBD6TC4Ge7c+3O4CNm3eXKYMP6uj7jg
Dtp3gYn314RJJsOV7NnkuHQcsj/hp2j+aa8JYNRyKtLycyQs7d91jHaKCJ2Z
l6cff7kLr78tFlh4qgSW3T7yZDDsDtK7k0unHirkJqB1sLrNzdtsTRR4boh8
phRbguznR3J39iwiEhHdcHrxi35fMuovbx0Eyt0SwDsmwcjsik9iVhWof9uU
T2t0qVJB2lJReFHhHaSPFJ48X/VHNxHh5e/rGq503o+ELfWfNlnspaL2NJs/
BSfeoKH2ePmQ4w9Or27IT4F74tgnJocKUHwpZ9Lwe+HqYnhzpGdPaVoyHFC0
9sc7lcDPMmkr6tY0NJ6cX+5WHlzdwXqqwivEFIee/5xzt2LFeu58btGskj6a
gubz/MzPjRs+JaHxm4g7E2JNSUfjR6rfvWWpYCqMCu72inlYgvwMPHsOIeXV
8w65FCAPSkuw3pah9qKtP8oQMihw+eJ4JfFVMhrPvcldK9dvzQKS4Wj1moIK
dD9P73iQO6GP+5kCG35ENDMaCiCX3m0RpMDPw3RqfV2wdC4DghzjfaIGisB1
xUY7h/fZYOFWQr4giQMR5VMvZdTzoNPw/INALQzCebzxbaRKZCrpZIHfJ8pg
WTAfB/LWJ+vvclMRg2x4btq08Vl0PvJv8Npv99hwWvZpLvJTNFgcmBjn6gH6
ckI/Pfbx/RY8+yTzfFyY15Yc9H6yfEbskvf5sHOnVjijH4fuF6To/538SgC3
um7HozuyIWFV5OfbykQIS/HZ4kHNRfPVv8g41A2XCRL3p1MSBUrgrlVp2h9O
DjzaWb845yA/r5I3n/taz5WNiuWi+cydV9fXmsiChtW/Vy3aWILa95YxGVEk
laDv5M3v+2POf6I+ZaH25UqYfg5L8iF8TQ4+lkFEz9cnq0xeJFIg4JnDZmnf
bLQfHv/EKqTqZ6H5rxKm/B7UKgAzjexb2I0VqL2lWnLfRL5kg9o5hTVNQkXQ
Y7Jby2dNNuLbPPn6x/5xebFyEdxqCT7b4ZeD+Dzv1zFqheJybCGUF3gXxRwp
hn7zqa5trwpBjb1bOMK1BC46PoSt3zFgKS2Zc+QiDs0jb7586AIcuUcF/Pob
ZbEN7ccKkRzzkogOPNdUiK5f1f397bxTEXwfJRrkLC/l1zsITbuxdLAYenUF
bWqsi2CBzIMhSgUZth8akevrKYQsyecXOIIV8MLsb8bwziJwSLGYHOHKAV5/
eON/4Pzh8J4j/Hjy/i8u0Y98CmFMVVs2pKsMravyU0ol3ssoqH3e+K/ZoK0v
08t/3oDji094UwRavX1b1T0xoJr1actRm2JY0amAv8HVEw6G4T9uVMTBriAn
hmNVGfgofvuxeC//nOT8ZU2faP5Y1L8TXa8n7m7CQdHDVht6JT8vA9XzGV6n
I+2CR/gZd+/w+I4Grly6ehwzJU3kj/u13QHzKvxzlZ/4rqsNO14CQkmjwphN
BFDVt44901uM1jHvvqX2f4MvPS+BDyd/nQtIKUZ5GrzrhTO/nfdeJkDNhvdx
PetK0Tzy+r9WKjro2p8ShE9UaA+jqo+WwaLdYQVgiAfKg4fmNQFkyJsN2/vG
Cg/7tfQKT3qQ4VS3smaDEL+uNg+v/HlH//3Dnojer06YLU31JSJctZO9Ury2
uwyu2J4gRFZX/mu3DDwWkjondfh60Q65d3H2MmUw7X/yOCOtAoRMOhnZGkS4
0KRmGHiSAtZObJ3Nh/l1GXnjjaU8Vh525tOxfgHSH69SQNivxOpwIx5kZZ5W
CXdQkB+wclX8lzvmNKRnjemcWT7TSQMzo8pm7Rp+XVmefnEluMHo4mYa0lNO
1WwzT11DB18Xq9yiUDa6f4We2Kv3c3y6Mu1PsJ8Sv/7Lbvn8zN8tTFjhG0nJ
PEGHv4pTJeHe/Lp1vP6xihuxGcp0CJn1lmJXMSAowfBL2ygdBh7dl1E05Ne9
4/VvcbOLyGYNPi3eHyoXtoiB+pufsSfG4gEDIl6lrmlL5tc5In7wuU8W5ud/
YsoaR8aW8/O0Y/dKCXU2U2F58P2olQFMGLm9eGr3WyrIjJtL6l9jojyg0dyB
29hoJiy9IZnZOcGvs1Lu92k4+Cc/L1bYQ0dS3o6J4ph5/2M/LhZMkGNCSNbT
/Zkt/DrKvPFoz44T1d7Dp03qTrsvyufXu8ZhqkQ93JiQs9bkHFOB/97G098V
1r3g1+nl6eHZH1j+K74z4IPt+J7Hbvx6yLzxOzZ4Q+HlJT59+55b4qbH/LrB
Z+Cl63VJJgitfTNvbsx/P8urX3d9MT/vtWBzqsjj7UwIJZJXSonz8y/3/v4l
43a9El4sGs7QTeDnndZz+qXZUvw6sCoLLKuWLKhE7fL+VxBpfBJcwKdXCail
1stWwkTqkh75OH6dX17/n4XMr740x6fj4non4Ta/3rTDG8mcZzsrwVrduU/m
D/+9vHzOpGzpQZ2oShg1/+gce5GfB9pg8UX//h9+ezy9/+WCFoP+WD7dbT1g
IrGIXwdX1aRY/vFfFnz31Ghu/sP/3vVHbwQ03uXTX22U4wX9GajfPPv1g80O
m5W38fNN3V9j5ZusOOAqV7Rkjz0HtduF8yfdfsqvn8v7X/ly2FJTUz6t59Fx
rqaQTxs4jHoyf/GfU6Tv2NI6xYb5liP+l7/z79N1FNmz059PV+enRfc+zAEj
qdDI3TVXwFCh5djqnmTwsPmbbqoUBZcV4rNbufJ34b3Nr5ZYESCLVaotn4eD
qnk9GxdNAorLSpQLfWakToGN2rj4bffw8DutuCZ9LQXObIw7/Y6Jh4OXFjdW
r6NA0z3BO8m6pVy+UiAjtpsCRaEj0dViHKBKhnxMNefi+POvD8UJVEKr5pE/
Qko0GHfXalnfVAqUw0XVk6/oIOI0fYiVToUr35dvzvbi28HPkEtvvb5GB7Ma
bRsXLp6/nbrfc2QdAwKJ+U+P+JBAuH9C7d6ZSqS3llVMdtZerYRi8mbh2cUU
GIXDlnFbOcjO/t34V/+Pgxx4Msd8l91LBZ8dwbaZRziwIqiE2qlNA2/3hxJN
BzjIXrk+Wn4T5jCf1tFjLvcb5M5H2KIjuvY0EAkrslv3CwuCk5a+Qek0kGwz
mvrQhIVu9+btofpYcKYKi+dmcvXPQ33aPpPFYJCzV6H8OQ3WZicqKxwpB+uP
w52Kh9ggKHh8q0FOOWgFfM604/LV4k5Baz+bVKQ/mpTHkcjdqfD9Seijxwoh
sGZx4YJzgrn/+nUG8CeMldKkc0GV4ztT32kKE/q/a3925oAT8cvL9hZXyG18
lAaeNDi/9Ncu0vl4yLyBs5awoIFBiYi+jXciCK106llNyAU/1pvxiD2l/+Rg
LpAea3so7yyFrOaDcn5kMmxz+VK5zJyfr0ZQ8bNV/lYKI89x9Wu4cm791EVn
25oSGAkgpIc85+IhS1MTx0i+XVdtcaNXc0gx4M+6l/90pkHa7/SbDXnFoCnS
ZqUwT4OKlTKTB3yLIUJR2SJRhA7WpMbnLxcR4MmLllmRYjJ8KFwh0/WtDLWv
OZtx9aIbCdHngmkQIlkOnOEl6kFONEhSGS4R202E176JydOlNKjeJ6l/1IQI
qbOr//g0l8Pk8NbTF/rIIOr4J/rBKTKs9DNLXT1UgfCbnai3nZAdV36bBZLD
TKjgtDNhqb8tBRT35sxUClOh9VXNzzNcWjD1lKKoCb8+7Rbv9VoZRDaEfO+J
kvKmQBr9wvG1XHl3scMCf2U93x+4ol3ysLcCDSiqK9WtSeWg97j+mrU0Dbar
eBuOJ5TDu9vFbetW0yBTOfN2UxkFSL/0Hx3ZQgV8trHoBJ0CUxiW3cxmKvwQ
nUuz0KCB5R+pKX1TKmzGLO+8M02FpckbbUr0+PluKt+enDAl0eDnc9KPB1x9
2Mgl0vTqKBVUL2eT/wRWgt+CRz/j8ynw1KT3fXwEBbxGjtjgyDQQ2NT3xfQY
FSYMTDrsqDSIINAUV+lw93HxiWN6bfz8tPE2ybSA1Qzw2rTKtaeYAseOtx9c
fpEOaYE3ki6zKWBcX7j31QU6DI3U72GepULz2iilz9z9nHXStxo7QoEPMykM
Evd53no5niZwSNOeAbqXf+n0rKBD6HxvyJ0GOni/rEs7LsLHRz5dRippNUzY
VTIb+uMqDQyNvd81VxFRPCfPz+FQflZbJImfz9bSq3E/qqMSbMVZcgMpFDgX
vkjlbB9XDhoXdt9rp8DEAfG1L99XwrDz0eLmU1RwVG0vqmmqhGND2doHZiiw
xPbqIOt1JYSdKp49RKJAZ5v78QZvfp5xn81k+P+c39fieqsWLlFh58svqsVc
HOA4sbcuu4UK+sWnXs01VKLvUNoUlip5gk/Hb/k0E/22ErzLbfbJH6OB7qLX
YgHNlTB/7e0LHHceQZPoKcjt/9vuz4qeUnRgtq5y2fulEjxPXyFAOw16iFfl
Ejv552pcbFfPmQ6vhBOXj0anONIhqLKH1DVeCVbDM6LGV+lw97nPS/9f/Paj
DU8Zz1pzcd5Tm9Ph3Pcd8z+ymfWKDZ0velxwzUxIW94upNvPxx1mL5p/v9Zg
8+uLYs5Eb17Jho4Tf4fdCBQIGVpdvtoLD3cNvw7Pi9AgofGV5dHVBNiz+OEy
Re46z6t5JpAoRQDijE2/nB8NNum24G4JE2CFusXnwkNYuFcRHrMxiojswEuj
P+tFWBFh1wXTF3uGKSB6XnH7Wh8iqvt91tR0nuZAhPXYwx5ysRSIcM/dMepA
AZNiA5+Al9z1mv9Mwes0BZY/2vpNMZECc+133+4aoULoyD64/5yB4s7/268s
0EguNN8sQIPllZh9b04zUTspF17ltV5hwbPV45yyk1Q4LzvU8usAC11PWP7b
o4dAQ/PAi7/WXVGh4JBHB6Xp25J3L9Hhy42myf4BOtzSwOw7d4sOL3VWZbhM
0hHeICzT+ehVQYeAj9sD41PoYBxfavjRnA4Hs0Jygj7TkT07IOj46cFzDGSv
tfpu/+w0jV8X5z/+zoBcq5yT59U4ELuujXHBqRLZG1Nbsd6aV/JAdElALDGY
AB05bcnW7nkgLflD2jqIALKXBBi3nPNAbu3FgoUBBDijpfW6xCkPNm/s2lLu
S+DqfWd/tjjkwfatxxm2XgTorY1bPX06Dwx3PjcS9iSASsKDXRts8sAcjBso
rgRwtR2y3X8iD47tZx+3v0QAkpLsda+jeWBvpflBxIkAo9/352YeygNnu2IX
ugMBtNkBD6v354G30/qJs/YECLhd/KHfNA9ueKQGi9oSgGXjHq7tioOJtxtl
1MhU8BjP8xB3xMHDhe6LjPFUULz78sTQKRxEqlMnTuVRQfbhfYuF4zi0b0kb
bhXNPcNB8C+BZcqfqYDpiTks5o6D7Kr3iqLlVJCQ0jseFYiDrcfdjx+kUiHE
ZNBGMBoH1d9mw+4yqLBAWWSqxAgD518sdzvQQQaLFyf9uvdiYI1y9aDUKzKk
+uImJM0x0Bzs7f6hmSvXZCd89h/EQPgbxeHS52TY/MR4PPgIBvQ02z1868jg
45roTT+OgdGoiO+GT8jwQOLjaL81Boo/7by8uIoMIuytXnL2GDi9u/9HG4cM
/pVPR3K47VefOrkK10kGmcyyrVXc9nfOH1Jz+UCGh9cS3D/twwCpxHSP+mcy
nLf1Iyzktq941ODkaC8ZFunZftvIbT9zWtuN8ZUMRFkjZXNu+8sxareuDZDh
yKyikyu3/fADSqkGw2SY7BTB3DmNgZkxWcKCETKsGqM+V1PGgOPaZVcP0shQ
ZU2p9pXntrfQmXG2lAzOVeWs+zIYmB6oHvfOJ4O4MpkkKI0B01bZbRGpZLB3
ZIvP78IAvfzG09J2Mtg+rMxQ2oEBecePdYYvuPq/bKX8fk0MxK7YW99WQ4bj
AawSD1UM/HyCa3C+T4aFUi3bPJ6WQHr/W42V7VTkZziIe/798hgvPzwRDvjp
6q7Py4bsBjjSf5Mfl7s4ep/eag4LNpSfrEzwKkd6xbFHYizFr+Vg3yym3lvH
r2PA84P2vxxYcVihHPJqv2HtlpfAkZ4Jq61RdGQPuau19YFnKw1smuXvNbB4
dWhp0HVZfuNjWSw8E9dYfn4LGdlDLPpvREScJaN45AuneyMuHyPBVpvDnflB
RdBRQtt4LoIMj15Ufcw9XIz2+zU8vb11YzHMDT38XidMh0/elOOdXDx/8cT6
tz05NAicO+3u7IeHqcZh4YRULm69IxI24Y6HSJMH2vpxXJxY+NQ3LJ7nf+Hi
4gGz7OcFfDpke131Ciqf5u2bwSVjKeOo/g4Vtl1r/DbawQYh6YgzEh5USJSo
3SHdzYaILRXLu6qo8EX2qWdTOxvh8+MS6+/YvGTDA5ey6q3DXBxTI6U418qG
hm+Oitf1GGA9/GnGRoQDy6dXPEvk0u9rP6Sc4dLbqI/eZifQ4dj/2u/4+Tzn
JYq+9/WwITjZrWsQ6GBbQft1itt+qHvbPglRBvzs26Gx5y/3/X/jXxeS6UA+
dq2gwpYDNTvY1068piP/+n92cjpE5WPzn3P1Ol6c+KesVQs0WSwwW2SWf/0g
BZQcFeoHZVlcPb1D2GgrBbJlGtbmybFA6m9HuvMJClx3MvrbdI8F18MfCBmv
ooDhgBxN/SkLvK+uPtNaWYHkjM6G1U4xJ9jInifjNpUWfJ2F4gvajTvMU2Rw
4Pi83g17hMvfDhtflhbEgVuhISXsIBencpZ15ErguPe/exW6jwrtQe9Mqw/w
6hHxzwOhWt4u9qtlw0u38C8Hh8r/yQU2kk/kCs3ETy1sMEld58Tm4umJ/FUv
g7j03ikdNwM8DRa8PbdZnjs/MDSWt+5bBoQurvu4+z6/DrKvwct2McksEJR4
vLjqezqyI9/rWtj2eqYQ2U95/loXOWL1fsBCipCJpoVWAVxp1Da4rIpDcUmV
OebCbb1YCNc3D1VfXABbhERLbgziUTxS/dEze29oFqP3rQlezM5fwLd/zi98
8metCf+8tNCxH9GHelngNzwy96oxCwQsJ2uNzxchfL5xS/hZjgV3nYgvNXOm
k0FfjZx4y5YBzX2qdts/loN8ffIpzC4GHChi1XReLYdsTM+pqr0MoP3Wn1yq
T4HaU40hJlw5Gx0f7nPGoAJcE9u7A7QYgPVO9SwarwChJcfzRpX4+TWUkGMt
BwxYUN1/3jPpPRt65Y+GNzuSoTnq51rvt3nol/ZXYOHT4cL/x95cCF/tLC7r
nMMATkA7eEKvAJgkawz+dBFcPHvvhdFnrlx0FR58l0kBy/BjJ84Gl8H+rDgT
9WsUZC+9dlUt97Ecn97mJX9Vs4cCtkHeKnu+keDYokbdAS4/eaz0h7Y6lwRS
Qp9Xi3JxedbqmoNuUUXQYomV/fMBC94NbxTf1RXBirfVNd8oWNite2mY04yF
TrOjcfVsHOxTc8V8ccAi+zMPzz2I/2Gysh0H4sIpwne3FkMK6MfUvSbA0TfF
zLnsEvCX3/3efCsJ6tfOxVAPlqB+8vj7o0JK3taTJFg/nhh9wIUAhrE7Wraf
4Z97GTpStGnldDhg9gzeamrO+udP49IVK9+tFkuHhqn0eNnVWAhei3MQ/5kG
TWbqjR1C/H7+FQguaTtUAoFPww8/EcCjdiPfrpy15vZb5dt8zqUqPGSGtWxQ
j8Wh/cvj381zCaENQ3i4VHQ4LEObX3eaZ7/UjIz88VyYn4fSr/ohY0ttCSjc
wb24/pGK5AiPXwrMHTjeXlMMd+wj1l97V4rkUePyxxveRpcCXEr4mvusHP54
DfvlFJaCwr2bWX3bySieQbDaimByiYzat7GTP+akSwQPrb8V3hIMSBb2WBRm
Vo7iEf03HekUW1MOAbGLvDnaJKCmxW7dqkCHiMYfo8WjRIhWJ780UuefV7ix
/z7GTv3/Oo8j/kW68QEq2CXv5MRO02Fd1cv7T5dTQWTdrkfecgyEl0s7p4ue
UulIT+O1z9htteXxQj4e9/UOdqL95fLhhqVGKZIMeIdtvva+nobu1zn9O8eu
nIbsta8HgnPGB+lQ67Iq5uIcP+58k+8q92Xb2Ki+E8/O19uwviJ5lonsbyff
5wq/CmUBwW9mQjGdfy6XZ7bZug3C/Hp8vO833747NDCYDSXiIk/X5FGQfEqM
v5lPySmC9HtSkZk/MaAZWrl5x5MiiPNpilJ+y69v3ydW60k058r7lf5iWv5M
uMQ2LrltjIXMpuqVwNXvda5tUDOay4GD3hoyL/qoIFwlVegbggHpVYZRylxc
y1t33kYqxIbfbLQ+1mZ13ZUYYQPtl0T6V51yGEkeVTolwIFn/Yttz38rh47v
l3xWyTFRf3n6An5/iZkWVx/8btd/sauAAd5piQOr9rMhnKXz1qKSAZNZrbnC
XPlv5rlo4Z3fDFDY6Ndt7MyGW/RHNqse8eva8/DN2nn6HqP3RCg6lB/0YCEW
cjsO+5rTiNATPXF/Q0Ex8uPz4lU6sG8DBjypUL8Qs0liUzE8efZY4vFNKtxb
tfLm9hQWKP2SS3+kiAeB8Num01VlQHh6/fl8FhO+t6+8M3C/DFY+9Xx6L5sJ
qf+7HsvgcL75vg8sJowdr8DanGdA1B/r1l84NlpfXSJ/J0K2EOBK4oyAPVd+
UsnNJoHri6FJfLJSarQE/ppHLzO9S4aVWF3L+yLZEK0bMeusHAZjffHx1n+y
QJm4ffCpdRjyo9qIKEzsWYr7lz+Ph1MChoYnHGjwRORwFcWRBT6Lnvox8nBA
3J+u6OPL+jfuuH/9ZcGpRR7eh124esc62yejfdkwj4lxbfqbCBeNpeukk7Jh
bcXIjdseSbDb+eknlQ9ZKH6aJ3cn/Z12eQYnQYTEwcGQ0gIUP32HYlPnegIH
B1LCww+FFAGmDVtn3M2Vu7UcZe0JLFpH37YpWHRw5bFb2nKNt3v4fJsqvsvn
3ZFiyLk9/IbdXgT0PPbc5FQxvPSeWdugi0N8kuYms/QB933YDrGHe68Xo/dy
mn+7BtaXQNfJI5uJIWXQHfhDueFFKTzGkxZPxRLRfqhmNz2+VloGavlan4vq
K2HAXfHa+fEyWPMgpydatAAsRppXPjBMhlSHyAtXpLDIv81bb0aziUPelALE
d1sksopCg7Aoz5JmbO197+lNUHzXsxqO4pA+bLy86xXdqRTRX6P3JXU1lqF4
HZ4cOvn2yaqzqSFgF+3VFzhajq6nSId9f1RARc9f/OmWfUiVjq5fXiYptPcd
A3aGY4J2iZjD5LTO1TUVhSg+hSd/FgnL4FRi4uDG4Sq9Ni5e5F3nxZ0f/ePn
X2kWi/5/KXZWY41hIlzp/P1l8k08/C97W5kAyWlfLhAnc1C8LC8v5EkQ68Hi
yDS4sPpF1MDVQnS99o7cC6XfOETz+jNpV1tr35AGzW1Om3yvE9F1Xn+M8RNF
N8rSYd+GqSsVEVR0nZ5ddnlUOQ2mKm9Sls2kw9sTKlI7LdJQXurWvzsujCSU
ongKnt/Y8ZSGrsKfXPT+Bxr3zks78K8f2Nax/ExPEQh8eptsJUxC+443P3py
RoG7hYqQXF6457ccRZ7vT+/YNtvdt6EY0b2xE4+WPSYg+TWz5VrsorJiZFdU
tPX7vesKAUiumCUVRytRfst/64sDgjO17h93kSGsf71qi34ROBbcEY4kkPn1
57Nf/enAkIFpddbxrSkBuk1JkQK7acgPbbScbbLfkobkkkn3x4r3LAo0vWua
/zTIRPHYxzwUdDb9ZQJBLr7GiUaDV3lDR6858+14mj252OwZPm1iXb7wziQJ
urIWzN7qZqL3X7n2OGXBewb8ilq9yT6Tf65sTc35+LO2fHnJ8x/urxo5lNrK
gHCNhvjbSfxzQ5fQ82qurOb7d3njN4cR1f3M4p8beldo/27FuywojzoeVZDL
Pyd00vLbXZIcX772d4vZrzCmgVDNwviEJu53/PS7HPuWCrMnL4UPNFTC4PyS
/EEunnhkvMlHfRW/DvRkV1TKgg1sED8buUNCiV8nlmcHU5y5K3vfgsOPAyu7
nv7S4CoQP77uWnM8DuWfLrisF7UtKu3f84Eg91RsfPpiGhh6EOP0pa/D27Lj
1+O56zfVTUKoa8cNtG6XXj83zKqPBcZCQgkhIw/Fn61TXdgzeTUHxe/oJZwh
C/rwf1H/txgYzm/PQ+vFOly7u0eXu76v1S5uCuJA31rzyad0PBAXbJT15dL4
GOda3D08BK3zjA6WKfr/zivRUM6kEi0JcOCW7aCVJx7tmx/ded6KGnjwWbNv
yv5NKXruSHnEe7ExEpo/v8+XbogbkIE0s5HjoE7g1xkPKlgSzX2u4ldA9E0p
CihmuSYOOJBBci/zrYweDZzNMPYeQ2T4+jrs3MBmfh7YwNr9DhOGNKDcLu6T
5OoT67NadM89p0OB988P35TJUDvUVKTFokOgvWK+jwAFgJHv9DyYyc+TOT9C
9JdmgeqKyztbue1uj6wy3HehEk7XvV+P9aHAHHNw97tj/PN/d7TsHP+QwYHD
l0tXzPbRQapuY8excxw4Y54VfVuKAa4SvQavXTig6mrkWTLEBN3ojrEDqhy4
nWr16VUxEz7Y195cf4WD9NvOgZQ8/Vs4KPxl6K67LAteSR4c8nHCgdFNjEuw
ahZc01+19L4dDkizv6c6vtOgtq3M9k4yFr7efOG2fzkdXuYsqF0cjAUpBdPY
N42ZcLf0R5DUXBT4HyzK7LKphOuSIYU5OyIhV+rgz+W2lag+LT38d/f3x3Q4
fDh+dqwiGR7gdKRiWuhI3vPwL7w5knuDkgQqotLqW82T/+GOPNCZuHArXooK
2OXU1uvumbB0bfCPgW00qE40PPRCIgfNt9rDljZLYjYol6bmY4/REI6IUtFM
XIihwabwM0cmN2ZBit2Ywp4oGtKzePYDV0Kd01FCFpQ+/LNbYREVAsiONfqR
BbBPYUn9YXWuviH+0d5FGYPao0duzdecL4TIU6tydtjRkF77Hf9K/fY9GjjN
FvTRPQth/8ARrUEGDcVr8dora5kJf0UvRPrRiXOndhdp4+CLSpLj6CYW3OEc
S1BRxkHFJGeblxILxW3+Z1dhQSrH015mGov2b1gs/kWbVCmcVfbeKBKR9y8/
sxTW2DP11czLQeLbhR2sn8Uwv3yLUboCFXwv247dsCgBv7CTUYWqVKAn/4i1
MS1B/pBLHgcLKC4lIPtDJPzXBQ6Uqa8OhtYS6K/YQ1lnWQ4X/DPVe/Bl4PSj
zpTTQoMP2+xX51oQgdFqalWKZ6O440aNTzZrStgw4JzxPHUJETbsn3KaK2cj
O8cy0yvTT1cUQb3mX7tj+yqgHRd7+qdEEQhJuXu93V0BOcLFVSpces/PtxFn
t1bA+UuPFazFi+DGu305fRsqIKS2c+lfrn7yJ0Y75skE71zaImhlyw1VClTA
MqmrxwPHsJAxcZpdnEWBHpPj54PFcP/4PQWOt/2qFO6lARjFLME7VMCb4nxv
xWts4Oh+GNNIqoCZVdfzdnDHK3tZ8+TIJioY2prZHximQacwibNSmI70DeLD
I4VOe+iwc8X3ZyGkMjgYGiq1+zMDjn7Z12MqRkT3WfcqGayeKwPGpfP4kBYG
HPhANs6ToILV8bn9kufY8KxtKA1vSIXXdWTBydNslA/y58vasUEujpeUvV04
PMUEoZXxvVeKS5E8jG12/aybWwphXTJ7tj9hIv2l6eQ5rO9NJhwMmc0xfVwC
Qft/5r4IYaL4OF59rAdyYUvzlEoRP796X/+sy2ISqG9pXFszxj+ni9fei18R
H3ZokOBp2WIC8yUTXe/Vvyt22pUDs25SJeq23O+u2uTQzqV5883DAbQnEwaq
khVwZ8Pk+rudVGgafF0sJVKB9sMTdZMZOYkK1J7Wx88C6lVUaNO60ujZwkR2
W95+TGi3kxJMoKP+i2f1fYmLo8OKG6mi67wJYGv26GTaVu44fCtbUJ9C+Cc3
mGheEvXwOnfiOaCduPGW3l8WPNl8QKU9oxguDoQFnhplIb2uwU3s77MvKbBp
xuduozAGDluzKHO6lQivlnQ5SV3dVgnpByMEVo8nwNqULcf3aVXCpRCVELpY
IgxRMbu7V2LB8/je+2sjKZAxu/eGsSwW8PfA7UcUBUzM+qrwcljoVjCUeRxD
gZH4CAFRJSxIx+jVp9yhQM5bFdPLm7BwaFQ34FIcBfYp1ke2qWEhzFpHZXcC
BcbdXRt2amHhftX212JJFDDb7raSso4Mj+lPZo12csAq0ndx0Foy+DbGC2zX
4cqT9zdmTWTJoNxrJ6K8gwOuGpE/lsmQoWNGZdkabQ7430743LGaDDGSE5Ji
2zkQ+iazHbOKDPqqj9bMaXEgTrXomftKMnw3viM3psmBrJvEezrSZCiwtd7Y
p8GV820M8rwkGay8lVQ7tnKAqlJV2LCCDIIxI5rP1TnwMOhZSooEF1cW3td5
qMaBhuaXkWfEyeDMjtKncOXZa8X3gZuWk0Hm5XFj7BYOfL7a6zG2lAyN3+TN
0zdzYPj5sMN9MTIEzw8ditnEgWm5n8ciRMmgsZp97IYKF9f6zpsdWUKGTxrh
NleUOXB+w4cKxwIy1OzYNdi+hgP1/4t/yRC95ZGYpiIHWmbfOF2wSoHo6gT/
HUmFEETzjUs/z4ET+AisjnEKintbWFojY7AIC79IgWf/5jFBMZFsNXKBlw90
BwiT50f8fieC1+Lhgv7HGLiXLTEQ9LUMVORIGbo+XPyi1lYpN0JB+GLp5VA/
d+46mRkIW9fBlfM8vFNzGx9CdWEgnM/zrwoXRpL+mJCQ/r8hKpjRXEsCx7c7
HRO3siDhMyvau4GE8IQxtWgVeSkHzv3qqW9tTwPngUM5b55ikJ6zTdDgu9lD
DDx73yYY15eJfklXK07KOmWCT7PaWp+PeQhPLGAm5Z4ozkNx+R//Um1YVvmQ
e0HorOJMBrJzP5a+tJllkgHWFne+l5Lzocd2b7PhqUKkj4dY/h5yUCoEoRjM
lexGLIrLvbAz7Js0lg731VoW2L0sQ/uaJ1fwnCfKQ9J8e/TQvQX6FzZx+eeS
kKYTj0hwN3pmuUY2C+4bDR95JlUEoekuK+UTS6BhUO1yxy8MtJV7qj3BlMD8
bVzKh7JCsJ53HbLzKgVC7w9O8EQhUG3g8bhJKYyt2JOz0IeDxn+PittYxJZU
9N08fXxIelR5qVQGcBbTfC1mckDR/uT8jUAsxNfE7fP3ywG1HWssO3FY2PIi
bdmilRgYUZJ8dSaJb1do+VMYuKSDDH77jt8eL8ZB1duAxvBGMhzwG8o7WMCG
/Ndioyq4MsC1bfCvwrLho1Fn2KrPZchOdlJ/SVaGBQuO9ZxTXeVfDjE9+/xu
HGWh8RqztxEsyaUB6Uz2BoP6MphcmLB1HE+DX6GeLn2HsOiXNy/nIo+Rb8UU
w4GjXWdEArAQHCaepMfVJ3n2kexccaPMD2S4EOJymLW+BNb9MBHa+JsMAj/X
+a9dyoaXn5J70hgkOPpcJOGYcTz4vlEf/1rgBbYiBNm5M3GAmVZcK8bxhz7V
MZ0aPTp0GA5sKBBPh/djFVkaplQQOGe74ERZPrKrbVLBnnm2Lx92ys93lVyi
ovXV+VrkoKtBOii7qKfOOhaAbs3KcmkpOsgybmxacZvLRywP79zBxSfKMo61
fU5kcFC42hAkWAz1m9adbo4vh/iNm+/LthDgjHeE7/Bbrj6ac42W9YkAXhox
NzVf0yBEsPH7ZVcyrJkra9YOYgHeVG8BsYgMTdSNeTe9WFB3aCtc4OqVvPMn
zl/dKBTGlTu8/BdNMecFPnZ02DKv8NnpRBqEiPdKzLvSYRG9y8J7OhVWXzbO
6pStROsL5cGeJoqe2UsCj0m58cppFtTP5b6OOFoBZ88wdNuWVQJ9g+XczpwK
vt7aVTv6YiwHHlwx9kq+zEB2EjisetBsNxv5r5CddPlVIX+DUoQTvGZzZRdX
MVB8Ymu14992aTa4rS8wMCBWgINkbJ2CBBsMLC603JmogL73h9foLWLDlYEl
Lg+NElB83yeV67gfgQkgcuNH3byAORhUOa79MBUPRWp1G0nel6CxrfPSzIIE
qO1brBOWdxFi/H8+MYlIR89bk/pSZLPTYUupa9WV1WZcvn75/fGUdChrcn4d
pXgc1LqrGz6cSIeg3qc33yi7wf0v7z5FBaTDLvkvF7XazoOknsxYtmslet/i
RdFb+l0qIW1Bkq6i7y4YXbmz5IlzJWypjNuwwcYNxc0SD071VRrEQFrtl+mq
E5WojsPmpDStSTcWrBItN0oXTId4KO9deL4QdtX034nk4q13fesVPGexQDwZ
e76JxK/HE1Qs2ILtIyPa8l7RCt0vFJhQnVXtlGCC8o6fg2GfKOi6jorKq5xE
7n6UdiqTuMuPu+HhpeSJhZwlc2zYeChvNjGRAn7HJQ9lCnMgLF8jsusRBdQU
XTUcZ9igR/xjH8N9r6hPR1/KBBtCqwnbVrgxwDyjLWWfJFfe0Qo3t+ZGgntz
YU53fjJYFuh+CnoQCabLMk1m65LhlTFd/mtRCmgu3SPqLoBB/O130/ReL+lC
+EaXbbqcmApLODdvpO/m83Evk1bJsHIKbC3TM/e0L4EeuWU7dPUZ4HNkn2E7
V/6TDBdKhPRXwrcn/ta7r+WBwvGbDj23CRB88+pZ9+A82Fv8p6o2nABSegEX
827ngdPvILmSSAIQpgI8WqLyIOLQ7+CYaAIA9ZqvQFweFBcEdLvHEuC1R2CQ
dnIe1I9PGVjeJYD75qDQixl5MGDml6sVTwCBvqDojNw8EMsan5VMJEB6wfWE
BkweqA97nZ5KIoD66Rvps1w5Zgkj9zq4uPDxquC8raQ8uJLsKXsvjQDWbcE4
B2oeJH0ZCszNIMBw3E1iElcvpe1ye3eTK6d4eip2q/aWyDACjCtM1J9cWgAp
qlI3a+UJ//hzPjxSLdtlDQQIXSp+jzZeDM9+7C9b20GHFyVX0o/+LgZFzJoH
L17RYZXJS58f88UQfLy/KfglHRw/aB25u6gE3gqzP2o00YEYmKSmuqwEtNlR
Yx8b6DAlPS5SL1UCcW7Wgkl1dDgpPp4RwKXtE0PFF/2hgz004xWWlwBHWrzT
+RcdnK6U0RsXl8DKrNzihnE6uBVEPvYXLAGf9ao+aj/o4NVyvkV+rhiaMZWG
cQN0CJg36m6YLgY1FbMlI33c+3PwM9dFShFuHjqu81h6DZ/2WPo0iryZT3+v
PWG5bzefzqUl3s8RLgU9nxkGu4kBaVn6NflipbDzz67nQ20MiA/5+hyzohS2
RwZ8lHvLgGjnpDbc6lLQkGBNWnUzwCW3RFtLsBQWkJ0zCxsZEHt8dfqd2RL4
ED9UufApA0iiUdNfJ0rggdeVjgtcfrZy5sigB3cf/ofbOMAwir81e6MUDowo
fk4kMmCPBTuZ6FMK3uqtMmfKGUC4oW2ZzsWNPP7Ni6s47Dt48/uRFLCI18of
G2GAxHj0BTXREtDZVbLlw1Ymkov1cVmK9zkM5P/kfXfX8c9J2weLgcw8s8PY
pBLEZ8v+9n4sgTtLnYfuX+IgOc2L67m46uvon/85Z+9crv/zB2TwZizu7V/D
5fsyuGvKThzEt3cPX/Q+J8MG6qy/3goubqYkF3HIKmyQZnnP3OLKrdZlN8BY
gw2PRnbnnsonw6Ucra3EF/w6n9NiBndOvGLD8+YvYw5c3K7mPwHhdVx8kfVR
lB1BggUjX9tD6tnwWOis9OdsEjBbX8y+ry0Fk8L3n/J9mFC0JfZVx/NSeBEr
fE3TjwkJoebE9pelcNJfS7zan8nV04XCWt+UwgeH08VHA5jguu2JXXNXKThb
RBp+vsaEkzG3tjf2lMLoDmq7dxAT9n42EK3vL4VA+S73hTeYQLqszNz4sxTu
GH7uep3BhKoT5Tnlo6VQEnco1/UOE1r0dG/vGuLi5O7K03+5eu6SNs8njUlZ
YFfa5H3zAx6EPKdLTitlw/XHxBe7HuNB1dw37W9EISSR3806DRejOJVdz80k
RWPoUJ9d/O3jjjJ4Tt9t9yaEy8eTZmVTg8rA8Mm2oT0+/Pz6DyFu9+N/08Fk
XsfesaMEHBd8aT3CxaNN3yuyf3DX89ef1od/CTPgVuiP5mYcEa6WH5N7TWbA
b5sL0Y0VRKi+bnX1CXf98drXEdFuWmLOgAZvwUHtg2UgfubMn+u7GTD7R8T0
5P4y+DAiI7BOjwFhLR16+FtFMKBjhBH7WgryeZajaalF8EhGfmjDu1L4/bk0
WTIcA+f2i/++NlgCLOLaiF59DFyW+aVvtZqfd3hlU8KvcIFSsLWuwUWfwyB7
Ec+O9XFZaN+9A6WQFoLFKi4shkcS7+rOLebXmzyQ7vkp2KYCHCu8CWKCeLia
TFTdKVsBd5NVWuUf4qBOr0ysfk8FRI09fpn+iYX0/5tbZIo+pbDRd2s+J6dE
JrDhlLzYhsxmAphyGOftsrj4USh+ubl1GbgaYU6QM9iwTE9tu71RGbIvv1sb
mLuqNhBM1Cqey18sQvZvnr7zzbJjyNP9GkSNTt56c52CrrvXtT+ql8kHisnq
0/sxUSA7NfInbZLLv60N36/cEQ27jwQ7r80uhKqJ84Eb38TBx/pvZ/X3FoJH
rJ3nFfFESFgZio1yL+T7p86FG1lw5QLPXl7O9rTACcdB5m9R55FTidDrITtk
nItH/ISn3/xY4ugew8V/6osO7TvIxZu863t3eRndc6EgOmkkY+CNPxWSnrb/
PH8oHR56yS9PNKPC7W91zy84ZMA6dbPlXfZU5I961pLcLe2eCxG0qpxf6dlg
3qu/f8fZPKgpTan9zcxC47dE8e/6QsVceCDo4lCNLUL2fUWlrI51TgREx+Lj
X7T6UhCNN072UaXi0ToqjmvSUJAnI/pStcHdDfYY6JIwFfB2Kkb/a6e30cPO
FcNt86v4luD/yTPQ6a4x5dfpqR+OefdNGAtHRmpJzCo8aK8NS/jM5dPLKxPq
XlkWw9F2p8VjiqXQJM3aqtlcDGavBz/daytB/lbDkwNWprNcPvJLcIvQayKU
v9f89nVBGQQmdHYLi5EA07Jyl+1Xrjwv+PTg+C4isBJ/rjWzLEPrsn4y68lF
7TLYHLY7R4lDROuzH3s4cki2CL5uvrXvM7UMZl0+z9wQK4KpicQJkftlsFxT
6cfUiSKopJ1JD0woAxeb4NGl4zg436s+kIEhI/9jSwZeg5NGhge94vcEdfDI
7nD6471fMRZM+Flby76CJ6P49EWpX+38hMvhE27bnzPHmUgudMpHzkkGEGBP
5PCFwO4KEJsebr44QYAkDOm5dnEF7DlXsdLqFh4cUgQP3BmiQM39s4+aw/Eo
PoXnz7fS2cW53UUBpW3Lf/unMKHDFjMvvY4OR4fcIuxITJQvybMPduxqvEw2
oEPa1PhB1nImqv/nYh5zLlWZKx9XUXQsFFLROiEGUmZJ/jnIDn9x3+suid25
MDC0sEd7IhtiZoZv7+3OgWalp8H3XDHw6I72sikuXisMPap5HY+B6b8ro365
EZBedPKR/+J1r7l61Ivpk1OLSMhvEP1Lts/UhATbrGs/Br+lI/shfQaT+P42
HTY5ND0u+0OFgulyQfItOkyPSL72/kyF5BjSZbHr/DpoWoeXPZ4NZiL9J9R6
m5x0FBNiFqR6O+dVAK0zRCUhgn8OVFDy2PVcrl5RITuoXFldARTn034yXlxa
zSHHpp7L9+L1/m68UgmcTSodwQFMhCMue7vvGrPkys1rOm+mrThQ/cdU/0xu
FBg8ya1UnAxDfpNn9vi7y8kR0NrEyMIERKH4L7uKXGa1YAzKt+LpKW/iH78y
qgtD9ZWL6t2aBW5lwvj1j/eznNnIbhNWUx6vfYYN9rEhyRZ6WUj/oDb0i3ip
Y+GefvvxnUsYMKeC2b5ODIviGb+Wx5T9hhJYZGz5S8KIyx/Lt5TflClBuEdC
/1fIoB8dvW8y39VuwfkUYOh8e7i7go76xfPrFuU+sy3IyAThlTVbz3NoqH+8
dfpnUXUXcTseJOwT+m1CCoE4tfn2uEzZP35RCGaXvh1cOkeAPl/spgAqGapU
VwhqcPE2aj8w8doul2I4tGb5hj4ujiXIPrSk+RVDkuunHfs86TC3IJRu7lyM
+lNY8GPXOwECCO5yWcu5S4bzW24GlRWR+PUEh3+sdP5OBZFUsYKqaxSQZ0ZG
xMowoP7D4olDfRSYXWGgEvJ/5QOJtnllfyPTEa5L4Zh8x79kwHFL8+zr0hXg
Uftr+emzvDqg5bBvlbj6pBs//w87cu+U7FE2WufOGg+/nOXq37zv++B4957J
QjaomWXWJefR0X7EB+GHak4zQan7zbuUDWwkDxUrdKtHMXjA98insnIpKK5E
1ape1bSzAuaTv8xFTGPR+t9UW7+vZgsOJPNi1UU0KEjPk4ofvvhelwFCWzk2
qYokMM8hHhA3YYC49/wqWw0SrN911fFvIldPud+qsC2XCDpPn7/CzjDB5Ddu
gYEZ3x6p4qwe8vAcBYquew0nYri4/q5ty7lf5Qgv7/da7NS0swL0TlTSfzgw
/r/4ddFHz1rvZFKB+VviesEFOuJXvHhqqY2pwt920mF/3Nze20UMkBypk55R
pEOO450rXsoE5Of6b18S4AXTZ/7UdiayvyRF239vEyoBmdC3aiJGlZDlK/B7
7+s4aFDcmGGpXwkuDvTuhx7x0DMl/d1RMBFKDyfR2LfS4N3+XWkdT+KRXZWH
E9ZNx3savU6DGiEFh0dliUiv7tbz2u8inQzyNqaxEf0p8FrjM6v0azLaL7y4
J8H5l3TbG6lgHbVT+2ZnHNDYQxt2GKWjfbOKZRQw8aAIGFCkeNUwC8Zu7t0k
m1gEw7SVcwuuZCLcpspQ3xizLRNe7hesli/GIX/76FD6qQedZZBQCB0ai4pQ
vQHefHBqg769kysD0Rt3ctqZLMi8o+T9vrkM5RvE1AmKGtoSYW+bLvVDNd/u
yLDSVGkoYCE5zZu/RffrLh6OKoOGiu2Fa/axYKneDluXZWRIiRnQXnGWBc/j
9G/fPEYG9aiJH2mviuHSva0XGzLo8PqIwKfuBSX/1ikdlKOxRoPT6eC+Z3XA
mDH2Hz/KAKnY7aIrNmMhMUuiwT8oHQa2LH5y2B0LxBZtalB7OtBJnzGxnlgg
OId4cDRowLZSuI5tYUP39C2y7OcKUHHLWTbbyEL7gX7F8/CQJgvuy13Z8Cip
Ap5O5f0049JdI0ajRe8KQHUDlhboVfbv/gKIjMH0XuR+X9vNa0/WaxWiOD5d
qYALh28wIEj4pUzSUwIMyzrm3K/i6wGXK4/qytizIP5X7S/tcgIa/34L2Tfl
HSRQiP/QbDTEgGtWcjKjQmQwfqr54pEGC+lzvo31DkNaXBx1e6d+UX75v3ko
gsm4rGx6VTmcXLF49N7PdHjsPBX3wAODxqv+Vv/b00cxYLosroJxKR3V8ePh
StZnot7XpGwouPvl+K3edFB6FtfBuZMNF8Ttg3+SCmGfvqyjInd8rYnLErQe
FcKtdHGzFWexyC84qCkSzZZkwYX6h1kFu0iAO2MkMr6ABX55HrWEFSS4b7mz
p30xix/vO7Lq+toAGghfSdOLvFYKe7Ovdiq70MDr+Gjt8H4cqLTaNOkuKAeB
OteLo6dxkOMgOB8zRQaRuYj0oh5+PTvP4qLLHYPloBd9kXXFmAWTM0IDBdIZ
QOvWKrm9Jw3iz1nfoZ5KR/uV9727Vj0N67qahuz8IltZy1gpqfDsmjyOfpRv
9599+PBhVm8m6FwynjZ2TkFxBR2qW5xSspKB+E5yvYZUFtrPr1xd3lfvzkT4
nrd/bTY+VxcvTIHDis4a7StyUD9E59fPpTzPhsha/yBbxQwI83XB+yuko1+e
HdzGzGLnj/tF4JSdbpRKy4dLITePBd8tgnCXVjuLORK8fkt9dKCeAj+qI7Ue
nCeCttKvBOUYGoorOMmU/WUZggPc/v4Xt4RwiF+EXtc2S1MpRfPonS8PseJ8
+4HEJ69A2jD/nJgc1/7JT72VQOrNHZvEE+EHkT6W8bcSrNc/cpg6RgLnWLtP
2EU5YKE4pRWNv47w4hzn1GLMlD8UH32K3aKZg+KX9Jd/z1hFzwF/lldb1c70
f/KxCOqSlVfG1pBhol6pbFcVE0TEn6VpJpcjf3GSqP+T0SUVYBk2d8O6lonk
x8R2be2weCbKm+Dh26N+zXYJoeWgbUscwgWR4PKP8QOpdjRweqPuqFFFggb5
rHrfozTYjPVWfbCNAdaKX62WqLBhem1hRYAFAza+v92ps5V3DjgDDo3tfhy8
mQ2Lbz2wGPTMg6rhDAGbA6lovso01+krnktBdnm76zat49cxIL12QNDgWRHi
yzy/c+tT9YXnMDiobvC11LxSDDdJBUslc3CIr2ru8ph62UmG9GXuuZffE+Da
7i23sjNJEDyv+kHofBnC0Tw+U7nojuG2WyQYlRoMCO8qhc0HRfLfS5NBRXRN
RO6PUpg9qGP7QYyLg5TqW4xlK5EcGpj3bktVqQQf4y/r0yoTQa6m8ELMATbC
+Zv1ZrVfGrPhS5cbKfxoDlg5vLtlZM6GN6vmM1NY2TAwUOFvYsWGzO1XWjIn
s8B/j8XPGEuufs80XZignY3wT8nVe2WPCnPgxYbyKNYcFemRvOsp5IsHpC0w
EP0s6I0ad1//9304eDHTeqzNgwkXnnj5eBeXQPOAXfWOM0yYPpqy4n58CUCb
gqhfXRHCXTz9c82BgUR2NBHWEqSuu8VSwGumTCs4kwieNvv+3syncOd5T1tz
AhH2909e/PuVAkmCNlbvfIngNElS+n6PApQYl23Xw4ngcONx95sKFsJX0UoL
m7TqWMB6brT3Sx1Xrx0c8r3FlY8tZ08f3EHDw432ko3pr1mQmGSjt/wvrx4S
C0p6jsnq/cIheVm0MMX2+0E8vIxP17mVx/qHX/DwHpMTj9mHAZbNEjcbBgnG
8kaxV0Mx//YvCd498A9yXIdB+/W/uAcMnN7ltke8ngQa3s/PX+DKk2CH6OWB
+8og2y7knSJXjuXt0Hm4hsyEM/ucHnpG8+vi/Oc/4t6fo3xPoIwNr8h1a0u5
659n1+D5p/feHNNbgyNAWd2Dhs9bWChOr2hSlP1GggU7nceEsF9K/41TGjir
VZ4z/4SBfSexuEUO6eCRr9NwZCwb7ZcVO78+YHL5k4isBOE3Nh+CziQcOGyL
Q3xHyefmmi8+NDCQ/BiXrUCCHEvzmmSuvOjGz9Uod+BhW+hefeNTXD0DJ6Ns
/AoPdjEzntbWNBRfs1ttYaXlQyJ8H7ZIKbWjgHNMPHVBORE8zFeVdwlRwFqT
1SL0jgh+r/6OnlMrhtsP8+cPvsCh/SQb/tlFtK8MdGgtVym7ysAkX3eugIuP
ru6tDoq0LIO6AzqNcTVlcO/t1wUeTgxkL1LiqCndPMAAhkwzbuzjHcgPuLRQ
zooBn8x7xa7vugOnLJgiMTe543vy3R+HhEiYq1STLdjNQHGgpx5sfWP1NBbS
ZdzSTbNuwe4P3qd2iXOfv/bM9rNBIqR/HLDKe3gXfH01rY5lpcOfJ4293lw9
esHPljzqzzxIVIn2vTyAgYsueHPKomI48XGgJTEaD+WnKzYtsyQj/edtfOL1
6WUsWLfgcDE7nQI91g3uElIsCNsodSerkQI7D9SrtYuzgH1mUNL+Bwaq2/Rk
W40I0N905nlSEVceB6b+jS7h41XnMf2tat2FsE02PNPAhYP0SJ7f6+9H5/j7
2yvArzGyXXgjEwRFBYzT6ri4zIEwKyrA19NHn+Tvv7WFCaL1EhSxSDqKz5gM
nSHnuNPh/Me2M7+XMJFesNRJ0p6wtAwity0pP7GInxe/hzP0QtmdA2rOR5NP
naFy8a7n0deOHPAixJ67o8VG/Fjhaq29I5fP8+ykXdbbt8kcYaP9br5x3c2A
JXTA7HENi5PLQO8nOad458kUgNORQDnnqFzYNG0iJHQQC+3xQ+FX/Thov645
TdM8ZsdGfP9tb8fKYW8m9DaIdA5eyYLdSxOyXuxhA0vLb6xCAgdXNo7/ZJJC
gMNatWd/awx0f3MWP8Hdz1elR02f/s2G64I5ze8XYhCu4u3/xKWS8veUS8H8
wPeKH0N42NOeWxqYU47sQ482eZSvY5cj/V/reof0yu5E9D2dawZv1ohnovfJ
qfiI2kUVQ9njvq+HmsqQXOLpAaqGU0YFnmWwZqvVqS+NOITPeHkjm5LWt9py
6el3Gnn0rTS4KhD9clMMHY4qrfDS1auAqtHfTUFcud1+ZtURmlcF7MCzpoJi
mHDzU/KDd55MWJffmEtcSYTq/QTsrVTeOYshcHq9C3nb+3DI0zMYsSyPBPmb
J8/avr4NX163KlGtouHwwOHpZwFJ8NMjuvAgLQtEiErqCtswCJ89XVNLMjdj
Izy0f+M60VrlSrReV1s6ODwqZcKd1nXTP2K4eGfzgtkM/yLYYK+t0ViKh4mw
AkKYPHdcxoIcx2ZIfPkWYJp8SZsM/r2SR1/eI0CH2UEzA3kaqNrtGjd0IYOv
3HYbiedMkHswGUa9yIEFWtnbzdj/cy7lRcmzlWxQMguYXv2KiPjyKtH09kN+
RKgya1j0gM5GdUQs7V/ePuJI/ffLgbl60RUbtXMhcGSHwPqG4n/2hRwY2b4n
SOBzMbxYrfhNMgkL+7sDnd72V8C22/Mzh1ywyO713z7Cgv7iTa6Dfyqg9MVn
o2tiBDj51Uv+QQQDjK/Xael08s/l+G+flMKlNUvaHOO5fEvZZlCxIg0W111q
r3lYAJJK5Qfrgwmwf3JhX90gDbqCiPcXvmUg/33jyM2/k0IEkGmb/PKigAlq
+ySv96wgQFLXbJtJHhPu5uKnW+QIsOTbwur/yZcyD/F+2qfDRnk0C13c5bK0
2dB7+hv+96kiEGdc+JbJvV5+V/LcKUYRuNe99nmiggOzYBPLwNSKf+OBhZoL
ChnteRR4x/yWt53Ln/7DaUSYVj/mu+4CB/lLxn4dKOo8SgSb73paDlw9rv2l
6w9p3SK4a2SGvy1JQPaq6/IGDqGepZC0L8pC9AUGSvHXHF0flkDh0MvUrSfw
oBfhpvHsezniIzvzno91d5QD86X541Z/PMIrz7wUlE8L3gWzPkv/d48S/9kr
SkBZY9hNPIKO8Eyam9LUB1c84qdR5X5u9wUJ6PpB6sm8gf+ztxvh/fyNKZlL
/e8i7nngvjA5JFJ0pf2pgKqp+rab7He9avNfwbPSvki+RdgQWG/2zFnnVsmx
0t7m8dT1+SLb7FuPNM9c3bbGXrto7g/mo1vsr/cmsf+x2my/Ia6i6IHzNvtd
CxkM52WutP8W/dXqtjPsvLq19sd371KPz1hg//vd26hJsxfbv9WU1OG6uwM+
Pn7VrypZR2IHXP0TB8urO+1n2+/7vmxDwdppcPdXbbpjZQCMf1+mPy/Tp6+y
X3wstLBy8Vb723My9r77sMK+ZnVQ3F9gu/hhYvYMj5tT7Z2ybsqzTiyFl7OZ
F6ynKFxZAy+XTlscZv60F9ZPWGaf5LvHSPELov0c+mlNxmTeTfYVeUI8szhX
wcPNBVxPANPr6TDRK5Kb4P6Ydaz3+YNjW+3/9PP8Ddm70Z5tvjLX5mdz7C0a
F4oaH99gX/PmsWWA/gJ7tZSPJz/d32C/+v02W63Cmfbv1uy5suTsAnsWnnWv
mPcvg/djjipz9pyft9X+a+3rlVOEZ9gX8v89KSW4EJ7uz/MwCiSVA+ujV9uX
G29baK8tVtYVX7LEHgCRh2CB
   "], {{{}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, \
{}, {}, {}, {}, 
     {RGBColor[0.40727119999999994`, 0.1122916, 0.5819972], EdgeForm[None], 
      GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJw1lD9PU2EUxs9FWkwktOTaXLAqgdu7OYt06AKLURgccDBRaUmc/DeYtGHV
hE9AJ+KHMO3Q2LoyEyfQztDZD+D5eR6HN+/pec+f53nOuV1vv3/2bs7M3vq5
4WeQmJ34qfnZ8XM/Nev5vbFs1vbAscX7uR/yrhWLveAFDt0+c3vb766f725f
lMx2y2ZVt5/Pm7Xc3p+P+EI5oyRijvxeSaM3dZp+t/18dftpYVbxWgeZ2W+/
f/mZuH+vHPaRsA8U/8Tjl9z/Mot3cuh7KXui+gNxOC7FG/6Film5EppM/K5X
Azv9wX0qfUbCCXZsOBa1yG/noRn1xtJhmMTvunO8l4ZOmd930+AJ3sHNqE/u
sfDQmzf86HUnjb748cEdjmjxX+896cnsSo7nwVxg7gkn77uK/+xYX7jvz6rZ
ahF9N73H4lLYYAFXRRjo1VJ9eCSaeVNaVrUbV0lw3ypi1h9q8T5UTM1zO5oX
d12aTJcDN5jPNVd2CR74qYkGK9Kht2F2y7Hu5KHXUH1n6lUT5gvpeZjHfA/y
2IVL7Qac0BReJe0AGHj/UYkYsNELTXgvaU9G2gl4XSl/LE3R9vG62Zu10OGj
69BPgiu8urLRsaV93heOU+0YGvQV31E8uj1sxI5uNgLXorCxs+wMfL5lMUdm
S8xU2oIDPMxnOw/fl9uh8VTf/FYjuD9qRP8T9aUntcE50g6eae4zaY4O1/p/
+LQWOrBrQ8WM9Z/TVE38zOjfbqgXuT3F4GcHf5bjO3yVBUe+9Zl6UfN1FnH8
Z6AfsWCDGxw7eejXV9+u9oc9Ym7gZqb0QR/y/wLJLJZT
         "]], PolygonBox[CompressedData["
1:eJwlj0FOwmAQhR9IC4mmNcGmIRobabtzq61s4QQu3ClQDe6Apd7AC7jmEMYt
JJ7BHWch4ZvM4iVv3vzzzfw3zepx2ZZ0gTqo6ktfgXQWSd/4u0J6orGLpYfC
M+udoo+hVBfe2zNzSFzmjfGTSi8owl+eS3/MPlP/9jyb4ivmt7HvsF3zXAqp
u6iE9Up92/bsDT/Jfbdl49yZxjbGPfNN7rMn/KWmt4ZRUvyHUsYnB2QpalrS
CC0yuC1/846/opegjfzNnBvjwG+2241hLMtm1Nd9ZxrrEx0B6Soing==
         "]]}]}, 
     {RGBColor[
      0.29899359999999997`, 0.13914120000000013`, 0.6854056000000001], 
      EdgeForm[None], GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxFlb1PVFEQxQdWYWF9Lo+FXRMIT3aXUjsFLBWMdgqRDpWPZRckaom4tKKd
DaCGoImJtYkBG8kaCyNG7QDBWPgfABWN4PwyYygu773ZueeeOXPm0j58r+9u
tYi80hXTFRwXKYUim1UiT/R98phIWt83dH1Iiqzrs9QoMldv8bmUiKZLpz5H
IpH+hMhMTqSgq17zi/qcyloOufNtIgu694U+0/od6Xothr0YM3ww0h5f1rPq
9LezSvJXILKtS7fKqTqRr4FxnAktvqR7DzX/QFdFcwZajP9aWuRNXCSvmAWv
ZUvz18Swzyi2psm4c4Z7rebGqanaMHkHl/NqPb6i35Iyjp9Pi3zUzxstlsse
cjgbDn/098GM6TuUMSxw0s5ZHLOi63GNcVrX577ujasuq0nTiD49zFr901mr
Bc3QZLDVdJpt0loU83uD6R7pd6/m3G82nbZcw66sadjtfXhbbZrDCc7Uc0UB
TuiqiVkNxL+kDWPDzz2XN36d+ryk2v0+KdKjz13dtxMabjE0/uw5n7c6PumZ
P6usPnqBBiuNR9qiK/Uk3I/kEH/vOfi06L9dTZpeIzGr+1uD6UJ/l90P8OF3
ziQHjcjDz7yjFXuIUTt+e5A0zRq1npda11SHnqU69qhH+yPjfOhcwSg55tOE
ceI8eoVv4PzM/c8coCv60pu/zeb/rvwRJ/owljNvXkiZfqs+J3uhnQE+i9rR
sZyzHl6P7BzqoZZyaHWjIZ5iHgquww/3CTN94OeiW73PXRDa7OCBhPuh1/tW
cExy2QPXecWJJ83L+Jg4+jMXtT5H9B4P3NRZGA+tl8wGtcS9RxMau+Nx+oD+
234H8M683/KZYrbgAj/4LLoPqJ+ekd/gvi17DnWQzz540SNqZx6Yi3LWvIXH
8C1evpgwfUf9ruPOwwvEl5xzwvWhX+ylzq6UzfVwzmIlj3c0m05DGn/UZHoz
x0XFHVDMscjuNzjDvS+ys65FphO9hP+s7y0pTm/WvHtZn6M568VIzjDAgue0
3yGTrTav9Iz+o0ng88687PnMbPq9iW7dPu/MPVx23Fv4cc/nHQ+n3Xt8k4Nu
/z2BH+jthGsFDhhwA2PXcdBp3LWil3iaOwfP0l/6DPeKY+74XrDaI8td0D/v
MpbLnD1vM17c2bczdj53ZML5bHof8RXvYJVdtwP/31fx/02HfrcQK/kdwv2E
tsw78XnPD3x26BcenvGeMluBx/8BLS4EEw==
         "]], PolygonBox[CompressedData["
1:eJwlkksvQ1EUhZdHGyrVKn2F3KvubcwMtZ3SimJAGx2WlrQajceAaNRMhcSU
IoLET5Aw8hiKgT8gJn6CMLe2PdjJPufsvfY63zmR4npmrRXAMKOdke8DrlqA
627AZwHVASDUCTz4gKcQsG0CW4x9njUY01Gg0gO4HcBCEEhy75O9Jy6gNgTU
GW9u1dhl7g2ods0DfLM2zP53L3DZBtyx/5jre84aoakDevkaBI4cqhFn/x57
sl3ALb3WmZcZLo96LzHf9ANOauVYU6bPGeqt0l+Kd1qk/gQ1PqhlsD7C81gv
wON/D+KlaehZk/7PmMyyZoxaSUbar3eWu/+Egd+wMhE24lm8Xxja+0KNc0Nr
pDYdAaYYG371MsmhCdYXgspOPIrXPNc3UKbCtkEGpy5lOs65BcYz2XTwzsvM
47aye+Q6YaumaAsDYVFkzaFTe6Jcr1jKVphVmM/3q9cqAeaYL1mqLTNl9pyp
rIVBhnnWVBbyR+SvyBvKWwrTFNm+BlRL3kzeLmarN7nTqK1/Qv6GMN9h/gfk
OlPe
         "]]}]}, 
     {RGBColor[0.250728, 0.22538600000000025`, 0.7691520000000001], EdgeForm[
      None], GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxNlcuLm2UUxk8zcerMJOmXzEwybdK5JKlQuijjxrHQVVHQutBJp6500UVV
mGZw1Fq0bhQE0V0VW3Uh1D/BlYJatSJVJL1QcSV4AfGysNKFG+vzm+cIQj7O
eznnvM95ziVLxzZWh6WIOK9vTN/90xH7JE/1I7a3Im7cprM9EU9pXysinpQs
dNZuROzcFvFuN+LOWsQl2f29EKFfXJjzfUffh3L66IxtBrpc1XdoKuIhyXfm
I7oTEc90IkbSbej8s5LtsMemrjd3NXx+bjLiQDliWev7ZiNuSj64YN1diefb
pYhHqhG7hety+gHDPyW/i8318Ygl4Z3Q+dSOiFe0/0Tnv6e8EH6XN7/R+sV6
xEv6ftP9yzOWr4mTB26P2BCeu8u+R69as93ZSeOs1XzH+eSEdbBnz3pV67vE
wx7F+svOiKuFce0VvnWtT+hrKa7zTcWs935ejHhVut/J17BszniLN7+fN963
JZ9ri9/tEb/KZ2d3xIp025LPKn8z8vlwyzkm15uSK+Lr9UrED/JfFM51KflH
wi0Y4Q58pbp1sGd9Retq6iLRbxR+izPW+AIfuaqnDrKROsd7zsdjPccGv3D7
vLDtEF+nJZ/QXUU6j0teXDQncHNk3LxgN50+eetE2Trk9Kg4Oaz1muRay3E+
3XeNYwvPP8nnH/L18ZxzQ01gSx7IBzye1ttdYXihZ96Xs07WZs053F/sWxfu
yTt+8Hd23vl6c961Ru3tlxyMOwbwU7/kF0xHW47npPwNC2MF5/Wsc+q93fE5
/Up/HE7esMcn+shBrqkJcJ5qGxd8goVaGmW/ULPULrVa+19ut+qi7v0d0jsy
5d76s+36oJZvlXx3cJsl96zhiX6HK/KJfz23Jau5pl8vZz+TB/L3Hz/owCE+
8MWsoQ/B+NGcY9if/Qv35Iv1KH0SF7MMrv4SV/dM2wdz61rh3tuX/U7OeIs4
qW3wl7PO6U38jRLnlbTlHHkte3iQOYdz5k6RfVRNf1vrmvWIfTBruw+ErdGz
PrOTOFazDsfq5h+cN3qOqWga263kGZ2riRvub+Y5HMHVesf1eyhzdyBnGFyc
qbgG2X/ed91/0bdv3iDGTte19T4cdo0BLOgOc15Rg29U7AefzBZiXM73eGuz
Yj32zB10vlQsXzc9VzfVO181XQM/LtrfmfTJfwZ1cLLj/Ub6XFpwHd/b9Yzf
m3P+YOYAzgfZZ42cRaP8f6F2eAueP52zT7DA91jmnr5kLmFPTtYzXvBhe6np
e/4TN3LmUovv5fxeSf/kZyzziF+4BeO5ef/PvZUSjuBnmDyC+V9BeOEg
         "]], PolygonBox[CompressedData["
1:eJwlk7tPVGEQxU8QNizg3c0FdjG7LO6DykoLg7YGE8BCeVY0PjERiKhgFEsx
xtIXPgoL/wRttFEjRDCxMiZWxkQTE7XRaGn8HaaY5Nzvm++cOTNzq0fnR+ea
JO0lmolnRSm7TXqfl0r90liflG+R/pA01C0tNqRO7t6R+6ki7euUUvCtDmmg
Jr0pBL5JfN4prZM/S/4A5GvgY/D9g2u8XToOPkIcANdy0nJdOtwXWj4bBa/D
sQDXvTYCvb87uCeGq9IIsYn+nkQ61CpNlaSv5A+BZ9F7Sy3n0cyj34SHcbw9
JebyUdNr7u7AuRu9VfhXwRfxXE7Dc0o9C73SfHNoPMLfE97f4O4XUSpLvZxN
b4+zMvhxIby6hjVq2SxELT8z0he+X/ZI2NrifNUTPXKvbhMb5C7DkUuip+7t
Jb6TJM4ugzc4+5gNzQ/4v1uJ2lP6VYV4kZpq2dAYJPd+JXpnj/b6oBKzc85D
8DT5beDv1LfSJX2jt/0tsQNj3bED3oVdvBmG7xQ9aWdWL+A7Ab7Gmx+Z4DDX
BDMYaY2Zbc2uEW8TOM6Bp+hfFzglLvB9phza9mivM3B25ILT3Nawls9Og6/U
Y1e8Q96lJXsmrnK+Uo8Ze9bWWIL/YC168xw/g7XIca53yLuUL8SdZ+7Ze4e8
S+6xe/27GLP2znh3zjbCi3dqgu/95FzPRE9O1sOTvfkfmSzGTD1b92QS7v/K
8HJ/
         "]]}]}, 
     {RGBColor[
      0.24540959999999998`, 0.33407080000000033`, 0.8066976000000001], 
      EdgeForm[None], GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxFlctvlVUUxTfQctvaS297W257W5r29sNI0oEPjAMHGBM1AY2mPBqnFCaa
QKgWRjqX6IDJ7UMHtdchYNHWkOJAGjGxDk3RGBMnYBhgGPgPuH5du3Fwcs53
vnP2Xmvtxxk/e3Hqwt6IuK2xT+N0TXN7xKUiok3znH5+sifiSCniV42qzmxo
frct4pgurPRFfKnxQ0/EQCWiR6Nd9+7s8XxV86zOvt4V0aXz5bL+dUQU+vdG
l/dbOrOm/fHeiM/0XTkQ0avxsu69JocTnRGXRyK+FqYZ3WsJ43mdPafxvc7M
5BpszJ+2ez0rTFe1XpXf5T7zgsvNDnNjPdZrv3XxnK97PtyIOFPxP75f2Wc+
cHlQNlfuftww1n8mIu72eL+s8zPC1yf7bx02P/i3Ug/0AQcDTNhcTg3RExus
sc+8kvt/SoM7Jds63uF4vKT1B4Vtzhb+z7nt8N3ltPP7UxFP9ouf7LwwKJ9a
v1q1bXBjn3kz1wziCzb0PJ+aEhtsPC+OGwfN9cKw/EiHP+R39lDEc9LioTR6
W3tbndYBW8QSv9z9sbC99ZptojN2J0uOJbG7rTOTmm9oPil+UxXHHn22K/aN
H9bEhPvE7Ghi4v9cv2NXZD5Oa39TNreqPjudNm+mj+ua1wvv3yocM+6jAxzg
wh5YOA++9+quh/c1d5cdA/RHS/bR8pvi//xCJ7RAB2a+wUSuYP+sNFnMOBLr
xW6f4fzPVZ+FB/FaybojzytZL8Oyc012NmrWeL7TepIvzU7nDBjRBG6T+10j
2OVsM8/v1hW1c6rmmvlQPOayL0zXjA9b2EEzNIXnMyXnKL7Ic+6Sh6fE/zf5
Wxi03+0O+1lPrP9qHh7x/lrqgA/6BljID/BQ/8RtTVj+GpVN5dBlrY+Ouqe8
qPlKYb9g34l/h3OAnCA3np0w10vdxrk4aGwN/T8wZL2+0/oL2VqSzc9HnWNP
MoeJz2LGmlwnF99puOaOZc5sDvr8Xc3r/dalLNtvyt5CKfHstX3ylrgNZP/c
7Dff6pD3d3vqvTFj/kr1d6LqHKRWqAMwwO3KuHTX+py439O/i/r3U/YHchQ9
zmTu43eo09j0uVOL/IMr+hzJnn9ywJgfCc/fw85V+hx6oRuxHRH/G7J/iP5Z
y/dDfo9XzYHcJA7w3+U+lXV0ouxegLbXsx5XC/u8ltx/EecFcX845p49lu/F
R9mH6cfoQE3QE9qzzxILuE5lf2gbs7ZozJs2mRzBTu6Rm2Anr8DIwB45zFtE
P0Wf03Xn5tKg+0Mr34hb2UO+LZy/1Ecre+lMvlnECpuT+Z7SK7Fxf9y1SK0/
EM558d0S76LhN3KiYe6s66kf+OBFHdMLdnstmqInbynfO/vtnvFBXlDz1N7j
CddW6aBxYRNszW7nBjXCGjzkCXvNXGMTzeCFZkupG1qhE9iID9hWs4boa2Aj
ns2swaeTI1x5N8lh9MU+trn7H87DE5g=
         "]], PolygonBox[CompressedData["
1:eJwtlEtsjHEUxQ8z7TBMOzXttPPoa2YqJLMgrTSxJEg6XYhquy82hKZFO4gt
idTCRh8sBNtWQ2vRSkSpxbAT2thYMCIeEZEQK3631+Im9/vf1zn38bUODB46
tV7SXiSILNRL1yqkiZDUUyeNNUlXw1IhIt3GNoBswV7aKD2NSQ9yUn9USpLk
PvrLuDS5WfpeKS01uI/5LpDveFIqp6Q76zzHR/QdWSlCbJn8O9FH0lIW/w7e
zqKvtEp5ywW2N+i/E9IvpIDejZSoN06968j7FukyOS5l3cd8/8LhFbW3I1V8
PwYTpddiPuD/hbfPSBEs5wwb+TppxBD2Zey74H8g7JgNeynmWN6C8VZGOsxb
1wZpG/nna6VUI1iwjSNp9DP0ZAZ7gKK99G6S+JoqKYpcJP4nb2PYjtWQp03q
A28vcp68F/6L6YbRsN6NOzarYbWMs3GfQF5gC5HvEfhfUzNF//r5DlY4hlGw
NFJzOuI9td6WWzzWOBv3SMK5JMh/kvg94L1S6ZgN+25yPKn2mS3gH8M/H/Ie
W6+Ng3ExDIblW9a5zgakr+jPiR+MOudn6CPIStgx9uE/y3cP9iN830M/mPHd
yNPzAvU/JXw3u4npZDZzOfe1HZxHn865r+WYQW/HZ3/YZ9hh/vXeG+tBOuMz
slkZpmX8j2IPRDzGYodyPrtq7KdzfgN2C9aTdnYpFHdu1oMgvSw20+dm30Hb
xeFG3xW7CbuNG+ScCjvnd02+47br9naT74e1vqu2U7Zbf8i1uslvYl/MORv3
Rew/sA/nHFsdUkQ/kfRbW2JGi9SbAmM44JxGmXcWznMRv2m7bfMxX5vp2mwb
/HatptVuy/htW8zWjNewWvaP6ALPPzhpmqw=
         "]]}]}, 
     {RGBColor[
      0.25730520000000007`, 0.43649520000000014`, 0.8079510000000001], 
      EdgeForm[None], GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxNVktok2kUvdokDdX0kdQmNY/aJNqdKHUQBkFGKCoiDNoBJ0qLNUXUxhEs
ulG7HBhk1J0KtuJz42N8NJVRNx2oYHVhq+KuVbBYcVR0JTg653iu6OLn+/L9
997v3nPPuX+au35bt3OmmQ3jqcCzJWy2LmhWCJhN1pk9xbMUBr01Zomo2TzY
HML7X7G/DYcRvOuvMnuM85NV2r+fYXa10uxJyGwt9nVB2XFfiMqXMTI5sxRs
Uimzbo+ZnKm14HueP67UXX2wfYT9Ley3zzU7jzv/iZmtwTMVMfs5a1bTaAYz
W4azDDZTeN7h3s9zzAbgF8P7S3mz9lqzi1g/4bwf57U43wzboaDiD1erdmIx
ntf5eNysKWFWxl0tWb0jRozP9zeCyjOS0N0D8NufNDuOnKcblePWoPA8kxFW
pzLK8T/gnsb6BpjsAdZvsU7Bt4zz51hbgdEz7B8ih1hQ58S1hPt31gmLq7hv
A+q6hvUynl+w/wvrRLXu5r0dXiPz/KNePTuLHC40m7Xh/HBcNqtDwuFIXOd8
3wtO7MC9uwOq9VDwW18O4OnEU8QdJyrUg+lZ4g05U0acP2G/PqV+Mj59GXsC
+afgt3w+3mM/iXwexNWPecCyJSRf8oGcIrda4LvAz+nLnMgx8nAUtd6vUr/b
k8qpXC+ciBdxI4Zcycl7Mflta1J9HwKKtzEgPVALVypUTwmx2sGZ2fi9Lyme
bowqx12o9WhIfAqg6Jewr2yQ30v3JQ/Ih3Pgz1BCvQ+h7r3Nqu14QvEKrpG/
G5THj3nlxNyYcymsOMzjp6zyW5w2q25U3eQ748W8RtbGGk9n1CtqudPXRt+T
d9yzZ9yzFzz/PSKeUNeL0qpjIdZwg+59Da4O1gtn4v3cefsD7hqLu3by4jc5
zDijUWmHnDyZl14uAYPdNcKKmNHmblT86KlTH+hLrTxzvazKiosnYqqbfS/5
TCIfaE/NUe9F1+uEa7Y1I3yKyHE8I98xrItz0v+inPjCuxmLD/eMWUqJ5xHg
PZRX/8t5za5u18U1n4HkKuvY6lylLu+GlQ+5ctR1c9N7vWOubItu/zAvLVAT
1A85PxTXLNwc+javqHPiyR4mvI/HYtLfipjm2aTPtAXAbRB9nY91JKJYfa4n
6opaY17ElLkV/Zz5fJ07xIPzu83zJGd4JzkxSCxQ53XvO3v3zntBLJgn11Hf
syf8zTjEptv1fiMuHdxBnFc58eNfrC9y0tt0Ttogbl/x412ch5yFnDWMxbzI
KebW6/qmHkZ8dnz5NgXUX/pyxvf5TNtUK/4w94PgRxfWXFZ4FD3P/VnhTLxb
E7I55dzv8B4xF2LO2VfwmZH0eolVt3932R9ixdh8R5uesGYTc+cs3+T5fJl/
3hfqus/vYu84B9m/fu8hZ/LFZtnz28saR7xOzpJex+Rjk3z4beR5ye9lj9o8
N+bJvlILnGFp/86yT+zXyqzyIQ7EhZwkP4jnEtcd9Uc+jrrGB3wOcB6kU8KH
2lrtcW75rLniM6/H5zn7RZsO/6aQ58OuBfag67u+HXB8+L+Bfl1xzRLOONZC
3dCGObPWjNf1P02sSSI=
         "]], PolygonBox[CompressedData["
1:eJwtlDlMFFAQhkfBZaMuLK6yXLvA7iKdgYCVhYmJUaIbFcFgMDEu2HisJp5E
sYVYeDSIJKARj0bwQI5YUlh4NFyx8yg24hHt1EQTvz9j8ZJ57838888/815N
5kRLdrmZNbPyWf3lZgsFZi9CZk0Js8pKVsDsygqzyahZX61Zxxqzq+yn2dcn
zWYKzVrYn1lrNlhq9hb/cTDawNoYJy5oFuG+CXsGn+Mk/LyKfNVm98kxiO8i
uV9HzMZqzOLEb8X/Ovi7uH9X6DkayLXAWS/cPoLZCLcB8tXlmT0Fo5V8l/Bf
Ahto68G+wdkid+1hfFJm4TKzYfxJYUXYjzlr466LfA+xx1Pue5j9E+wEfNPL
zH4jzk1ydUW9FtV4Dq6/wPjJ2omdrnEO4qIYxQpT2K1gjmFvS/zXjrUd+wOa
HARrb7HZZrS9w354pdlt1mXiJ1ld6HULzoXk2U1MLuSaSJslNDlZ5DX9qTKb
Jf4Nsa/w2YSeFyrQG61Wc79vnVkG/g+oPUu+NPmmot7bOjjE0PN93LmcBfM7
2Nei3gvNwCj1fePsVJFrLK372PcmXQNp0RBDtzzvcT12pMy5a6/eT6PBgbDX
sCPiHMSlmByd5PqR9NzCCJZQf8q5aeY0e+qJerMfjAnsZym3X1LjCPHd1HsM
+zT9+kLukbjPljS9G/cz3UkTabMl4rOSAbNRs0RNkyHviXojTuKmGc7hf5T+
duS7hkfK/Y3orSimivh7ce+dZlSzOseaIv4QePNw7aZH56tcM2kXoKZcwGc+
RHw/fAYC3tNP3A9FfFaEMRv1GlWrZvYReMmEc28mJpXwnqv3whBWLWcTIX8D
egt76PHfoOecIl+WmjqDXtNz9N4Q815phuaoZT7qb00xitUb11tXjGJD6DmU
5zM6wV11qdeqP0R/iTiJmzisxx5N+VvQDGgWLlb4bOoP6MEuKPG/QTP2lfr/
ARuQrTI=
         "]]}]}, 
     {RGBColor[0.28204080000000004`, 0.5262284, 0.7773838000000001], EdgeForm[
      None], GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJwtlk9slFUUxR8USm0z03Y6nXZoZ9rODNGQQLSwaNMQY8UCGxP8ExGpMRqJ
RlIaCKKignFjFBMLCRtj1BZckGJCwFZcqPHPDjWWihBbogkY2Siu0eD5ee7i
y7y53333nnveufd9fU/ufmBsaUppTk+dnt3dKX2oxWAlpWutKV3VMySHmY6U
Ljak1K33/ZmUNi1PaaOe4ZaU7tFzTuvTWfv8vSSlNfUp/az1TtkfVYznGr3n
VoPtvF9UnIWMfUrdts8qz36ta7el9IJ+7yylNKX1Xfq9pBglrZ9f6jy3Is54
qzGMKE4ll1KfnpPNqiXvvLvKKb2Vdx1bqilt7TbeeeWq1lKalm+t5pzE7xMP
R1TLhJ4z2rN6RUorZf+gzu8vZuyzV3n36JlRrDnFWiPbe20p7VuW0ramlLJ1
fgYU40FxsmtlSp/r9ylheU0539a+83p/udG1URf1YIdD9r7f6P3Hy15PlX0+
32utMOnPouqX7336My4OrmTM64/6PyjcxV7973LeSwL9Zt7xJhVnvzDsa3bu
HTnjAMPdq7z+TT4LTa7/admLRde9XDGPqZYnhLW303h+abLPOnH7mfD/JD6W
FPwOTZET+4D2z3aa/63hey7sk+L2h0bn2KOcA3XmHxzguV2avFC239qSeYIv
9LO+YjzgKpWMZTZvHYOhV7ahNnM2V7auwUTef3qM/7q0ca84XJ+xtom/M86o
p9PxyZPRelp+9ausQzBwXp3i5abitKrud1dYB8/Kfizykh/94APP7TIelsZu
KOZg1pphT59wfKL/laq5R3fUA6fwdaJsbr6qNz8NBZ/ljapjEfNVrR+mfvkd
qrofqGfDMvfL5uCc/vi2wb1JbjQH5q/z1ti/4qYn+IRXtD8VPfKKdDWmvS93
hf6073rJtWMnHlpHe2iQPCMxN17vsj/6JTfvsBN7MuKDcSjO6A1xvV2cz9Ss
VXqP8/i0w3beg5e9cM2MWpfxuTAP+mN9vs1cfySe7s+ZZ/Jw5v1x7qf6vPcd
xZ4vW5Pf5K2RhdD56l73F322ttlncUed+T4T/f5ii32YC8wSZgrcwj+5yUt+
1vAC9xPhw95R2b+o8+/jOc8ZZuRjLdYls47ZBX/ModHwqeq8ZxRnXNiOt1sr
2ao5O5WzLzG2RxzwkhfMzEc4P6y9G1uMD2y/t/o+4N3lmBfwz/uZ4PClFuME
+3TOudB5JnghPtqfDjuYwPaQcpUK7rObstX3mnO4B/OO8D+bNSbwkId81Dsv
TRzQ+kKHuYRffDhD7iTOnbjELxfMExzA7V9Vz79fYyZQIzixMRvpV/qGeU3v
oAHmCRrDF16oj/uHvGgVjq7GGg6mIx9a4L5DD/DOGkyHKo59sOJZSCz2bmt3
7IPCeKJgn0rN+xYjzkDkAjN8wD32L8ueG6ngvNipF58DwRvnz51BLHoEPf0/
B5rd59SeK8S+buclFpgfCWzP9Jgf5gs8o8eTwRU9QW+gL+yVuJfRWjb08F3c
X8yDP6rmlXm5peK8GzRre6s++zG9PBp9RK8xL7kTiXUqZgI6uRZnQnz4Agsc
k5s6wYl298bdDb+ZqKk/uIAHsB+JbwA4uhKcM6vORl9QF983+MMRmMHOdxF3
CfOEu2I4vpGIR1zwT3R47nzcZ/vR6P3moud+S9FaGI44aH40+mtzxXg2VXyO
i/EdNRL6wZ+e4x4F/3/q9kuk
         "]], PolygonBox[CompressedData["
1:eJwlk0tI1HEQx7/layt0VzPXTf//fSmB0LuDkhI9IDvkIQ2sLhEFhaEiiGVF
det1yHOEplmXLQhqt7oUVHSRIg0riugUeamOveszzWFgfr+Z+c53Xul9fTt6
50vahhQjL+PSvRLpPrK2XqqskX4ukoIFUj/vtlrpQZE0UCl1NEo/stLpqDTF
X4DvwaRUjv4R+37sIfZbFWCVSzfSUivxuSrHrE1JL8iXJ9exGLkbpAR/LWWe
owq8Uf42Ycsh5cRejDvWGiQH3oVqaT0FtINxPZROka+lyDl0L5F6sd8m/5OI
FIF/P+887ztIOusxFmt/Wd5fkSHqeb1Q+oL+GRmM+l8EPr+p7xm2K+DP430E
zAZ6AxUlElIKjntLvSarbXUgTWCfhe/GjPfEemOcz8MlFTjWAd5J9GHwjyJn
yHsWqQd/NuI9tF4Wqt13jJiHcP9Ozm/Idgh0ICPoA2Xeg534niRnW7HPyGZ1
ebG0HK7v4dOOLZP1Xmyhv0n0OeIH8e8l54k6aqP/uahjTFLvH3r6jtm9RX7B
cy7rOqn0Cf14ncdegkMXvjfhtI5cm8EfA+sxjs/p3zg9WRl4jVar1WC1dFLv
34jXnKd/rfBdim8TeFHs49TcTP2jYFxFL2303bCdLdD7idBt3XA6BL9r1NhS
4TVZbbYDtgs9+PTBpSTlszNOpSmPsViLmSJ3AQ6vIs7JuOWpYTf59iAF9A+h
78obZEOj/5nNYoJ6n7nN3nbIdmkG+3DMZzAN9uHQuexiJ3rQwxq/JbuBJvh0
wbG5yGdqs7UeWi/tJuw27AbtFu2m/t9W2m/Dej4Sd0zDthlm8Z8M/bath+eq
feY2e7uRFPqKwGdjO7sq8Ju327cdH0KPJXwWtgO2C0/B7I95T+6Sbybut2w1
Wq3LMt4bu4lkrc/c8O2GHpF/a8Z30TAMazr0XTKfGfR/YYCoeQ==
         "]]}]}, 
     {RGBColor[0.3168312000000001, 0.5996118, 0.7208711999999999], EdgeForm[
      None], GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJwtlU9sVGUUxW/FaQuDM6XzOnQ60zevnRlBEjBWSZRAQmVjoiGRaHRNWBDl
T2UBdmEgxrigJMiOjuhGjQixJWXhjigqbHDdlbAgcQNGFrAxEDw/z7d4+f7d
795zzr33e1P7j+478kxEfKlvjb6XhiLulyOualHbELG9FrFUieitjbjzXMQ2
2Vyu6kx7l7R3fSriNe4VXrPP+pt1Ed/qezQQcU/fae1PaLybR9zW+UWN88/a
Dpvvc9ufySJekK916yNe0bi3F3FhMGLXeEQ+GXGemLIdrdiGWDvHbYNtU+e3
hHNM+/1B84Dg69MRq9rfIz5ftHRPduc0/l02Z+ywx4Y5uMAHZmJe01pm8Wtm
fy9OOta9steDhXUrafxnxHfhVZKGC8J6XPOpkrXA5yZp+F7Zc3z/Wbb/wxPi
JoyviuPZtrVCs59z2/2UWWfwPxywb7TdrflyxbkiRk/+O/r6Wjca5vix+Ha6
ER/Iz4e57y2lu/jpJ5z3Zb8qDc7Kvl+zLjvGjRddwPy0bY1/l59F6T43HHGq
GfFHzZjBviJ/VyvG+WPVdUNsaora+ky6faQYubgc0/imzmZL1gl/rJlf1/xK
4nVXuj+Wtjcbxoy+8CDni2uNCR3wDzd0WkkYHow4N+ADx6WkYTfphL+jmfeG
hWcm1SH1+G/HNXdy2j4epBzzgRFNvuoa8/7MfTCaegGMz1eNcyVhAsN8y331
ect4wY0mv+SuhV01x+IO9i8Lxyc636NcbNG8LGx5PeJAz7k52LZOy0krsGPD
HWL+XzfhvJLfN+Tn7Zr36OOTTetOPsELbuoBXc8nbakbtDtETTadC3Iy1XG9
z4l7e9J3Co2nNzp/X0ubt2p+P7rK3eOyuYMNfvB8lN4JYqPnZN0aoj31u6rv
2hrHp5bgs9B1v9A3t8vuSfoRPf6quF7hRI7I1bmGOb0jnCda9jeX9Ng9ZP3H
C78nvCvf1V27XcUZKvxeDBfmAJfFCb8B9Ahxz2x0DV/oOuZs6nl876zaP2fs
L8i2r/szOptoGC9vIJh5X/D3W2Z84NxQdz+hF1q9m5kLnEbr1rRRWL9NSUP8
4v+WbDdXfcYd+OETDrOpx8BJLzZTrm/kzjvvLv1GrrcL8/KYNUf7bYXzOJ8w
Egufn1Zde9Qg/dVLPTZQd56eqFbfHzOmU8pvp2Pu/Af4z4APP+R8JuWdur48
Yg3pAWpnq+IvZM43fUC9EJu4S+lthFfRsXbtjnubHj+iez/k7g3+Ce1kM62x
1HOs9YpTalkfahmfvF+8meSTOXiyhjXjXfwP5njzEw==
         "]], PolygonBox[CompressedData["
1:eJwtlEtI1HEQx8fHquvaavpf3c19/N1dK4IEq4tB0IMeUiRFYWfrEBHaA3pS
SklQdummUp0MCokCD92k7HFJgyCwDtot6O2hDr2gz5fxMOzM7z+P78x8Z1t6
+vb2lprZLqQcOZo1O1Jt9qPErC8wu46MYX+Im3UWzHqwd2IfqzLrb+YX+2eJ
+xT4/pz4BHmGo2Yv0DvzZu+XmLVin0ubnUQmysxmedvMt0PEH0TmyDWP1CTN
xuvMHlAvTb7VodmFUo9vQz9DfHul2SQ5TqNvafBcoxUIeoaYh8ROgS/C933k
PgW+Ud7ifBugZgP6eK1Zvmi2je9bkY8Zs09IHp+JuPfUgj4IpsvIt5TZd2Qq
670BwZ6gbwfvYKljjrS6j3yVU7nv4jOPbwcx99CL+CzU+dsMeIeXgb/Se3qJ
/wkwZ6M+w4A8M41mZ8s9RrGv9JZyTML2iJjJaseUAX+EGX2Jeb4Ufr3ka456
zuPoI9RrI/cavo+id1NoBbNYjvTT7+2iz25ThN03+c61+25yDlFrOvBYYRb2
i3wvEjuEz0Lee1Dtr/hXguVN1vctTBXYV9KLuxTn6D/F29+Y7/g1sdfIdxX5
BfbfSFXouZRD3Dmfg0c595HvQLNzUTPSrG6kfdYd5N/T4BwSl8QJcWOoyXsT
h2/Ra5SYzzGfkWb1j9zz2DqKp4H3pN42wocE9gA5VtY6p/YHPjPNTm8HEs4x
ca2APZZwzqtf9VhPrfbQsVXXMEf0LG8x9Ev4/yG2n3r1ceeouLoudF/NZ23o
N6Jbedti9g45nPPdaIfa5dJGv42b3EMS/w1J13WDusUQjoyAZxq7A7s38FsX
58OC70C1hGkV8euTfluakWalnWg3u6ndhezg+2yZ34BuQTel27qP3MG/b5F/
mmlJo/eoXtVjBrtYdF/95xTQjbe5mHP6cdY5LW4Lcw79WeC7ER/ELfWgXlRD
tf4D6/Sotw==
         "]], PolygonBox[{{7736, 4882, 6764, 5219, 5220}}]}]}, 
     {RGBColor[0.36048000000000013`, 0.6557590000000001, 0.6456919999999999], 
      EdgeForm[None], GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxNVMtL1FEY/dRmxseMTs7oPBynn+PoIrC0WojlgwwyH4taVUILiQgKxVoE
EhRERaVBglCCLrTUNhVubJemtimjZWBUf4FmbYs6p3OlFpfv/u7vu98953yP
qr6BE/25ZjaGlYc1HjHLwLbDLqXNXhWavYY9Gjeb9Zt1wO4qMFuE8xVcHI6Z
tYXNJrNml1P6l++ZRcrlk8S+H+fz2BfgbA1raIfZ9QqzuoDZNM4HchWjBavN
B5+IfLI1Zk2Idx5nh+CzH7HCQbMDsKlqxAaeIPA8S5iVIM6HSrOTwBNHnCHg
mSlVnHb8e5FvNoo4AaxJxJ/A3R+IcQ04FnLM+qJmz+HTWiifRFjffp+wEytx
jkSFJQxOhzPiS97kRr8m4ImFdZ93+f5gkTAwxtcicaaWxH8EWjdldJYF/lqf
sBIDeX/3673VuPYrsNXwO4ezKthmrJvYL+PcV6O4zNXngO6/R9yf4HmjxOwX
7CY0mS0V5+aw9uVhYaYdydHZnPNhTrin71lw74E+jWl9lzuO9J9xcYbjykVv
mVk3dK6HPregTzQh/pew3ygVDsZfR7wnheLA3E75hfk3dGqC/1Ke8kA9+Bbf
2XB5nU6K5+Ok3uY/6rwzJa2oWcpTrErYIqxv2BfDekH58t05pwk5+VLKS2W1
arHZcbwYU27uoK52I9cZ3O/yVGux/3TbdFqw7ln/0XLV2pLrF74/72p+vULc
PlX8ywHf2nQcGaexQDllnRDvutMq4Cne26jwEit9mK/WsLSlliHgXMtTfN4n
znrcLcb5Xk8aFzsf1ktJUPrv87Rv8BSz2fUma5kYGOtpWrmbS4sn+aYS0ob6
EicXfVjD9wuVF77DPqt1/djmckv8V1PSqhM9cRv7BvDviYgL98R2MC79xpKa
EawFzhVi4rvkOJGVDvdiwsUcUK+ujPacAXs86VMHOxGQ1sTA/jsT0rzg/OkO
CfOgm2OcZ4zJ3ues5Ixcg89UnvqD97drhfYCMKxAo0X8W4Z9WSWMxzxxWgiJ
F+/Th719PKK3H6SEg/j+zgrYj64vmHtyephUvbIOOBeJl7kjZvYHded+PKm7
j5LiwVokft5nnHeI1+l6o8PTzKDurA2/yxUxsLfZ45y75E7cxHw3q7z2Is6X
InHhP+aJ+VqNah6QA2OSN/GRe8iTD3MbxH4L94PIaVlCs3F7Ri45fU45DJw3
7N8WV/Ono9KWGnPW0p/3iH3U4SfvLcf9TVo+q7B/AD4S3cU=
         "]], PolygonBox[CompressedData["
1:eJwtlElszVEUxg86eX0d6KvX9/pv+68+EqS0pjSi2mhCdQi6MiQWIjZCUxtp
NSGhJK1x2UYllGBFbLrUlmKhlViRCpJaIRQ7U/0+x+JLzr1nuN/57rm3fH97
25G5ZtYG0kBjaBZGzRaD5YvMXsTMNmSazWabBfh+Jsx+gO3lZjtAKuH+qvlm
LQVm/UvMPi80G55jdqLYbAU5E/PMcqlXhb0/5r66fLPBlNkYNVpyqEH+TvIb
i8xuZZjVsL4YmJ2kRlea11TtV8TvI/5eltkbfOXED7OuJv4s8VHWyQyvkU78
a2LuEpvgvN1xs98VZqfynJO49bJXn+456YHHKDYOOuE3Dt92BBoivpBeu8vM
joNe6vSBpsVmo/gGyW/G7ot7b5vAFfIfwqeH/I3gPLVSJV7rIOsK7C5iiog9
jyZ78NeiwQT9PIhQt5R8MIL9Fv3/cG5rgfd6nfOuYUe5o6/4ZkA2/cwS8w67
kjuJwXea/CnyO9i7WOaQLU0nyL+RRMdM11BaqqZqS6Nf9DdO/mjEa6p2eYlz
F6dH+G6DmxE/Q2ddCrxX7d1h3VDk9fK5/zXwK4YTMv3jHGVdEvpsScNucmvI
aSV3KXdyGG5Z+Mvo9xg1M7HPBD5rur9O7MuBz47O1NnfK/wuRvAXoE1u6Nro
DnOwg4T7xEFcmkOfdd1RLb2Nlbr26rGU9dHAtbxPTofOKnJb+QNotTb03ibZ
Wxb6zGp2B8n5lPAaqiUNH1O7mzu+EHHNh5I+w5pl9Xwg5jOl2dIb01tLJlyb
l8QPEP+c9SQ4TV7Pf8j+wt4MaChwbtJss2YT3wiYhsd78Aj+3zKcg7g8JecJ
WMfcrgdb2dsCPhD7EeT/v0/lLAj8DJ2lGMU+i/ndiKO43ivkvYE+5voc2Iu/
LuJvcAoe20Kfdf0xTaFrJu3yWK/Grg7d1p+gv0GcxV0cxXVV6H+J/hz9Tf1J
10Zr/UWV+HOiPnOaPc2IZkV7K0N/03rbenO74v5G9VbrwTnWV1Nu60/Q33Ao
7rOoHnrx/QUeCrf/
         "]], PolygonBox[{{9356, 9355, 6765, 1318, 5996}}]}]}, 
     {RGBColor[0.41596960000000016`, 0.6926310000000001, 0.5613951999999998], 
      EdgeForm[None], GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJw1VUtIVGEUPk3kqHNnHJ3bjJN3Zu7M2IMEjbKCoCAy6LmpTVZmGdGTol0P
iRZFD3puGxUiiQqEFgXVMq0kQ6MMhIKiXctqW9L39f0uLue/557Hd875zn+L
PSe2HY+Y2UM8s/HUhGZPcIilzeI4/4qZJSA/N5ndmGW2yzfrSpr9rDI7PMes
AhnWmD2Fz9E50uUQ8HSzWTXOnRmzA0WzaQ9+kBXY3sGD8PayVudqnMfj+kZ9
Q2D2DsrbebNu5OqAfj30e5LKfQRxv0eVj7me+Yr1Ji8dfYljMCPbV8h7Iy89
Y3cA63boE/AdRd65iH++So+Hcw/kWuiLnuzq4TMG32Sgusdc/GewicN+P3S1
afWN/dsXSN8DuRRyAZ424F+Cbx5itkD2lfCeMOsvqU9fq4TrbspsFWy3Qq5p
NDsFjJV5wsQ8rNdzOakbyauHxZzwU0f/SfSnNSpMffBvxzmfNSvn1OfmnOr2
XO3P45L07Q/U8wHI1bAbwnkzMB8M5HPIfV/n5tKEb3/BkxLk1Gzp2dvXdWY+
ansA3qTQnzN4/102uzdPdfT6qoOz5Ptl168rkPcxu72Y9Ytmfd8a12xjobjm
IV6IHn2qU3z2+FtcfS57mg1js8dteB5DfylQf4qN4hH5RPyTiPEjqThXkW8h
zkczmiFzMw73gFxnbtoy5v+8SdlzNxiX8QdR3+aS8GyC7A2ELxdqxq0J2TNG
q8PGWXEHyH/WtLteuBif5/Xwa/A0J86IvsRB/2VR4SJX/pT1nTx6XzB7BNzj
kDsy4hn3kjHeuHlTjrrzQFQ9ZV0jRfV8GHJFSXbLS8I26XrO3DyzFmLkN+Ls
dLm+NOluaHf4uIfcx+vgbC9wBMB/FvICdnc4Ic5wJt1uLsvK0i+FXJRULxif
MTg/7iD3scvZsyevHbYIej2CuG/z0jEXuUjMnAF7zp3jfvN9ptcztfBM3V7H
E+Ykr8lv5jqWEaZrzYrD+2ImFnvO+NMxzeaU21nyklzyQumbstob2tGGO/Ww
Vnm2hLJvASHSWfFiFnRzs+LKK1/7RH9yvhgqBu8M7jl7noOspMTbn2XdBfRl
rOmC7t1h9OdjQXgnCsp/wWFYEYpzYVo1sTbOKIQ+An0a+om47l7G2umrF2fQ
k+u+ZjMMPMthXw/7Qlp7wPO5iHo55O4Qzonzeu7rnj7i/iWsj7lYI+9O4iG/
L+aFs32+7j/6sq7FacXdEIr3xP2hoLuGd8xIo/aGsyUXhrKqnT0gFmImni73
zzoJGYTC+8EXr9kH8oR84s6Qby3ubv9b1lw53wDylvsn3cwLKzHf8sWVKddP
7ka74wn1/O/wG/MxbxtipzzF53sxrfeV0G8KZb8RcrEvzPzfxtz/KJPV/Cfd
v4BzJQbm/QchwveB
         "]], PolygonBox[CompressedData["
1:eJwtlEtI1VEQxkfLfN1rmtdr6lX/916zqEjpoWC0CIzMCqpVL8rc9KRahlqr
7KllizZdbZMFBZaLAm0RlNqDIjVaBAVF1KoWWcss+n2Ni4E5Zx5n5ptvTrz1
2Laj6Wa2F5mNXI+ZNWZzzje7WWy2udCsgfvWOWZnsfUlzGrzzAa5GygxG64y
24NvC3IL/9XzzVL4/sw1CwdmzyrMnuSYjYexETuVdPv9WWY5UbPiEtdRLYre
jf+hDLNXWWaX0BPlZteyPcdQxKyKc4rza/I1kO9MmVkn8oPYKaSdGquxL0fO
oV8tNXub6W+qtm6kC9lVZLYbiRGzAvtf6o1QxC/qa5trViMs6H0E3yliB8i3
hrc3Bq6/o+bF+KeooSbPMelFb+XNMPYh6ksQuxT/UMisEInj3wVei8BqHfGD
vN/FexeR39QxjbypNLtDLXkMZRJ9jJ6XZXoP6mWUnOXYDoLRmHRiVmILeLOR
evMCx/4B+XPR4zP4CbNkufes3u8Sdw95WOWzE+b9zC8U9VhhEiL+KzFfkOf4
vihxTogbmrlmL8yF/XrqbEJKifmT6xgWkitA5oUcA2HRSM2nqL+A8yrOJ+mx
o9IxEBY1gdvlXxt4T+pN80sV+sw1e2FSxLtJ8g2H/Y06/Gs5P+f8DKnDtynw
WcWxN6OvSrhNMYrVjDSrJPZN2M/HnDua/wLylwfOJ9UUQ98QeK61xAzF8aXm
EWZ/Gn52wtfD4LMQbKqR8+DTjsTQn4LHI7A4DlcjGX7Xga2Zej6F/Y2OmHNO
b+tuI7b+Ut89zfxGqXNEXNnC21uRyqhjqXhxf0nUewlxbol5jar1Izl2RrwG
1SLOirvimLimHlbQywFiirIdQ2GpHMqlu/0x54C4UEef9UhPxHu/jQzQ/064
taPId0y7dqXCd/kwPfeg78L/UppjdIH+n4DH4zLnmLimHMqlP6iP94bxH81x
DusvqA98lzQPcSlKP+kh51wZthQYnUj3nehFTwv8b1GOdHEz6dzSnzat2YHP
Znr9jP/SqM9c+CtngP94pf912skJ9MsV3otiRuO+Q9qlCWqbRCbQx0v8T9Lf
lE8PL7P8D+mmlw/cZWU4Bu/LfIe1y/IpwLetymcln+3FziFxSX/GkWL/o/RX
qV/tmnZOu/eNt78jI9RHqv94jVZ4T+pNf9I+8idm9lMYxdH/Ab30y/k=
         "]]}]}, 
     {RGBColor[0.4799870000000001, 0.7186916000000001, 0.4805375999999999], 
      EdgeForm[None], GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJwtlkts1FUUxm9bnb6AUoZOp+0w859H00aJGmzrolg3aNLgK7jRjQ9CqQtB
TKgxaQthofER2wImLkoJKnUhVtAVVerCGuojlfrCqCt1wQ5jwOgK/X7z3cXk
nt7/Peee853vO7fF3c/u2l8bQvhGvzr9VvXHmIx/a0JYrISw/+YQ5ttDeKkl
hIH1IezT3/31IXymM2WdH6r1mYLWbm0UUiFUtB6Tz7D231KM9zrlr+/D2RAm
NoZwSL8L+jaumCdTjvWjzn2ivcvy26l1YaNjbs2E8Iu+LxdD2CD7enMILUkI
Xfotaz+jvXnFP6yz328O4Vqz8yM3Yv8ccy0k3l/Vmf8U61XVEkoh/Knzt2v/
gPzbNjg3vo2mnGs1z9YQPpD9T43Xs9Hu1Zln9D0v36GbjA32aoP3yf9BxZpu
8t+/6a5l2acBujGEBxrsV1RudeuUjtaD+pakjP+VlG3uahF253RvQ3cI27Y4
34ubHZc8wHo8F8Ilas04F/bJ596s8QGnj4ruEb0C770p92ZAd4/ILme9NxL3
n2v1eWp5WGcGlfcx3fO+apmqc74Lss80mzfUBFe4/xGtK/J9nj4J29dkL2l/
QP5/6Fyf1kPCfkT248LhvOoZ1T0l1Xcxawz6c8aAe8CBdSraL+Ztbyu7T3vo
t/6+P7FdyrqfE7GnB1t9P3xKqEV3d3e4//N1xnSt4FouaZ1r9D45/drmOlYU
82qzecN5+Hg12i+02IZ7rNeiDV7gdjznu35vdtwbDcaB+uA7WipE/ZEDtVID
teyW72S9seZ7r2rpaXX954rW5tmicceGDz8UnDO5f5k3977QeodiHlHMpxXz
Nu2V0u4DvOQM9d5Zdo+/VYwdOv+Ozt+VmB9wo79kzqIxdAjn4Tp8HIu8oH+1
ieutAW/9MvK5R+uJTmtzVuu77Z4hzBv6RL/g5ql658VMgkenon0+a20sZj2b
8D2ZM4cm4xn0CyfgAxiwRz5PbLLO4cEt6v2g+rM9sW7gw+E4p+D+Q4k1h+aZ
SeAEV8lpsGS8VoTnRMX7B7rMmbX17u/2ku0h+Q0ljo0Wi9Lnmr5vTaytnXFW
fK7+zQj/6bx1B5b0EU3RV2YF8xFsznQ6Z/CkBmYZ2F2uODb9Yp94+DEH+hPv
08+FvPk2I83NlozdpxljQD/J9WiT/fGdynuOvZ63PuHIonz74ixiJj3a5Vwf
6zLGmYgzfCEnMM1EvbV3eBYzkwsdzpG70ObbFXMYXk+qrz3C9L60uYZNfksR
D86/HOce8+/NtHvQo3xOxLqoDyynYy1onjpf0fmFDnNmruS+ch6uDJSsEbTy
RnyTPixaq2gWLoFllTfC+cmcuXarMLw78hy+M/OY9eQKZ29EvaNb9MscYzas
xThwjfeGefBUzvXxBqJD9PhdwRxmll2I7yRx6CVrb7T74oz9KeoDfcKxmbz7
ejTvuxYit/Edj/lQJ3vH281RcksyxrD6HqCNTbaH49wlH3LlzdkXecvenqhD
5jCcwG7KeFb+VTbGe+Pchn/gP67+5xO/220Zv7dX4jvIndyNbmbTnq870r4L
XJbie90TMWSWMAvQzFdlv0lfl+2D7xb1vy/rPu1K2x+bfpHXaMwN+0h8F6mD
u6jletn/x/xN7LR7yFw53W7MP66YX2NxBlXfkFScUZEzcGc04kCeczn3EI1W
edEYtbPOfEOb/wM4jkqq
         "]], PolygonBox[CompressedData["
1:eJwtlElsTXEUxo/W1D760Pa21fYN7asKQUJbklI7IeZ2gyAhipUpIhJKSNRY
akgsqLG1UFSsDLsWpYIaStgh2BhiSixMv895i5N77v/M3xniS1dXr0oxs2VQ
b2hUYFYfNpvZ32xevll6zOxTyOw7lIFscdxsEbQWWgf9KDbbhH57qlkE3Yxc
s7ZBZpegfiVmW6JmddA+9BqgMt6GDzbbj/6OiNmJArNVfcyqSKIJfjdU2c/s
IfJd8A3oHEg3mzXQ7BbxlvK2rK/ZS+RL4MMxz20N9mWFZicz8dnXc/pOvMI8
Mz6eH3xH3G0b8XkTPqCmjlSPGcPXgYjLDkKN8NuLzLIzzPYQ/y/6DdTXif+T
6C/INjucYzad/KO8XUH+hFovkk8d8ovE68FHC/67sZ+IrxbyCzLcp3znoDMG
3c/YhMjlHTW8he7y3gU9xF9ryH3Kd3bgtZRjEyXfxizHTpgK2yf8b03xmoZh
/xibC9iu5/9B1Em8fHbDF+EjdYDr58MPAdNIimO+n9xLyGWF/PF/l/87Eedf
YW/ox8inG9ta6q/gvxN5c6rbXCWXlfjbhuyF3uBvZ3mvhImwiQbe67PolGM/
P99nz9LMMnN9hjRLl6Ew/4lix3r2EOYH2Wxs6vFXif4c+KYix34xw3wcfnzM
fSvHOLFah5rd6OM25+G/4G9j2GfkGL2ZApWm+Qxplv7HINY0bA7lOKbCSjp1
1NNJThv4/9mL2uBLwaspzesXdhOJX4nvAIwnwT/Cvhuqp86dUFWmz4ZsjsL/
RvYLmsssVccdA2Gxl3zK4J+Twxvw+QNVE79/iWOjGTyCrAOf7fk+Q5qlgdT8
LeQ7rF1+xNto+rcFjNqIczDis66eq/eHCxxL5VxDPr2weR3yGQ2SM6nZHE+s
CTm+k9rN++TTzH95gWOhHCsKPEfl+p78r5L/poT3ppa3zfBdyf1QjBRijWQ+
RkC1+F0OXctyLKUj3WcJ30X1sAc+LXmf1MP0wDEVtl/I8Ss0tthvjXZgHPzk
mPdCO1IVcwyExSloIft8PeG16Cado55pxJ8KfQC3j4V+w3TL1CP1qjrTe6Od
1m5H83w3hbmwl0/51s3Q7dAN0v6+4O0483c64bNVQU1nEl5zbfLG6ta2xV2m
m6zb/DHPb4/8PSDePXKpCfsMPo36m2R660J2Ldex103WbS4v8l3VTlbAV+X6
rOsGxMHj2FDPTW+S6SZ9Ts6PsB4Z+C7rBs+IOcbCWhgJq39O/+cv
         "]]}]}, 
     {RGBColor[0.5511106000000001, 0.7354392000000001, 0.4078444], EdgeForm[
      None], GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxFVjtsk2cUvRBIQrCNIwfbCX/s3/7tkqUBqaSB4AQYSCkEAckCAws7IEGL
lAEQSJVadaEQFCMqVUUEEKBEatOSUgmmhHdFgKQCijoU2DrxGFvO0bmIwfqu
v+8+zj33YRd27e3fM9fMruBTg08+NJsTM1ucNiu3mn2/wGwpzi7cd9eZPWoy
+6jZrAL5IeRtuF8HeRbym1qz9ZDfzjH7pSD5Me5vZvV2umzWDr9/IdBm2H0d
N/sGn2f4Plkj/8uBYUPC7BjuD88zWwHbZbBN4TwwXzbUPx+Y9QHbBZx7cvCH
t904r+Hsgs5W+PksZVbCGQLvCuQwAv1FiLsfcdrwtgM4hzJmq6BfD2z78rpr
A+ZfEaMN+oMgZzXee9xntdFsdKHZGtz3wFcWXK0JpUsbxnsCHGfx/RPEnMgK
Uz9wdsTFA/m5gLMcExcnA30/lxIvvFsGnlZCnoYcQf4Dby/h+1/ksjWU7ZZQ
nNLnd8D8Q0r89eJ8lBfOO5HZ8WblvN/vyC19fQy/T+F/DLVqCIU/jru7wD/V
YPY7fN6OpMv4Xy6GDXROI6ehZsm8I8aK127Qdfg+hlivasXVGdifhfxfpPin
GlXfEdz3wq4/JS6p86BGtSKH5JNYXsBXhnJWPm/gfF4n3tgP5I4yDS626O1S
i3IacT/TiDsJX/hqwyn568F5tCgMxELfz+vNrqNmnwaSO3BugtFwo3LhDLBX
S+Csr6jeXZtVPtRhD30bKI9tRd1V3ZbxOVPEQB/kjrxxfjhHa0M2rN5v5tT3
7P8dS9RD7KU/AXy6Qfwwh6rXgtzvq9f8EAt5/jyh+pE/2lB/Bn7vQ55qko/7
fk+Mp7y/+RnzPif+nz2vg0nNLOeQd3wjN5xFnpyRL/LqN/bdAmCeAqa9iDkA
fivQOREoTtV7YDQne870cQC5AsxflZV3e616lPPX5/534m0ctg9ahWHcsdE3
OeT8PGwVnnOBcmA9aft/QbVmzVmHKc/9nzrNEWOR4wLkjThnSsp5FueNJnE4
m9P+IHbGZX6VuPR/gv+VkE9ktIfoi/eHAu2IwzgPBpoX7tEB6IzGleeirOLW
lfWhnMDdREKccG90xuWfctX5Jw7aMwfiHy9oZ53MaJ7+9j6jjw633e07cxg6
25fIjvvgdaR+5C652qR+vZPTLqc+bRmLtSGPnBdyS47JH/3TV8Jz+Q1nW1Ez
OhQIS8XxDOW007sj5TThOXIHcW7zzeoT9jH7kbXNxDRXt3KqH3+j2CvMrRRp
l3d6LRh/lcvE3hn/wOFmr8vytLARI/uae4Pf+c66bvTfk9W+/xOOjfuSdSPn
5KOYVk7c2aW0MHIHNHj/cw6yae2KI94L82L6fTmW1JwyT4vp93fQe/aa9y3t
zO+jULaZtPJenxTv3aH4qYTqfdaEtgPeX+T6TEn6P+K8W9DbvYJ+I7kjk6F6
uct5qxS1H2a857lf2G/01e49QBvaPoZOf1E9x31PvJO+35gzZe7LXKi3N5Fq
T1+XW7RTKPe+/w+QFCfvAK69JPs=
         "]], PolygonBox[CompressedData["
1:eJwtlFtMDXAcx3+EihLrck45Tud0ThiGEaJT8RDLZVQv2lw2D7xpq83mAY94
YKOSBy8My2Xlft14QEXaVGSJeUCeeJAexefbr4ff9vv/f7fv7xrdW1d9YLKZ
7YKmQGMxs0vTzHqTzApyzO5EzdammyWgswGzdRGz9clmfcjjyK/mmX3l3YY8
XGC2B/3dUD3UAHUGzUbw1z7DbCjbrHaO2VLeQ9jvgB+Imx2eZXYce8M+P9fs
PrJDgOrJMluY6/ESqWY1mehhcwz6zf8IFADDlDSzBciPhMz6sUmg/wW6DLby
oPuSTgzslbxbif8N+bU89yFfldhtgjLQuZzqGGbi2+Ku/4n3Et6NIcei9xn4
BdjUTjK7O5saFlKXuc7fgXbyPo18dJrXSLVqxWYL9mXke456VpPTBvOaFIFt
A+9l5jkcRjcOnlL4l8QLEr+Iv2dTwZ9itgq+Cfqc5BibQ56DcvkJjl9QRdD7
GST/sojXRLXRn2SD6FYkO8Yu3rfo2WqwrYGawDcfH+fBC2stYKsq8N7Lvhp+
jNr9haqxq4n6DGgWaqA3vLvDYJ/OPPEuRXaTv5XwFfT8IrUtibi/APhK4bdB
hWmej3qlGqvW+tuO7ELcbR/MRAaoAfz34v8785VEfRIR96WZ0ezoT7IOdN6g
u5h8F0H7wLE/6jOp2WyD3uWbzZvIV5gfo9cT9VwOUvMm7AvZj4fELubvNrLl
6F9K9Zkpgl+a43gVvwos5RGvvXJUrimFXtso+WWQ3wA5nEj3HXhPbrEc3z31
fC36N/I8tnq8DFkL+lunes/uEX/FRHzVoBO8j4Lu+yk6D4M+Y5q1Eugu+qfA
fzLmPVPvtGPaj0lgzCfeuqDPmv60O33o9Ob6zmn3umNeq2Hm4TX8YHh8RcYx
fIR/gc5zaBhcP6CyTJ+dt+BL0P8nWd4L1Vi17shymexVy5Uhn23djA7id+ET
0bj+K8WKee/VA/VCO6Zd24y8H/s6dDpSvEYH4K+EXKadaws7JmF7TU7d0NGQ
3w7lsBGs7VG/TZpRzWoDM9GQ7DteDz9KTEvzHf0T8xnaN3HzdPs+BLz22lHt
qm6abpt2/B/yxoDPjnZMu5ad47WXz3DEMQlbMXprAn5zdXuV03T8Xc/z26WZ
0ew0B7y3utG61UfBeCTfe6xe/wcBhdhI
         "]]}]}, 
     {RGBColor[0.6271284000000001, 0.7434926000000001, 0.34670379999999995`], 
      EdgeForm[None], GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxFlkts1FUUxg+tUKcPWmbaoZSZ6XRm2gI+sKKQGCtFJGxMI5WakGhM0AUR
hagkxoXKAmUBLow8jZG4gWqMYtQYqbAwxkcooBAfEFz4CtDiwkQgYmL8fn7X
uPjn3v/9n3vOd875vnv/PWs3jmyoi4izeur1rCpH9DVHLMxHfKqFJQ0RA1rv
meP5ifaIlxsjvp4ZUdXGLa0R7bK/XTb9c2z7WldEd0fEuL6v0bzQbJvNel8m
/12a98r/Z3MjpinGPR3+3pFszsn3720Rv8nXE90RDzVFPKlxQHZdmvdrvicb
sVfP6PSI7a2eb9M4lfU31t8UzgvytVDjYCViv2IdLUWcn+n15XWODYbzZdvx
ra3eGM4nm58zfmc+SznKLIZyEcdajefqtP/3gHlpZ8S+GbLRuCDjfMmrT++H
WyKuE5bFquUl7f1Q+8a19nGL6/lrg9+Z36AYm66NeP6aiJXyM6hnpfzvLHi+
Q+PmgmNs17isGHFQ82JvxHDOvaAnOc0fVqz59Y57psG9nd7svWDrzPu9pjos
Eb4vhWFAeGfp/bL2ZjUulf93ZD/SazzYrFOeuxT7Dr3vTrj4xjocIR9yeUM8
GNL4kvhzvfwf0d5++a9T3APCkhXOec1eJ8cFFdekVzb1shmTzbfqXYdivKL5
X+rbmibzhP4sE6bRWREvlIxlUcacJP6hhBNuTOrZrWeD7B5TIzeWzB/2wpk5
zd67VVgP14z9XWF/QP7XKt484e/Pm9PLy+bm2lRb+gQP4EB92XmR36WsNQNu
bOEZdvDrXOLbRMk5kiv1pk9w49ZG9w//7/eor8K4Z7awdzv/9RpPKr+Tjd4P
X15vMBb08KjWf9H6gYz9Pa58VmS8tq3OtvgGw7MF82K2MExo71E9T7EHfc1w
PsS/e7o5D8exh2doYzitY7euzjph31h6/6bbNb6lqpgZ58h+dHCq0fjo1WDi
zxedxnhaNe8r2se45q/mnM/iojVCrmj4vR5j26n6/DHDebL/Yos5Ca+oCefD
n9OcN/0g9z2JF6xPtVhH7D8un6v1fqTmONSrLfGPfp7Q96tpDjfRBhoZErZa
3nwaEhcWaT5f89War8w5/+cKrjGYiQuX6Sn84dzk/Hym0/ymvtS2sWD7XbOt
4yWphhfk9yfZPa24mwqu5XJpaF+XbTi/96azkRpkcq4R9SlVrE00Ch7qQN9P
Fc3V+5XTV6kO1IM41AKc6xMPH9F4b9kaHi37nBtPuqNvnL3wYaLHsYhJLHhG
XuR0NM3hC3yGqw9SO/ncp5w+0p5h6eWQxk9Uz+OyH6pZW2CjB2gazlNPcp1K
fR2Rn375GdC+atnc5Zz+scVzODyZ7OEouI4lPMQkZ/LFFzjxf7bDdZqoGstE
0stoqsPNinWmZG6f1lhr9jo8pP6NqQecweAAA7oEP31B52hqrOAzBHtqx9iU
9jLPpPUdJdfimGr8dsn33/6C8YHrhw7fe6zDpw9kN6i4uxXnctY+iXOo3T1D
c3dVrDU0B+foEzpD15w7Y//hTTWhD2Dg3GQd/+SCnugj+aGrg+kMIiaxyeWm
vM/rt7p8Bp9r8Rl+Id3FcJGzZW/iFNpAI1u6zVG+nyxao5yb6Huy6vNrquq7
Gi3R0xsVa6vWo2a9ovkV6e4E2305432x1TjvVE/n6r0vb3tswdyU+kjd6C//
Ttwdt5X9P1NNcWqp7+jyVOI2/zxz079TJe9/qb+r5thk0uCVrOMR6/N271tU
dH36UyzqR3z4z/15Md2h3GvbEn5srqQ6cw78e+epl9+XrLXvSj5/uI+oEdql
F+gXrcN/ztiRivuyquLabE/+6TkY4CHnXC1h+wfqy21D
         "]], PolygonBox[CompressedData["
1:eJwtlVtslFUUhTeMFKdSoe10Op22wz+dmZYit1q5htqWEkgINqEUjQ8GgyQ0
hEKQqgETqYkRI6ABW8u96ENLiBFNNIZySTQYNRTQchGIPAAhIIgvBIw8oN9i
z8PO7POffd/rrEkuW9OyeriZvY08gfSWmdWOMvsqbNZYbraowuxmHt84b+bu
2ajZOO7TSHNgVsm5FD2CzOT8eaHZbHOfFnzfxWc8viO4j2E7L2bWScI450bs
M1HXZdOJ7fG0WSu+KWyOoTdhUzbKfeR7kPh3uD+EfT311XMe4rwzx2wH+q6M
2YMCfkNmD4vMpmHTj+1a/Keir0mYteea/TvMLEy+Z0q8XvUwh1wD1Nz8tNld
vq0aa1ZDzl+IP58Y+7GfGDGbgKxImrUhb5LjDWQ3dnuQAuL1k5sUlo/+Rdzs
xkiz34hZlzK7QP4DIa/nJ+L0UO9t6l0ywuw8+TYQaz3ShW83kiZmW47XMJ3a
tuHTgG+YXnfja8xo02jqQ+3j2y16vImcxHcQaaWnanrbhM8CYu2lnsvUMw05
TawD9NRM7ibu+9FfIsdf5DqOTEBfiFzN8/1olyepv4/627AfiHhMxa4iRwu5
6qlnkHpOIz+w2/+o4RGymFm1IpP5VpnFzwvYX6HXt0I+A83iQsTjyWZR4DWp
toMM9MuEz1Cz/IRzF+fh5NtCrq1IKO071myHuL+Y8B1r1wvpMVf7pp9jeT5T
zba72O80g2+obye17ijxHWgXr/JtKbIO6UD6yryWychZcq1HroUdM4eJvYD6
p3L3GfO9R5yGtM9CPf5BvAJ6evCU2XecO4h1iRrPYn+fb2O4+5t4hYUeQ7F+
T3gvwriwXpvtTz6XE44RYUUYFBaVU7k7njT7oNRnotnoTS8NPIdyaf8Bti8W
+lvXm9Lb+hGfE6WOIWFpS/b91oCvZu6rYo4NccBiYm3kvpr7E/TzDno68Leu
93qO+ofKfVbLyPkK+73F/bCQz+xP9CowH+fuFDV+DzZmBM4l73Gu4NxFzDps
B5ST+a7D/jXsq4mxXfOlnt4cx6iwWhz1WvQtFXhMxRYmhc0jEceu3uBgwt+M
3o5ydJOrJupYFt99yLmTfBuRj8Ddx1mRLkwL2+Iccc9a4t/me4Z6jlLLEaSa
es4knYvEab8mHfPCvt7spKj3pN7EEVOivjPtbqJ4jfhfx50LFXM8tg3lzn3/
8F62cfco5bMSh4l7G4hfkn3vekviCHHFZs4/x5yjNV9xahX5mioci+LIuRXO
aSuymBf2TyX9rYlzBtHPEHP6SOcQcYk4RFgSpvMDx5TOwsR88rYz41W5zrmr
0ffFHUuK0Yt+J+WzE2eGAseMsFNEfbMC37F2vZz4Heyhh508H/Z+xd2pqNuq
J2FnJTYvY3sdmw3lzuHicn1rRx8XcSwKQ6+P9R1pV+KEyphzvLheHCguVAzF
EkZrinzmmv3j/5iM/ycKK5p5mlouRXzWdfh/m/T/SO1bHFzL/fvMYEm+c5a4
q6fYbR/PKOGcLe6eyfdZyHMp/2+QT2PGMal8msGn6P8DY2oNbg==
         "]]}]}, 
     {RGBColor[0.7050380000000003, 0.742591, 0.2991669999999999], EdgeForm[
      None], GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxNl2mIlXUUxv85bmM6d+5s3ZmuM3funXEbNUctk8odiUItUyu/5AKBpgki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         "]], PolygonBox[CompressedData["
1:eJwllWtM1nUUx8+gRAx9fHgu8OAfnssfBAFtIKvWRUFa603N8MFpWyt9tlaZ
1ZTltJuSFs22mi01Z+HakmxWsvlGh71oRr0woQuTELBVI9Au76rZi/p8d16c
7Zz/71y+5/rPbn6666kiM9sJ3QA9njV7DHoE2gS9V2V2ucRsFVSfMguh4WKz
OnRz8F0wr0XNHkBeXY1Oxmx+mdmX6PQGZkNxfBLgBPLXNWZ/hWbH5rmPVNIs
Av1zk9nfUCzjPuVb3+LInxB/htjT6Dfz1pQzW1SKT3wsrTQ7i/wgunsBfwY+
m/LYwtyPbR4fJ9C9wreVxBrk2xxvhcVm52qxRd4IvYCvF6EegkfLzcqh39PE
wOZ7bNdgswZfdZUeWz4aiZfMOPZt5JiAH+L9+RvNapFfIvcj4HkH2pUwew6q
530L9r1QM/a3ULPjpZ7z0ZjZV3H39ZFyoF69YHgU/wHUkHaMwroXfh/UgO+7
sP0O/WXwnWD4YJ5jrgf7r/iYWmDWFzE7HLiOdH8E/wB5X6HHhYVm+6EfKswO
8v429CxYd0AZKJ3wGqlWr+BvH/7OLzLrAPTN5LCVeE9Cy8BVRMxfwPozVAyW
5fR7GD5CPbejP4WvQeQ8eC6EXhPVRjEVuy1039IZI7/d1ONb5G/mU2vwf1br
vdtBjS+CvZ36XSzxGdQstiR9VtTzLuJX820C/XuocQe6p8B/coH7lO+prPdq
E/lPZ33GZN/Ht0u8t1R6rzRzt+Z8B7QLbcj3069ZYvQz7wf4tpY8roWeO2Z2
FX4g5lg0wx9Tv7qk11896sC2CZ1zyg+bP8h3fcx3SZiF/XiV90oxx8BzKPBZ
FMaDgddQtdwPhkniG/rv834a2ob8Z9p9XyXGp+R+BJv2Up+ZbmI9g30s4j1q
Rb+h0ns5TY1WkO/rgecqzLsDz1G5fkg/hpf4jGhWjmL3LjRCDbup5Qg6//K9
mxwby3zm18EfIF4L8Vqh7bw/BEW1m8hv8XYHOfchb0a+s851pKsdeJlcJrPe
K83sEPPaH3hvNZMP47816buumIq9RzMEvYHvN6GehMcSBmERRmEdJZ+EalPr
tSxwTz7HV54azS30HqqXs8xQG7EG0P9iic+kZnOM+u6J+w5rl8exuZv6XQ49
lwI0GfqOaddmsLkt8JiKrRm+nvCbqfv1Ezr3YX9vzHndzGPw7VBAvk3oR5nF
EWLuKnIb3b6mar8durmN8IsBM1viO9pIfwr4j5T6t1PMyniFY9E3vXXmHHsW
uQd5C7UrL/Ybu1V8xt8UM5rxHdQuquej8FOh5/oqNhPwv6Wd103Vbb2Q8vlR
DVXL9VU+q5oBzYJmXLOuf8hS/N9e4bMmG9mWpzx33Rjdmp3Vfvu1g3Porw69
F7rBq+BXJvx2asY16xsyvtvagY0Z3wnthm7CIPwK4i+P+z9Q/8L6tM/CKDYt
+LpU47utmz0On0fnepnv3H9gm4j77ujmztT4zdXt1Qzlc/5P0b9FO98c+k3U
bdTMX8P/E2mPpZqr9v8D/88Ulg==
         "]], 
        PolygonBox[{{9104, 9103, 6655, 1954, 9105}, {8545, 8544, 8564, 3328, 
         5965}}]}]}, 
     {RGBColor[0.7766468000000002, 0.7254445999999999, 0.26849659999999986`], 
      EdgeForm[None], GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJw1VltsVFUUPW2lQzuUPubOnc4wzNzObbH0QRMshgSkqAh8CCYI+GhIFPHX
V4kh6fSFUGPih0JrjDFoQkJ5hIfyYxB5SAj0A4VQsLQU5YNSQPFP5EvXYm2S
NvfMufvux9prr3NqNr675p1C51ymwLkiPPeVOLcX/3OwHgude7PcuQk8b013
7m7EuVPTnBsude521LkkbFZXY40PF/nOLY9ovRL752AzCRv8uZdzzk2VOfdS
zLmv087dhM067D0f0Zr2jYg5UOXcFfweSjnXhndzEWBZoL258D8Uk+3amOy5
34fk18PX/mLkjf1kJfKDn4OIfw7BT850bjpt4OcP2C+AnwN4l8d/BPufzHLu
4yfgy5dtT6nsB+HjC/x/iHdP+8qTud+p0jvud5VrPR853cgIt4WznXsWz2UR
xdtUgW+QW+c02Q6Y/VJ8f9hinUX+g7CfQL0J5O/jvxvvtkSV233YJ5FDHvH+
QS9GkrLnd/kq1ctaG9CLY4hXUaf6LqOe4kLV1G2xOjztXYDtanw/jByfw/pe
3LkTsO/At13wd6jU4jIX/K6uVL3FM/TNcvwuxH5Dkey7DXPGJb51hfLRZfuP
vq+Sz6WIsRa/O4BVT7nWxPP7lDj2jC/MGgw3YnkT/1cR62BKHCAXyJ/bxqEj
2D8N27fSyuFMVP3dAbwa8X5zXDiQz8QiBj78gP1yxGoq0Zqc35oWt57E+15P
dRzJKA/mswXPZmDcCj/9yPkAeL2xTO/Ixz3F4uRm1HgROfyZde5oRlgMeOr/
lPGcvSMHiM/ITPWL8ciBi5Z/XS2+Raw5teoZe7cBnF2VU57MdxA5/Yz/NU7+
6Je9vp+Vj8ZQ/emyPpIveevLOH6PVSo2e0HOs8/c4zvW/W1MnF2J54vGzf4i
1USOsqfkDfnTHAr7s1HZpCq1T36urJX9SfYioz714rkwIvw7ket3GfHnsM3T
SKl0Zjyj9XlPOQ5antShK2bzQiAeDeX0/o7NG2eo3+aI3CWHGYv1EXfW2Ge9
9tPCIv+Yw+XClPPai773VIhnbwTSusW+4kxZrBFw4XypdG9XiXSQ64Vp9eha
AvXD5p5paT38lCCfWb443mY874NdC2LtBGaTWeF5C8/5wO4S8novFOfYe3Iy
bxrAvpODV00b8zaz7N+FjPI57okHsSL5IgbjxgHOEnWcM7YdOTejhtuB/DE3
+mxKavYOYeaueNrbg/XrgWZ1FHuny1Qna+R8lRjmnFdqNeNQ3+mzHs+HUZ09
5AH7fLlMPWUtPDsYPxFoRidQx2tYN8Hnq3jejYtro6F8c5/aS4yZw6eIOzBN
nGavWSfXnKUp4wl582tGZ9sJT70bNl4dNk7+DfxHTXu3QbvmVqvOFvDt7aj0
0CvSWULOrUDvsjOECfOfzCiXMU9zVFYlXm0MhPk4sayQT+I2D35PYV2POF6g
OckhfmSG1sSzrUQ8pF/2OWI4P8Leal+bk92X6OecQP1i3/7KSmeoVcSn07hE
np42PbkeSjfH8Rz2NGvXM9J/av/7BdJC/uZ6f0I+9qVVH+tkb3bH1Mv/4Oej
rDS5I65545xRa6mr8/DfXqD7BOvinNE3YxDb3RF9y1g7amXfmxCXyWnOOM+O
A6bJi1HbKuwvqpMG0A+/pUbxnKU+tsa032618Ldn+TEWz5AloeakLZT++VYX
cyS2nBfqJzWJGvOTJx34JSP9ow5esh7RhvNIfvJexV6vi+ne8BXwWGA5MB/O
wz67j/0bKsZDPH9MqGfjNc49CBWT5/mNGp1HEzXq9yN+IIfjCWnFdezX+zp/
eLdifTHDk9pGjWM+YzXqI/vJM7nH9vm+z9bHzJ5cIbb0QfzTvvJ5YBrFfBib
us38OWv9OXE/VyedY+8f96fZONCAGfsG+TfOFo9oP93OP85uJq37CbGl9jFH
5kretvrSAN77mB/fcZ895J2MXN9m+kadazBusQb2l/EYa3mgGV6B5xJfPTua
0qxyZtsDaQl7wZw+iMuXS8l3k/WuKdSsceYmTceoZ9m0vmU/WUfSeMK7KHnb
Y1pIHKhFm8r1jvW+khJOO5O6+1L7Cmp1vicNk/qs+rs1K33iLHnWb+6zXzxL
GPOpuGyoZaxhQ1yYrEeceCCN9gOdc7x7kMPkNnNirG6Ly3sFuTNoGkLN2Gv5
U7+oXWFSNe2yfc7TGbszEKeE3TM4Q7SJ2l202vDhXBBbat1vns4jnku8/7Hf
ownd9ejr8bwmbN6vFWvGiN21UGcrz1hqOrWd9+vPsd8Cm89C6Tj1/KovvpKH
23M6y6mVv9cIM9oTtx5PGnQcur0zFIbEsj0mPFrg/3+nv9lZ
         "]], PolygonBox[CompressedData["
1:eJwtlVlslGUUhg9dZpwuUJ3FzlCms7R1utAmuFAjUlDBJqaYYEGkVzR4oYmY
gFESqtMRqTHRRCxgxERNSGRpKAg3xlQUjZFeuMUCpZtyQUfA6I0aeqXPm+PF
Sc73f+c75z3vWf50//Mbd5SY2ctIGZKvNXsF2VdvNoQ0x8wulpr9dofZoUaz
Z9NmzyDbkH4kh+2X1WZfIMszZqcSZsWg2cPI5Qjfo2a7K81GK8zOJs064mYb
iXOD+zPYrubNz7yd4H6a+76U2XrurhLzPmLvb8BvDe+Qwp1myTqzAIAPlJvV
ow/yrb3GbWS7E4zVYB3i/Q1iT3J/HtuvkE7sp8D0Zoljbs94DsqlB7sNyCVi
vl7mmLvx9xD5jeNrD2/Wov+bNfs44JzksH0VjsLorche9O/J4QK5TOC/C/9j
vLmO/XbwjeB/hvuL3BfxXx5zzsTdeaQZ28VwUo38xfe/kUkwFHg7iFxG30sO
bSHeIa/VuU/5nlgMl2CbVV3wNYIkeP8YPk8EvCaqzYMx5/7abWYreb+E86dg
7+RbBO6HqU/fIuf0HeI9Hqb21Z7zEfRGbAJVZgNLzOK8fQsfl0rd5gnizRD/
YLljmEs7p+L2OfQdSAf8t0e8h9RLHRnPXTkq19ZlZh+GvCfUG93EXEG/tPKt
h3OamqaQreTSh2wBT1uV56hcD4NnLba/guk99AFs9yCHyOtd5AH6o+d2OIev
dtUSHwVq20X+R9Gn+ZavcJtV2ObifncVOZbwmqg2AfRgwmdCs/EiPbMOLKvg
pFjqPdyf8hqoFuqBPHkXqX9XyHtwHr2n1nW92VDrmIVdOT3F+2LKa90EB/Po
02nv/d3IFPokPh8hVj3262Ub97M42AR3g8QYqPCZ2YVtM/x+EPIe/ZzzLs69
5JqnnrfIvQz88/Tmt9x/l3TOxN1LmmOkhnw/q/GZOk3+/2S9F1Sjj8I+I5qV
EHhyyh9/wSrvGfXO8TrHrh3Qh/1ZfNwMOgfiQpyK21vgWkA6kWMhn5lx8N4b
c36U41b83ZXy3lANm1JeU9V2O5jm0P9kJkd4G+T+D/SjGa+Vcl5DLiv/938c
uR89G/dZEGZhv5ucfyrxGc/xfjPYjnDfwnln1GdYszxOjB/ga7jBd9UQMSa4
u47N15Veg7xqn/VZbcRngXwWNXjvKqd7sJ/M+u76hjdX0LcQ70rAZ/LJhPuU
b+2oN5aaPZry2msGNYvX6v2tYip2a9Zz/5FzG/qmjO9WxdyM/j75Ho77jGhW
FrLeC9p5dcTah82aMt+p2q2/17uvbdhMYTua8F3fTT1PosfAs1DpOyWc8p2l
3aWeaan1GdIsqX7q1TNwchJuTiEH4WNpzHtHO067TjtKu0o9spq7cxHnWj2s
XlaNVetzcHoT/KeTzq1q/gn6gYj/exRDsRRDsUZ50wi2CxH/96gH1AsvRH2X
q8bD+B6L+CwoXm6Z7xztHv0j9a+czToX2hkz6E0N7lucDcFdb9i50cz3ZrzH
1GviKAo/v6T936SdOcaenE36rAvPHLolvNc68Lkf/8uznqt6ckXUMQmbdmYL
+ttZt30a/wVq9R/MmR98
         "]], PolygonBox[{{5496, 5495, 6301, 1753, 6744}}]}]}, 
     {RGBColor[0.8359268000000001, 0.6909257999999999, 0.24626999999999993`], 
      EdgeForm[None], GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxFl21s1uUVxm/oREqxLfTp04fa58Wn7abZUCcCCgqIdrz4ghGBBWHMKri4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         "]], PolygonBox[CompressedData["
1:eJwtllls1FUUxg8Uy9IyBTszbYe2U6YdxRjZpOxroZQiglJoExbBYsFgAphC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         "]], 
        PolygonBox[{{6664, 6663, 7673, 2615, 5195}, {6748, 6747, 6271, 1731, 
         6749}}]}]}, 
     {RGBColor[0.8785128, 0.635593, 0.2285552], EdgeForm[None], 
      GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxNmgmQldWVxz9672Zp3uv3+jXQG++9NmY0gsoAokagAYFJiTjRRkdMhRGj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         "]], PolygonBox[CompressedData["
1:eJwtl3twldUVxU8SSAIBk5h7cwPkcXPvDdZiIUoLSAGhwQDRMUoVkAHRQBBI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         "]]}]}, 
     {RGBColor[0.9013818, 0.5570535999999998, 0.21163639999999997`], EdgeForm[
      None], GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxNmgmQldWZhv+mF7qF3m7f27ehV27fNhE1MUGiRkTRVCBujZZAo6iplAvS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         "]], PolygonBox[CompressedData["
1:eJwtl3lwldUZxg8kIQkhIST35uaG3CTcXNSyjQqWUiAgVrZKE5hOCRABHVBA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         "]]}]}, 
     {RGBColor[0.902853, 0.45396399999999965`, 0.19201399999999993`], 
      EdgeForm[None], GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxFmHtwVdUVxk94JJDHvXmRm9zk5nFzaUetjtbWFpRasaBUigoFERCrrRVB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         "]], PolygonBox[CompressedData["
1:eJwtl3ds1GUYx1+gRWiP0vbaXrne9a7HoQFi4qp7RFQURVAIiFJRURyoFNAg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         "]], 
        PolygonBox[{{6239, 6238, 7363, 2408, 7362}, {6863, 2050, 5719, 6459, 
         6460}, {6460, 6459, 5720, 2051, 6864}, {5729, 2063, 6878, 6238, 
         6239}, {7560, 7559, 6615, 252, 5082}}]}]}, 
     {RGBColor[0.8830562, 0.3253591999999996, 0.16678759999999992`], EdgeForm[
      None], GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxFmHtwVdUVxnckCZGQkJB47yW5Ifcm906nQuujRbFWBK3OWJ+gojgVaFUo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         "]], PolygonBox[CompressedData["
1:eJwtlndslWUUxg+jCJ1Ay723u7e9NyYunKUOlOKKsYqAIkYFXCCYuMW6UKEo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         "]], 
        PolygonBox[{{8323, 3151, 8325, 5363, 5364}, {5475, 5474, 6754, 1976, 
         6750}, {5364, 5363, 6905, 2081, 6904}}]}]}, 
     {RGBColor[
      0.8656581999999999, 0.19594679999999975`, 0.14346919999999996`], 
      EdgeForm[None], GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxFmGuM1NUZxs+ue4HdZWF3Z3ZmZ2bnsjvTtKmtYNq0XkCsIn5AmlIsNVpY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         "]], PolygonBox[CompressedData["
1:eJwtlmlslFUUhm+HUijQUugy086006FToxFtS6Js1RSIAROoEQsVFygICIga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         "]], 
        PolygonBox[{{5746, 2082, 6906, 6247, 6248}, {6248, 6247, 7381, 2420, 
         7380}}]}]}, 
     {RGBColor[0.857359, 0.131106, 0.132128], EdgeForm[None], 
      GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxFl3uM3FUVx+++t3Tb2c7MzuzOY2dmdwDTWEwUWru7hX/k4a42Rq2rxEdb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         "]], PolygonBox[CompressedData["
1:eJwtlmlslGUQx6f02kJpkd12W3bb7rarGGMRjcjNB0HkkBpISgXRlEIPtYAi
QkDEQMBEEMoHARVFIBEBiSBHOEINxJhKqUeiRDBGUEEBKYK0YCgQf3+nHyaZ
933mfv4z88SrZk2Y2cXMtkApUHPE7Bh0u9jsDtQ3bPYANDFuVgFdi5l9kmn2
W7bZ2VyzX5BpQXFtwOw0/IwCs2GpZjX8q4evSmAL2X+xHcLOOP6tw+GobmZP
FZk9jM0zsgcFOW/rtL8TuoD9n3qZjcVWRpLZKfjpxFaBr7R0sx/zzJah80gP
s37QOnwtx2avZLOf08xWwD+ITl9oKHLDoDUlZm9Di3LMXocm8G88dBK7p6An
C83KoFHQaGgSNkYTawnUB75adelulk9MI/PNDkXNKjPMXiS//fmeg3JZRzxX
iGcEvodDt8j7NvRKxGuzm3zmwGfdTf2ItRwqIJ8q7N/CfjU2G7H9bdR9yWcN
Z3nY3Eg9u/BvPPU5zPlcc51pnL9LjK8Ra2UWNQiarSfX96Cl5LoMKkv43T2H
zpfEFUP/VMBrqtpO4T6ejvud6+73kNPzyCZR773wb3E/5Zkek2J7P0QsnJ3v
anaVem3iO5XvJmg59vcjMyXDY6wlnhb+bQYfqeiXE//uqOcymfhP4Hc7MawJ
uE3ZHkI+peRzH/UaXOQ1Vq3l4wD8ceWMfnJPs5nUMgV7RwOOwaXU81XifZx4
n0D+d+wt4ntMpt/ZQWSXox/L8jvWXQtTwtZi8pmD/Nm4x7Yee41hv0PdZRa5
ZkONxHs44jVT7Wqobwp3n0S8Z8h3FWctqV7DlRHXka56TL12Dn898dcH/8O4
n+vE10psJei3w39GTPM4D2FrJ/ySQo/tTTC+GH4LPku7e77qvVb8X4dfSwx/
w9eTw1by+xgKg4N95DwZ+59Sg/PUvznhtX0Z+ePwS/Lcl2qoWiZBRwJuQ7Zm
YyMX/MzC5yDijaAzuqvXNAp/FzX6SneLzjbyG1vivTOWnh8D386/toj3mHqt
AX5EitdoNfzUkPeGbIaQr8Nmeg/v/4vEdTnhualn0pBdTY0q5Bsbz4KHJdTg
L/K7Qb1/QD4H+Q3Euwv9MvI9hM/HkC0jno3o9ybeVvQvQUOo5Y2Yzx7FtBX5
BeB1PtSGrXZoHP9upjue+uNvJv9q8XdUeAo6xnQmmSb0CvO8t9M4zwafk9HP
THGfQ/F3Me61VE98oX6Lur56Qr0hTAgb6oFBRT7DNMs0UzRbcqEcqBa5OmhH
xGfxHXLOQW4AMY5L9zvfG/UZqVnZH3oj7DNGs2YBMTSFfUZoVmhGalaqh9XL
6onN5LYn6LNbPaPeeSHXZ0EF51eQnRT1XIUBYUE9oF64jr97yX9axLGxg/zP
oTs71+9O+h3on8ZnNbHP5byVONpDfqaZs4K7Gcy/3t0cg8Li/kK/y33g5SD8
H9FOe8g3IN8S89hH8m87vnoTQ3sPn0kNYOUZ3QfxLET+m5jPfM3+R6Hh0Ach
x658PlTkM0W9pp77KO6YFDZl40PsdZDfzU6MC+vCgLCgOziLrWK+4/qHnQ7o
JHwg4DNga8j/6UyYE/aESWFTPXAP9RzYeZ//29T8DPosn0g+u8j9asJ3j2aA
ZoFmlmZXHfGew9aFzniD6G8g3s/DfqYdEEf//iKfPeqh0iKviWojjB+J+s4R
NjdR/3zsT034bNEboBL+WtyxJIwL6zPIpR7qrl0HRfCXSnzJUDXy20Iei2qg
WgiTwqZmThf8Hcf/vEzv2WPwlSHvZe38d9D/Pui9/isy/fDdUuy7TztBu0E9
q94dgN5A6FKOz85m7vNP8ltV4NgUJoSNA4WOJe1Q7dKVMcefMPUS+awP+S7U
jtKu0gzVLNWbRW8X7TTtNuVYS3xfJ3y2ngFDLfDzY1477aSF8LkJP9OMCsOv
KHasasdr16tHdnTa19tLPa5e107XblcNVUvtnF7U7p9C38V6Y+mtpR5SL6mG
zeh/x3dNsu8U7ZbLOV4L9Zx6b2fUsSSMCWs9w15bvdH0VtNM0WzRm05vu4oC
n316o5UX+A7WLtYbbDq2TwT97aeddpTc/gOVTH0B
         "]], 
        PolygonBox[{{8334, 3159, 8336, 5377, 5378}, {5378, 5377, 6928, 2093, 
         6927}, {6929, 2093, 5762, 6252, 6253}, {6926, 6925, 6924, 145, 
         5054}, {7361, 2407, 4974, 6468, 6469}, {7747, 7746, 6003, 3348, 
         8585}, {5063, 5062, 8613, 3373, 8611}, {6469, 6468, 4982, 3582, 
         8805}}]}]}, 
     {RGBColor[0.857359, 0.131106, 0.132128], EdgeForm[None], 
      GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxFl1ts1EUUxocWLIVewF22e+l2t9siEI3hogkBSXyRKEqMKITrgyCCIihG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         "]], PolygonBox[CompressedData["
1:eJwtlntM1WUYx5/UkkPHWxzOjXPknAOIrVbqqpXOLstcYk1DM0v4I2uKqZSb
tZIu6IYGiriW5SSzsFyXf2yaqEXz0nIW/ZWydCZrCaW2EBXEvPX59vDHd3ve
3/u+z/39Pr/03BdLKweY2QYwCEzMNxtzs9kS5BdyzGqTZmcDZt2gDvnNlFkW
Bz8ZZpYoNOsZaXaNs39nm/Uin0+bBbLMvrzR7GDE7B6+JZGbhpqFCszyCv3u
FhBHbkLfcnR/jhMfIRcnXG65yWw0ckcI++juApfQNSLP93RmGPJUdJ5B9zb2
78T3payj6D7D/u9Rs33omDnYbCg+70X+PmxWHzT7BZsLiec0621Bj1Gx9hJz
D7gPu+PBfmKoHGK2GJwitjpQC1aCVWAfd1LYToP9yAtyzSpAI358AN4ipq2D
3H4Ztq7g02WwLG5WBS6yP4t8bWT/FPun0fkStk7g/3j0rCXGZeyfAe34MqrI
7MJwckON7ibe6eRkGpgCSsAJdNsNnrN/VRt8ugqGIQ8H77B/Flu3cyZIfD9n
XJfutBP3syGvVQX2lmK7O+T5S7Luxt9HwKS465TunzjzI7iGnusZz5FypRgO
4G8n395A32j0Z6PrAb7dH3Ed0vUEOloC3nMPEu88fJgT8Jjr0ZvH2Tb8vY4P
8+mXavL1eNB9km+X2N+MrQ/BLRnvEfVKN+hkv2+k92Yx9i8ib4pRF1CHrdXg
UMJrI53LU54T5UY6c9BXj3/n8WcAOY9hayp3+qhNDfbnkP+j5HMw8lj8f4i9
8cR/Oug176KeM8EU1tvp2Sc5+0Pa39ajfDuIXIXNjeibzPp15DK+XUW+yv0W
4n+K9WXW/7Aeo1zgzxHwPrY2gFc4s4Bc3UaMEXyfEXbd0rcMfXs5m5/tPhVG
vAfUC6qZancvuRg4yH04qX5Iui71SCvyPHLeEfQaxLnfwJ2qLO/Zz8KeY+X6
MeIvIx/V1O9t8ze9mPz1cr4nz3tUvbobnXHVBp3JiPe0els613GuJOb3E6zP
0h/NfBtDParpob/Qtyjsvaj6T+bs6qRzkzjoGPn9lno+z7oczMeXCvwfiL2T
+D8KWyMy3ivyQb78mXHdypFytQvEdB7/opzvirsv8ukb9DUSbwm5Og4OR51D
xCWHwSLktSnnJsXfgNyccF+a0bkT+WPuT2O/A7RxvzPhZ2dhbwmxFUfcV3Ho
RGrfhv0hxFrK+SPIq/E3jb8ZsAZ5ev/7eZX7X3B/Qq5zx1fYG0c9ItwJx52T
xE0Hks5VyqlyewVc7q+RalUa9n4QJ/alPAfKxTlsrOHubzkuD8SnI/i/lm8X
At4jo4s8J8rNCvZ3UJ/tMZf1pvW2z9EDewKew27k8nzvHb2pZ5D/4ExfwN/U
r+jaGfO3phy0Rz1nyt0q1rvYKyC2TNw5Vdxa0s+FD4NJoEj9FXSOFle/Byev
Fy+Ti+pcf1N6W3pzenuzwRXkWzkfplbro/4W9e1p9j4NeS00YzRrtuPvQnqj
YQQ9WeQ5UW7EGSdyvOaqvXLUgP3GpM8m+TQh7W9Ab0Exv5t0n+V7bf+saU15
bdUzTSHnIHGROLWD+meFnNv+71nWexKeG83o3cjjyM3YuHOuuFccJa5Sz4h7
xRHiCnGUuEqcKG4Ux4hrNKM0qzQTNRtf6z+vHozxtl7O81mhmarZqp5Ub0q/
enMGNkvBUc4dAyvRXZPrNVAt9A+gfwH9I+hfQTNcs1w5vQO5POz8LD49jh8r
8KEm4P8A3yFXRl3Wt27i3RTy3tc/QUmB11C1FEeKK+tT/tb0nsU1qplqp56c
ne8zW7NbPspX2ZRtcchm4vk64bNab2QHcmvcZ5P+EfSvcFe+zzrNaM3qQ3Hn
fp3X29qadq7Yhf0tyHMz/q8kznoO+T/2oHMk
         "]], 
        PolygonBox[{{6898, 2077, 5740, 6242, 6243}, {6243, 6242, 5739, 2076, 
         6895}, {6931, 6930, 5002, 2445, 7427}, {7410, 2437, 4994, 6930, 
         6931}}]}]}, 
     {RGBColor[0.857359, 0.131106, 0.132128], EdgeForm[None], 
      GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxFVltsVFUU3VOG6diXjzvtXGZ651EoKh+YSKFBgyLGH0qiICIiJoJ/ImAI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         "]], PolygonBox[CompressedData["
1:eJwtln1M1WUUxw90g8tr1kXu5XIvl8tLy/6wJRVT1ySK/pC2IMssaeuFtWUL
N8uKtNS11IT+0FzqRPujrNabrMS1XK82iwWr2bSkRF7CrFUGU0Djpc+3wx/f
7TzPc37nfM/Lc55f8sGVdzSlmlkrCIAbImZ1bOwGlcjLw2bRWWbnM80mi8w6
is3mBs2uQXl7vtmeUrM2sHG22SbwHfrtl7rORNLsq4TZYfA5Ol+AkajZx2lm
r2F/GHkcm39nur9zyDvQeQWsx9YGUM2387Kc003I2eVm+3PMmuGahTzNN+f4
finnU8g/YDMz3aye9VHkKvgsAjXIt4LuErMHcs1OcV6BvZa4WRD9NuLZgnyo
jHPiXYX9R0NmjaxTWA9mkxvieRxu4cvMnoZDNfwukI8h1h9w/i/yu3nOZSU5
+J389RTCg3hTWC+BRx97Wfhajf1TEc+xYj+AzlLkI+i8jW46+fsHfyOgOcf3
ziK/gc994AV0N4KDcOzg213ot+NrCP9t2MsipovkozLp3MVRXBuwn4q9FLCa
s8/i7qsPTp8in+ebvzI9Jz0Rr4n4aW8U+UVsNGV4/TYjn8nz3lANJjgfg8Mo
qEOuL/IcKVeKYRh/l7M3C3yLThfog8+fQY/hbvy1oLMFbAKbpU+9euA2SfxX
IOehU4Huh3xzZ8ysHFtloAgkwLYiz/0U/F9Gfhj/c8nRz+iXoD+IHEhxm9uJ
txMfdTle8zfh8hs+Bjh7Ff0zyIOF7usEezHOh/Ef5Pt+1iPI20A3fMbJ8bWc
78amkYtc/PdztgD7n2S7zTLO92NvZ9BjVuzqSfXmFN9Ng/XFnlvleANyBWfz
ot7D6uUn4L8OF5NwboTf/Ihz0d5jnI3k+fcnsX8l8T7F3qoMv3OHkJfBpzrF
e/KepMek2NQTT7KuJV+13LfF4F7uR1PE73Mv9q7CXlfYbcteY8TvtO52BL8F
YG8BMwG0YKcVHCzwXpfN5dib5JsJsIaY1oI5MbctH/ejOwD6C7ymqm1/od91
1XwAuSPkd0V3UnfzR3J2HOzE1y6wjpzdlu05P8t8GkN/FCyA20JwIey9pJqF
SrwH1YvTyEYcJWG/CynUcH7Sa6raXs26Cz/lrAcDXuOFnC/BRyDgPfdssces
2MVJ3E7iexr1o+i0st6X572RRszHiL834nf1/5kU8hmqWaoZqFmoHCvXquH3
5Ko05r3cTr1mRzyHyqViVKzHo25bM0az5o98n22T+Bgv9jupu7kY1ILDce91
xfQlcnfcY1WPhOFahr3SqNdMtRuJ+WxXvYaRg+g8A/e17G0t9J5Ub6p/Q+Tn
JewdC3gOeuEXwVYYPEKMK8A3M/dPObwL++nYa871N2EMfh/FPXfy8Su2Mzhf
g7wDf++pdlG/6/XYeCvsezp7Dp1MdE9g83Sq3/mfkO9LeG9rRjYg3wi2prlO
FXxS4/62KcZL4j5TNVufx0cHfXkzOpVZ/gboLVDNVfvb8f81sdTA+ZYin2Ga
Ze+Q/2VBv/PvF/qbo7dnDjau131gb2JmZmp27ol772nGaNbIp3zrTfuFdWfU
a6n36UDIZ4Zmh2aqZqt6Qr2hNzJBvi4W+9skDuJSO1N7cRTXRQm3pTe2Cvl0
iedONRtC7ox5LXWnGvL9juuuPwSPxqjXULXUP4D+BdQD6gXVULXUG6O3Rv8Q
+pc4kvRcKecr4H9dwnOhmqq2qqFqqZ7QbE7MzHa9eXr7FLP46ly983qev/Wq
SQ22/gOOPFaO
         "]], 
        PolygonBox[{{8353, 3170, 8352, 5379, 5380}, {7377, 2418, 4983, 6899, 
         6900}, {6900, 6899, 4992, 3585, 8812}, {5380, 5379, 7207, 2270, 
         7209}, {7400, 7399, 8354, 3170, 5758}, {8811, 3585, 8813, 7399, 
         7400}}]}]}, 
     {RGBColor[0.857359, 0.131106, 0.132128], EdgeForm[None], 
      GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJw1VltsVVUQnd72tr2nF2m8z7b3nntPW0wkUeIL0i+1pSHBGiNSSaORVhsj
ImIC1B/FxCfqh9IafBARK48SqyC2+CjBH1NjoMHXDwbBR7QtaKDV9C26Vtfm
42T22Wdm9syaNbNPcP/GVY+GzOw8nkI803mzj6JmywIzr8gsWmJWUmA2HDO7
FDF7M2u2ZYHZZ9A5EDZbWmy2Dvu9WN+TMiuD3ALbaexVwHYYzjdD/6Yysx58
21RjNoq9hoTZY3if9MzyeO8uct9NvlZjvwoB/Y5zZ+FrB86dgM0b2ItlzL4O
ZN+DM0+ncQbs+ivMfJy5u9SsBT5vKzdbiScC3/3lipPxnoDO6SvNkpB18DOK
XKrhZwpnblyoeLL49hKeP0PS/cnpM8aRkOL8NKrcuNe5yOwMdLZDfoP4DmKv
PS077h+LKCfm9mWBcoqUyNfV0G/DuighvIkPMd+V1/5a5HUG6y7svZqDDfRr
kdP6arPvKmGHfL+vlL9tzuf7SbMV0JmBXSdyvqFMtbglp/XNkO/h+1BY2F1M
K+eRSsXN+E+wnouEXRTyEZzn46x/KoU78T+O9XLktalMeRXkhONoXHsx4LMY
erdi/0a810P+AJsw/BxFTZs94ULb5wLpPwsZgt4axPtBXByZcjwJY38W63Nx
1YW1JCdmPO0TN+I349bTWM9hvaRAcsatR5FjCra98LPf5UJODWTEl7uy4hl9
TyZUR9Yw6TB+pVg4+7Vm+8CZHGQDfNfj6YT/+oTiIN8nPNntCokz5Av5/jxq
04z9FajvcKU4eyguzrKPqE+c2Gfsxasy0h+HTqMn3MmJrKc8mZcXVgzcPwzb
goj22Lstpar5HWXCgjaTgWq6AXxZnZF+HNi8hveHEWt/Xj1D3rIf2RO0Y1/c
l9O6KaEY6Ztc6svL9ghkB+r5+ALFdiHQ+zhkAMzPQv+trOJnD9LnJV94/QfZ
haeTePqqVafjQDSs3MmZIXcuub4mrfef4XssEP6sA3m4+HLfufnGOfd6lWbU
edjFoD+I/XZwfBu+rcL6Rcqs6t4M/n+eVcyMPRSoloWBOJhyPGyF/RRy/CSm
OnIGkQ/kFN9ZU9ah28VMyXi4Zn9E3Mxk/Vc629udH/oYT2vGjaUVF89qg9ye
U92v8TUPOEfImaZy8ZJ+6KPJ+STnyKUJxD8L2x9x9jSwOlWmNXPpQt2/Qmy9
ReoPzhH25Nak5g/nEGNnDpyHO0sVN/1fDFT3QWDVVyouXq4bJflJLBkj+/RJ
53M0ozlOHh1CfZal1WtL06or63sQ+3+nFde+rPx5zufHqNk6xHQY8qybw0Ow
a63QLOWsvd5X/zyFGBNp8bsmIzzbXI/vTAn3/bW6T4gF+/OCm5Ocl8Rm0OEz
5urydlZ8Iq/O0XcgbNpr1UN9DgfWmDrEszWnnmxz/cR+YC9wzrI3v82oP7l+
x/UU5xj5bTnNx0LIX6uE8y9VukuY77t5xUt/jP86lzsxqM6opx9MiO/kQwq5
XOuLM0t8xUqf8/gWK1f64R3PWt+bEl7EjdwmR5gb88qkxInfEM8U9J9G3NOc
N55y5Ex4Ia8zH0pqnrLWxIszde9CfSNuUde/x1OqKWtL7KnDmBpz4vwezMYB
16fs15ak+oZz/V9fMfM/hXiwXvP/Cb7uoTt9zRL2J/vxWFaxfgE5h7ifQfwn
YTvr1jOB5gXj2BwTlw+4+3RDTHjVgQMjMXH8L6z34D6oQ8y7a8Rv6h6JCV9i
NX93eHrnuiPQfsbNS94HnusT9ssTSfmiz54acYG9SvzZG8Rmb1Z3Dv/BRtzd
2OFm8vKc9hsg1+Y0349WCFfmRfznfNV2JK7/I84IzmHWnNjy292uT9mvJ4HJ
A1eY/YG8PqwSlvwfyVWr19hzzIP/kcSLdzzj3QHdlwP9DzTizHCg/8yiQP9u
7B1yYX1MPBuoVa14VrfDnvqsIeco/0HJRfYeOdUPu62B5gT/pzizT7lZR8l3
5vU/EoSNAw==
         "]], PolygonBox[CompressedData["
1:eJwtllls1HUQx6fH2lNFutvdbrtHLx4wigasIRrlqjyAMVYqqTHSqiRqFUio
+IIYidJ6hR6Rlquo0PZBIkosSkCMBjGB1jvBAzUC2hZFtCZtaWn183V4mOzM
/ze/me+cvy1+cHXVqlQza4HSoZWFZjWZZlNZZgN5ZjcXm72Ta7aWswr4Eag6
w2xfwOxE2OwM+tvRz0a+D3k8YfZdjtnqq83GQmYLkW9CbrjS7Dx3VxSY1XF/
I/IY8uGYWYD7P+P8EPyupFkcuQz56Xyz27k/m/utV5jVg2cqYjYJrY9yDh3g
WwPY+vG/nO+z4vjMNls6zWwbeFqRW5HD+BzifDjo+KuIqQlfr+JzMNUxLsLX
TuQ453/wbQf8M2Cs5H5bitkG+H7i7YOs1CwFqsT+Ms6roSXw57A/AT8OpWOv
E52dUCO5aIK+LPL4lL8v4E8Qwxr4JP6Ow7+e9Pwo/g3E3xd2XWGeUeQ2ZKsd
mx3QbfgYSPUczUt4zv/PPf5TkLfGvJa7sdcBX4q91zI9xuGIx6hYh8jHXOIb
BEOMsxq+DcD3lJndSS6zuF8DnqGg2x6FLOGYhV05bot7zIr9EvQ7unM4nw3N
w+98aBgf66j9EHf+hv8RDNnpXsNT8CVhxxLj/gdgWxhy3VwwVWK7HvmxkOdU
ub0f/ZyA9+A67DXjqw/dfOhN/D/Htzz8rSU/+0OOSdjuQq7F3hZquRz7Bei3
w1eAYTO91oR8kF4tx15Z1HtOvXd33Gt9lH4YRX99vtdKNeukdvUlLqvGj8M3
4b8wzXvkJfi9Qe9FYRTWA2DqVYzYOgd9S8wnoa182walced98vEGNtv5voo7
MwMe0/OcfY2cnuk5VC5j1KuL+ndDcfjzfMtI8Z4MEK+B/1/sXMPvdGiM+RmF
bgHXrVAQ/RT6ZT82T4PnJPZncf8p/P2Fv4/J+UdQAbrRoM+8Zl93ltGfLeVm
P00HC7Q56jVULePQEfgt0ESWz5xmTzrSPQU1czcX6qXfKqhBgvwt5vyOqGMW
9m0x3xWKaRDcP4A3K8Nt/oq8J+i9opx8xb0z1PC06sjdGdALSZ/9MDaOg3cQ
/c5U76FJzpsTPusLwNsCvzvo9ufQL/ORPwv77lK9a7GbKPNcy14jth/Jd17z
ugn5LDl8FyyPgm8N+LrRXzLNZ2o7tn4p9FxLR7raWdpd0pGueky9pppPFnpP
q7dHwDelfRPx3r2I/bPY783zXa0evpeze2I+u3WqT8x3pnanaq7a7yv03bkY
nbfgR+m5Dvr1e+KdIN4GdI6Rr0+hYLHnTPHpW16xf9NZG/6eQPftoO+Ovej8
E/Gdo91zEJ0AuofKfJdr5/UQa3qxnz1JTv+EfwX/L4d8BjQLu8hxZ4F/01ld
wmf3Ij4egO/hWze0CV+N0G9geOgqf8P0lqlH1asPE/PKqO8A7YJF5O8G8peE
EnG3IVvaUdpV6jn1XgEUifrO0e7pinlsmjHNWv/l/ax5Hy32GdWsCsPn9O/S
kGN9kRqtAO/hAue1Yy+A97q495rerOvhx5NeC725E0nv2fLLGIVVOVKu9GZ+
A65jYZ9N7dQLnH2Cj6MJn1HNahc+9kAzqdu1RT7zmn29YXrL0hK+y7UDU+Hn
RryWeiP0VixIeO/rjdFbox5Tr2kmNHvKoXKpN/JG7Za496Zm6lLc3yi9Vc+S
h43KRch7S/8R9F9BM6/ZV8+NcFaNfCTLd0hrue9g7WL50yzqP4T+S2gnpsKX
Fvmu0I4tKfIZ06xph+Rw/8OY7x7tMO0yzYBmYQwbtSW+c7V7lSPl6r08PxOG
KnT/A/A9WzE=
         "]], 
        PolygonBox[{{8374, 3178, 5780, 7428, 7429}, {8697, 3458, 6094, 7415, 
         7416}, {7416, 7415, 6095, 3459, 8699}, {8698, 3459, 8700, 5763, 
         5764}, {5764, 5763, 8373, 3178, 8372}, {7429, 7428, 5779, 3177, 
         8371}}]}]}, 
     {RGBColor[0.857359, 0.131106, 0.132128], EdgeForm[None], 
      GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJw1llls1UUYxQcoFLpA21vaW3pv772lTUU2fTNqTIwSNQoqYgLVyBYiMQYi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         "]], PolygonBox[CompressedData["
1:eJwtlmtM1XUYxx9QRORgyOF2zuFwzh88OgN13bZW9qKLg1a6strUWqIbzaXl
aqOtJph2gWpeX5jIBri8vpBKEAyotpq9qIDaepHTtK0LCLpcLRCp7PPdw4vv
9vzP7/k9l+9z+Z1gw5ZVL6ab2T4wE4RLzAZnm32TaTZeYNY03yyVa1aaYVYf
mLWVm7WCJs7eASeKzOo4G5ll1o/uWMxsFBwpNjsKWpJmDVlmUYw3I2fFzXbx
fQBf74XNctHpxP4pkJUyu1Ti+q/nEAO2P+TOu3wv5P5J5MnAv/dw/zpyd9Lt
6bwLuT7fbGCu2RA55GPrVNJ9SacTuZnYD4AdxP4GaCCGRnOfz5d5zIq9gruV
4HLUrIP8CrBfW2h2I3BfimEKeZL718Ey/N4HPkh6rjs4P4zck3R9+T+DPAg3
AyCNGNLBfvi4wVlGmtlv2OmLwCvcj1KUK8TRV+zciiNx9RQc7Z1n9hoxr+Ju
U9i5UDwvEf9n3N+Iv0/47VPkSXJsnoFPbE4lzO4gxsqw17SReh0Dj4TMniTH
Fvge1G/IU/A/hPwo91dmm60Az3L/HOhC7gY/c5ZA53HuZ8+hR5BfJb5FeR7D
Wfg6js4x0EjsTeCMfFOf+WA38d6Kfg65TxBPRcp/01k52FnmNVQtv+O7gdiP
wNlh0A4OgTY4XR9yzl/AXzs5t4Gd+NwF7qJ+d4L7ye0BcInfTmd7DsqlDhux
W7BNvss5u1ritROn24m1Gp17sl3nFXSv4uMwvp4hpkzq/yW/fQGixBYDfdzf
kOWcrkF3KzktzfM7V/iu5XuY+q2lvh+jX4X91enuQ77OJ7x2ivEC8uaw10Kc
ibt+cmswr8k6ztcnvDbt2KhBXlbuXGkm70X+lni2ZHmP13G/hxy7C3xGNatX
qUmM3riJzgjnDXBVH/WeVm+vKPdYe6nvSuTRYu/VQ+QzplmJe+1D4Gjcd4J2
g2ZMs7Yo5bVVDMc0+2Ve22H4vEntAmoyAlcx7vdyvhGOHgt5TzVyvhYfP+Hr
IngaeWGp2QKQBAHYm/JdpZnYh/wr/PwScR3pVkU8d9l8G3sz4GgSX21aesgX
tT/Uv3DcEHgMiqUE9MU9J+WWwMdf+I/CTQRsIsfNoK/UudHO0e4ZS/hs7Gbm
/uT8Qb4Xp/mMP4S8lfxqQt5jl6nNHGLuyvWZOwsXi7FXzd2XsbE34TkqV82Q
ZmldxHtTNlqJ/U1ifhj9fuJ7C/l3ajYLf/9gfwiuxwPfpeJAXOxJuG3lrNw1
E5qNKnKqBqvJ8TxcXwBrir1GqlUP+mnYulbsu1A9+Afywfh074S8lqMJz109
rl6fyZ0lxPOvdlzgM6JZqcXXc1HfqbI3zv3lnN8duG/NjGZHHItrvTl6e87h
70dwkN9awEf5XptC5nEYe9+Tc+1c3ynX4OIr4jmb8BnVrA4Q4/Yc3/d6ayzw
3NZyv6PQ3yC9RarJPPJrjnvs4nQYewvwkQL/iRvQE/Zd/Dk6NfieETj3qnk6
cmWR55aFvU3sxyfirqsdoV1xOd97UTs6jThH832WNZMZfG8LvDcT9Mft9MFJ
zoszvYfTE74DtQuPgxMgjE5eqb8xemvkU77FSUWRz6xmdxv5vs/5RIG/DXrz
9fZ3xXy3aeaS6J/mu3W2v0m9Ed+x2rXicCLwmdRsSqc75j2t3tZOrkd3JOq1
UY3VO50x51o9Vor9paX+9qjnlyD3x3321DM/RH2Ha5er5qq9elS9auimgb8D
3916o78u8pqoNtph2mX7Y56rOBN34lBcamZum7Zh05yJO/3H0X8dvWF6y/QG
6y3Wju7g/v92fFsi
         "]]}]}, 
     {RGBColor[0.857359, 0.131106, 0.132128], EdgeForm[None], 
      GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxFVktslGUUvdU+p53aOtOZKdNhOv1nogVXmigJbkRQMMqiEgM2YYFCaTWl
g0ICbVFxIQa0LIyJryiRR2rSGkH7oFpXREXpgAtto/ERF4B98Ag11ih6jucm
LP5833z//e8999xz7zeZTdtaOm8ys4t4bsbzQdjsLzz5ErPyGrNQyOxCsdlE
tdlkrdnfRWZ332J2D56N2PdV6Tf392dkuyRudrRE9s9iLakway03W4N3L9eZ
LYP9u4HZo/j2GPZhxFjn+wRs5mNmA1inF5mthP0cAB5OmRUqzc7g2Q2gLWVm
HfDbbfJHDCmcv4M4E4j5EL4fyghve9KsAfbL8e0l+OrFeQg57suabUasOL65
iFg9ObPzwLEM72cazF6E/zms/cXy2YtYq9Py8yDWeMKsGDbrYbMrJ5/0fbJe
tp8g7kij2VPwOYx1MCYOLKPvHi5FTBMPXRXKnTwxN9o9Vq+zDnz3R9TsCOK2
IU5XSDz847VgDZh7P767LaL9DLAtwu8x+HgDsTfC5i2su2Lav9mo+KwNY72N
uOWOKd8EfKj3PvjakhSmNqzvpcTFVfjoCavW5LPL7bc1SS/kmucr6pXLJWCP
gqMmco/9CxFxO4uza8DyZ400UARehvD7X2BrR14TnuOhcsW6s8hr5fsCYk7V
3tDmlOuNHJGrL9LiucLz+g6/j+P8e6x54N8elk4ZkzipJdqWuH17Vj3QkVVf
7MT+GayFrPYTWFdmhO92aP4z5LsffsaxziLXbtThOnDGwNtr8BnFerVOOp5O
39A9tf5RVPluBvZOnI+GxFcz/F6BzQrEWYuemUOuj2A9DI6ewPn71FdWnNwR
lwYLronlgTi6N5CuL+D8JNbmUuXDHifG3Y6T/UctUnOn4es52Mwj7jl8vwHv
vg1UG/L1Kmr9Vak0R73trRYPrAvzIH7WbjAqHVKPQ7AvrZHms3i/pVa5U88n
KoWBdaaGqJ+DVeKTXFIn5Iv2h1yH1OPliN6dA577bpVPckEtTLo2iIe8EdNU
Wvn+jDr8iqcH+3lgm0wLw084OxUTj+zpL8HDAHh6IC1s1D1z5BkxsM+JcbhS
XO4Hnj5qDth+TOv8B6wtYWmOnHO+kn9qaW+gnp2OqKepe/LGPJgPc5vJSKvT
Gc08fketlqcUK5RSfVgP5vNLnXJkrl9nFPs01q1JYSZ/a9B7v8F+MKHep945
B46lxHMzci8E6hf2DbGxTvS7EPZ8kMuOiGbXNw3qJfYfz6kdcsU6cv5yDmdh
s6pOZzsCve91Ptmr//dsIP/MkblSv5tq5PeIa/551OcKns+xDyGvM/gmD2wT
gXon79rbvlh7vqfu2APU3khE/D2NdQA+23D+YaNmALVNHniPzPpdsjPQzF/t
2iEP1/3uo0apT95RA35HVGa0p3aoc/YGczwYU6xBxOprEgZiYZzhUsWqSag/
x7DW+r4CtWhNyObxhOy4ZyxqnLyTX85v9hhrSW7Y67wHX/FYjEl9EC/xL42r
Vzg/RquVF3k779+SK+qQOdBuKKm4xPJSVnf+XVFphDyTe2p7wbXBuZX1nuX3
3JMH9llvlTCwrsyR9mcD4WNfrspo1vN+XvD/JNQE4xArcY763fp6TDqK+/xp
cQzUD2faOp8dMzHXQE4zkrVjDQuNwnMc7/dENXd5XxELe4p8HSjTvcY6c54d
8P2puHo5lNPMoV6ZE+8DzsORpOrFvmMtet3/GLTZGJfOPk7qO84qvuMdwJn1
e1qc8pz1XRxXr56A/dKc7s0lOfUwe/k41g0+Z9cnNMOYH+tEH51+p7THNOP5
/yIflW/+V2J+T1YrL2qOdaEeR7225Jyzvs81z7nX7XrqgLYM3+6JiB/6oD7J
X8ptqMsh/8/Du2jMddbu327FerbJMUT0bsw1/GlWc6AfHJRldD6LPCqwH8f+
ckxaveb3aYfn2FqvuXvU5xJ9jru2/wNXE6M0
         "]], PolygonBox[CompressedData["
1:eJwtlU1slHUQxqctLd0tS8Fud7e7S5ft7lILeBRJUBIKqJCISeUAlphIjFBC
kEXlIC0keBD8QK9GjNZocUkAAW2h5eNgIQG0C14UMMoBI2VLS0mbqDHq73F6
eJJ53/c/8595ZuZ50xtfadtWbmadYBq4kTLbVWHWV2P2M3a40awODCXMimC0
zuylmWbJ6dgxs/F6s45as+85P8z5qrRZ/wyz82A8YrYvaxYMmb1QZvYWdnuD
WYyLtgfwSRI/blYg1qUqsxFiX2sym8B32UNme3NmL/L8Kv47Z3E//sujZq3g
afxWgWTYLAFext4EvuLO1cQvgM3kO5R138PEuIBfAWxULGpYkjH7jXxug2Zq
fBgY+a/Ct5ccyrC34F/N+Tu8W87zzZRz8w45n8XvXIPbH3D+IndPcKaTu/aA
y9z1I+dPcH5bkJqJ/z58HQDX58A1yPNuO99Ok8888snBSU+l2Q78R4h1l/r3
8i3LmYucv0TMrpDfobvUA/UiyPcx+PuF2CdrPKZiB3Neewv8zubsQMzt17ij
H3srPrvMORbXx6b4G6Ce6cQ/Fvb474Lz1HqF/J7jW4j4h8hnEZw/GveeqDcj
cF4CPcQ+BEppryUPBvmer/NZO0eMAN/uR9zWzGh2WsE49hFymORbifPNdT4j
mpUx8mnDbq+m59wzQE5xnruI2Y/9XdJnSzkqV82IZqUMLsrBVviZU+Ex47w/
xXNfvees3Jt5Nw/8S+5GvLfnmq2d4TPbQT6PZ3x2mlia3eQyxHM+6D0uZpxT
casZO8PslOJei2Io1l/c+yd4At+l4F7Eub7DDj2b9R3SLhXBg3rnUFwupJZH
wDowLeAcistBnrcEnJNW8r2L/1CN76R2c6DRcz1NjmewY8Sq5HwAbMD3m4Rz
18dM9GIX8PkS7OPcfvAZNXWDAjgMno/52XvwvzTpnJZNaYS0YjH9+129pP4U
/e7B54upGIr1DBid6Tkep/75zOcfs3zn71PPr9z9RoVrkLSom5o+bfCd0e6o
J+rNbnjdA9rJoZpaDpJPI/edoobuat8Z7Y52QruhHe7IusZIa9bDzzVymSDW
P2hTF/cX6c9l8m8LOafidjLtuzwGhyu5/03wGL6LwIf4LyNmsdY17gK9DKZd
+7RD0qJSynupmm7hO4jPtxnXLGmXeq7ei7ORiPdEvVGPozHnWFx/DOZS39cJ
txVfu/r/ToU85ytp50TcaMY0aycTzo007Sjn1xGzt8o5E3ctOd9l9WBBzndc
u66dOhp2jZJWfUTuB8HrGediCTXtxH4q5bY0QlohjZPW/Q2n+bBruLR8mPsX
kOvCqNtRclqZds2V9qY1p+ATYi6u9R3Vruqfo39POe8rMq6R0krt3A7Ob0q4
FmimNdvSYGmxeqLe/JDxXncS7yr259QyWu7/sKtNfqfu1sxr9udHXes1QyvI
70CT/wukke9hP0m9Ryo9xop63yntlmZ6TcZnQrOhGvbz/UTEZ0ua/BO+DyL+
b1KMGuJnk86VNF/aPxx3bqTx0nrtkHZJPVtPfZMxr0Uzq9nVP0H/BmlmC2f/
A0gvK1Q=
         "]], PolygonBox[CompressedData["
1:eJwtjz1LgmEUhm+kLCtcXhAExce3f9SWQ0MNfYGvDlIuUUQhVBgUQTWWYzWW
s6KT/6HWyvaaug7nHS7O53Pfz6muJyv1jKQIZmG8LPUWpVFFGpAPYb8o7UGH
pZm81Iilr5L0CVM4zknfxC36Yr5DfKf+gMOCtLEkPQbft3dJ7DpN4i/1H9TQ
X4WDyDW2mf2k2keR+9s/EvTq8BBct0e8gzXy2+Az27mBXXpv9LJlaQ5O6Z3A
a/BZP3jf5jno4jVPXEjzM3zP8bwo+i12033q1UZnQt1grxX53+0Gu8VuemFv
k71L9p7T/Cm4v/3DNE37irfXaBTw/AeB4jy+
         "]]}]}, 
     {RGBColor[0.857359, 0.131106, 0.132128], EdgeForm[None], 
      GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxFVk1slFUUvfy089OBsZ2Zr/PTod/MNyM4YNRooiZGFAkrDZGklUCpUhOk
LJzWFlPiD60LNSYiJgjGpUqiqRoiGw0aTSguJAoYpSyIEYwabSm10I0s9Jyc
m7j48t68d99955577n1TGWhueXqpmZ3GtwzfoVazD5abdeC70G32MMZPA7OV
FbNY0uzdsllbyWxPzCyVM4uwlsA3Cbu+LrP7cD6fNxtaZdbE+nS3fnP9KZwb
T5ntx9eCvYmVZlWMdywxOxuZbU2b/YDxJ3x9mE9jfG6F2b1tsuH9xNaG+XwW
WAD81yLOVoXhfWA7VRam9cB7JjQLgfM67p8Ctnac/RbrO+JmrUn5GcmYvYy4
Hy3IjvaLGLelNd++VNjJB+/LxxVrCmdPw9fRFvjuhD3O98P+O9zT6fGSj6kO
sy/azR6H/T2Ifwg2WfB2NhQPx8HtYcy74XexKM7WI+bN8PsKfN6Ou47A5g+M
E3FhPQmfBnz/gr8Z3FHH3ngg/riWxF2TOd15F3gaLchmAjZ3t+tsPSMuyQV5
WF0zewS/D4LL1or25mE/i/lF2NRxz46UYqxib6wgDcx1KZdfp5Sjvcj7CH6v
gb9juOfFlPz2xzVnXNQNz06GwkecA3XlMHI9vF4QV0nks5EWbmKmXsZdP+br
jHlXSfm5mlXOqNuXTPyTrxOw+325eCSHVzKK+7ei8sm7mVPmnGfpg7iZX+rm
H8R5K8Ym+BlGjPtQLD/nxAv5qWH8OxBv5G+oqhjJU1tF/Cxg/xTWXsDZsWXi
g1yRE+IjTsZCvUw55nWIMcqIg70J4WJcrEPWw3sYf0EMNwHDpaJ88Cw5PReK
q3XIxUPAsID5npr8rU3LJzk86fass4Tzz/po8Rqp+pzrzCM5ITeDVemB2r/U
JV3srkrfzN1XuH/W9UmdMtZRj/dyTjyMgMvZjDSbBf7nvR574HMur5zMZRQ7
+WD88bLqIobx2YT2yMlwRv1rK7UaKbaPI9U2fdI3MRHbgYJ4pk+eZ97IZ4dr
9aLHSX01vK6uZhwPcH1Tlpb+Qrz7AsVODg4G0gn18gA4nwfnD2J8sq77dmL8
cpVwT8PmDbe/QcxprTMWaoP1M+Lcs1cwF3PgqARsVzDeHEmH1ONioP6wAXcd
CVWrb4fST8PrPSgrdtYW+ybr5QnEsqWmGrgeiLMlbs8+RC6Yr0HsFTF/LVQO
qWOuU1PsiSnPH/M4Q73WpJspr1/qjXvUKbXDmpr3s6zLjormu3DPtUB4iOuW
TvFMvhlf0Xsgey7zM4NzxwL1saRr/FpKPpuB+uo7oXor5zH0iURFOqFemANy
fgHjcFb9l2/Xj2Xp4nyXapfvEPU/6v2Nfe58JA1Ty28F0iR7Nt+unvT/+ua4
GrYDgfS1AvdvrAhnA3F8FKn+2LNPeD+jztc6h+SyF/4eS6tvkHfyzznfmUP+
Pn2OOG8jP4EwUE/UEn9z/ZNQvhuei5jX0eFA7xZreTvwn4u0z7rcVNc7/WdV
muz3/G0oKId8V89EwvY9xme8N1KbgzXpgnXDe/k+Ma5e54d21BNzOoP87A/U
K/heRf7/gJzTrsdj4djrPNDfNvfJOqROPiuJ7x63ebMqzbFHZkvi4U6MayJx
+CrWj/r7S73wXJ/f1fReRT+7S9IYtcb3gZhoszMv7pnby94DxwJpecF1+KHn
hfff8HfkAGzur0jn1PvGnPrvJvxf+g/jWTcU
         "]], PolygonBox[CompressedData["
1:eJwtlV1I3XUYxx/1bLqj7jR1x5dz1PM/Z+KxtTYYrIKYa4qg1E1QjZo1Fzj1
oq3lxsYY6i6iddEc7CWiILWlZq3YIDYo6GKiLEqN5UZFYLRFqMssF9RF+3x5
zsUXnuf/e97f/sHe/U+/km1m+0EIvJMwq84zS8IcjZrdTJntjpgdzzGbhZ6N
mx1aY3YYfFmFXtJsE7JduWYHoOcqzB5Afx3fGsrN5uEr4PvACvbexn5rgdv/
BVsfrTcbBSfLzN4EH1SarQmbPZZv1sj3H+F/AO9Cvwfeirq/zdgbxdYKOgl8
P0+Mc7z/Tgx9a81S2BhHbwn5EeTPrMZuYPY3/Bh8GfpF8FfRuQIWYmaL4GY1
OaF7RPlCT5aaHSs0+4qY85F/H5ureF8NBqA7kp7Li8TQCX0FG7/B3wFpdN8g
/3HeupE/WGL2CPw20MBbI8iiRgZ6+NYLboP8LHj8TZPfZNxtvY7Ya8VmldiI
g33IdYB/oO+Jr4EHveRXE/IeXkD/mXLXVQ8WkD8S9Xj1fo73Rb7F8jz+/7Ez
TfxTIIdeh8A55Ldk6n0V+X5yfCrkPT4NvTPw3irnOvK5Rk2SYe9BE/GkNxA3
/Gf0pw76EvaeDHnPprDXHvVeLJHvjsBlJCsftdD/kfO/YDux1YOxhM+aZuBU
1Gum2klGstcDn70Lq8y+hm6hfs3gInPyKdga81yU01n0f6b3R3M8plv0u6na
Z089V+/D5HMg1+XzoLuIaZlYC+hRJ/TFhNtTPP3YeyLwXNQz9S6HHckGJWA9
qE35Lmkm0tB7iGmQBSxCvg16V9xn9XFQCr8c9dnTzGn27ha7b+3IdNJnULPY
Sgwd5HY37vXRDCxAf4OPZyOe40H876UnL6H/xTqzlzMzo9mZ0KyDT5C3iMt8
DN1CbZsrPAflUhh4rLn4XAudG/NZkr8eYk0hk6zyndZuDzJ/A+AUdD94iJr1
FviMbIS+w9ttkEanDtyK+21pJYZfka8PfJe1s9sDl0lnfMjXUKXHop1ZpDbn
M/Oqnj1KbA/Sw78KvGcN6P9R4vXWjOzE7+d8qy/0nX+Vt2/J+bmI10y1003Q
bRimFyOZGdIsXQKXwSQyE+AaGE/5zdDtkI0p+DS1q63wHdeu60bpVu0C07y3
1XgvdFNvVPrN0Owo5sbAd1K7qZt5nlmbJ8cwuW5E/0TKb4pui3asu8prrFrr
Zup2hgOfDd3AP6nNdyn3LRsz0H2Ze6GZySfPy1G/PerRTMJzVu6b6MvDcZ8R
zYpyVu668aqlarpELBuQ+Un3BHRibz7wXdS3BegXyj0f3ZyuqO+EdkM3R7dH
PVfv9c/5Hvsp+KyIz2Qr/L6Y74b8tcfch3yph+qlbqpuq2ZWszuMzodgEAxl
eqRe6Ybqlt4HrPT1/w==
         "]], 
        PolygonBox[{{6487, 6486, 5738, 2075, 6894}, {6542, 1904, 7446, 7444, 
         7445}, {9123, 9122, 9130, 3841, 5411}, {6892, 2074, 5737, 6486, 
         6487}}]}]}, 
     {RGBColor[0.857359, 0.131106, 0.132128], EdgeForm[None], 
      GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJwtVUtoVGcUPtageUyiM8lMcmcyydy5Gd8LHxULGV/YCqK1NiJC1aIR7aJG
ISotFAzio11pXRiLb3CR1EdrdaNRW1BHXVqNtpsKGl34SiKIu9Z+H99ZXP7/
/vec/3znO985N2zf0rb5AzM7j2cknv0ps40xszM5s/6s2bRKs3UFs9/GmEUJ
sz2weV9n1gun12mzCzhvSej7TfiV8KTKzG41mm2qMLvdKD/aPMP5g8isC4Ge
Js0GY/LhnYlQvm8Rf2utWQd878D3S9x7qUo+rcCyGfuriF3AfjWB45mNsx34
/n6EzmjL80K52ZrRwjqY1n5lYLY4bhYDnl+ApxX3t47UnWOB4QYwjMHaD5x9
uPdRs3BGjn8Cz2vMxmPdhbUJvjMQtwP37kfYvcC+pUq88duf4HEp/C4ir/Et
Zr8i3kSslhSuo/ieAM7Lo8xqYfca/uXwPQXul1UpT+YyjFhDHu+zQBx/hTuL
sLkOrnbBrBd59cSFqwMxdmN9mRf3kdeoDXHLcMcmfC9i7QYn3wD/4WbFup1V
nP/GKq+7wFcHfM/A37oG4VzboDNydbpMtvShP2Ow7sz5CerXhf1POdWtNEo8
r4m0RsAyL1QuG5FLZ6Vqw3z786rP/bxqxXPW+ADexyHWj1gXJpX/ImA/Cf+Z
sK/Pyrbd71kI7X6B/c2seCf/E7AOJHXffWCZmpA94w1D28vByYJA2qYv6/4v
zlfhvC2QHju9Lp8mVad7eXE86Hrm3bShJmuQ43WcV2NdEuj7d6jzkWZxXIO7
lwHTc8T7vEVYiIn3xsvlS56TWeW4L1CdWW/Wkvql5qiNYzlxPtAofsnzqUh5
kzdqhX1EH9ad7zynfli3nTHVjhx8XK1zxiq6/buUeFoOnJ11yu8HaGN7Sv1m
GcTHfhL2o7EvZcXfc/CzrUn29DsIm9mwmQGbYqUw8X7mcS2u/pmMGBeBe0qL
clodU4+xLtQZcVbXiUNyWe/8nEipDi98JjGPTzyXQzn1HWfYlVA9tx72b2rU
Y4z7ymfFikC9w3jMgTOJGqBeX6S1py76Qt1/vF73XPHZRI7IFbXMXmRfEiu/
v/FY1Bm5fpyWTa/3L/vs6wrHVxAn7QXNROKYH2qWESfxlhpl31mrmcXZ9Q/W
7gZp5Pu0ak6eqYlK8D4Z/FdklDfxEDM1QG6p0V5wtQH89WDtzon/b8HVHMQe
wn4u1mtNyuch4l8OxfXVULkN+7x6GGmO/xWpN9kX7A/mzdnHHE/n9N85m9Ms
GXY87AX2AXuNfpy91BBnJGcQ+4J9E/c9c2xyrRIjdcDasd+Y09JAmuc/g/cM
+Ix6inV6Rpr8MKP/E/8jf+P8I7zPwfmhlPz6/H/DXiEG6nCW28zMaA4OOX5i
GfK6M5fFPmc4d4uuedabPcb9H6HqyHp21Urv/LecjfSvOhdJ1yX/d7KurC/n
OrVDDfH9Z6/dvpR66IL3y16/c2sg3ZP73xGzyvWwMyXMxEQ8L127r/Li45LX
gnVm/ejP2dDjs+h/JVIfvA==
         "]], PolygonBox[CompressedData["
1:eJwtlFtMFmQYxx8OBugHn/AdOPhx+IAvkVzWbKsNEtvUphQqrc0VNKWmuTyU
xOaaRS7dWjfiDbqWXsiFhAdcdCGH0qko3IGatBlbSbTJJN3SdNNZv/+e7+K/
Pe/7Pu9z+D+HeMvOxh2pZvYxSAcd5WbP5pj1Bs0WVpr9EzX7O2B2FyyLm7WW
mO2aa3Z2ntmtiNmiIrMqkFJolgpmkbsx2JzBP+RvCsyGnzHbgX4P+rnYuISt
KM7Wot+C/dxMs350NqE7gE4/mF3Af3CHePYRz9IUs+yw2eKE2dP5Zgli+LbU
7BV8vAxW5JutzPcYFMuX3O0Fho1Epsdk2M3gXM35AMcHvK8nx9vk2kM8AWKb
4i6P97eI/x7+WgtdV38y+dvF+RjowNbBiNvQexM5dZaZfUA+YXT3cr7K+Xfe
vzLn9CC5NOJvJuicilvpSHdbltnlGJwWOR+KaR26h+CkNo3agE7kqkqvzQX0
26jF5/DxQp7ZaeL/F3vjxDgG0ivM5oDPQu5/ZTbckt/RfJdXgH7Ov+KzHdtN
8DOBfJUY181zm7K9rdJ9qwbbkS8Vm72Ta/YDMVRz3lDssdTyZxV8dOFzKNVr
fhz5Nvam0/3PKuwt5G4gx3tIvTTB+b2gx/AL8ilQE3Qbzcib+PMiuj/x/33k
twu9t/bgcw+5TdIDA/h+Fbwe8RyUy6D+YP9GzGXZuE6s6dylgQiIgq/h+78U
j6kKf6tLPRdxJu7UQ+qlx8hPwJWY12o/728Qy0DIe1c1U+2kI906emc5uIzN
YVCMXAKG4s59CE4GkbuIKXOu998x5MP0Q3uW9+sh5DPUvBf0gR/BYjjvg58G
9Md5/zPm+urBdvx+j043eJ77JWAU3yPJGBTLNfBFmnN2HbmRHN5N8jmJ/sYC
z0czoFm4Uuyzpp54E35fI+btWT6/y+M+c5q9NejWg5fIcSe6Nfg4gX49NtfE
PAflop2h3aGa36jwGdesK2bF3pLwWsuGbG3FZn+Gz4BmYZT6jJR6TspNMyvu
LjJD85GDcZc1g5pF7RztnhpyqKDe00X+Js5nQx6zYldPqDey+X8h4PXUbtoS
9VzF0Qx6fVHnXjbG4L+h0HtBO0277T7vwwGfcc365uR/3eXx/ht83gRHiOto
xHtWvasZ0iytT9ZDHLcS3x9FvovUj9olu6O+a1TzW/BaF/fdrBkb5v+G5Hxo
57WhG8F+GJwj1vNl3mPiSznmxL1GqpVm7iR85oR912rHatdGk7OinaLdIg7F
ZS1YhPxdmfeq4jlS5jOpXlIOykU7Srlpxj4t8Z2h3aEefg55Kz4+THhNVdtH
+H8Y9ju9acdq14ozcacelX3lqFwVg2Lp5PwX55/jPlsfoXMO+RNsBPK856ew
syvkb+pxze61ct+d0pHu/3yBBPE=
         "]], 
        PolygonBox[{{5389, 5388, 8363, 3174, 8362}, {6965, 2110, 6968, 5396, 
         5397}, {5150, 5149, 6760, 1977, 6761}, {6920, 2090, 5759, 6516, 
         6517}, {6964, 2109, 5781, 6535, 6536}, {6933, 6932, 6963, 2109, 
         6962}, {8364, 3174, 5775, 7419, 7420}, {6536, 6535, 5783, 2110, 
         6967}, {6517, 6516, 5761, 2091, 6922}, {6921, 2091, 6923, 5388, 
         5389}, {8384, 8383, 6542, 1077, 5792}, {7420, 7419, 5774, 3173, 
         8360}, {8359, 3173, 8361, 6932, 6933}}]}]}, 
     {RGBColor[0.857359, 0.131106, 0.132128], EdgeForm[None], 
      GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJw1VUtsFFcQbGOw1453dpedWXu9a3bHn1zCJShScuYARMHEWBz4hCChCDAC
TAArgSjAIQgviANCxBLiJ9lghEAkwCEQPkZYkFxxLghxgZwAQQ4kEv6FKqo5
jF7Pm379qqure+K1vd1bZpjZJTzVeCr1ZtmE2apZZitrzfKwh+HQN9tsfsps
xwdmqYxZgKcP9omy2ZoGs+NYLYKNM1Yw+7bDbH1gNtZq9rBo9l2d2c6s2R48
e2H/jb2v8vKvhv9Zj/kmjXtwd6HG7GWV2QC+12Pv2UyzmpLZFPDVlYRxUVI4
b8eyb8X6fg24/gHm63g/iji7cOezZuWyPme2IRC2oEpx98B/WbWe3bDHcXZu
h+wgNDtSUq5Xkd8kcB8E/gtlYWfubYgxLyPMH+OuJNahpPLgesZt8jYI+zfc
W+mQHYGfp5HwkLMKOOlF3MUF5cF8iHN5i3JaCN/GVsWc2WT2I86sw9kH2DuI
3D5Djh/ibL/H+aQgXskva3cLuHuB+Q7WyWbVdho5fgH/5fAfh306J5+RsnAR
BzE8T4m7P/BtPK2YrNdd3DmZUP5Tzo+1CBfP0P8J7voJ29ezumdXnd5ZG9bo
85LqsNtrESXkF4Lb/jmq86lGswWReCAfP+TEfS+wJ5BnD/y358UB7Yvw24v3
AdxzGPfUFoV1TVG6Yu2psYUe8zEwdOWl+yng/R36WQCeb8TKYYNrZgC8jwFz
D3xGZqs3yO2vZeVODnKtqi/rzBoy/mo8G/PCTOz7kdd+fPsenL/KSEPUD7XN
/ZXIebRWWLeCkwdl8fFNTvyRk3ccOg+MTd2w7lnktBjvK2DfB56JUHYn9m7G
Ov+oKK1Sm+SBNrmnPh/jWxkxu+HfnVK+xECMXOl/E3i2gJcbWCtZ8Uy+6fPK
/Zg368vcz5dVkySw7QtUb9aA2vkoK/3w4XnGDyL5/4JznZH68n6LNLkqJV3O
K+jeqCC+hwLh/xf4+5Hja6yb2zVDNmH9q01nx9qke+q/qqDZxjqyvoyT8vl2
ORT2Q83qI+4z/rVY9TkJTd5rE0d/Yv3U+Wf/1bsm+/LCNZjWPLhXVB1ZT36j
D/XLXgo8PjUz7b1fW5L9JlTfjbjeGIs1o3/SuaorKB/m1dOkGdWeUC3ZT3ca
dPd/OfUn50dfzr/nVX/iYEzeRZu8055Iqw94bsL3mdeQzzT68jz3a7zX2HPV
TfI70KGeoZbmhLqP91JrmVh9tySvnmMPkN+vi9LnoUbpib1AbfCepP8j/m9W
jtMee9T7ZWeo/1kFfZYMpbkXrcK+zucYeWXtyfPP3tfs76529RbnFnVB3/f/
i2Wu/7s+84iPvcWZRW6/9BnCnM75TOB/g77UOXucWuAMJ3eZFmmGs58zlVyz
vu84dp4j1/kw4iVK0iS1yXqyru9nK9dtWNOxvjXE0su41469SF5X+z99xHOj
vrl3JZTuA/9fHCtpJvN/yLnD/FKx4jL+UvD0Fto8Jy4=
         "]], PolygonBox[CompressedData["
1:eJwtlElo1WcUxS9Jk+eLmijJG/Oa9xJjoXXhgIruVDC0JGoaN3WogQraFDXi
PIATaoziQksrtFUXUdqKglJdOLRSnOiyxp3ajcNCRV2IOCX1dzguDtz///u+
e8+999zb+E13x4qyiFgMPgLVdRFbhkZsBT8XI06XIk5xYV8y4gz2yZJt/TuB
/Q93VpZHPBsZ0TUaBx/7/BBmb23EpcaIluER8ysizmN/Uh8xZYjfV6ci3hDv
q0REin8P8xE3eP+mzBx+wndFA7xAGmTAk6aIXdURjyD7GPs17werIgZAJfc7
chElzn7FxwBnF4lxATwl7jNQA4c6zv8eFjEC+yBv1hBrRk3EH9y7BOcx4B18
2gsR/aMiFnC2lJj3OB9sjugbEXGM7/JsxCru7iTXBeR3jfufkcOnoAwe5eAm
HJdUO6dZvO9vsq9vwS3siXDqTrheE7C7suauHL7L2qd8f04NL8O3Ax+HuH8V
9BBnMm8mgRT/0+CvRt+thf/iNP2Bf0eNe6Re/QfOD3VOtzjrxP8V7s4gxqKC
a6raVpHjcnJtoIb9lfZxnfvLmn0mDuKyP+O3x4mZ4W3ApTNh/muJP5sazOd7
M5rYTK2OZKyFH/B5Aa43iDkv4Z5cL7hH6tXv5H4CtJFja94akBbUU9UnB+dH
/F+atq0Yc4g1oN6BadybDvaOdq/64JeGX7Le2uvifpXq1uSztdTke2ozkLcv
xXiXtyalTXF8i78viub+nPMW8p9LPR7XuMcv4XIGzqfBWXAu6x6oF5qBi43W
sLT8L7Fv1lsD0oJ8yJd6qt6q5j9mrSFpaTv/d4Bj2H3gALEPgmTR2v8aPkOK
nkHN4nhq8KrONVQtx1LbcWAD/3qqzOl+3pDdy7+NnL3Muj+606PZy7q30ry0
f7fo3KUhaelsyrXTDGmW1uVcW834PnLv5nsUvd1G/x8UrAFpQfVs4+wXdkjn
MGsm8HWv4Pv6d7jkHaRdpJkfrt6XPCvaMb9hH6j1t2ZoJLvjfsGx5EO+ppLf
FDAT3bVkXEPVUhqRVjTzmn3tkASxyj/oV+83pd0j9aoC7VeC3gbXSjO5p8E7
QrtCM1SJfRtsSnqntZLfC773JF0T1UYcxEWalrY3wmF90jtHu+doxr7l40/0
cqfgekmT7Tn3XL2/Q653weoP9VaM3cqnzlpQD9XLWTnXWj7kqw20FqxRaVU+
5OsIPo+mvHM0u83k8z/8BvO2VZOF+Pqy2btTO68d+z08yuau
         "]], 
        PolygonBox[{{5398, 5397, 8384, 3183, 8382}, {5395, 1903, 6967, 6965, 
         6966}, {8385, 3183, 5792, 7447, 7448}, {7448, 7447, 5791, 3182, 
         8381}, {7397, 2432, 4991, 6509, 6510}, {6510, 6509, 4998, 2440, 
         7413}}]}]}, 
     {RGBColor[0.857359, 0.131106, 0.132128], EdgeForm[None], 
      GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxFVVtLlFEU3WnNqDWjqTPOTWf8HKPQ6q3sD2QUUXSDciyI7AoadPESvXW1
EpqytxK6CNFDF6WnDMoe6i9UpEFFD/lWQVdbi7Whh49zZp+199l77bXPNO7u
2dRdYmZ38ZXiW5Y3e1xpthzrirTZfRzWxMzWVJlNh8yuzjF7mpM9DnsnbAV8
K31tmifMlaz2scCsDt+LMrNLdWZnys06gGvBWShjNog7N2KdXy4Mz/hxHwDT
WWs2jHifkctb4LJzzdYnzX7DPoocOuvNHgK3KiTca2DqgdkBeztyXl2l3xdT
Zi/DZlGcr4N/A2xvsN+YVEzGngXmCeIcTJgNNQtPv5FqcVLAPbfzinckrvjk
hfV2I84+4D9mVA/relKDPOHfhFr+YP0L3yjiz03ojJj+Gt3Hew9gnQC3w+Ai
gfyncO8rxLyGxmxG/AL2W5LinfyzPyfhP4Q4XbAPIKfFuKsU9imsP8r+c8OV
nJNH8tSbVn/Wlir/cFb7McSuiKmWPDBtIfnTNwr7IdgXpcVru9ceySjHbzHF
WO128sT9HeTan5Rva/q/VoihHk5FzB4h/g3Uex1fvETne6qVY9T31MN51HsR
PgZ+qvAVsY9incb5JPaNYWG73He8UnEZc6HjLyPGXscw9qRznsR5X7nyZs7f
MuKBvaXOqLdiTj2mvQf20Yjyr0Sc7fXKYRu005RWvay71znvSQnLmslnnffx
eU6ap52aOO09PQDfcw34KlB3g2qkJqhLxhl13mZg++LccR7Zs8D73uZz0eYz
yj1zpX+Lc059U9vUOPfkbMx7Wcwq/g3HhLLi5gfmr5BUnn9T4o4c9gbCzng+
t/LSyR2s76tVA/Pn+t57FoSFpYamHMM+dnl88jHt+VMznIkpxxzy2XmXEQcz
nud154QxXzqee2qj4PwUXfPjMc0o54tvwYjXSx74DkUdf8HfEL4NPGNfNgA/
lNKdg+hRGWLOwl6OtRjo/DL6+xDf/gVmD7AOeF/IPzW4x3XI+zsWKIezDeLl
O+obzsl+NafaA38TSqJm98LSzOGU+IknpKUBj893inrmu9jmdtaypln95ns/
CEwLMMfgG4JWl6DmeWm9GZUeh33q8/n6kNI89UEDn1Kai5+1qpvn1Ec80IwN
4p7ShOrj+3c0rre3Avxc8HuPJ/XeUT/PUONsRjM+p145EXMe2F/+5vPO/lrl
wFyY22xE+ZEP8sK5IHfkagzYnf4fs8t56HQ9rfX/OM4i+8m+Mu7NhDR3K6E3
jDphXa0+1yf43ge6d6JGNTDPrxlx3OE8s/+My5oLfm/g+mRuvIvn7RFhJhq1
H/H/StbC/o7HFWtpXjqj3tqbdU4c6yX35IB5sreshT5bM6qFNdGfNmrzH4XJ
CKU=
         "]], PolygonBox[CompressedData["
1:eJwtlEtIFGAQx8d2XXXLB+W+V10fKz0O0SnqVoeUUgp7QGkFQZkI2SFKkS51
qFUMfEVdMlA7ZFCWdSmDskNd6xSR1T2oQx4sH/3+jIeB+eabx3/+38xXfaar
5cI6M2tBgsh8hdlXZCxidh9pRe8uMlstNmuvMZvd5PoctuPc5bJmZzeanUOi
3N/h/BO9Ld/sVtLsb7nZAwpUkvxAwmyR8yTn/QGzgiqzE+SoCHoN1XqbMXvM
/SjnOfQucozmme0MmV1E/5M224Z/e4HZAnpf1muXcB+Imx3LOrYf2IbRv6S9
dgOYZ6vNnuNTiu80+KbRw1V+L4xLYOsFYye5z28wG4yaXalxLPfgZoTe+7jP
IU0ps2bkTcbvhfk1egDb5kJ6x78Nv3FqfKdeY5nZ3ZjZq4znUsws+qO4Y1GP
J6kfoV5tvnMqbnNR71eYask9lHGsVdiG0cdi3tvNMFIJXwnnZgsYeokNxp2b
d5xj5I7jE0M+kutTyjkSV++J6YffXKXnilKjBzwdxL8ivp74vJSL9Db8V7g/
knBdtsvUW0l674pZRX+ScS6FvyTimIW9Fdso+mQd+Mt8BibQV+B4GdlD7r3I
dmwvSs0Ocj8jLsi5FQlQN4j8Bs8v5CE4p4SVGi8jbtNdR8Lx6E2CnHcwD98K
nXNxP5JxLOrhML49emP8pzh/xnc+7b0ox1Xu8lPOrTgOU6ch67MujI1Z50Bc
KKaT/AXEt4Y8ZyjtmIX9Gj1cRwaQD+SqRp7S72l81hd5jGLFsbDVknMJ32ec
awo8RrF1KceiGemj9jCYhiK+w9rlEO+Zv/bmevvlpOfSGxwCRzTuu6UZPUq9
SWwTCc+hXA3M1z6kibjmNZGunMq9gM/tgO+8dr8+5W8tPP1Rn3nNvt54vM57
Vu96Y711Efu3GvY/IVTlHIgL2Qo5d5f7LKrnG9TbTeyupGMStpmI/yXamWH8
S9I+y8JUjD6Y8dnRjl8Cz0DMd0Ecn0r7H6BZWMTWlPad0G6EauEfaU44V9q5
f2D5D47/smo=
         "]], 
        PolygonBox[{{5777, 3176, 8369, 7421, 7422}, {6529, 6528, 5009, 2450, 
         7440}, {6507, 6506, 5755, 2089, 6918}, {6315, 6314, 7216, 2271, 
         7217}, {6989, 6988, 5395, 687, 6986}, {7425, 2444, 5001, 6528, 
         6529}, {7438, 2450, 7441, 6537, 6538}, {7422, 7421, 7424, 2444, 
         7423}, {6916, 2088, 5754, 6506, 6507}}]}]}, 
     {RGBColor[0.857359, 0.131106, 0.132128], EdgeForm[None], 
      GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJwtlc9vVHUUxS8DBTql0yltp515M/M6dCYaiRo2EnWrQSDG30ZAC0GDQQRc
EIkhXShuZECF1gQTTNBqorYrUmMklhpUQtVtt1ISFv4D7ox6Ppzv4uX73p37
49xz7v1O6+DxZ48VIuJzPWv1/DUScb0v4k4ecU8pYs+miLOy/7Ax4g094z0R
G+Xz2oaIQ9WIaxtsW1gT8XIj4tfeiM9aEdPjEXsVe0Hn1iziUcXer/Md/X6q
qFoq+oziXtrk98PrIlZ6nYd8fPP+rXB0hedrne+q3lHVW6M6JdkKAxG7lCsf
jNjZHzGqPI/JNluyfWDE/jtU91LLfZwekr3PfvjwjX28oxxl4wHXTdmvyn4l
Nx9gnlT+rs4zRdfqr8tPfZV0HhG2Q6q1LrMvfd71V+zute7xzeQznpm3q4nP
2+vNL+/zY/7eVjcfYIQH6vymmMke900P/Daj3qf1dIV1SpinFPOnYrtN9aXf
P2pHfC//7waMe2mzam92zKR4vCH/gdy5u6kvaoNhbszx5Pm4bZ6bg/7+JOmL
zh/WHH+x4/rMRkv6/TMsUMJZzM3JjyXzsKxelvW+X72cr0Q8IN9T4mZRcYVe
8wV/t8rm8L+6ff6tOwY7/aJ5nvDABbrD1S/C9JawfVExbn6/LP1fqDt/RX29
vkV+et/X8KxRE70/HbX+s/K5t+Qez8m+WnZdcDEjnPRSSjqgFfztGzTPaAuH
aPr+kHMcVI/rM88A8wKX4Ifzau5cNZ0T8nlI8R8I/yvDzsNc7JL9cdmfzFwD
Tdm3M/LbLntb9vv0zCvfCfnPtc3RT+p9S8rZyqxVY9CzRJ5mwnA2vZPz7Yo1
fL7qb+4C9gQ+4OVG0mc1aYHOt8v2gdfVxNWlijHvVt0nOuZnh86fk0bXdeYJ
c9+Ic5CL/MwJeoNzPrc+3+SeXWYY+5Ex4wRvX+445pq9WEpzXs+9L5nOV6v2
P1nx3UYtMFNnMe04s8AMoC893sVQMDfwBR/wdyBhm6p6Pi9U3Df9w0mr437y
jued/OT6o+TeiF9JdxfvS037XGsaN77koVf2n1r9uWeJmZrRU1Suk5rlL9u+
v75qew/R+G/xuVDx/j8oe7eW7gv9/lzVeWbQoebdO17zjtELe8m9yf35XtU7
gg/coBN6MWu/6/2cOJxjx4fd2yMT5gcMzBX1qPtix/020rydSBqcF4ZC5nuD
/5ZtqS73dzHV6sl8t7I7h4Xn4QlzdnnUO8Z/Exi5Y8CDduwHc4teV9L8MEfw
Op3mn/1Hr70N51tOPLPP5CPm6Qnrgj7k7qb8exrWZ3HI9eGHGPRcST3CF/7k
KTfcF/9jC8OeqacSVytpnmbbnj3uof8BojH5Xg==
         "]], PolygonBox[CompressedData["
1:eJwtlE1I1GEQxidT19XcLc11/666u7lLUWp0ivRWh4zo04q0jLAv+tIgIUrs
UhH4BWndCiwzKjsWkahFVNjHrbp0MIIOHoPoFtnvYTwMvO//nXnmmXlm/un2
zt0dOWbWjOVi9Rmz3kKzA8vMmrJmm7N+7uNbb7XZg8BsDBsuM7spS5kNENe6
xOwW5y8Js89YqMasACtM8lhk1sJ7V8xsELyXJcQJs8KsPfD4NMmPcP5F7ESB
2XTIbBL8tiqzd2HH+LvcrJ+Y6RLHEFYG//X4P6GIQvwT5IvimxPljfslYt5H
MHyilWbfwZvFRni7iyXB+LHUcxQROx7nnu8cxOU8nPfDfQs+9+lNHhxzsSvw
uIrV8e0ZuZ5jT/GdJUdP2Os5DdZQynsjfNWinql34iAu4iRun+DYDdf5UrN/
2EbOm7BXaXIXUzf976P/Kfj2m3NOc+6EwxS9OgXGBfiOU8MA9U+Ct5r+B8TE
q10TaSMf+b7A5hLuI99u8C/j94j4CfD7wHicdM2l/QdyDJJraIXZyojXrNqH
ua+KuIbF6n3Sa9U3vaXIcTzk+iQTrom0iYAf4HuPHm1dzDdi9tKLOnwa4VZP
/3roc1fcY6Vxlre8hN+Fmc95ET08G3L/eeK7Az8Lo1b1xlyLo/jkcG+o8V4f
zjPbwPlk4FjXyX+Nvq/NuJbaAe3CscBjpWkP778r3VcxZxS78K5vehOGzvqm
2J/U+JpaD8H5KXqG6Gf+gibSJhb32qXhOfq7L7uwG/Szhdq+gXkx7DOoWWwq
Zyexbfhuxx4mXStp/rHMNZSWyjnHvQOMr2HXdAZuUe4RrBdufdhUqed6g88J
9LrDvL0N+4zd5rwn8P5J3+bAcyq3alAtEfjNFPhOajdrsTUVviPalYqkay0O
4jJS7r3XTI9nfAY1i9q5Nvrzp8xnTZjFYDeC1VDhNav2sYzv4i4wRjmPpH03
xPkg+KNxf9NMabZupPzfo5nV7LZWea3qqXq7o8a1mQJjZ43vtHZbO6hdHIr5
PGnG1sF1utp99U/Rv+U/iyu1kw==
         "]], 
        PolygonBox[{{7450, 7449, 8823, 3594, 8822}, {6262, 6261, 5769, 2102, 
         6946}, {6522, 6521, 6956, 2107, 6955}, {6945, 2102, 6947, 6521, 
         6522}, {6530, 1901, 7440, 7438, 7439}, {6539, 6538, 6989, 2117, 
         5788}, {5794, 3184, 8387, 7449, 7450}, {6949, 2103, 5770, 6261, 
         6262}, {5400, 5399, 8386, 3184, 8388}, {6987, 2117, 6986, 5399, 
         5400}}]}]}, 
     {RGBColor[0.857359, 0.131106, 0.132128], EdgeForm[None], 
      GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJw1VE1IVGEUvTrqaOOMhjM2z6fz5jn+MRNUhEHRsiJokdSy8Wc0MiIsJbQs
CiQqUDKK2mQlQWUZtIncVCi0qKxVoKs24aJ1QevO6XwtHt+d+92fc88934SD
Z46MlJvZFXwRfKVNZgP4vpaZvcPFMJwbsMt9s85qs4lGswtps50VZvdh342Z
3Ywpbgz+PPw34L+cMbsKXz6HehHZX1BnGv7eSrPlEL0i6sX6nxNma5vNVmF/
y6r/08CsrtksDRyTSbOXUbOOBsUvhYo9BVynPfX9jdgl9OtHzSfIbUtpBh/2
Omsn1HsoqlkWcXcMeIqIL+KcRJ174CBEzUIo+xb6XUwKA7G8cfXZh3nETRyT
LuY96qyAj1/wv8V9T0724Zy4IA+LgcOYECfjrWa7gL+pRRhZk7Vo99QLM+dk
nzTOvozyiYW8k39yuZoS1wuBcjkza+XrxS3r8Fx3NnNmYsp5Ech+jvO4J46a
0asWv8vgr0RtLxCf5HUWvlcV2gXn5aychZzQJv6fKc37XwuMYwx3znzmrtVI
Q5xj2pOu6sDDcFLzcs/kqc/VJ9Y+p0/26nd+zll0faOe7qkj39eea4BlHPpc
rjJr99WXPTkP56C2iGeuURiIJeZmD9o1U9H1GmlRfhPuC+B2K75u8NmFuidR
Zwy5i23a3fwWYELvUfgP+doxd/0YfQYyem8lnLOeYo76wkrMc7BfJ8XbBnrt
wO+90O1t5HbEMUdcfYuo2QV7HlxNuBn/NItHzjKF2negsXLUqUOd7mrh5Juh
FtacTvh+6DuB+KqU4hOI352Tnvbk9P7OR8XbXCgcD0K9E76XS8h9FmhHvZhr
yGlp0FMu88jzv7cf0Z6uu1y+ue/APlWtnWx3827DeQDfPtgHcZ71hJ98Ezv1
Ta18yIpD8t3qiwfunPcFtyOeefemQuz1B+xsuzTB+HNpafNTrTBQqyWHszGU
PxWKe+ZSH5x1wP2/UQtdbi+M6XT2fl/YuOeCr3n5f8NZqT32yjj9cD5qs+T+
e/m+Z9wbX2hR7LUms3igHXG3j0L1ehhKN9TPKGb52CCtUrOBr91nfWHscNj+
AuIQyMg=
         "]], PolygonBox[CompressedData["
1:eJwtlEtIlGEUho9jzoyNijA6ze9M8/urk2HaJgq6LItukFLLvBfVIgwlqIha
1HSBRFtkG+1iYGkTBNGyi0ELY2pX7aKIFq1btK3n5bh44fzfOd857/d+7/dH
o2cOj8XM7ABYA1pzZluTZl18nA7MHodmn6rMBteaPSG+F5ltqDfbCPrXm53L
mHVSfywBqP/C/s8g2W5WC3a1mO0E+9aZ7Qc/2PMdzDebPQLP6DmVMpsBL0KH
4q+1Zitps5aCWVDwnur9hjgL4VfweUvcxdoO5p9ifop+S+yfTHlP9e5l9iGQ
oDYJPlIzTW6Y/UN8XyNXAv+YZU1mDyM/W3ej2e0OeNN/N/23oMeFLBpIE3CH
PjNgkRnD1T7zKfGVwGu1Zy97JzPObzmOVlnnLO5/Gsz60Gc24/Xj8N9DfTNr
C+SGqBmk9mDOc6qZo7YldG1eo0FAfB3uz8l9qDPLwH008Luopkcp7ZpIG91p
SK9f7HkH1xKcf5PrbXcuWnup83NHfZy9wtp2csv0HKjxtXKHa5hYvRPdTT7n
88rwyYl/5FyksbTugV83qIFXHGympgdcIr4McqGf5Tw98sQLoZ+9Hxylf0Tt
XXP92oizoIIfu+AzBZ+zWc9JY3khkH/h28kdPoDL/cjjIpglvplxb0uTArVX
056Tp+cir9F3FfzrQp+hWeqp3vKEvLEJTBP/zft8cbxBr/Gsa6EZE8T9BT+L
OJ9scs/IO3oDegvl0O9CHqroTcBv26of3re6ZtJOHpVXJwLnrvPKW0v0+BZ3
DywSnwh8tjgkm52juOoOb8FloOBvWR6T1/QG9BZGwDDxWJt7R3d6nF6tRbOf
ja6JtGqAbyzlNaoNi66VaiLiI6t+1Rnm5f1295Le7MUm/wfoX6A3qbcpjuKq
f0gs555Vb82oZ9ZIwbnpH5SAz3+62JMP
         "]], 
        PolygonBox[{{6524, 150, 6955, 6957, 6958}, {5392, 5391, 6983, 2116, 
         6982}, {6526, 6525, 5778, 2108, 6960}, {5120, 5119, 5187, 1757, 
         7593}, {5381, 2817, 7947, 7518, 7519}, {7519, 7518, 7951, 2818, 
         5382}, {6959, 2108, 6961, 5391, 5392}}]}]}, 
     {RGBColor[0.857359, 0.131106, 0.132128], EdgeForm[None], 
      GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJwtVMtOU1EU3RFoCy1U0we9vfSWa+uDRJ460RERFIZVZyitNjU4sKD4gIHR
RBIRU000OjAkGgeiOHBuGkMiU+c6U+MnmDh2LdcZ3J5z9tmPtddep2F96ezi
HjNr4uvAV8dPOWpWg/G4b3ak0+xx1mxxv9kQ9n1Fs0wJ9/CbD8yOxswuR3U3
Df8pnKewfoHtc9ysCr9JnD8i376M2evQbBw+Hmy1mPZnEDuaMishJoT/Qhq5
e8wuIH8W/ruwP8ibxQvABP8hxJ5ytTaBbR51KsjxDPh9X5gGsG7ElYcY3gH3
I5y3sI6XzT4lzSawziblRx/mYC72PtkrfJUu2Rn7v2f6Op/hpM6sS9wlx9tp
1+9e9Pu7qPufWG/kzHYiZgdD9czeD3cq3wEXS+5Zj/u1hDDQN4JcH2CrgYNm
RrXXSuqPWImTvJCfE1i3Bs0aiB9GrZin/N1Y7+K7iv2Ir37aDv/FQLOvYd3o
Vixn/wJzH0POLPy/wfY9oftWVvfLyNfwNH9qhPiIswsYVwLhuo016qm3S9g/
Kav3HHK2UqpPnpi74fLfT4hzcnEzLz2tBsJBPP1YD7l+qYuXvuougeOo44o2
zoCzGMV+wZNWB8HJmC8eyAd12nYaeI9cfeB0uyC8xEEM5G+iR3MeLAsnOW4V
ZZ9Oa23G5TOTlLaY83wgjb2Fb4C6x4D5YVbvgdgqsCWK0sJmKH1QJzsp9cr5
8+5aTjyvI3Y9JZ7+DsCnLJ/n4H/Zaex6TrkY9yrUXDnfr6h5z2ngJOqu5DRH
zrMaSBN8329wnkXtc77TY4fmlPfFIbmsOJ2v5sTfjOv3V1HnH0XVY91MKK1S
D1XHT9u9qV5w/RS9JAp6l9Q9+6H2uWfMHHr8g7tIv2ZBjvlGqBnaOQ++v7qz
b7s5Wlr/NdQbdcfZE/8VT/67LmbE6eGOp3rUG3HectqjBv8Bnu+R0g==
         "]], PolygonBox[CompressedData["
1:eJwtk0tL1GEUxh/UuTrqwmb8z/ydGaeZoMjBS22KAqkgbZO1LC8pRhE5ltGV
IEjKMQoqslUUBKW0aJlEhFAfoesuW/QJgpbR73RmceC85/Kc51ze0vTc0VqT
pP1IC5LKSw8S0tmYdCMrXc+6brb7nVJfKL1ucls/eq0ojbdK1Q5pNi3VM9LO
uLQeleYDaQP/Q3DfEfMT/XOPtJCS3hI/UJES5JwEawc5IXgJ6m3hPUF8Dd+f
bmmJ2r2Quwze3py0Bxnpkg4hi9Tb1uIYOfLnsx67C7ytvLeXpG8px1iE/72M
+2ew9VS8J+vNYiy2F/me8ncE/F9weA+XD+BfzLnNfJbTxqzWO71X6zlPvSj1
y8T2Ya8S34Wt37hQcwrf+cDj69ie4Dudde72/gu3sEAfyBd8X5GnJc8dwP8M
/RaYH2New2oliI03cix3X+i7sR0NNTAMK1GWkmXnYHiv8Mforb3o87N3lHck
7brFpPClqTnd7DUz6GvIUBs7T0qnNjnnemPfF+gtynx+d/gMbZbVks/abMeY
9xm4TMYdw7CuFHy2oxH2i34AzMGk30AcrmMFr7XEDo6j/yj6LdlObDcLZb89
u7G7zLw79FuynmbIH6z4rR3h3Y/+nJzZVq+xwf7mAu/X4s8FvhPrx3Zit7k7
9Fv6f1PoU3CoxHwmJ9AvFZy73bTd9kv43QH/Ju9PvIPQd2c9W+/jxE82e8wK
satwXEGWqfU47TmWazVi2MU82pM+f9v9o82NXsBbRr/duAeLWc37n7C/cRj7
aENMtxuxW1ljXsPM4yDyBn0ETsPIVXq/FrjNfMZxouB/0P6i/XH76y+KvgvD
MKx/sPWDdQ==
         "]], 
        PolygonBox[{{6979, 2115, 6981, 6543, 6544}, {5526, 5525, 7648, 2610, 
         8076}, {6941, 2100, 6942, 6512, 6513}, {6264, 686, 6982, 6984, 
         6985}, {6544, 6543, 6995, 2120, 6994}, {6266, 6265, 5787, 2115, 
         6980}, {6513, 6512, 6952, 2105, 6951}}]}]}, 
     {RGBColor[0.857359, 0.131106, 0.132128], EdgeForm[None], 
      GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJw1VDtMVEEUvYDA/kDNyv6ey9v3doWYaCIkFNhokMRYSuOnUKSyQFBRdkGN
hk9sIJIoiCY0VjZSmJAYIaI2JhYG0YYKNNHa0FiYqOd4xuLlzpu5n3PPPTNB
32DPQLWZTeCrwddSb/YMXwE/95JmD7AXBmaPGswe4vtRa3Y11D7P+z2z9h04
T5l9SJi9qtPZCey/wbqSMetArhHk7K0ym8maLeD8GM7ncL4aNxvD+TRy3cd+
BrVmkX9/I/LAjsTMXsOnFyC/+siP9fcms3dR+TAmChvBN4t1OSafavhvFbRm
3ExUfvT5jP3r8BtuVk9HIurrKDB1Yd0FG8uKizhst+tlFL3cRMwoYm/BtnrK
dwU+t7PiIZFXP3dqhKHHU7/s2weO3cBTgH0JDG3wnwdvlzPibRB2Kilexotm
nZ6wHfbkR/8nWJdRexgYKrDrJfzvMvsIWw9e+oD5Amq92Cl+yNNZnG1gNgfB
7bcmYdv0VZMze468Bfg8Rcx0Sv2Rd+JnvvcJ8TyAWB+xUeRvK4nD/1yyHmsR
L/OQz5PAehz/C8iZd1ytJlW3PSKdkI9KTLHpQLU82Euu1gBwHiopfztr5oSf
feQ85bmb0ty5XwXMuUA9/UoJG3Nzn3WWG7XmzIgn7zimDsjvYr30Sv2/zYqD
zYJmuhJXjS++1lu+9skV9Vm9xyyF9VJeeu+PS/NDmOsScv8mD764pN4nI+KC
WJljzGmGd2LF3Ysz6HkbvZ+GDdDXGvjZB9tbFHfUFDF3xoSbnBEL69KyD64P
IGYZderS8Ak093yg8w7nQ76IpTnQfaaeJ8HBdlr3vyFUHdZrTEpn1EfakwZ5
v3jPeBc/JcTvmtPnutMg+aE2OGfGsh7vN+8a8ZLfstMeNc75cV6RrDB2O46Z
a9lxSm4vZnU3OMM4cD52+Pk+kRPeKeanFiouJ7VQduuqtHCfKklz/7QHjZ0r
yv88bNbpkzptyKt+LeL+OAyt2L+R0VuRzItf8jwUKi/zXwsVw1jOhLjG3MzI
BzVBTujLuZPHvTm9yV5O3I9HxP+8p/XPlM4nIppn0emEeomG4ovaTITSeSyU
76J756d8aXWuSW8c8fP9Hm1W7+SgxfkSZylQv+z7L348yN0=
         "]], PolygonBox[CompressedData["
1:eJwtlEtIlVEUhbdW3sfvo7h5n957//tIu4MgnRVkVEJQBNaomiROalAZ5dui
oKSJQVRaBk7DSQ0CITK0mgQNwgiKRhpBTstJDfsW28GGdc75z95rr73OX+of
OHW53sxOEFuJsGi2IzD7EDMrgO8lzeZbzA5GzfblzA4rwF18fDNjdqNgNh43
qyfJe9bHU2bHiN6s2UnidsVspsGsuMXsUqtZY97vLhJN4D0ls++NZr+3mT0L
zQJytEfM3sJhne/z5HjB+g41/yWdk7g9hGsePFQ2izWbjWw3W6mafYPfVyJO
3YBYJ19zAh7cf8L+MHyH4DtMjIAD7nfC5XET3MDt8PkCnwX2rqUJ9j6xfkS9
q+Bu+BzIeo/qVZzFXRqF1I+XPdcssZHyHtTLGPUmqJeCQ3/E+SfB+3OurTjU
wLPEZNS/iXD3b9K5SwNpUaOnRfodJd84+XLw/Qi/l9zPguPsxbRPtBVcM2n3
nPttWa+hWvfRMED/np1mfXVmF+E4hZ6D8I82u6bSVpzFXTO+Dv6T8n6TrGOc
N5W9V+3pbIxvRuLOUVxVQ7Wm6beD2oNwqMMrt/DDEHgx9HNxeg2eg+9R+L7D
MxPofxpNN1qcUx35F/JeW/7pJl9HyWelme0GT2bcX/LoIc5nWr23Mfqf52wX
36xszrcKDjfXmu95zhN5rz3H+gG+OZJzrL0e8GjasTj2sm5IORd5+Cxcz1V8
NnpDfeCfaLoc+BuYSvhMNBt5VF5dTrg24i/vXcg4N3ESt0LJZysPFsG/6Gcp
cI2ldbrkXpIHMuByyXvR/Yow86mh3Ss03Au/Nfi8CZyTuElD8ZdmT9F+NfS3
rBproWsqbprBmap7VvWUc7rsb1xvXZ6T96Sh6nehT5Zvc1n3nt50nLPVos9e
HH6AP1f97coD8sJowd+mPCKvDKD3UoO/Cb2Nu0nPrb0rnMUy/m+Rh6OafdV7
1RvvBP8HrXmhKg==
         "]], 
        PolygonBox[{{6977, 2114, 6976, 5393, 5394}, {5394, 5393, 6992, 2119, 
         6993}}]}]}, 
     {RGBColor[0.857359, 0.131106, 0.132128], EdgeForm[None], 
      GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJw1VMlOVFEUPEg3YzegjN3N6+7X3URZu9No8AMUdaUriUtRnDBR1IUhkBgc
IsogxiFxAYJxCDMkoG41EYxT3CguZIm40RBBq6zr4uW+d965darqnHv9g0f3
Nq0zsy482Xhm1ps9CZiVZJldzjVLI7iMhNchs+/FZiP41x42O11idhixj/lm
H/BMY+/2mNmOPLNRD3uQ24H3ceTfTJnV4X0r/vfhacf7Q+S0xM0uAL82bXYv
pvy7xMDThNptEcWINRo0u434RXw/xd5DAe1l3bqoWTP47ikzO4FaOUVmJ7Gu
IX8KeYFKs3gCmgrNkgntJWfqGgZuC2rN4P0H8pbxXYC9gxHFH2C9gpr90FyS
o5XfxN1ZbbaC911YL/nyZrXC7LgnXwYQq0ppj9WAn9O1odzsBv55iLeg5iQ4
9YLbeELe0lfWonbm0EP6zX/0gfV7w+J6xnn4rVx1BhzPBngagG8H0tIdLJLW
r576+gy6ppKqNY3Vc/7QpxfUjJzzwN4CjJ4izUEv+BeXmi1G1DPWZX36veRm
gzqyi+UndVIv+8lYwMVZmxyeY+2r0MxwdqLw5BX4xHzNIGcxiBqdIeWzX60R
YdYjfyFPnlAve8yeXK0S3y7HuTVbWri3G7HNpZoVYs86fOYxnzNPLbl4RoKa
d35TF/cxh3vpAflxLzH4L+gwelzOkZD6RG5zlcK7A85Zlernvoy4UwN7yr6t
uPxTKcWaU4otuPjuMmFz3jPw6A1q1PjSzVkoy9LM9hXK5+qoeP6Cx7XIG8P7
I099Y594dnie3obEiXyJQzzOykvEhwPC63WY22I6yzzTre5uoG88T+wTv8mL
uKxH76+FdOaGPHnJs8I63WFx7oR/17G/1JOf7A29TPi6d+K+ZpOcyOF+ueZy
KK3ZacgTDvs2H5LX9KzDeVsQEcdYVPzYb37zHiI+OX1KCmcCXv3JyAPeH2lf
mClfM0wf6B/1UhM9vBVTTfbZKqWbflM7c1izMSZ81uG8zDqN2WXiPhnTWTzi
zv5UQtgTWN+nxJV359L/mQzqTP/rEd6PuTuHd89cRro5R/XuzmmHB/kpeb4M
jv2+8FmHZ4747HUopbulEOtiuXpcyLvC8W90WunJmJstzpgX1T1CDfOovz+j
udqEOufiwjmLtS2sGSXnL0nNxuekvGDf2Rfu4d6NWB97miXe/eRN/mFwi/jS
XuULl/jkO+hJxzvkhNM6j6G0+JHnT/D9XaEc5q764rSG9S+CkQSq
         "]], PolygonBox[CompressedData["
1:eJwtlEtIVHEUxs84mo+ZUSEbHe/M6DykfcuitHUP0kWPTVnLMI1yEWaLEIOI
lCJsMrKohZZRhpqPIKhNi4JSKttVLtqWbYLK7PdxXBz4/ve8v3POzRzrauss
MrN9SDFyeaNZSaVZdcQs1WD2K242gaKK74XArCtltlRu9gk5CV7YZDaMbU+p
2YOEWSZj9hT7hahZDvwVm1yYuOiXwfvzZt+rzKZKzG4S7xv+59Efx2eZfIPk
KSX/BuRU1iyb8Vj6Jt00MXaWmdWEzIpqzIJ6ag15jUnwDDEKEa9JtR0g3wr5
ZtCHas0qiLlC7kLMLAqexf6Zuc8cOJJ13QA57lJfMzF3ILvw3Y3002MnvbSg
vxH3GlTLED7l+C6Qr4N6z1SbLYK3JOEA29/IHvBI4L2LIyNeHf29jjrn4v5I
jjlQbxg5DH5IvxfwncJ+HBzl23Vst6K/R39z1HC0zOvZTuwXCef6KjFfoesI
XC/OhnmP59xXM9FsZvnWvq5vxnYi5Vyl6Ocatc0F3p9s5sE9ta67xPsO71b6
7w55TbGcx1As5VRtT4h3scxjKnZjg+/Wc5auAdxEjsWo86HdEWfibhqO3oHb
4L4VqUgzm7TPQLPQN+m6s26rGWvWKWL8AL8lZgM4QN6AJ4lfC05nXCdO/1Df
aty51U5qNwfr6LPYew7XeI2qVTNppz9rMhuNuc0a9nuTPtsxvpXg+4/4/eBJ
akqCC8Q/EfWdmG/0HdeuX+H9hffnRscDzOxlwneqZZ0/zW6E9y3kLLF7kW2B
67WDfdhvJsf7qHO8Fvce1at2KgG+n/DbVE2rvA/mfRbyOZT3HdOu6QZ7xDHv
oUqf6VLgO6Rd0s3r9pVDuTSzPPFOZ/1Wxbm4H8v4v0E3NZrxG9ItiQNxoRlq
lkkklfYZaBaaUT32j1K+C8rxGPwh6/3I5iP4duC7p5vSbUXory/s/4CKhHMu
7uXzl9ixrN+mbv4ne3Mu7VzLpzftM9PsNNM6bP8DSnG10A==
         "]], 
        PolygonBox[{{6534, 1902, 6993, 5789, 5790}, {6268, 6267, 7443, 2451, 
         7442}, {7709, 7708, 7127, 372, 5200}}]}]}, 
     {RGBColor[0.857359, 0.131106, 0.132128], EdgeForm[None], 
      GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxFVU1slFUUvXUokHa+GZzOT8fpzPSbGRcalE5LKDEx3SkJYJSksC60JmB0
YIHFVrcaSaBBjVJrwKgJ0vLThr/+JJAuCFDjApPpupBUFli2JoZazsm5SRcv
93137r3v3HPPexMerO375CUzO48VwWoLzf6Mmv0Paxmzk5vNzuXMBstm/U1m
n8H2NGsfxzqCpAHYJw1mR/NmH20wq8Fejpkdgn8Z/sMR7f/G/jbqncLqaESd
RuUzl7X6PT5fMNuJfTPsyxuVw/hoVjXq7Wb7K2Zfwb+aNhvLaU/fAuJ/wf4p
cLSWlN/YysbM7sC/htgR9FUNzCbQ4znkb0fsl6idDVTnboNwETfPW9osHujv
BaYuYPkCNT7FakXOSCgf61dhZ1CzFzV7cNZ+j2fe1U1m44gpoe4EONqCHi/B
TsK/PSL/x0mdyV4TeWH7HPh3RJTPmJmi2ShmMA27LRC2acRdAI438f077M2i
OD+Ecx/kxccfedViTfb9T1zzIv9TqP1Wk86pY/6JJtWczYnPmZx0EfcZLW9U
X/exv4a6Kfivw17NK/cK7PtJzZHzfITvLuwnoJ8G+BPIO1gUhmrCrK9BOvqp
WXhYI+kYIknNdQTYVxDfmVjP474CzOlAfG5tFBbmtvgcyRVnSQ0RNzE/T6sf
6v07rBbETwLjw5RibwFbd0RnsP47iPkX8e/CjmcVw1jyRx0TM7kfa9Y3a7Hm
VF4zn/TZseaU7zlzcsLemcNc4i0EyqWWqN8O53mgII4+dE1V3T/kd3I3MM8V
xeFfwLa3Tb93tunMHa6xn3PKHYJ+U6558vZDKH5utsq35Jrv9DrnkffY58h5
8i5R8wcK0hY1tgD7Deq0oe63oeaQ8FlQqx2Bag7420Gtk5uzMfExi7nOxXV/
uir67stLy+Sc2uv2Psgb+acWuK/5+3MvrTtP7t4D9jPA8QrOPZERnsWodPXb
Fr0tjOMdqruf7wDjyQmxfB0VHr47xHsDHAdlYf4A2nw7p9957zkDzmIPbB/s
aEx4eW8Ox6T7Ho+fRvxqqJ4uZjX3YiCuiGebc0UNdnu/g+jhNeA+BW5+TYmz
aFlnMYZaXauoN3vV7I2YOOR5fF/5LvO88VCzOJ0RRuqD+Ysl4ayXpHfeO871
9VC8RTLSZsFxtgfaV/39a/c972MmUL/fh+prOCNdLLumeZefxYWZ/wlhXP7e
ivz/pXUnRv1e8K1N+1x+LKm3+RazXFl9nSiLm6zzViuqdi2ld6Lq78ZRn82x
ot6MlNdkzIrjGS4Lz66U9ERdzWfX7y1ncTpUj8czqpP2fvsL4pr/mbxHWa/P
/xzOlBrjOcTCd+MFv87xHw==
         "]], PolygonBox[CompressedData["
1:eJwtlEtIlWEQhudommhHrdSjHY/HX21hdBNdRBdsZS26apdFK8sEkdKgu7Uq
CiO1+83uBeUxK7tYGnRZBCUEERTUKoJqEbWNoqznZVwMzP/PfO/M+858X7C2
pXZjkpmtwcZgI1Gzx2lmV7PN/pWZ7Y6YVaaYfU41OxmYvS82ax9n9ijLrIr4
6RKzaZlmKzk8j7PPCsya8etDZk/x+2NmE9Mxvs8Rzygym8X37bFmtZPMOsAo
p9Zz4o059EC9jjTvQb08jFMjw6wbG8LvyjcbTvUc5a4Dbx14ffQQLTV7QE5T
sp8ZxL9B/WziE8A/I7w871UcPsDlPjlfQo4xgP8m1+wsZ9fzvR7sztF6P8mv
gX8Xlh82m4ommyPOUVwryf9ErYF816qQnCPk/qLe15BjPgI/iTMPqf8OvCnE
y7G3+AfgY8QWBF7rGzkvwatFk9lg96NXHXrNhcMcbA9192LJEcfKIecO+UsK
zcZT/wU1F+MPxxxLfDW73lLvtQqNrsB1E/HqFJ9ZK34beHF6L8KOBz5jzXoI
qyxzzdpH+2umjxX8+57lHMX1IGdyw655L3g3sQnpzlFcz0ed60fsNbU2oUk9
2pTRTwt+H/lZo/MKwf1S1GetGWgWWzgTAT8P6wDvEFYQ9h3aRuxo4NrPhNPS
uOcoVzPbSryxyGermW/I8Z3UbqrHWzHnJG6XqTmEv5MzFSm+w8fAel7g+dLo
BN+LqFGd4T2r9x7+zSBWgXVFfCaaTS52F385NU9l+v7PZ57jSn0W+hfGXxt3
7uLYKXwwEvRyi/xq8rfzPSnsnMW9DrzTma5ha9x3UrupnMPEd4DZkO497sRv
yXWtfzCzlczuQtR3RRwv4i8kHmS55tJ+NXo9SfM3YBX+PvhXoU8N/5ZGXWNp
rTNt4P/Oc2zthHajh/zPIb+TiQLnLO56A5bRe33Md0tvyBneksGoa695JxO/
F3PtpLm01x3QXRBncb8Ox+lh32Htcm/g2uuO6a7tworDzsEK/c1RfWkqbd9S
synT55eI+Rukt2gmZxKBvxmah3LekfsXfvvTfMe167ojuiuqoVqJ0f19xb7/
Idcm+1uqO5lf4m+Y3jL1fI2znRGvpZ3R7uhO6G6oRje1RwLHkoZ/8beX+lun
mTYwj/+mL8gk
         "]], 
        PolygonBox[{{5057, 3629, 8857, 6971, 6972}, {6532, 6531, 6991, 2118, 
         6990}}]}]}, 
     {RGBColor[0.857359, 0.131106, 0.132128], EdgeForm[None], 
      GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxNlU9slFUUxW+BUpy2TibM9KOUmY+vUyypaRdqXLnAkIAJBeOAFIqJFLSU
GK1GURTdgXUBrX8i/+KGaFQkLvhrDGFBUGOrbtwIe7fGBFagC88v5yW4eHl3
3nffveede+6dYs9065VFEXFGa7HWfD3ioVLExiJit+xtSyJO9Ef0d0fsKPn3
ww/qbGlES/bhLtmdtk/Lb/6BiAnd+1pnZ7X+bovY2ogY4672F7TycsTBZkSt
Yj98tut8p3zG2LV2yR7XPrsi4o4AnumLqOvecfnf1u8/Vke8r9yXeyKOdNn+
qc3xiLtf92/JZ1D7gvB812PsvGkhj/hSfjdrEZvKxj+lx1/JbV/WPqXcU7q7
X/u+kv3H5fNb7hy/ah9pj/hzqc/hrNVprFXlP7os4nvlu1D3vjiLeEl+E/pe
Ec7n5bu70/aM9nVa/+jbuOJ8IPtf2V/ktheE8xntw+32+arT78OHGOeXOM7V
3PbdHucHB9ziiw0O9lo6513r2203xMOqxC851iWeKyXn5my2sL1HeeY6Ip5M
7325GjEpv8lU2/UV89lINnG/KczVZNVa2F5yvS7mznkpdw37un0O9+ADGxh5
D/bPSZ9/9ZsP4oDtxYb5/V1cfaxcz1HPFdYlWoX3p3Nj/kTfHx2wNh4bsE6n
/peLvNR0Q+H3oUE4qyZdkX+t1uPyPykc18XF6ysjThXWGFqbzl3j17Q/Ie1+
pt66vty84Q8+dvyxd62xDj7PzRM4wEDP0XvzynVC8QvZ72U+x+bu2cL+szof
XuPabc7Nx2CH385Or8LHTJd7hvho+EjqHbAQl5gjCU+5mnqxZAyPtNtGe29m
rsGxwr27I/lQw7FU32/r1tCo8DS7HQsf+hlun6r5fc30xqHCtV6k2G9lxveh
zt7NnPvTwjWcSxxuSdwe7pVfh33AdqhpP2qO7vnGOffxOaR4o2VrdEjz7EqP
ebmpmXFtmfOCn2/MO3iDp5FUl0rSHT1yvHD8H3utp8E0e+gJeKcOrYSZN/Od
OYl+0D79QZyt4voA83Kl+yZPPYnGhxOeLbnrS53pJbRybMBzbCjh5D5xWlXP
AmbCNvm8kfltc8L7UWGbMzQNR/BDvak7eiQnPuQ9WbhOp7VfrN+fbTd6/a4f
el0n+DmYWRPcP5CZF/i5JP++pmfD3oYxge2eMM5l1jBa5gzOmGnwx5sm0myk
dugEfaCTc4Xf3Uiz69U8cVg1bxvKrhP9Oph6Fm7xBwf8rk78w2s92bHKudBd
W9X1RsvoDL3R088OeP5O16ylTSkm/yHY4L5V87z+JTeWmTRL+T5avo99NN19
p2k8b2v/DyOS+pg=
         "]], PolygonBox[CompressedData["
1:eJwlk0lsjWEUht/2aksHQ7i9qu3/97+3VCq6ILEmosSUuDqToIa2hBKpthpW
qAW3hqS3GjtiXEmHRBoJYdGBjQRlbWvDTiQ8x1l8yTnfGb73fc/5ovbu9Jlc
Sds4CzgPQmmwSKpfIs3EpXP4h/B7cqSz2Hu5S+OvKZSmK6Vv+E/xn3A+EH9X
Jg0VeI7lngg45J6KSccD72m9m7hL4/clpLo86dVC6XYkjdPzFvUvATOGfZSc
Tmqz9Juk/+9S6QWxw/iN1dJzam5Qu5UeQ/R6HzqWLvqfpHY3/jLsn5Dchf0x
7lisxxT+6+XSusVSLWc4KXVQ00F+px3sefIfFfmdxWbBVIO9ljOHHUs4VsNQ
C5aJ0LFeKZY+VZFP/XX8NvJbqP/M3VVig5xJuEwTb4v5G7PU3l0p/cn1moeh
Y/qPDX8MvzclVaBfyDlGv67AsdoMbBZZ8hvA8wYNR5KugWnxmPhX4j+SPrtN
zHPpCvLgf5+5zyySRon1w6e8RLoGvi9gbaS+hfxWTlPgGpqWVbx/ESzzVc7F
OBiXvpRjs5mVYw9FPtv1zOdCwjUz7QzDDPYAdxvyfObD5LbxxgFiKTBcJpZJ
+Gy/50vPiO/k/Ur6b7b9wu5PORbTxLSZC52raWha9iT87X3cZahvoH9zoXM0
rn/LwZHjGFQhHal0LWzGG9mv8dC1tzft7e2RY/9F/3rs7rjvov2RbuLF7H9N
ge/8afTNoG8233fMdm2UmmSJz+ge9o6499pC/QD420PHajubQ/0kHA6iZURN
lvw9oXO3P1q3Go6R11rOHeyb1a6V/ale+F1KeK3N0GbZHPgsjbNxP7/Kd8X+
7Nsy31nbXeNgXCZKfRdsZ213bSY2G+MwEvkftr9smu4PfMdt122Grdj/AMaC
mIA=
         "]]}]}, 
     {RGBColor[0.857359, 0.131106, 0.132128], EdgeForm[None], 
      GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJwtUTsvgwEUPfV5RDxS8azE97UNm7Bg9AMkDK2hiMXiMRA1WYxiskhoa2Qx
e8xNSFQ9Rsp/kPgDwjk533Bzb+7jnHPvzazt5LabAMzQAtpnP1BksBUCR51A
rR2oJ4CFCJjtAObo9wL3/DC/Grg+TXuNa1/E2A0cq6c2AvySZIH5J9oK8xfs
He0yx1QLiXuABG2K/ck+4LAb+M56RrMPKWApNF+Bfj00R4P1XGhMYU+MGWc+
cl38FcJfMfeXNL68+h8T3kd73dCXM9ZUoZ+kpnyze6RPOrWn7qLdX9ifj3nF
X4i11anhWljkPKX+/UFjLbJebbMm6dmI9WuPkyHgrRV4joytWPe8G7CG97RN
8W2cE5ZwPtLGF4/mpEGz+ts4b3jOnmqv9RzT1/o92+BcPXKsXCnr/rOs/6ff
bYa+lW6nPWXi0k0uI/NJ+33KPHvD3rkccx4M+nbLoWekW5qlUXndU/8pxppL
Gec19w+cIGCP
         "]], PolygonBox[CompressedData["
1:eJwlkM1KgmEQRh9Lk0iNwC8oqM9PdFe5cd0d2CLblATSKjdFeQ/iHfjT0jat
s9oKthD/ttlFeAlBZ5jFwGHemTMzb3T3ePmwIWmfiBOVUIrtAcRpUfo+kP4o
eCE1hme8L7ek503pN5Aax1ITfiLu4S9E7ZRUSEu9yB3mOt+RLugdhs490u9w
/UiabHuP9TYPfdZJRurmpRuc5YR0i/8a7kfutlwXviJXgmu8V+FV4LuMktIU
/26W2pjfdMYuH8yoxr3nJ0dN4G676ZX6QeiuN+prRQ9jc5hrzU6tjP/JhN1X
OZ9lzk/c89D/xv5kAXfyfovdaLf+A4lMMvY=
         "]]}]}}, {{}, 
     {GrayLevel[0], Opacity[0.5], 
      LineBox[{5006, 5056, 8854, 8115, 8116, 8010, 8014, 9517, 8013, 9518, 
       5135, 9563, 8099, 5577, 7762, 7763, 7764, 6009, 8407, 5813, 8406, 5814,
        8408, 5576, 8138, 5592, 7783, 7784, 7785, 5594, 8141, 8140, 7786, 
       5593, 8139, 6291, 8100, 5578, 7768, 7769, 7770, 6014, 8600, 8602, 8601,
        5815, 7520, 8855, 8856, 6771, 6595, 6596, 5454, 7624, 8941, 5136}]}, 
     {GrayLevel[0], Opacity[0.5], LineBox[CompressedData["
1:eJwVj70vg2EUR09ZbdRX6YearIxmJISkX2Js0Y2SoKVsVm9VUxJbR8SCdjEZ
DNgkBn8KC6fDyXnu7773ee+TKJRS2yFgTVIDkB4VvRODXSl1CUN2En4HIaN/
9LP5p/lmFIqy5UzfCHzFoW2vI+vmkSRUZMNzWR/KkSzaX5L7cQg5W/AcJGB/
CM70ga7pPV3XFX2uy92+OxSdubUOrG90Td/pHj2le/WDdz/Kk7y626V51byp
jzVj8BeBVXfLSVZOzK/sd4bhQjdkxd2q7rzge1t+H9ibM5+XN+/+kHf59u0z
7jYteevrCXjph1lnTv3/sv4HB7o3Uw==
       "]]}, 
     {GrayLevel[0], Opacity[0.5], LineBox[CompressedData["
1:eJwNj7tOQlEQRRdRK6UxPlBAxUdha2sMfgCoQOIH2JqItsbOxMrExgaIaEIh
AlGp9FJJZYuFFHTyHfJYxcq6M/vMnXMSJ/nsWQjISXIZUouQ1dMrEJejOdi3
zujwBsxIZR7q+i8OfflagrZ8L0De+lwupJqAZ2mtwqcE8iE/ztc8/yID86HE
5N/5mnO/69CVYhQa1nW5NR+YH29CyX7He5Y1etvs1TNv8mCvqd/l3v6l+ZO9
R9mJQVoOZCoCEXewBSP/OTSf9Oyd/QnfGli35FR6a97f3Um/A72nC87u6mvf
cKhvdNnsyvlZd48Bq+I2ng==
       "]]}, 
     {GrayLevel[0], Opacity[0.5], LineBox[CompressedData["
1:eJwNzz1OAlEUhuEXOgEb+WcchgEMugkTl6AWaiPGmmgCWgBaUhoTKzSxYQ82
2rECdQMYC6m1wcRC3uLJd+eeczL3xKfne2cJYF93WciGMCzBYwF2A1jLw445
KsO9dx3PD+a2+WRvMgcrdfguwqr5Y6bMjNKa2De2/7kGL3prwrtedWn9Qgee
E84dmkfajKGlf+ea5oZiNVTXre/sOtdT6Hekqv7sr5iBiiqrpBv7w8ge1RTp
pAFtHWtQhS2zb36576f1D98609S9r72/0lBz62nvUgoqsK5f/xuaC3PsvnNr
Sx8ZLSM=
       "]], LineBox[{6718, 5963, 6737, 7690, 7708, 7127, 8971}]}, 
     {GrayLevel[0], Opacity[0.5], 
      LineBox[{6568, 5526, 8076, 5188, 6408, 6409, 5486, 8046, 5485, 9091, 
       5004, 8163, 8160, 8161, 8159, 5605, 6773, 6772, 7800, 7799, 7798, 8404,
        9265, 9266, 9264, 8852, 8853, 6934, 6935, 6497, 5383, 7065, 6255, 
       6256, 5767, 6938, 6503, 8480, 6504, 5886, 6259, 8486, 5055, 6941, 6513,
        6951, 7435, 6953, 6970, 6969, 5773, 9248, 8358, 8493, 9306, 5894, 
       8492, 5893, 7437, 7436, 6527, 6978, 6976, 5393, 6992, 6264, 6985, 6266,
        6980, 6979, 6544, 6994}], 
      LineBox[{6717, 5962, 6736, 7689, 7707, 7126, 8970}]}, 
     {GrayLevel[0], Opacity[0.5], 
      LineBox[{5793, 6995, 6543, 6981, 5787, 6265, 6984, 6982, 5392, 6959, 
       6960, 6526, 6958, 6524, 5008, 8491, 4999, 7414, 6263, 5772, 6514, 6952,
        6512, 6942, 5768, 6258, 6257, 7068, 5385, 6939, 6940, 6500, 8814, 
       7950, 5382, 7519, 5381, 7948, 8603, 8606, 8607, 6937, 9358, 6936, 7018,
        8631, 5223, 7772, 7771, 8101, 9143, 9142, 7774, 8981, 7773, 8103, 
       8102, 8403, 6407, 7777, 7776, 7775, 5580, 8469, 8470, 6790, 7592, 7593,
        5120, 6789, 6406, 6701}], LineBox[{5538, 7648, 5525, 6567}], 
      LineBox[{6716, 5961, 6735, 7688, 7706, 7125, 8969}]}, 
     {GrayLevel[0], Opacity[0.5], LineBox[CompressedData["
1:eJwNji1PQnEUhx9NbIzdgC+8eu9FKDiDUb+AwSCDygi4mRwWhxtMg9IIMqy4
MZOKyZmFYHDjaxjofgGf8Ow553fO/54bty/rnTWgIYUQ8lLehKzOSacIP2n4
sH6XV3mTF1m6N9PVXbjdgZX9r/3nBpya1WRu/iU9s6AAfX1kfijTbd+XYRHD
0J0H65FM7ZvefdITufd+VIFYQkl6o+U80I8lSOmBO+0snMn1FqznIeH/nNv/
efdCR2ahJM2r+ioDFd3VJR1Lz709vS831mO/dWAd+OZY35kF3h7qibMTs4yz
7wie7XPOuv7TP129LCA=
       "]], LineBox[{5187, 5119, 6788, 6405, 6700}], 
      LineBox[{5537, 7647, 5524, 6566}], 
      LineBox[{6715, 5960, 6734, 7687, 7705, 7124, 8968}]}, 
     {GrayLevel[0], Opacity[0.5], LineBox[CompressedData["
1:eJwVjztLgmEYhm8hHQRF0DyfUtuy6FckgkuZoOISiIiQQR4QaWhoyELwEOiq
NunYmEv9CwfnRpc20a6Gi+v9nvd57+f5jm6ql7cGSTkY2qVmRPIEpO+w9AWu
Qynpk1LQ8UhW7mzwyNmA935pBz2n1KZ2Ql8LR/EztbqbdzjGt5ksIzZBhZ4D
XMZPzC3iB7wmq8KbBm/S1K5gyB5vMIA+FJi7dZAXkmr09f7r7B2PSR98n+FT
SBxLF9AJSl2vNOL8yw4WZljhlVqX2gse4AxkyV6yR4m8POccrOi9J3dG5jtM
YezC7DmBa+6d+I6cKjT5rx8osOOC+jn3c7yh9sn8P5X3NFo=
       "]], LineBox[{5186, 5118, 6787, 6404, 6699}], 
      LineBox[{5536, 7646, 5523, 6565}], 
      LineBox[{6714, 5959, 6733, 7686, 7704, 7123, 8967}]}, 
     {GrayLevel[0], Opacity[0.5], LineBox[{7244, 6321, 6325}], 
      LineBox[CompressedData["
1:eJwVkDtOAlEUhv8JxtHGxMA8fIBAkCWwCTUhFlREEzoshs442NDxMBTIAtgC
PkogcRkGS2AFQIIwAx/Fl++c/5y592ZSpcq9Z0gqwO+l5EelAeSpD8GER3iA
tiM5aenAlcKMFMGta8kma2ILd6+kb0t6x1/YxKsYZ+FjOIJP+vY5c7zkjHpC
eqGekPm4Sd+AHvcNU9KYu2/OpH9mM3bW+I7+jzyPA7INhOTGhVTmzCfY7jMo
shMhr9rk1K+4gqd87+EFnsMz9RuzLLsnvL2flD4gYKY47+K/1Njp4NN9T33L
bpTdHLbxiP0fcJkP8QB2vDw2fg==
       "]], LineBox[{5185, 5117, 6786, 6403, 6698}], 
      LineBox[{5535, 7645, 5522, 6564}], LineBox[{5563, 7151, 6314, 7216}], 
      LineBox[{6713, 5958, 6732, 7685, 7703, 7122, 8966}]}, 
     {GrayLevel[0], Opacity[0.5], LineBox[CompressedData["
1:eJwVkDsvg2EYhi8bog7hU2fqsJmE+AdE4vhZOiNpJEqQLkS64ReQOG9E/AGH
YKGxtl1rUBNmMZC4Oly53/e57+d5D7G5lXC5DEjITwMs9sFLp/TAs3SUai2w
3wR7suM6DGCpF5Ly2Q1fEjF3aF+12u+MA9eZdpgwm9XfsvbdCLP25N3nZNVa
UT/nOXl5tacgo9bi9o6oY+436uEmBidRuFbv5FbmnXevPshTG6yVcvLmHac9
Z0aq9GqlRhbMZ7t8l9mMjDfDpvlJtU5/Sk2Y+bD/z3eE7gvm4mrKOq3inY6c
cSxFvXdJOyNpZltdV8vNpdRKtUIi9lyav5Jf8xfquQR6AzIou+aH1SEJzD/q
n3lm1H84Vf8BgCNBvA==
       "]], LineBox[{5184, 5116, 6785, 6402, 6697}], 
      LineBox[{5534, 7644, 5521, 6563}], LineBox[{5562, 7150, 6313, 7215}], 
      LineBox[{6324, 6320, 7243}], 
      LineBox[{6712, 5957, 6731, 7684, 7702, 7121, 8965}]}, 
     {GrayLevel[0], Opacity[0.5], LineBox[{6630, 7721, 7715, 5546, 6282}], 
      LineBox[CompressedData["
1:eJwNkDssg2EUhh+TwWXgr7hHlbQuG4PJJRK7JmKSUAkbiVZikIiJqWWgZh1E
ymQWC4mRhNZIMUhUJJgMPMOT93u/837nnP8PJ5bjSxXAohxFICeREMyop3Ii
ef1gAIlumJc5uWuDQiuct0NRfZAXc/fmi1KQkj5pPeo5JtvNsGKflHerEuuC
HonKTifsyqOZJxlvgk+zz55nG50piQaoCUOtHDo/J+V6eDVz0wFn1m/Vfvv1
Sa9cmplw3zd7X3ke8e2wfJmNW/9W6/QL6qg6Jtd+S9K+k+6wrk6p786YVj/U
svy5W9ZZB1Iyv+b7fc8/1ipbYEOfMr+pVumr/Rd56xn9r/m0eqwPrA3Inn7L
fFYd0gfmL6ynvQu59z+1Z0Pj
       "]], LineBox[{5183, 5115, 6784, 6401, 6696}], 
      LineBox[{5367, 9576, 8136, 9160, 9157, 5149, 6760}], 
      LineBox[{5533, 7643, 5520, 6562}], LineBox[{5561, 7149, 6312, 7214}], 
      LineBox[{6323, 6319, 7242}], 
      LineBox[{6711, 5956, 6730, 7683, 7701, 7120, 8964}]}, 
     {GrayLevel[0], Opacity[0.5], LineBox[{6322, 6318, 7241}], 
      LineBox[CompressedData["
1:eJwVkD1LQmEYhm8XSxs7+dG3qaH9jBJ/QENENTWUR6SjTrqJQ0MgODk0FdQa
0SC1S0RhmkM2Ba6eg1bk4uTlcHGd53nv93kfTujY2j1zScqAsSL5oBKUvHgW
ZqDmk57WpXN8h6t4vCxZG1IWCuQH1A7YUOL8lpyFL3ER9+inyJpwQL5JfYjT
nO1hE1+QtRelEd/bISnul555v8+dxyUpRp2gv4V3cDrCPRjO834AcJvsDXcS
C1JyTXohO0f2j5lX9K8hxax7ai/9X+zGP9iDc8zYZzc/845wAJ+SP4GhwV7s
2qD/SvYNGsy3sQNR+hEwydans8hnV6Uue3xCKyy9QxPy9DdxDn+z6xfnD+zQ
4h/88+YIevTbZDrwAQ67GfwfG5epJ24TSjQ=
       "]], LineBox[{5182, 5114, 6783, 6400, 6695}], 
      LineBox[{5366, 9575, 8135, 9159, 9156, 5148, 6759}], 
      LineBox[{5532, 7642, 5519, 6561}], LineBox[{5560, 7148, 6311, 7213}], 
      LineBox[{6281, 5545, 7714, 7720, 6629}], 
      LineBox[{6710, 5955, 6729, 7682, 7700, 7119, 8963}], 
      LineBox[{9126, 9122, 9130}]}, 
     {GrayLevel[0], Opacity[0.5], LineBox[CompressedData["
1:eJwVjzssw1EUh39dSE1EvenDY/DYLBIiMTQsSEyqE0kXpGJAJNpEE9GE1mAS
I4kY9B/xalraicQjxOiR6NpqE4TBxPcfvnz3nnPuuee4JmZG/BZJIdgsl9Zr
pDVsbZCKIO6UzmClUjrABvzWS7ONUpi6BeqXcYFYDnbJ74Cf+i28DRnik9QH
qfNQP4fviN3CHn+0tkjt0AYf5B6pDZmxKmmqWerAbpfko2e2Vrrm/s39Bv9g
dwU9m6R5GHBI/WDYpDR/xXC+WkpyTsBJnXQKXmJj0MsMTvocEzPoX0y/Ah7m
3zxeYo4uYg5qPNSPgpc3du5HvIlRI/IW+GPXKLNHYAPi7DIN45wf6HcPl7wr
oWcZfay41JwNEnBOfp98N3v0QJDZbfwVwEk7eRgiPgiHxHy8z7HrJ/tn8Rd+
xxn8hN/wM36FF7hg/xRcMXOfOQtepEeA2cPcV6GTvv/HwVfR
       "]], LineBox[{6682, 5484, 9119, 5513, 9113, 5507}], 
      LineBox[{8134, 9155, 5147, 6758}], 
      LineBox[{5181, 5113, 6782, 6399, 6694}], 
      LineBox[{5531, 7641, 5518, 6560}], LineBox[{5559, 7147, 6310, 7212}], 
      LineBox[{6280, 5544, 7713, 7719, 6628}], 
      LineBox[{6709, 5954, 6728, 7681, 7699, 7118, 8962}], 
      LineBox[{9125, 9121, 9129}]}, 
     {GrayLevel[0], Opacity[0.5], LineBox[CompressedData["
1:eJwVkbtOAmEQRj8u+wQoXgHXaOn1FTSxsUItbARMSGjEF0BtvJSCiaCYSAVW
JgaNJsIbGGNjZ6INcg1qYgILNB6Lk7P/zOzM7L/m5rY/apMUg+iwdGBK+5Dv
l2a90hzMwx6xXXgfk+I+KQFTxKdhBtIDUm5CusBXeN0tFUalFY+0CsFx6cEl
+Xlem5ROIAHHzIzjFvNc1Ldxj94d3MUWtuFaHwtiB9jhmnNyREpBY1CqQ4n+
b/gTJ5lzCovULkCT3e3ggBTxF/YpUxfm/Qo+J3YGBnknfMEruxWJFeARTL4t
javUN5lj0LfOHk7cwEEcgg1YZu8ALg5J39T+QJV+Fbih9pdzjl5Z8HBfXvDB
Efcb4e4O8RLvttjjibkf3M0zbnPeIp8hv4NrxGP4knOAeot8ByziPdz9/5/k
78jfg8G8W5yHPyNeVxs=
       "]], LineBox[{9128, 9120, 9124}], 
      LineBox[{5180, 5112, 6781, 6398, 6693}], 
      LineBox[{5506, 9112, 5512, 9118, 5483, 6681}], 
      LineBox[{5530, 7640, 5517, 6559}], LineBox[{5558, 7146, 6309, 7211}], 
      LineBox[{6279, 5543, 7712, 7718, 6627}], 
      LineBox[{6708, 5953, 6727, 7680, 7698, 7117, 8961}], 
      LineBox[{6757, 5146, 9154, 8133}]}, 
     {GrayLevel[0], Opacity[0.5], LineBox[CompressedData["
1:eJwVkLsvQ2EYxh9JN7aeqkupnoPEP9DG4hr/gDQkGEQaS90SNLFYLGyiRgYh
Iam0XY5EBJtEK66DhcRtqImeSITW5dfhl+d73+95L98XGJnsnSiTNAejHsn0
SRZ4qiS/KVU0SeUw5ZZeaqVHeAKD+zC+Aa/0TOxDYwFpCJ1FB9GfeilnSEX0
D34hQbxcI+2ir/RYIReHDLks7FB3Sv02etAoRZnb7pc6oA26oBM2qd+vloL0
CEEf2Hgj1ASpD8FXg1SAb0hUSkn2TMEDvfvx7+FPE9v0uSO+hxt2uIYt+vcw
p5s/mbaYi+bp6cAbnNDjHb3Fe1wnHcEhmORbya9xXoc8PR2wSnl0nJkG9zOl
XflfN+cM/7jEjovgMLeZ+Ax/BP8l5yv4YM4Y/ijkiOd5zwZ+F3u1EA/zhnNq
PjlfoEX6LuCx8ayiLnaJo/+VZ1No
       "]], LineBox[{7165, 7159, 7761, 7755, 7749, 8587, 8584}], 
      LineBox[{7210, 6308, 7145, 5557}], 
      LineBox[{5179, 5111, 6780, 6397, 6692}], 
      LineBox[{5505, 9111, 5511, 9117, 5482, 6680}], 
      LineBox[{5529, 7639, 5516, 6558}], 
      LineBox[{6278, 5542, 7711, 7717, 6626}], 
      LineBox[{6707, 5952, 6726, 7679, 7697, 7116, 8960}], 
      LineBox[{6756, 5145, 9153, 8132}]}, 
     {GrayLevel[0], Opacity[0.5], LineBox[{5971, 7130}], 
      LineBox[{6277, 5541, 7710, 7716, 6625}], LineBox[CompressedData["
1:eJwVkTssQ2EYhl86uMTCoRcUVcUqWIiE2aRIXGpha9JahKSJqNFtIEwWkRht
4hKLS4ImOlaQKEJLLM1pXVqTx/Dk/f/ve7/Lf45rfNIbzJM0Dxt2adglDYG1
XJqukmxo1CldQ4tNWsNTQsyol3Lcy9BSOCLv5L6OvhjSLb476KmQ+oh1o121
kp/cBf0vYbZO6rdKIXQAHcR/RXwPT6RS8hLLkvtAF+ixCEtwj++rRvqGT8jC
DxSw1yo7F6Kv7HSI185Oy+gDPWPUxdEV7g7iCTxJKMa/S10R2saOjR6pHW2F
KPlHauLU/jIjgSeHJlEf+TEYgV7eN4ruO/DjfYIb3hCDHbxTbumZ2CazO3mj
h/mnnM/gHA6Y/86sNzjh3kC+A1+Kt8/xDXxopJr/xDkMJj1Neqdhgr4p9Jg9
ZyDDOYwG/vtRs41/Cyzs2MS9GYLUmGgaDGZbmJkPf2K/WAs=
       "]], LineBox[{6755, 5144, 9152, 8131}], 
      LineBox[{5178, 5110, 6779, 6396, 6691}], 
      LineBox[{5504, 9110, 5510, 9116, 5481, 6679}], 
      LineBox[{5528, 7638, 5515, 6557}], 
      LineBox[{6706, 5951, 6725, 7678, 7696, 7115, 8959}], 
      LineBox[{7164, 7158, 7760, 7754, 7748, 8586, 8583}]}, 
     {GrayLevel[0], Opacity[0.5], LineBox[CompressedData["
1:eJwVkcsrhGEUh3/8AYTB3FzGbawoC8llyYIUolAWRjOjZsZELEQWNupjZuyR
UNJsZxiE3Go2spKVokhmVm5l6/kWT8/7fu855z3n/Vye8MBUjqQVMIqkQoe0
jC8gj3XIKhXgfMgtlqKVUgzendJ0iRRh3W2TPu1SgL2H+CDu4pu3SurEV8Re
wj2xY5w9EbtdJmW5Y7JGqiuV2l2SG3fgUWJ+cJr9OXke6kzAGWs/OSl8BDFq
uGvpCdfjF8581LOT58UO7MdD1Lvjzmv2Gere4CxuZZ6ZaqkNN1VIWxZmYd8D
jewbYAQM7k5Qe5A7htn3ct93ufQFm+TEeZsN/MDsSeZNgI/4CN+j8Mx96zgG
B/Tyxztk8C/+wIfMkoQW8t6ok6bXV7zA+SLMg405+om14lX6WYM++oibs3G+
S7xB3g5+pI9jaqXglLonsESM03wT832gmd4tzDlO/Cx9zcEttQLUDEII9nmj
PfM/MMs/MD5WQA==
       "]], LineBox[{5527, 7637, 5514, 6556}], 
      LineBox[{7101, 8540, 5936, 8535}], 
      LineBox[{8582, 8585, 7747, 7753, 7759, 7157, 7163}], 
      LineBox[{5177, 5109, 6778, 6395, 6690}], 
      LineBox[{5503, 9109, 5509, 9115, 5480, 6678}], LineBox[{5970, 7129}], 
      LineBox[{6705, 5950, 6724, 7677, 7695, 7114, 8958}]}, 
     {GrayLevel[0], Opacity[0.5], 
      LineBox[{5502, 9108, 5508, 9114, 5479, 6677}], LineBox[CompressedData["
1:eJwV0DtszXEYxvHnGCzu2tNTqtXjsrG5BI3JyiARsUh7lBiaIxHp7giDGmxY
GjYnCGqgEhKDRC8iQVERXXpcEi0itVh8zvDN8/+/z3v9lSunDlYLSYZxoz0Z
Wp9cxPFicnZj0k+rm5OJDckkPrUk1/iPupJRPMT11uQxrbclY91yMY45tTN6
zNOvan40e8qr4Yya9+b1dyTd65IynpaSRjl5QmfpHTpFR3gPsGNNMr0p2Un3
m7WL3hW/hxF7PV+bHODP8v6Y36DH9K+gjlX6HZHbYe4KN3XRZbSTLqeL7TSv
/ifm8Bu/0KJumz1W0+30jVmv1byltU43Yav7tuAbf8Hsvzgn/sybTcnrM/8d
bdWjomeR3ha7hRk5n9Er3od2b1bCgH0K9l2EC/Kv8M7Tq7SX96J5rxuL/kto
Q483nqQvMYYJjDf/5S5Rs8eOPdiNvXIb7rgp/oFfp1/8D9v7u12nxT7ivhmH
xA5jVLyKfd5+kJ6w9yv7XXLvEBb0+KfmtJqTzTfiHZV7mVcwb6V7a7yB5tv7
Xor/8lNosQ==
       "]], LineBox[{5969, 7128}], LineBox[{8111, 8113, 5584}], 
      LineBox[{5062, 8613, 6276, 7172, 6274}], 
      LineBox[{5176, 5108, 6777, 6394, 6689}], 
      LineBox[{6003, 7746, 7752, 7758, 7156, 7162}], 
      LineBox[{6704, 5949, 6723, 7676, 7694, 7113, 8957}], 
      LineBox[{7100, 8539, 5935, 8534}]}, 
     {GrayLevel[0], Opacity[0.5], LineBox[CompressedData["
1:eJwV0ktszFEUx/EzXRFWHq1p61GPtbIykkqbsJCw8MiQiJqoUm0Qi1KPaM3U
o1iSsKqFx4YiQWJBrSyFhU2rMtMmnVowLRINkfj8F9/87vmde8499/7/DQdP
7DyeiohXaFsc0VobMbgk4i4GlkdcxfpFEQfWROTQinW8RpxcFZFRc4w3JZ62
LvLGUUJFXFjGl+u25zRO4Sd/E53hN9FB/bfZ/9zel3iBAi9dH9FPW+SaMVQT
8dpceV7dyogF1uWGiGH+JH1Lx1ZHfMGA/LOF1rwR8WeMYkyckqskc+Gd++7W
p3uFGaojHjlzCD/E4+K+pfran6uLeCC+QSdoxp4Rva6Lr+GQs56mIz7o9RF7
5LO4bdYp53zFFr3WmvOCOzfSXjpPj77kTcXnaFHv7eYs0RkzPKT39J9v30b9
Ruku/Z847z5/rnVKXRVuqsvL36LttJdWyf+jj2mX+sP8srpvtJ63Vd2kMzbL
/ebtEM/SGpTcu4g29dXii3Jp36EWd3hXeP28S9Yd1pfpUdrjLlk9z9NO8Znk
bjiLkrknkvfRYy/+epeyN9rA65CbY893tcPmeYMmb7pP3EKz3q+Z5r1Ljvc+
+T+sC/ilx6xv2a7PH3qEfpLv0XO/mmnrCv4Dd8Z8dA==
       "]], LineBox[{5583, 8112, 8110}], 
      LineBox[{6273, 7171, 6275, 8612, 5061}], 
      LineBox[{6675, 8954, 6668, 5199, 7671}], 
      LineBox[{8533, 5934, 8538, 7099}], 
      LineBox[{5175, 5107, 6776, 6393, 6688}], 
      LineBox[{6002, 7745, 7751, 7757, 7155, 7161}], 
      LineBox[{6703, 5948, 6722, 7675, 7693, 7112, 8956}]}, 
     {GrayLevel[0], Opacity[0.5], 
      LineBox[{6001, 7744, 7750, 7756, 7154, 7160}], LineBox[CompressedData["
1:eJwV0klsjVEYxvFX6OZWm3BLW0OpYUFsNFpDDIlhUe1CCAlpNIYQFuaFhfmS
1EIkpgUbISkSpJeFjSIqERY0SDrcW03bhUSvS0KUxMLvLv55znve4TznfF/1
9v3r942KiA5kKyNapkb0JiOKJkVk6NsZEW+QL4/IzYr4MjHiBj0vvk5baN90
/fZvTot4PSFieVXECtyVv4famRF1WD07Yg3G20uiDAf1HkKjc6vkdjizDQ3i
DeKLuMTLBXqZVkyJKMc/53ysjviED7jPx3PzOtS8wryKiPl8Hzb7CHbq2YO9
qJEbV/CBJGoK9+N3pfUqjDWnBKVIoBib1Wzl6yHaza+31+3Ow2b30ObJ8riN
BC+l6n/RJ+7RZV1UFvFC3wCvOT3fcEzuqVw7mvSdFJ/A8cI3MHNQ7RAe8LxF
zXc9Wft52kd/0Axt5KWfrqWfaQNt5nOu77HAO82htfSRb/AYbUiL07RT3TOz
h/V8LdyZ54w4iz608tVLe9CNEvkx3qjYG46mCVppP2Wdkrtmxll6i+/dNFWI
cQpncBpdzhxy9ghff7DJeiMGvNFRd1rnDml3bjJ3ofwyXuvoYizCHXVL/Kut
dND5V3m8gnfe9z2WynXSnHyG5mk/3Vb4Tupfml2v5pyzfsr9lTsgt0tuxPo3
/gM6DoG4
       "]], LineBox[{8955, 7111, 7692, 7674, 6721, 5947, 6702}], 
      LineBox[{5174, 5106, 6775, 6392, 6687}], 
      LineBox[{5474, 6754, 6660, 7666}], 
      LineBox[{6674, 8953, 6667, 5198, 7670}]}, 
     {GrayLevel[0], Opacity[0.5], LineBox[CompressedData["
1:eJwV0jtszWEcxvFfJQZhaKsuPXVpi4GGSJpOVY0OVRPpopy6RCImPdqhhIUa
DELcE4YKBuIS2rj1QnvaRURIewYDqhGD3kjcIzQ+Hb55/s/7u77vOUW7UrUN
WRHxAsvzIq4sjriK1vkRTYmIRmyfE/FsaUR6nu/iiB04WhSxjz9C99LDtIHe
KIi4jopFEWtQjpTzFvFh/cf4CYzjIn9O/0s0Y955Z918zdyI1WaUOLu5IOL4
sohtsyPuoFO8ND9ihn3KaA//FLVyU4URG9ReU3MLo/xr/tDCiC79nss5Y1Za
fh/K+Do9byOpXz1W2fOgeQPqqvlBmnSfrWhBhp+u1yd3OqDvA9+v1HfoN6z2
jZlvsUesVewyGtU1oVdthZ49dC3doi7HWye8bzYtoLk0e0nECm9x0vcJTNOj
0n3q7Z4jViKWZfdhPd+jSuyxnEd4iFG7jeg/Qov5hNxCmk+L6Dr5P8UnxfP4
375/4Q//lX7HN+SY94Pm0i/yPmOlnAZnY3STdxqnvfa+b680vWDfIfnV7r8e
NUiq2+mubX6vdmx0/9122O+dmlE61ddus5zNRLP6PjPa9E7TdtpP79KEeJVZ
vfw9/pgdOviM2Z20C0/s0I1KZ3/1P2WH0/hoxgd7vDTvLD8p9g+b7VNurzo6
4HecMP8drZc/NPX/p/3mptTWyMv4HsR/FLeG9w==
       "]], LineBox[{5173, 5105, 6774, 6391, 6686}], 
      LineBox[{5473, 6753, 6659, 7665}], 
      LineBox[{6619, 7559, 6615, 8904, 6624}], 
      LineBox[{6673, 8952, 6666, 5197, 7669}]}, 
     {GrayLevel[0], Opacity[0.5], LineBox[{5169, 8556, 8548, 5968, 8560}], 
      LineBox[CompressedData["
1:eJwVkDssQ2EYhl8L3Qx1jbYcPacGpJUIRYPFLDGpayKR9CI6GIxMFltFGBRn
bVxWQ9sTZRObBCN1ajAw2JB4Ojx5z/ud73+/7/+NlczMep2kbYg3SY1B6RIu
wDCl04BkQw5O4Bj2O6U7rxS0pGqr5MKkT0pz3tMmFVqkMc4W0Rja2yy9oS68
QAVeIdNBBmcs8kJgQh+9P+SZ1B3+W+ggfpfcPzTCzB5qU8wLoWH8L/V+zqX5
XoMU+PDz3MGPRiBKLVzbg95pvivoBvkJMgbwW3jbYD73G8IH6PWyT8IvJaGM
P8QfwAK5KWqj9I7AKhkute9aPvoOVdikPoxGodwt3cAT73aLPqNx5szBLDjk
luCBjBL9DhTgEV9Ebfa7Zr8deo/4zvN+OXSPO2ShgcxPfD36hXrQD97/vks6
Q7Pse45e8W5JZo+3SxOwTG2Rt11C/wGjuFB6
       "]], LineBox[CompressedData["
1:eJwV0clLl1EUh/FvYNNKQRssK4fmwYUGRllUlrpTW6QJJUhFmj9tU63dtbIC
/4GiVdocFkRSEEEbzdoWlRS1rShogPq4eHjec8+5555736reoUOD85Jcx5Pl
yemaZP2SpJ838AAXlSUTq5KnPLM62ep7G1qrkrplSaX1yZVJFdeLr1YnVzBo
bwGl1rsrkjIedcYFHlqbnMFXdd/wHQU93lv7oMc7nuXx8mQMz9FmngX299nf
pl8/LxT38GO50TX6Om+j7ynzTeOfHl3yzeo7eVzuMG/mhnXJJp7EDewU3+Ry
HNGnGzV6VmPYfNdKk3ZUqGvUe0TPE3wcz6yf5KmlyV2193Afw+50h2/jFr64
12cU+d6j/pP3/IiLZhrjkbkZudYM89U16VfE+/nhimQf94gXu9dRXsTHuNb7
vPAW5/U8h7N4qfaBPRMYM18nuubuYe69cqcqk7fOeyTfLN6ux0Hu0Kcdg/It
4j4uYAAz/nmvPlu8SYMZDzhnB0+rn8IruXo1xeaq4xIuceZPLuYffFndJTSZ
4414F+9GI367S+R+8V/8QYf+LXKteG3G//LhY54=
       "]], LineBox[{5472, 6752, 6658, 7664}], 
      LineBox[{6618, 7558, 6614, 8903, 6623}], 
      LineBox[{6672, 8951, 6665, 5196, 7668}]}, 
     {GrayLevel[0], Opacity[0.5], LineBox[CompressedData["
1:eJwVkLsvg2EUxh+RlA3p7VP3YnWpxKUGReueiCpdvjbR6ichwWBtw1Tdi8Gi
dYnWZWIwsRGR6B9gMvBv+Bl+ed5z3nOe8563I7ET3q6SdADjdinglaxu6dkh
LXVKL2ilVbK5JKNReie2mqUeQ3JT14s6UBc4wYCiR5rFy8P5yS0ViM/gEu8L
OIfJLmkCKviFmROBZfhmVgjNkffRn2iRkhCkNgQ39N7CHWSapDJagmv4ZdYP
NdWcR+nJ0+9Hr/CcwXMapmCP3AB399TF2qUjzsPsV6ZuCDXJlXj/Arv5iaPE
I2gc/USL7F+AUxgjTpJfpNZCN2ANUrAOPv7MxKsP7YdH/uEBvthvk/stqOXN
NRDEy4Zmedfh/x/xzjfuX+GE+hx9x+gHswad0i75eXoa6JlD69B6yEAa7Owa
beOO2gi6CiuQgiykye/jFcPXBC/xH4qARfo=
       "]], 
      LineBox[{5267, 6347, 7333, 7490, 8835, 8836, 4954, 7957, 7958, 7956, 
       7960, 9509, 7959, 9559, 5073, 8895, 9584, 5581, 9144, 5582, 8109, 8982,
        7778, 5343, 7914, 7497, 7498, 4961, 8093, 5571, 8092, 5572, 8094, 
       5278, 8095, 5574, 9141, 5573, 9583, 8930, 8931, 8129, 5589, 8128, 5590,
        8130, 9007, 7812, 9525, 5346, 7923, 7502, 7503, 8797, 4965, 8179, 
       8180, 8178, 8182, 8181, 5290, 7089, 7090, 6376, 6375}], 
      LineBox[{7663, 6657, 6751, 5471}], 
      LineBox[{7667, 5195, 6664, 8950, 6671}], 
      LineBox[{5168, 8555, 8547, 5967, 8559}], 
      LineBox[{6617, 7557, 6613, 8902, 6622}]}, 
     {GrayLevel[0], Opacity[0.5], LineBox[CompressedData["
1:eJwNkDsvg2EYhu8OfoFD0erho9JOFqcEVYJaWolGKxqJ9AeQ+BZDExUqMRj0
cxjYDC1jO4qaDVhoStWmwh/AxDVcud7nee/3+Z7Wm1qbX7VJMuG0Q0q3Sid4
Ay92SgmwqHM9UsYuHeAtbOHHNmnPIT3hMHUFz+Ib3pZc0mGLVMRH2Ee/F3YN
yfBJWbyOv8hWu6VnaLild/ikt8m7DJi8vWuXlvmOyym54Yrv17zSC1xyvqCX
bJb62LPIvmPsMUQviEvUEd5HYYR6xSON4hSuMTuJB6nPyC+wUxwKzLKxaz/9
OPcDeAlXyc/gMOyTj5GdI3sOf+zvJzfFXQAf89umOefJhDibXdIPmV9wcv+N
o9xNstcE+Mk66G8zdwey8EGvAXao81+8wTBzbtnjlXMT+Qdcpg7Qv8b31OPM
/QdnRUga
       "]], LineBox[{6621, 8901, 6612, 7556, 6616}], 
      LineBox[{5167, 8554, 8546, 5966, 8558}], 
      LineBox[{5409, 6747, 6271, 8070}], LineBox[{6670, 8949, 6663, 7673}]}, 
     {GrayLevel[0], Opacity[0.5], LineBox[CompressedData["
1:eJwVkDlPAlEUhY+JPSbAIBMXFsFhGUy0EILB1sTYGCVa2GivRkgsVfwDLo1a
WQEJQbDnB9hYGpDNTgu3ztpvii/n3vvOue/NBHcP1vdHJB3DqCE9T0ktj2RN
SnFIQC4k9Zg/MV+kz4A3IBngBhc5DxryS2Ew6SP0fvQvLN27pRVYY09pQprl
LAov7CubUgVi5CyoUtvoJv47vLewjXcLVselBudtckk8D9R1J493w4H9N/g/
eOs7dPGlmFnkbDSGzqGdGXZAnH4sIjXZsUeu45PS6Cv6FuQ/oH10CAMwyZ6w
s0WuxlmOb1uGM2YGuVO0yb2P0IDfaekHEniS8E1d5L4vtEs/gD70YIl5FlLU
Q/j0SgV6m3qe+hBdQC2yJTiHAv0V8yJ6je6geb7lCBV6yezCeR/ef/7jRpA=

       "]], LineBox[{7672, 6662, 8948, 6669}], 
      LineBox[{8557, 5965, 8545, 8553, 5166}], 
      LineBox[{5408, 6746, 6270, 8069}], 
      LineBox[{6301, 5495, 6550, 5499, 6554}]}, 
     {GrayLevel[0], Opacity[0.5], LineBox[CompressedData["
1:eJwVkD8vQ2EUh3/aT9BS0VJ66e0NtRQlne69iMHQyKXtKDFq1WJhMhnEYmkb
oe1sM5KQMJik7SIM7Og3aBdPhyfPOe97znn/GHuHXnlIUhmcYSkQloLgG5X8
Mak7I/1BjT0bPialT0hHpWW4Zm19WlqDowl66QlAa0S6iUhtbDCvQVwHizhL
zwW1p2Byjkv9xhgzsEWewQm8ipPUV6mrwDmkWPdY36R+By+SZ/ECzuHtwQz2
5rlPAZqDHvIV4jhO4gSexSaew3fc6zEuPUHLkDrQhn5ICtHfw1emdEmdw5s9
Yhvf8o48RMld8ga1u5zvZ44Pzvgnl70l/u99incQfzPrjfwLO9S8cG8bP2OL
mhTrJ8zaJy7CAZTggXvewzF7v5zxA1vUvo5L/6SBPFo=
       "]], LineBox[{7109, 7656, 6604, 5946}], 
      LineBox[{8068, 6269, 6745, 5407}], LineBox[{5165, 8552, 8544, 8564}], 
      LineBox[{6300, 5494, 6549, 5498, 6553}], 
      LineBox[{8064, 9103, 6655, 8532}]}, 
     {GrayLevel[0], Opacity[0.5], LineBox[{6299, 5493, 6548, 5497, 6552}], 
      LineBox[{6610, 7048, 6643, 5194, 7662}], LineBox[CompressedData["
1:eJwVkD1LQmEYhq9wsilQ1KL8OqdwqqAlAsnNpQalsZb2FLQ5aW4q/IK2BisI
F3OpH1CQLRWC/pjoari53vd+7nPznDd3Wq/WFoAjdZ6Bm2VoyoYqxOFkHb7W
4Fh+y8EqDNNwLx9UPwnPOejIkezKRf2oqpurqTPV0x87n9n5noJb+649P65A
Og8TZ5+qbbYYwJP+dsIdnLXt6qhBzCVD2NQ/zMKWrMipPSUZer8yV/Gbqroz
/2tXXn/XeSD35I/5UKa8X5o/MFtyp30V6Cf1L/RbqmxH1jdZ0p+521zt+A5v
dkw9R8xO5Kv3Df0X+fH/D3b+Ab3mMZ0=
       "]], LineBox[{5164, 8551, 8543, 8563}], 
      LineBox[{5945, 6603, 7655, 7108}], LineBox[{8063, 9102, 6654, 8531}]}, 
     {GrayLevel[0], Opacity[0.5], LineBox[CompressedData["
1:eJwNzztOAlEYhuHXSmMiFIjijQFlNDGxIYMNiBUmVJqh0dYF6ApsTNwAmFga
TWik8FLJBvAWbRQsXAMd1voWT77Mf75z+MkfHsdHY8C+hnPwkYLXFXjTVwA/
aXjKQE+lRdhUpO9ZiM1H510lNB5C0pwwzz2/z0PLfDBD3yvozLOms6sCXOvO
s1ttzLjDAhwo5RuRYndp63QZ/uxgDrzT18A3OvNwo7rd3RzsqelOLTW8t+7/
qTjbUlnbqqpmv+29z2lYtXNif8f+pUbu+KusvbQ7Bea7vcDelN+TfifMpBkt
QVE9z/tZf8v9qr5xoTXnoV6cPwv7/3pFMt8=
       "]], LineBox[{5163, 8550, 8542, 8562}], 
      LineBox[{5944, 6602, 7654, 7107}], 
      LineBox[{6609, 7047, 6642, 5193, 7661}], 
      LineBox[{8062, 9101, 6653, 8530}]}, 
     {GrayLevel[0], Opacity[0.5], LineBox[{5466, 6285, 5468, 6575, 7633}], 
      LineBox[CompressedData["
1:eJwVzy1TAlEYhuEbG9qEWVQEdhdJEhwVCcyQiCaLVSiY1I7VGQwqZsCkNLsY
LMgwY/Dzl/APvAnXPHve85ydc6LW+dFZAjjWRRYut6CjtwD6MQw01PM6/BXg
S9/61K9+tFeEXV3lYb8EvbR9v4eb8KCnDIz958h8NR/NaQQ3dm61aufe7OlO
7+5NVPYOTfdaitfgMIRtZyeu2zrVjvMD71dRcfFtJ7RTNiOzajacV8yC645n
urpWyTeFzgPnWTNenFHdfn/DtytvJ6dGypnmvnPZftLeiplxL1DC9ZI+vP/Y
98c5eDFnrmve7R+fxy++
       "]], LineBox[{8561, 8541, 8549, 5162}], 
      LineBox[{5943, 6601, 7653, 7106}], 
      LineBox[{6608, 7046, 6641, 5192, 7660}], 
      LineBox[{8061, 9100, 6652, 8529}]}, 
     {GrayLevel[0], Opacity[0.5], 
      LineBox[{5552, 9356, 5996, 9353, 5995, 9354, 5211, 7131, 7132, 5977, 
       9337, 5976, 9338, 5210, 8632, 8265, 8266, 8264, 5674, 8267, 7485, 6339,
        5261, 7184, 7185, 6341, 6340, 5244, 6819, 6820, 6177, 7303, 4941, 
       5025, 9212, 9213, 8235, 8240, 8239, 5330, 8220, 8221, 7292, 8778, 8779,
        5022, 9203, 5651, 8218, 5652, 6428, 6427, 8204, 5644, 8203, 8206, 
       8205, 6203, 6805, 5317, 6421, 8762, 7460, 7459, 7457, 7876, 7875, 
       8190}], LineBox[{7632, 6574, 5467, 6284, 5465}], 
      LineBox[{5942, 6600, 7652, 7105}], 
      LineBox[{6607, 7045, 6640, 5191, 7659}], 
      LineBox[{8060, 9099, 6651, 8528}]}, 
     {GrayLevel[0], Opacity[0.5], 
      LineBox[{4925, 7873, 7874, 7454, 7878, 7877, 8191, 6420, 7282, 7281, 
       7278, 5641, 6202, 5018, 4931, 8770, 7283, 8200, 8199, 5323, 6808, 5324,
        6426, 6810, 6809, 6436, 4940, 7302, 7289, 8238, 8237, 6211, 8243, 
       8244, 8233, 8242, 8241, 8642, 4945, 7313, 7312, 7849, 7848, 7907, 8079,
        5069, 9508, 5837, 7040, 9625, 7039, 5218, 9373, 6027, 9372, 6028, 
       9374, 6026, 7173, 8989, 8988, 6156, 9477, 6215, 6216, 7311, 6636}], 
      LineBox[{5941, 6599, 7651, 7104}], 
      LineBox[{5551, 9355, 6765, 7736, 5220, 7134, 8665}], 
      LineBox[{6606, 7044, 6639, 5190, 7658}], 
      LineBox[{8059, 9098, 6650, 8527}]}, 
     {GrayLevel[0], Opacity[0.5], LineBox[{5141, 8944, 9086}], 
      LineBox[{5540, 8974, 5204, 6545, 5205, 9088, 5464, 9087, 5463, 8040, 
       9572, 5259, 9033, 5260, 7847, 8995, 5232, 8993, 8994, 8991, 8992, 5230,
        7176, 5231, 7788, 7787, 9251, 9252, 5797, 9250, 8832, 8831, 9210, 
       5661, 9211, 5662, 8234, 5329, 8217, 5650, 7290, 8777, 6205, 9550, 6204,
        8216, 5649, 7280, 7287, 7288, 6425, 8197, 8198, 7892, 5316, 7471, 
       5315, 8189, 5633, 7279, 8761, 7456, 7455, 7453, 5303, 7872, 5632}], 
      LineBox[{6764, 5219, 7133, 8664}], 
      LineBox[{7657, 5189, 6638, 7043, 6605}], 
      LineBox[{8058, 9097, 6649, 8526}]}, 
     {GrayLevel[0], Opacity[0.5], 
      LineBox[{4924, 6415, 6416, 5630, 8188, 9193, 9192, 5014, 4923, 7890, 
       7891, 7470, 7472, 7473, 8769, 9198, 5640, 9200, 9199, 7904, 9535, 7905,
        8743, 6175, 8756, 6806, 6176, 6097, 9428, 6099, 9427, 6098, 5021, 
       8776, 8775, 9415, 6072, 9608, 9398, 9399, 7197, 6071, 7251, 6070, 7196,
        8990, 8621, 6032, 8620, 6033, 8622, 9376, 9375, 6157, 9478, 6327, 
       7249, 6100, 7219, 6101, 7845, 5258, 7842, 7844, 7843, 8041, 5068, 8870,
        6633, 7037, 7036, 5460}], LineBox[{8057, 9096, 6648, 8525}]}, 
     {GrayLevel[0], Opacity[0.5], LineBox[{5462, 7035, 6635, 7033}], 
      LineBox[{6296, 6740, 5154, 6297}], 
      LineBox[{6741, 6298, 8567, 5988, 7731, 7732, 7733, 7141, 7142, 5987, 
       9549, 5986, 5059, 6762, 6763, 5819, 9274, 5818, 7022, 5237, 9008, 9009,
        8783, 8784, 4939, 9400, 9389, 9390, 9388, 9392, 9391, 6051, 9396, 
       9397, 9393, 9395, 9394, 6807, 8741, 8742, 8740, 8739, 7820, 6050, 6195,
        4930, 5017, 8829, 8830, 9197, 9196, 5639, 8196, 5314, 6419, 5631, 
       6414, 5302, 6996, 5301, 6413, 7277}], 
      LineBox[{8056, 9095, 6647, 8524}]}, 
     {GrayLevel[0], Opacity[0.5], 
      LineBox[{6335, 8420, 5834, 8419, 5835, 8421, 5795, 8389, 5796, 7451, 
       7452, 9413, 9414, 9412, 6069, 6131, 9546, 5895, 7195, 6068, 8732, 8733,
        8663, 8662, 5065, 6999, 5066, 8864, 7538, 5836, 6338, 6337, 8185, 
       4933, 7286, 7285, 7836, 7835, 7903, 9334, 5974, 9333, 5975, 9335, 5972,
        9332, 5973, 9329, 9331, 9330, 9336, 4938, 9499, 6074, 5459, 6632, 
       7735, 7153}], LineBox[{7032, 6634, 7034, 5461}], 
      LineBox[{8055, 9094, 6646, 8523}]}, 
     {GrayLevel[0], Opacity[0.5], 
      LineBox[{4922, 9062, 9063, 9061, 9065, 9064, 5255, 7261, 5254, 9612, 
       6334, 7276, 8826, 8827, 8828, 4921, 8760, 8418, 5832, 8417, 5833, 6998,
        6997, 8390, 7833, 7834, 7830, 7832, 7831, 7969, 8774, 8773, 9202, 
       5648, 9592, 8978, 5214, 8019, 5449, 8016, 8018, 8017, 9084, 9085, 8035,
        8036}], LineBox[{8054, 9093, 6645, 8522}]}, 
     {GrayLevel[0], Opacity[0.5], 
      LineBox[{4920, 9058, 5413, 9057, 9060, 9059, 5253, 9027, 9028, 8825, 
       8824, 5013, 4919, 9497, 6067, 5629, 9272, 9273, 9269, 9271, 9270, 5058,
        5982, 9547, 5983, 5981, 5985, 9548, 5984, 5151, 5488, 9529, 5489, 
       8039, 8038}], 
      LineBox[{8521, 6644, 9092, 
       8053}]}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, \
{}, {}, {}, {}, {}, {}, {}, {}}}],
  AspectRatio->1,
  DisplayFunction->Identity,
  Frame->True,
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{"DefaultBoundaryStyle" -> Automatic},
  PlotRange->{{0, 0.1}, {0, 0.1}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.02]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{
  3.5842518530039406`*^9, {3.5842519866805754`*^9, 3.5842520228726387`*^9}, {
   3.5842520547590947`*^9, 3.584252071950325*^9}, 3.5842521660808907`*^9, 
   3.5842522211177874`*^9, {3.584252297932322*^9, 3.584252317525956*^9}, 
   3.5842523561360245`*^9, 3.584252406555313*^9, 3.584338105554042*^9, 
   3.5843381392033014`*^9, {3.584338184833381*^9, 3.584338250805897*^9}, {
   3.5843382857187586`*^9, 3.584338334453244*^9}, 3.584341038950039*^9, 
   3.5847847511929626`*^9, 3.5847848028758535`*^9, 3.5847848895340056`*^9, 
   3.5865894737007513`*^9, {3.5865896144441986`*^9, 3.5865896731939015`*^9}, 
   3.586595684904891*^9, 3.5865983848000784`*^9, {3.5865984269981527`*^9, 
   3.586598516089909*^9}, {3.586598588973237*^9, 3.586598602670061*^9}, {
   3.587120290493801*^9, 3.587120340593871*^9}, 3.5871215796086073`*^9, {
   3.5871216261586723`*^9, 3.5871216810687494`*^9}, {3.587121711228791*^9, 
   3.587121801678918*^9}, 3.5905606195050435`*^9, 3.6900054641735544`*^9, 
   3.690010174989998*^9, 3.690267903740813*^9, {3.6902679634508963`*^9, 
   3.690267992480937*^9}, {3.6902680570110273`*^9, 3.6902681030310917`*^9}, {
   3.6902683277014074`*^9, 3.690268401581511*^9}, {3.690268455386591*^9, 
   3.6902684990866528`*^9}, {3.690297235354376*^9, 3.6902972653330903`*^9}, {
   3.6902973042883186`*^9, 3.69029732564154*^9}, {3.690297364734776*^9, 
   3.6902973804786763`*^9}, 3.690297411213434*^9, 3.6903084869172583`*^9, 
   3.690444687883991*^9, 3.6904507852449827`*^9, 3.6904757380733857`*^9, 
   3.6957265490869474`*^9, 3.7057268632019987`*^9, 3.7057269059384427`*^9, 
   3.7057300385796194`*^9, 3.7057314223377657`*^9, 3.741431898653784*^9, 
   3.7414320796950703`*^9, 3.7414324296359415`*^9, 3.7414324797754297`*^9, 
   3.741432565965581*^9},ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"]],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Minimum with depth \"\>", "\[InvisibleSpace]", "0.`", 
   "\[InvisibleSpace]", "\<\" (MeV) located in : \[Beta]=\"\>", 
   "\[InvisibleSpace]", "0", "\[InvisibleSpace]", "\<\" and \[Gamma]= \"\>", 
   "\[InvisibleSpace]", "\<\"--\"\>"}],
  SequenceForm[
  "Minimum with depth ", 0., " (MeV) located in : \[Beta]=", 0, 
   " and \[Gamma]= ", "--"],
  Editable->False]], "Print",
 CellChangeTimes->{{3.5865896144597983`*^9, 3.5865896732095013`*^9}, 
   3.586595684904891*^9, 3.5865983848000784`*^9, {3.5865984270137525`*^9, 
   3.586598516105509*^9}, {3.586598588973237*^9, 3.586598602670061*^9}, {
   3.587120290513801*^9, 3.587120340613871*^9}, 3.5871215796086073`*^9, {
   3.587121626168672*^9, 3.5871216810687494`*^9}, {3.587121711228791*^9, 
   3.5871218016989183`*^9}, 3.590560619520643*^9, 3.6900054641825547`*^9, 
   3.6900101750009985`*^9, 3.6902679037508125`*^9, {3.6902679634708967`*^9, 
   3.690267995030941*^9}, {3.690268057031028*^9, 3.690268103051092*^9}, {
   3.6902683277114077`*^9, 3.690268401591511*^9}, {3.6902684554065914`*^9, 
   3.6902684991066523`*^9}, {3.6902972354893837`*^9, 
   3.6902972654580975`*^9}, {3.6902973043093195`*^9, 
   3.6902973256775417`*^9}, {3.6902973647707777`*^9, 3.6902973804986773`*^9}, 
   3.6902974112344356`*^9, 3.690308486927258*^9, 3.690444687913991*^9, 
   3.690450785264982*^9, 3.6904757380833855`*^9, 3.6957265491089487`*^9, 
   3.705726863214999*^9, 3.7057269059514437`*^9, 3.7057300385936203`*^9, 
   3.705731422354767*^9, 3.741431898653784*^9, 3.7414320797106705`*^9, 
   3.7414324296515417`*^9, 3.74143247979103*^9, 3.741432565981181*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot3D", "[", 
  RowBox[{
   RowBox[{"If", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"ArcTan", "[", 
        RowBox[{"x", ",", "y"}], "]"}], "\[LessEqual]", 
       RowBox[{"Pi", "/", "3"}]}], "&&", 
      RowBox[{
       RowBox[{"V", "[", 
        RowBox[{
         RowBox[{"Sqrt", "[", 
          RowBox[{
           RowBox[{"x", "^", "2"}], "+", 
           RowBox[{"y", "^", "2"}]}], "]"}], ",", 
         RowBox[{"ArcTan", "[", 
          RowBox[{"x", ",", "y"}], "]"}]}], "]"}], "\[LessEqual]", 
       "vlimit"}]}], ",", 
     RowBox[{"V", "[", 
      RowBox[{
       RowBox[{"Sqrt", "[", 
        RowBox[{
         RowBox[{"x", "^", "2"}], "+", 
         RowBox[{"y", "^", "2"}]}], "]"}], ",", 
       RowBox[{"ArcTan", "[", 
        RowBox[{"x", ",", "y"}], "]"}]}], "]"}]}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", "0", ",", "xmax"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"y", ",", "0", ",", "xmax"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.705731444697045*^9, 3.70573148849255*^9}}],

Cell[BoxData[
 Graphics3DBox[GraphicsComplex3DBox[CompressedData["
1:eJx0nXk4Vl3U8M1kditKEaVZoVEa9tGsQaVZRfOg0KRBiFSKBiHzmCEk81xE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   "], {{
     {RGBColor[0.880722, 0.611041, 0.142051], EdgeForm[None], Specularity[
       GrayLevel[1], 3], 
      StyleBox[GraphicsGroup3DBox[{Polygon3DBox[CompressedData["
1:eJw1mgn8V8P3xu/cmWuPkpKIElGRFlmiSFkSpUJkKS2kkKIoRQplX0J2Skn2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          "]], Polygon3DBox[CompressedData["
1:eJwtmncAV9Mbxu+951wj/EhZSTIiRYpEoWUmWkaEQmX9rIoiq40iMzMiGVlJ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          "]], Polygon3DBox[CompressedData["
1:eJwt1nnwzVUYx/HrLrRYC8kSPxRSimwtEooIjUqGokgosiZL2csSRZIkNYqm
pFQopX1By1gm1ZQ2KhratE2lRa9nzv3jfc/z+ZznbN/vOed7SwaMuGR4NpPJ
3IoCTvAzj9EFXelHcpnM5Hwms6lUJrMa//Hm0b/xJ8mZLv8u8UKU4w9VfyW/
Lf0p3REZ7fbgRfxET8Xb4idxWPUd9MBcGn+ttuvQnPiX157Xgd6Es+Q15T8q
3oX16rbkUvvop4z4D/4Uuh+G8frR+3AVfSSu4F1Kt5H7UejinPvy9uLKfFpL
rOlRY70R4yqr0HnxURhk3k3pXRhIP41Y5jX08XKnx/pjDN4S3vm8OsoSrOJt
LD6rKfrZpXyXfg87xeN5Z4pbo5N2bfCxvj7BYG0388vzRtANUY93I68CbyTd
CPV5Y3lleYPoaqjKGxzj8gbT1XEcbwivIm8UfTJO5N3EW2AulcylvLgHuskp
z3tAzm68KK8nPVPdbThG/Xh+33iJ/IsVXePZqfsg+uKPphvjJHXj+Fn+XGN8
q3yCfhJt5f0u5xRxP3VvqJstnoVj1U1Q109ZHbPFHXGh/h5S35HXRHk6rtX2
beWdsT9QVd0tcvsrX0d/3mI5DbAs9gB26Oc7ORtinvQCOfNxXCHt9QFxNui5
qCK+mXe1cq/ccfppxb8AnXkXor24Q3j6fVBZizdXm864iLeSV5N3e6whzhxv
Ba8Gbw7dKXJ5D/Oq8abR5+Ic3r28UsVx31c+Tq/G7ZiDyvInxr5X/ppLa59W
SOuJdeW1mc+bz1tLr4uzE2ed1xRNjHEPXTfekbgibzkq0d/w49KoWtxXsf8G
8beKK/GeiX1E7+WPEddBDXUT6G8xNvYoavFupr/GsNjLqMAbTj+XT3tsD+9x
nGGep+L+bDqrcWbjzKyQVzn2Rrx3z2Il/Yz46Zh7Ia1xRCHtrdhjtcV38IYr
G2Op+Io40/rbpH5HLo0be/zLeN5ytvO24VJ9b1R3mfJZej3qx/0nb5RyD329
uDbKyRtWfK7xfOupX8AfqWyHUrzL8J05H9Lfabxl2XRfxb21Vd1XGEqXoDzv
Bno3rotnh7K8ofRG7V8XXx1nmH6B7oaPsumuizuvO93BGPk4Z7xZkc/bj4ti
LnH38Q7QR8u7Jpveebz7kvBwL90Dl/Ne02Yrr4Wyebxn69hGv4Y+4v3yDmIM
XaK/O8XdcYm2T8nvxX8p9ku8l1gPvQi1tK3IO8w7T7svxUNi/+Bo+dfTX8T5
pqvgiOK9doHcevHO0Z/XWV/L47nqbwAW4bG4c+R9Lv5HTmn6Vbq3vK+z6bsV
+6oP3QNl5B0RbeI7JO9H3opYG0pjPt0ynn2cl3j22raiu8rtrs3FmCrvHeWG
2NM4Ud1CuaOVB3PpPptcSGc2zu7fuJXXKr6B+ruf/imX7tZJhXQPxn34T9y7
vNZoIW8ZXSaf+l4o7/nYByidT/vzrkIaP+aRy6czMI+3JpfeR2XeBP28G+8i
3gl9SDmDbhnnT91S+geMoxsUvz1x9/+JKXQznMZbTDfT96psOr9xnuJc/RXP
I/rC6cU77Cjj3E13K+6Nl3i/5NLdOrWQ7u64w1fLq6HczB8v71j651y646YU
0p0cd/NB/hbPvAy/nbId3Qjr6QPYHnuILuTTeVxQSOc4zvNJ4kW8nsWzEHNp
xFtC98ZA3pu8k3n30X1wLe+tOMe4T9xcv9PE0+MuxSQ05S1Rd4ayU3zrxIe0
XRn3J71Pzo3iuqipbiLdwBj3xFmL+473Mq+r3DXW9BU+i28ofQqez6bvVny/
htHfy10qbiGeEfspzhNmyWlT/H7E9/I/zAyNs3nL6QO5NNdm8f8k3hfaxv+1
bPof1l7deXQXPCX+kLczvl90Q3NeLO4V95i6V7T9H/PcNfA=
          "]], 
         Polygon3DBox[{{896, 895, 1334, 701, 702, 1335}, {1001, 630, 700, 
          1333, 893, 894}, {898, 897, 1336, 703, 704, 1337}, {1328, 678, 851, 
          486, 487, 1266}, {953, 952, 1339, 716, 717, 1340}, {1261, 848, 781, 
          271, 500, 1276}, {939, 938, 1354, 838, 839, 1355}}]}],
       Lighting->{{"Ambient", 
          RGBColor[0.30100577, 0.22414668499999998`, 0.090484535]}, {
         "Directional", 
          RGBColor[0.2642166, 0.18331229999999998`, 0.04261530000000001], 
          ImageScaled[{0, 2, 2}]}, {"Directional", 
          RGBColor[0.2642166, 0.18331229999999998`, 0.04261530000000001], 
          ImageScaled[{2, 2, 2}]}, {"Directional", 
          RGBColor[0.2642166, 0.18331229999999998`, 0.04261530000000001], 
          ImageScaled[{2, 0, 2}]}}]}, {}, {}, {}, {}}, {
     {GrayLevel[0], Line3DBox[CompressedData["
1:eJwt08lvTmEUgPHr6zxKitSQRspGLEViY+c/kJiHajdiU7HujkjEjsacoqaa
a4h5nudZTTWVmqulSksVv4PF8z3nPe8559773u+WVsweW9krSZJWFAkifuDn
JL6LV/Hv9CS5z5txED1otpdkJMkW8fi0JDnEP6RO8cOYY28RP0INMlJJkokU
Os0rk5uk7zTnyNXo7ZJvtD6Dx9iKs3iKJ0iZuZp/YobeAn3V4vMxw14Fp8lt
52xew1/MrDN7nPpn1rVxb/gqf4Sb4j7sv4p7NOMyv8FrTNazjtNxNM4h5qpp
U79bfAy74rnN+sDX0IIyfR/5BvLdR4/9DeJ5+j7zcQzBbeSal6cmF+nYJ1eh
v0Ntpr391g0oxKZ4J3E9XLE/UV23uC6eBwdwL57PnKVcbn9lnJfrd8QM+S4+
gW+YZr+T72AYfqm7G2cWZ2p+u/om3mN9C3ujT007b8RU/Xl8M/40apfwCrSi
Dd1qr/MnTFE7V9li8Xz5WeK34quYbu89v8N6vIwz9+zN8ZwYiOV4gZ24FO/Z
fj1P0Nti1g7xRXSY/Zyr5NZylvu6EFZfzMvQaO8wb8O5OFM9v3iMfA9GW9dy
udwonmPdwNWuNZyruIQruTcPdY1CLuUCHsz5XMJ5PCjeLw/gHC7mbO7HWdw3
vg3uk/r7SSVF8V/g/uaPjGcV18st/HfMyQiJmfIL/n+zfwAbyoSC
       "]]}, 
     {GrayLevel[0.2], 
      Line3DBox[{878, 995, 1364, 877, 994, 1363, 876, 993, 1362, 875, 992, 
       1361, 874, 991, 1360, 873, 1399, 1293, 872, 1398, 1292, 871, 990, 1359,
        870, 989, 1131, 1067, 1444, 869, 988, 1129, 1358, 1332, 868, 987, 
       1127, 1062, 867, 986, 1463, 1125, 1059, 1189, 1441, 1291, 1057, 1056, 
       1226, 1217, 1124, 1466, 1139, 1216, 1138, 1162, 1279}], 
      Line3DBox[{891, 999, 1368, 890, 998, 1367, 889, 997, 1366, 888, 1403, 
       1297, 887, 1402, 1296, 886, 1401, 1295, 885, 1400, 1294, 884, 996, 
       1365, 883, 1069, 1132, 1068, 1445, 882, 1066, 1130, 1065, 1443, 881, 
       1064, 1128, 1063, 880, 1442, 1061, 1126, 1060, 879, 1446, 1041, 1058, 
       1040, 1190, 1169, 1218, 1343, 1470, 1280}], 
      Line3DBox[{915, 1079, 1078, 1447, 913, 1410, 1303, 911, 1409, 1302, 909,
        1408, 1301, 907, 1407, 1300, 905, 1406, 1299, 903, 1405, 1298, 901, 
       1005, 1371, 899, 1077, 1136, 1465, 1336, 897, 1076, 1135, 1464, 1334, 
       895, 1074, 1134, 1073, 893, 1333, 1404, 1133, 1071, 892, 1191, 1476, 
       1192, 1070, 1147, 1163, 1281}], 
      Line3DBox[{1084, 1141, 1194, 1140, 1222, 1043, 1195, 1449, 1083, 1021, 
       1082, 1448, 924, 1020, 1385, 923, 1019, 1384, 922, 1018, 1383, 921, 
       1412, 1305, 920, 1411, 1304, 919, 1017, 1382, 918, 1016, 1381, 917, 
       1015, 1380, 916, 1014, 1231, 1227, 1228, 1230, 1229, 1483, 1081, 1042, 
       1193, 1148, 1272}], 
      Line3DBox[{1137, 1013, 1080, 1379, 1338, 914, 1012, 1378, 912, 1011, 
       1377, 910, 1010, 1376, 908, 1009, 1375, 906, 1008, 1374, 904, 1007, 
       1373, 902, 1006, 1372, 900, 1004, 1370, 1337, 898, 1003, 1369, 1335, 
       896, 1002, 1251, 1075, 894, 1001, 1474, 1182, 1072, 1181, 1000, 1480, 
       1219, 1271}], 
      Line3DBox[{1157, 1173, 1158, 1105, 1346, 1457, 1203, 1156, 977, 1174, 
       1175, 1104, 1456, 1330, 976, 1342, 1439, 1107, 974, 1437, 1326, 972, 
       1435, 1324, 970, 1242, 1259, 1260, 1489, 1356, 969, 1249, 1250, 1220, 
       1221, 1481, 1350, 968, 1155, 1170, 1288}], 
      Line3DBox[{1267, 1090, 1484, 1236, 1024, 1235, 1351, 1388, 1237, 1025, 
       939, 1355, 1389, 1256, 1026, 941, 1390, 1027, 943, 1313, 1422, 945, 
       1391, 1028, 947, 1392, 1029, 949, 1393, 1030, 951, 1394, 1031, 953, 
       1340, 1395, 1093, 1032, 1092, 1452, 1151, 1165, 1152, 1268}], 
      Line3DBox[{1269, 1263, 1094, 1153, 1467, 1046, 1095, 1240, 1241, 1239, 
       1485, 1238, 1033, 955, 1396, 1034, 956, 1318, 1428, 957, 1319, 1429, 
       958, 1320, 1430, 959, 1397, 1035, 960, 1453, 1096, 1098, 1036, 1097, 
       1349, 1478, 1047, 1201, 1142, 1200, 1143, 1100, 1265, 1283}], 
      Line3DBox[{1270, 1159, 1177, 1176, 1208, 1472, 1053, 1111, 1052, 981, 
       1461, 1119, 1118, 980, 1460, 1116, 1115, 979, 1114, 1113, 1459, 978, 
       1204, 1051, 1225, 1277}], 
      Line3DBox[{1273, 1150, 1164, 1045, 1197, 1044, 1196, 1477, 935, 1088, 
       1087, 1450, 934, 1418, 1310, 933, 1417, 1309, 932, 1416, 1308, 931, 
       1415, 1307, 930, 1414, 1306, 929, 1023, 1387, 928, 1022, 1386, 927, 
       1252, 1413, 1352, 926, 1086, 1232, 1085, 1233, 925, 1149, 1168, 1357, 
       1471, 1282}], 
      Line3DBox[{1274, 1345, 1482, 1224, 1050, 1106, 1245, 1246, 1244, 1486, 
       1243, 1037, 971, 1325, 1436, 973, 1327, 1438, 975, 1108, 1110, 1458, 
       1038, 1109, 1206, 1331, 1479, 1207, 1144, 1205, 1145, 1112, 1275}], 
      Line3DBox[{1276, 1261, 1473, 1180, 1146, 1123, 1214, 1215, 1213, 1121, 
       1039, 1179, 1178, 1122, 1160, 1286}], 
      Line3DBox[{1278, 985, 1161, 1469, 1347, 1120, 1212, 1211, 984, 1462, 
       1209, 1210, 1117, 1055, 983, 1054, 1186, 1188, 1187, 1475, 982, 1290}],
       Line3DBox[{1284, 1166, 1262, 1167, 1440, 1344, 1172, 1171, 1202, 1049, 
       1099, 1454, 1329, 967, 1103, 1434, 1341, 966, 1433, 1323, 965, 1432, 
       1322, 964, 1431, 1321, 963, 1258, 1257, 1488, 962, 1102, 1101, 1455, 
       961, 1199, 1048, 1223, 1468, 1328, 1266, 1154, 1285}], 
      Line3DBox[{1287, 1264, 1089, 1198, 1451, 1348, 954, 1091, 1427, 1339, 
       952, 1426, 1317, 950, 1425, 1316, 948, 1424, 1315, 946, 1423, 1314, 
       944, 1421, 1312, 942, 1420, 1311, 940, 1255, 1419, 1354, 938, 1234, 
       1253, 1353, 1487, 1254, 937, 1247, 1248, 1183, 1185, 1184, 936, 
       1289}]}, 
     {GrayLevel[0.2], 
      Line3DBox[{530, 142, 1127, 206, 1128, 143, 210, 1134, 152, 1251, 390, 
       370, 1231, 373, 1232, 163, 302, 1183, 122, 1484, 826, 588, 761, 853}], 
      Line3DBox[{531, 690, 691, 1358, 746, 692, 1443, 693, 748, 1464, 701, 
       702, 1369, 561, 638, 1380, 571, 1413, 834, 835, 836, 1487, 837, 823, 
       825, 824, 1388, 827, 828, 675, 720, 1467, 676, 762, 721, 765, 819, 
       1468, 678, 851, 858}], 
      Line3DBox[{532, 694, 1444, 695, 747, 696, 1445, 697, 749, 1465, 703, 
       704, 1370, 562, 639, 1381, 572, 646, 1386, 580, 1419, 838, 839, 1389, 
       840, 841, 842, 830, 1485, 829, 595, 726, 1455, 750, 727, 813, 1481, 
       814, 816, 815, 734, 1482, 769, 852, 768, 777, 863}], 
      Line3DBox[{533, 613, 1359, 534, 622, 1365, 551, 631, 1371, 1372, 563, 
       640, 1382, 573, 647, 1387, 581, 1420, 653, 1390, 589, 659, 1396, 596, 
       843, 1488, 844, 845, 1489, 846, 847, 832, 1486, 831, 604, 739, 1459, 
       751, 740, 787, 788, 1475, 817, 789, 850, 866}], 
      Line3DBox[{8, 871, 22, 884, 35, 901, 902, 48, 919, 60, 929, 72, 942, 
       943, 82, 956, 92, 963, 100, 970, 971, 107, 979, 112, 983, 199, 1121, 
       115, 297, 773, 856}], 
      Line3DBox[{535, 1398, 614, 536, 1400, 623, 552, 1405, 632, 1373, 564, 
       1411, 641, 574, 1414, 648, 582, 1421, 1422, 654, 590, 1428, 660, 597, 
       1431, 664, 601, 1435, 1436, 667, 605, 741, 1460, 670, 608, 810, 1462, 
       811, 744, 755, 781, 848, 1473, 865}], 
      Line3DBox[{537, 1399, 615, 538, 1401, 624, 553, 1406, 633, 1374, 565, 
       1412, 642, 575, 1415, 649, 583, 1423, 655, 1391, 591, 1429, 661, 598, 
       1432, 665, 602, 1437, 1438, 668, 606, 742, 1461, 743, 671, 609, 1469, 
       772, 685, 861}], 
      Line3DBox[{539, 616, 1360, 540, 1402, 625, 554, 1407, 634, 1375, 566, 
       643, 1383, 576, 1416, 650, 584, 1424, 656, 1392, 592, 1430, 662, 599, 
       1433, 666, 603, 1439, 735, 736, 669, 1458, 607, 785, 684, 1472, 809, 
       753, 780, 754}], 
      Line3DBox[{541, 617, 1361, 542, 1403, 626, 555, 1408, 635, 1376, 567, 
       644, 1384, 577, 1417, 651, 585, 1425, 657, 1393, 593, 663, 1397, 600, 
       1434, 728, 729, 731, 1456, 681, 737, 682, 1479, 808, 807, 738, 771, 
       779, 860}], 
      Line3DBox[{543, 618, 1362, 544, 627, 1366, 556, 1409, 636, 1377, 568, 
       645, 1385, 578, 1418, 652, 586, 1426, 658, 1394, 594, 722, 1453, 723, 
       725, 1454, 679, 730, 680, 806, 805, 733, 1457, 770, 776, 683, 778, 
       859}], Line3DBox[{545, 619, 1363, 546, 628, 1367, 557, 1410, 637, 1378,
        569, 708, 1448, 709, 579, 712, 1450, 713, 587, 1427, 716, 717, 1395, 
       719, 677, 724, 1478, 803, 802, 804, 766, 784, 767, 1440, 732, 862}], 
      Line3DBox[{547, 620, 1364, 548, 629, 1368, 558, 705, 1447, 706, 1379, 
       707, 674, 710, 795, 1449, 794, 711, 796, 1477, 797, 714, 799, 798, 715,
        1451, 800, 801, 718, 760, 1452, 759, 775, 763, 783, 764, 855}], 
      Line3DBox[{687, 686, 793, 1441, 611, 528, 672, 1446, 699, 311, 549, 
       1476, 313, 786, 299, 1480, 559, 857}], 
      Line3DBox[{792, 688, 612, 1463, 529, 689, 1442, 621, 550, 1404, 700, 
       630, 1474, 560, 833, 673, 820, 821, 1483, 822, 570, 758, 774, 1471, 
       849, 782, 864}], 
      Line3DBox[{818, 790, 791, 745, 752, 1466, 610, 527, 756, 812, 757, 1470,
        698, 854}]}, {}, {}}},
   VertexNormals->CompressedData["
1:eJxkm3c41f///6MoKpTMIhKab6So0JMokhEhszJSirL3yt57j1DZe2WEh2Tv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    "]],
  AutomaticImageSize->True,
  Axes->True,
  AxesLabel->{None, None, None},
  BoxRatios->{1, 1, 0.4},
  DisplayFunction->Identity,
  FaceGridsStyle->Automatic,
  ImageSize->{363.1353931691952, 296.2279922104507},
  Method->{"DefaultBoundaryStyle" -> Directive[
      GrayLevel[0.3]], "RotationControl" -> "Globe"},
  PlotRange->{{0, 0.1}, {0, 0.1}, {0., 4.999995863196803}},
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02], 
    Scaled[0.02]},
  Ticks->{Automatic, Automatic, Automatic},
  ViewPoint->{-0.4496633401954244, -2.788218483025798, 1.8637705254128198`},
  ViewVertical->{0., 0., 1.}]], "Output",
 CellChangeTimes->{{3.705731455192645*^9, 
  3.705731490437661*^9}},ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"]]
}, Open  ]],

Cell[TextData[{
 "References:\n[1] G.Gneuss and W.Greiner, Nucl.Phys.A 171, 449 (1971).\n[2] \
F.Ferrari-Ruffino, \"",
 StyleBox["Il modello geometrico colletivo: metodi di soluzione, transizioni \
di forma e applicazioni",
  FontSlant->"Italic"],
 "\" (Master Thesis, in Italian), Universit\[AGrave] di Padova (2013). \n[3] \
F.Ferrari-Ruffino and L.Fortunato, Computation 6(3), 48 (2018),\n[4] \
L.Fortunato, Eur.Phys.J. A 26, s01, 1-33 (2005).\n[5] D.Trolteiner, \
J.A.Maruhn and P.O.Hess, Cap. 6 in ",
 StyleBox["Computational nuclear physics 1: nuclear structure",
  FontSlant->"Italic"],
 ", Ed. K.Langhanke, J.A.Maruhn, S.E.Koonin, Springer-Verlag (1991).\n[6] \
F.J.Margetan, S.A.Williams, Phys.Rev. C 25, 1602 (1982).\n[7] D.Habs, \
H.Klewe-Nebenius, K.Wisshak, R.L\[ODoubleDot]hken, G.Nowicki, H.Rebel, \
Z.Phys. 267, 149 (1974)."
}], "Program",
 CellChangeTimes->{{3.575707032686817*^9, 3.5757071014469132`*^9}, {
  3.5757098944728236`*^9, 3.575709987312954*^9}, {3.5766474997679944`*^9, 
  3.5766475232928357`*^9}, {3.5766475820405393`*^9, 3.5766476153153973`*^9}, {
  3.5766476628486814`*^9, 3.576647681178713*^9}, {3.5766499794671535`*^9, 
  3.5766500167824183`*^9}, {3.576650236742805*^9, 3.576650238458808*^9}, {
  3.576650277583677*^9, 3.576650290110499*^9}, {3.583233860934637*^9, 
  3.583233918944718*^9}, {3.58425254169835*^9, 3.5842525601687827`*^9}, {
  3.5842525977760496`*^9, 3.584252610084471*^9}, {3.5842526446073313`*^9, 
  3.5842526467601357`*^9}, {3.584252699800229*^9, 3.5842527448687077`*^9}, {
  3.5842529216014185`*^9, 3.5842529313982353`*^9}, {3.7414324400723596`*^9, 
  3.7414324452359686`*^9}, {3.744688410492219*^9, 3.744688417465431*^9}, {
  3.7446884515982914`*^9, 3.74468847902314*^9}}],

Cell["\<\
* For questions, comments and suggestions, please address correspondence to :
 Lorenzo Fortunato
 Dip. Fisica e Astronomia \"G.Galilei\" - Universit\[AGrave] di PADOVA - ITALY
 via F.Marzolo,8 - I-35131 (PD) - ITALY
 +39-049-8277217
 fortunat@pd.infn.it\
\>", "Program",
 CellChangeTimes->{{3.575707032686817*^9, 3.5757071014469132`*^9}, {
  3.5757085750999765`*^9, 3.5757085895599966`*^9}}]
}, Open  ]]
}, Open  ]]
},
WindowSize->{1348, 628},
WindowMargins->{{1, Automatic}, {Automatic, 3}},
ShowCellTags->True,
FrontEndVersion->"10.0 for Microsoft Windows (64-bit) (July 1, 2014)",
StyleDefinitions->FrontEnd`FileName[{"Creative"}, "NaturalColor.nb", 
  CharacterEncoding -> "WindowsANSI"]
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[579, 22, 7713, 179, 368, "Title"],
Cell[8295, 203, 263, 5, 23, "Subtitle"],
Cell[CellGroupData[{
Cell[8583, 212, 1555, 32, 102, "Input"],
Cell[10141, 246, 2430, 33, 41, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[12608, 284, 1749, 39, 162, "Input"],
Cell[CellGroupData[{
Cell[14382, 327, 3331, 48, 23, "Print"],
Cell[17716, 377, 3335, 48, 23, "Print"],
Cell[21054, 427, 3327, 48, 23, "Print"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[24430, 481, 1975, 43, 142, "Input"],
Cell[26408, 526, 3392, 46, 23, "Print"],
Cell[29803, 574, 3731, 60, 142, "Output"]
}, Open  ]],
Cell[33549, 637, 1507, 26, 142, "Input"],
Cell[35059, 665, 7243, 148, 282, "Input"],
Cell[CellGroupData[{
Cell[42327, 817, 2350, 54, 162, "Input"],
Cell[44680, 873, 2110, 44, 172, "Output"],
Cell[46793, 919, 1763, 31, 172, "Output"]
}, Open  ]],
Cell[48571, 953, 19104, 471, 842, "Input"],
Cell[CellGroupData[{
Cell[67700, 1428, 576, 10, 34, "Subtitle"],
Cell[CellGroupData[{
Cell[68301, 1442, 2203, 58, 142, "Input"],
Cell[70507, 1502, 1615, 22, 41, "Output"],
Cell[72125, 1526, 1613, 22, 41, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[73775, 1553, 6005, 118, 262, "Input"],
Cell[79783, 1673, 2589, 37, 41, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[82409, 1715, 2346, 48, 142, "Input"],
Cell[84758, 1765, 1631, 25, 23, "Print"],
Cell[86392, 1792, 4885, 73, 158, "Output"]
}, Open  ]],
Cell[91292, 1868, 4460, 107, 202, "Input"],
Cell[CellGroupData[{
Cell[95777, 1979, 484, 12, 41, "Input"],
Cell[96264, 1993, 342, 5, 41, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[96643, 2003, 71, 1, 41, "Input"],
Cell[96717, 2006, 90, 1, 41, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[96844, 2012, 962, 23, 41, "Input"],
Cell[97809, 2037, 9250, 164, 248, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[107096, 2206, 430, 11, 41, "Input"],
Cell[107529, 2219, 165, 2, 41, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[107731, 2226, 363, 9, 41, "Input"],
Cell[108097, 2237, 17844, 304, 235, "Output"]
}, Open  ]],
Cell[125956, 2544, 1109, 30, 41, "Input"],
Cell[127068, 2576, 1079, 32, 41, "Input"],
Cell[CellGroupData[{
Cell[128172, 2612, 901, 22, 182, "Input"],
Cell[129076, 2636, 316, 4, 41, "Output"],
Cell[129395, 2642, 314, 4, 41, "Output"],
Cell[129712, 2648, 314, 4, 41, "Output"],
Cell[130029, 2654, 314, 4, 41, "Output"],
Cell[130346, 2660, 310, 4, 41, "Output"],
Cell[130659, 2666, 308, 4, 41, "Output"],
Cell[130970, 2672, 311, 4, 41, "Output"],
Cell[131284, 2678, 309, 4, 41, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[131630, 2687, 1026, 24, 202, "Input"],
Cell[132659, 2713, 220, 3, 41, "Output"],
Cell[132882, 2718, 199, 3, 41, "Output"],
Cell[133084, 2723, 219, 3, 41, "Output"],
Cell[133306, 2728, 219, 3, 41, "Output"],
Cell[133528, 2733, 216, 3, 41, "Output"],
Cell[133747, 2738, 219, 3, 41, "Output"],
Cell[133969, 2743, 199, 3, 41, "Output"],
Cell[134171, 2748, 216, 3, 41, "Output"],
Cell[134390, 2753, 219, 3, 41, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[134658, 2762, 205, 3, 34, "Subtitle"],
Cell[CellGroupData[{
Cell[134888, 2769, 656, 10, 41, "Input"],
Cell[135547, 2781, 946, 14, 41, "Output"]
}, Open  ]],
Cell[136508, 2798, 6413, 172, 302, "Input"],
Cell[142924, 2972, 7311, 182, 282, "Input"],
Cell[150238, 3156, 2035, 53, 122, "Input"],
Cell[CellGroupData[{
Cell[152298, 3213, 5075, 126, 282, "Input"],
Cell[CellGroupData[{
Cell[157398, 3343, 815, 18, 26, "Print"],
Cell[158216, 3363, 830, 18, 26, "Print"],
Cell[159049, 3383, 844, 17, 26, "Print"],
Cell[159896, 3402, 835, 18, 26, "Print"],
Cell[160734, 3422, 867, 18, 26, "Print"],
Cell[161604, 3442, 843, 18, 23, "Print"],
Cell[162450, 3462, 883, 19, 26, "Print"],
Cell[163336, 3483, 878, 19, 26, "Print"],
Cell[164217, 3504, 900, 20, 26, "Print"],
Cell[165120, 3526, 883, 19, 26, "Print"],
Cell[166006, 3547, 845, 18, 26, "Print"],
Cell[166854, 3567, 844, 18, 26, "Print"]
}, Open  ]],
Cell[167713, 3588, 99, 1, 41, "Output"],
Cell[167815, 3591, 213, 4, 23, "Print"],
Cell[168031, 3597, 150, 2, 41, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[168218, 3604, 1627, 33, 82, "Input"],
Cell[169848, 3639, 1700, 23, 41, "Output"],
Cell[171551, 3664, 770, 12, 23, "Print"],
Cell[172324, 3678, 5221, 97, 184, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[177582, 3780, 10023, 236, 542, "Input"],
Cell[CellGroupData[{
Cell[187630, 4020, 781, 17, 23, "Print"],
Cell[188414, 4039, 798, 17, 26, "Print"],
Cell[189215, 4058, 93, 1, 23, "Print"],
Cell[189311, 4061, 780, 16, 26, "Print"],
Cell[190094, 4079, 795, 17, 26, "Print"],
Cell[190892, 4098, 93, 1, 23, "Print"],
Cell[190988, 4101, 763, 16, 26, "Print"],
Cell[191754, 4119, 804, 18, 26, "Print"],
Cell[192561, 4139, 91, 1, 23, "Print"],
Cell[192655, 4142, 790, 18, 26, "Print"],
Cell[193448, 4162, 797, 18, 26, "Print"],
Cell[194248, 4182, 93, 1, 23, "Print"],
Cell[194344, 4185, 805, 18, 26, "Print"],
Cell[195152, 4205, 775, 17, 26, "Print"],
Cell[195930, 4224, 92, 1, 23, "Print"],
Cell[196025, 4227, 783, 17, 23, "Print"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[196857, 4250, 1335, 31, 122, "Input"],
Cell[198195, 4283, 1074, 17, 41, "Output"],
Cell[199272, 4302, 1064, 18, 43, "Output"],
Cell[200339, 4322, 828, 12, 41, "Output"],
Cell[201170, 4336, 470, 9, 23, "Print"],
Cell[201643, 4347, 3687, 57, 158, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[205367, 4409, 8324, 198, 322, "Input"],
Cell[213694, 4609, 320376, 5352, 374, 279495, 4685, "CachedBoxData", \
"BoxData", "Output"],
Cell[534073, 9963, 1645, 26, 23, "Print"]
}, Open  ]],
Cell[CellGroupData[{
Cell[535755, 9994, 1064, 32, 41, "Input"],
Cell[536822, 10028, 139369, 2286, 321, 100403, 1646, "CachedBoxData", \
"BoxData", "Output"]
}, Open  ]],
Cell[676206, 12317, 1726, 28, 154, "Program"],
Cell[677935, 12347, 401, 9, 120, "Program"]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
